@@ -54,6 +54,10 @@ public interface RoleService {
 
     boolean deleteRole(Role role);
 
+    boolean enableRole(Role role);
+
+    boolean disableRole(Role role);
+
     RolePermission findRolePermission(Long id);
 
     RolePermission findRolePermissionByRoleIdAndRule(Long roleId, String rule);
@@ -76,7 +80,7 @@ public interface RoleService {
      */
     List<Role> listRoles();
 
-    Pair<List<Role>, Integer> listRoles(Long startIndex, Long limit);
+    Pair<List<Role>, Integer> listRoles(String state, Long startIndex, Long limit);
 
     /**
      *  Find all roles that have the giving {@link String} as part of their name.
@@ -84,14 +88,14 @@ public interface RoleService {
      */
     List<Role> findRolesByName(String name);
 
-    Pair<List<Role>, Integer> findRolesByName(String name, String keyword, Long startIndex, Long limit);
+    Pair<List<Role>, Integer> findRolesByName(String name, String keyword, String state, Long startIndex, Long limit);
 
     /**
      *  Find all roles by {@link RoleType}. If the role type is {@link RoleType#Admin}, the calling account must be a root admin, otherwise we return an empty list.
      */
     List<Role> findRolesByType(RoleType roleType);
 
-    Pair<List<Role>, Integer> findRolesByType(RoleType roleType, Long startIndex, Long limit);
+    Pair<List<Role>, Integer> findRolesByType(RoleType roleType, String state, Long startIndex, Long limit);
 
     List<RolePermission> findAllPermissionsBy(Long roleId);
 
