@@ -19,7 +19,6 @@ package org.apache.cloudstack.api.command.admin.config;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.log4j.Logger;
 
 import org.apache.cloudstack.api.APICommand;
 import org.apache.cloudstack.api.BaseListCmd;
@@ -29,7 +28,6 @@ import org.apache.cloudstack.api.response.ListResponse;
 @APICommand(name = "listDeploymentPlanners", description = "Lists all DeploymentPlanners available.", responseObject = DeploymentPlannersResponse.class,
         requestHasSensitiveInfo = false, responseHasSensitiveInfo = false)
 public class ListDeploymentPlannersCmd extends BaseListCmd {
-    public static final Logger s_logger = Logger.getLogger(ListDeploymentPlannersCmd.class.getName());
 
 
     /////////////////////////////////////////////////////
