@@ -19,9 +19,6 @@ package org.apache.cloudstack.api.command.user.firewall;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.commons.collections.CollectionUtils;
-import org.apache.commons.lang3.StringUtils;
-import org.apache.log4j.Logger;
 
 import org.apache.cloudstack.acl.RoleType;
 import org.apache.cloudstack.api.APICommand;
@@ -48,7 +45,6 @@ import com.cloud.utils.net.NetUtils;
 @APICommand(name = "createFirewallRule", description = "Creates a firewall rule for a given IP address", responseObject = FirewallResponse.class, entityType = {FirewallRule.class},
         requestHasSensitiveInfo = false, responseHasSensitiveInfo = false)
 public class CreateFirewallRuleCmd extends BaseAsyncCreateCmd implements FirewallRule {
-    public static final Logger s_logger = Logger.getLogger(CreateFirewallRuleCmd.class.getName());
 
 
     // ///////////////////////////////////////////////////
@@ -98,20 +94,45 @@ public class CreateFirewallRuleCmd extends BaseAsyncCreateCmd implements Firewal
         return ipAddressId;
     }
 
+    public void setIpAddressId(Long ipAddressId) {
+        this.ipAddressId = ipAddressId;
+    }
+
     @Override
     public String getProtocol() {
         return protocol.trim();
     }
 
+    public void setProtocol(String protocol) {
+        this.protocol = protocol;
+    }
+
+    public Integer getPublicStartPort() {
+        return publicStartPort;
+    }
+
+    public void setPublicStartPort(Integer publicStartPort) {
+        this.publicStartPort = publicStartPort;
+    }
+
+    public Integer getPublicEndPort() {
+        return publicEndPort;
+    }
+
+    public void setPublicEndPort(Integer publicEndPort) {
+        this.publicEndPort = publicEndPort;
+    }
+
     @Override
     public List<String> getSourceCidrList() {
-        if (CollectionUtils.isNotEmpty(cidrlist) && !(cidrlist.size() == 1 && StringUtils.isBlank(cidrlist.get(0)))) {
+        if (cidrlist != null) {
             return cidrlist;
         } else {
-            List<String> oneCidrList = new ArrayList<>();
+            List<String> oneCidrList = new ArrayList<String>();
             oneCidrList.add(NetUtils.ALL_IP4_CIDRS);
             return oneCidrList;
         }
+
     }
 
     // ///////////////////////////////////////////////////
@@ -249,7 +270,7 @@ public class CreateFirewallRuleCmd extends BaseAsyncCreateCmd implements Firewal
                 setEntityUuid(result.getUuid());
             }
         } catch (NetworkRuleConflictException ex) {
-            s_logger.trace("Network Rule Conflict: ", ex);
+            logger.trace("Network Rule Conflict: ", ex);
             throw new ServerApiException(ApiErrorCode.NETWORK_RULE_CONFLICT_ERROR, ex.getMessage(), ex);
         }
     }
