@@ -17,6 +17,7 @@
 package org.apache.cloudstack.api.response;
 
 import java.util.Date;
+import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -27,11 +28,12 @@ import org.apache.cloudstack.api.BaseResponseWithAssociatedNetwork;
 import org.apache.cloudstack.api.EntityReference;
 
 import com.cloud.network.Network;
+import com.cloud.projects.ProjectAccount;
 import com.cloud.serializer.Param;
 import com.google.gson.annotations.SerializedName;
 
 @SuppressWarnings("unused")
-@EntityReference(value = {Network.class})
+@EntityReference(value = {Network.class, ProjectAccount.class})
 public class NetworkResponse extends BaseResponseWithAssociatedNetwork implements ControlledEntityResponse, SetResourceIconResponse {
 
     @SerializedName(ApiConstants.ID)
@@ -134,6 +136,14 @@ public class NetworkResponse extends BaseResponseWithAssociatedNetwork implement
     @Param(description = "The vlan of the network. This parameter is visible to ROOT admins only")
     private String vlan;
 
+    @SerializedName(ApiConstants.AS_NUMBER_ID)
+    @Param(description = "UUID of AS NUMBER", since = "4.20.0")
+    private String asNumberId;
+
+    @SerializedName(ApiConstants.AS_NUMBER)
+    @Param(description = "AS NUMBER", since = "4.20.0")
+    private Long asNumber;
+
     @SerializedName(ApiConstants.ACL_TYPE)
     @Param(description = "acl type - access type to the network")
     private String aclType;
@@ -186,10 +196,6 @@ public class NetworkResponse extends BaseResponseWithAssociatedNetwork implement
     @Param(description = "true network requires restart")
     private Boolean restartRequired;
 
-    @SerializedName(ApiConstants.SPECIFY_VLAN)
-    @Param(description = "true if network supports specifying vlan, false otherwise")
-    private Boolean specifyVlan;
-
     @SerializedName(ApiConstants.SPECIFY_IP_RANGES)
     @Param(description = "true if network supports specifying ip ranges, false otherwise")
     private Boolean specifyIpRanges;
@@ -295,7 +301,7 @@ public class NetworkResponse extends BaseResponseWithAssociatedNetwork implement
     private String internetProtocol;
 
     @SerializedName(ApiConstants.IPV6_ROUTING)
-    @Param(description = "The routing mode of network offering", since = "4.17.0")
+    @Param(description = "The Ipv6 routing type of network offering", since = "4.17.0")
     private String ipv6Routing;
 
     @SerializedName(ApiConstants.IPV6_ROUTES)
@@ -318,6 +324,18 @@ public class NetworkResponse extends BaseResponseWithAssociatedNetwork implement
     @Param(description = "the second IPv6 DNS for the network", since = "4.18.0")
     private String ipv6Dns2;
 
+    @SerializedName(ApiConstants.IPV4_ROUTING)
+    @Param(description = "The IPv4 routing type of network", since = "4.20.0")
+    private String ipv4Routing;
+
+    @SerializedName(ApiConstants.IPV4_ROUTES)
+    @Param(description = "The routes for the network to ease adding route in upstream router", since = "4.20.0")
+    private Set<Ipv4RouteResponse> ipv4Routes;
+
+    @SerializedName(ApiConstants.BGP_PEERS)
+    @Param(description = "The BGP peers for the network", since = "4.20.0")
+    private Set<BgpPeerResponse> bgpPeers;
+
     public NetworkResponse() {}
 
     public Boolean getDisplayNetwork() {
@@ -418,6 +436,14 @@ public class NetworkResponse extends BaseResponseWithAssociatedNetwork implement
         this.vlan = vlan;
     }
 
+    public void setAsNumber(long asNumber) {
+        this.asNumber = asNumber;
+    }
+
+    public void setAsNumberId(String asNumberId) {
+        this.asNumberId = asNumberId;
+    }
+
     public void setIsSystem(Boolean isSystem) {
         this.isSystem = isSystem;
     }
@@ -490,10 +516,6 @@ public class NetworkResponse extends BaseResponseWithAssociatedNetwork implement
         this.restartRequired = restartRequired;
     }
 
-    public void setSpecifyVlan(Boolean specifyVlan) {
-        this.specifyVlan = specifyVlan;
-    }
-
     public void setSpecifyIpRanges(Boolean specifyIpRanges) {
         this.specifyIpRanges = specifyIpRanges;
     }
@@ -631,6 +653,18 @@ public class NetworkResponse extends BaseResponseWithAssociatedNetwork implement
         this.internetProtocol = internetProtocol;
     }
 
+    public void setIpv4Routing(String ipv4Routing) {
+        this.ipv4Routing = ipv4Routing;
+    }
+
+    public void setIpv4Routes(Set<Ipv4RouteResponse> ipv4Routes) {
+        this.ipv4Routes = ipv4Routes;
+    }
+
+    public void addIpv4Route(Ipv4RouteResponse ipv4Route) {
+        this.ipv4Routes.add(ipv4Route);
+    }
+
     public void setIpv6Routing(String ipv6Routing) {
         this.ipv6Routing = ipv6Routing;
     }
@@ -643,6 +677,17 @@ public class NetworkResponse extends BaseResponseWithAssociatedNetwork implement
         this.ipv6Routes.add(ipv6Route);
     }
 
+    public void setBgpPeers(Set<BgpPeerResponse> bgpPeers) {
+        this.bgpPeers = bgpPeers;
+    }
+
+    public void addBgpPeer(BgpPeerResponse bgpPeer) {
+        if (this.bgpPeers == null) {
+            this.setBgpPeers(new LinkedHashSet<>());
+        }
+        this.bgpPeers.add(bgpPeer);
+    }
+
     public Integer getPublicMtu() {
         return publicMtu;
     }
