@@ -33,8 +33,6 @@ public class UnmanagedInstanceTO {
 
     private String internalCSName;
 
-    private String path;
-
     private PowerState powerState;
 
     private PowerState cloneSourcePowerState;
@@ -61,9 +59,6 @@ public class UnmanagedInstanceTO {
 
     private String vncPassword;
 
-    private String bootType;
-    private String bootMode;
-
     public String getName() {
         return name;
     }
@@ -80,14 +75,6 @@ public class UnmanagedInstanceTO {
         this.internalCSName = internalCSName;
     }
 
-    public String getPath() {
-        return path;
-    }
-
-    public void setPath(String path) {
-        this.path = path;
-    }
-
     public PowerState getPowerState() {
         return powerState;
     }
@@ -192,22 +179,6 @@ public class UnmanagedInstanceTO {
         this.vncPassword = vncPassword;
     }
 
-    public String getBootType() {
-        return bootType;
-    }
-
-    public void setBootType(String bootType) {
-        this.bootType = bootType;
-    }
-
-    public String getBootMode() {
-        return bootMode;
-    }
-
-    public void setBootMode(String bootMode) {
-        this.bootMode = bootMode;
-    }
-
     public static class Disk {
         private String diskId;
 
