@@ -28,7 +28,8 @@ import java.util.Map;
 import java.util.Set;
 
 import org.apache.commons.lang3.StringUtils;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 
 import com.cloud.agent.api.routing.LoadBalancerConfigCommand;
 import com.cloud.agent.api.to.LoadBalancerTO;
@@ -41,7 +42,7 @@ import com.cloud.utils.net.NetUtils;
 
 public class HAProxyConfigurator implements LoadBalancerConfigurator {
 
-    private static final Logger s_logger = Logger.getLogger(HAProxyConfigurator.class);
+    protected Logger logger = LogManager.getLogger(getClass());
     private static final String blankLine = "\t ";
     private static String[] globalSection = {"global", "\tlog 127.0.0.1:3914   local0 warning", "\tmaxconn 4096", "\tmaxpipes 1024", "\tchroot /var/lib/haproxy",
         "\tuser haproxy", "\tgroup haproxy", "\tstats socket /run/haproxy/admin.sock", "\tdaemon"};
@@ -458,7 +459,7 @@ public class HAProxyConfigurator implements LoadBalancerConfigurator {
                  * Not supposed to reach here, validation of methods are
                  * done at the higher layer
                  */
-                s_logger.warn("Haproxy stickiness policy for lb rule: " + lbTO.getSrcIp() + ":" + lbTO.getSrcPort() + ": Not Applied, cause:invalid method ");
+                logger.warn("Haproxy stickiness policy for lb rule: " + lbTO.getSrcIp() + ":" + lbTO.getSrcPort() + ": Not Applied, cause:invalid method ");
                 return null;
             }
         }
@@ -541,7 +542,7 @@ public class HAProxyConfigurator implements LoadBalancerConfigurator {
             result.addAll(dstSubRule);
         }
         if (stickinessSubRule != null && !destsAvailable) {
-            s_logger.warn("Haproxy stickiness policy for lb rule: " + lbTO.getSrcIp() + ":" + lbTO.getSrcPort() + ": Not Applied, cause:  backends are unavailable");
+            logger.warn("Haproxy stickiness policy for lb rule: " + lbTO.getSrcIp() + ":" + lbTO.getSrcPort() + ": Not Applied, cause:  backends are unavailable");
         }
         if (publicPort == NetUtils.HTTP_PORT && !keepAliveEnabled || httpbasedStickiness) {
             sb = new StringBuilder();
@@ -566,7 +567,7 @@ public class HAProxyConfigurator implements LoadBalancerConfigurator {
         final StringBuilder rule = new StringBuilder("\nlisten ").append(ruleName).append("\n\tbind ").append(statsIp).append(":").append(lbCmd.lbStatsPort);
         // TODO DH: write test for this in both cases
         if (!lbCmd.keepAliveEnabled) {
-            s_logger.info("Haproxy mode http enabled");
+            logger.info("Haproxy mode http enabled");
             rule.append("\n\tmode http\n\toption httpclose");
         }
         rule.append("\n\tstats enable\n\tstats uri     ")
@@ -575,8 +576,8 @@ public class HAProxyConfigurator implements LoadBalancerConfigurator {
         .append(lbCmd.lbStatsAuth);
         rule.append("\n");
         final String result = rule.toString();
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Haproxystats rule: " + result);
+        if (logger.isDebugEnabled()) {
+            logger.debug("Haproxystats rule: " + result);
         }
         return result;
     }
@@ -590,9 +591,9 @@ public class HAProxyConfigurator implements LoadBalancerConfigurator {
         // TODO DH: write test for this function
         final String pipesLine = "\tmaxpipes " + Long.toString(Long.parseLong(lbCmd.maxconn) / 4);
         gSection.set(3, pipesLine);
-        if (s_logger.isDebugEnabled()) {
+        if (logger.isDebugEnabled()) {
             for (final String s : gSection) {
-                s_logger.debug("global section: " + s);
+                logger.debug("global section: " + s);
             }
         }
         result.addAll(gSection);
@@ -606,9 +607,9 @@ public class HAProxyConfigurator implements LoadBalancerConfigurator {
             dSection.set(7, "\tno option httpclose");
         }
 
-        if (s_logger.isDebugEnabled()) {
+        if (logger.isDebugEnabled()) {
             for (final String s : dSection) {
-                s_logger.debug("default section: " + s);
+                logger.debug("default section: " + s);
             }
         }
         result.addAll(dSection);
