@@ -21,6 +21,7 @@ import java.util.Map;
 import java.util.Set;
 
 import com.cloud.dc.VlanVO;
+import org.apache.cloudstack.framework.config.ConfigKey;
 import org.apache.cloudstack.framework.config.impl.ConfigurationSubGroupVO;
 
 import com.cloud.dc.ClusterVO;
@@ -60,6 +61,9 @@ public interface ConfigurationManager {
     public static final String MESSAGE_CREATE_VLAN_IP_RANGE_EVENT = "Message.CreateVlanIpRange.Event";
     public static final String MESSAGE_DELETE_VLAN_IP_RANGE_EVENT = "Message.DeleteVlanIpRange.Event";
 
+    public static final ConfigKey<Boolean> AllowNonRFC1918CompliantIPs = new ConfigKey<>(Boolean.class,
+            "allow.non.rfc1918.compliant.ips", "Advanced", "false",
+            "Allows non-compliant RFC 1918 IPs for Shared, Isolated networks and VPCs", true, null);
 
     /**
      * @param offering
@@ -94,7 +98,6 @@ public interface ConfigurationManager {
 //     * @param volatileVm
 //     * @param hostTag
 //     * @param networkRate
-//     *            TODO
 //     * @param id
 //     * @param useVirtualNetwork
 //     * @param deploymentPlanner
@@ -164,11 +167,9 @@ public interface ConfigurationManager {
      * @param zoneType
      * @param allocationState
      * @param networkDomain
-     *            TODO
      * @param isSecurityGroupEnabled
-     *            TODO
-     * @param ip6Dns1 TODO
-     * @param ip6Dns2 TODO
+     * @param ip6Dns1
+     * @param ip6Dns2
      * @return
      * @throws
      * @throws
@@ -183,7 +184,7 @@ public interface ConfigurationManager {
      *
      * @param userId
      * @param vlanDbId
-     * @param caller TODO
+     * @param caller
      * @return success/failure
      */
     VlanVO deleteVlanAndPublicIpRange(long userId, long vlanDbId, Account caller);
@@ -194,30 +195,25 @@ public interface ConfigurationManager {
 
     /**
      * Creates a new network offering
+     *
      * @param name
      * @param displayText
      * @param trafficType
      * @param tags
      * @param specifyVlan
      * @param networkRate
-     *            TODO
      * @param serviceProviderMap
-     *            TODO
      * @param isDefault
-     *            TODO
      * @param type
-     *            TODO
      * @param systemOnly
-     *            TODO
      * @param serviceOfferingId
-     * @param conserveMode
-     *            ;
+     * @param conserveMode       ;
      * @param specifyIpRanges
-     *            TODO
-     * @param isPersistent
-     *            ;
-     * @param details TODO
+     * @param isPersistent       ;
+     * @param details
      * @param forVpc
+     * @param forTungsten
+     * @param forNsx
      * @param domainIds
      * @param zoneIds
      * @return network offering object
@@ -227,10 +223,11 @@ public interface ConfigurationManager {
                                             Integer networkRate, Map<Service, Set<Provider>> serviceProviderMap, boolean isDefault, Network.GuestType type, boolean systemOnly, Long serviceOfferingId,
                                             boolean conserveMode, Map<Service, Map<Capability, String>> serviceCapabilityMap, boolean specifyIpRanges, boolean isPersistent,
                                             Map<NetworkOffering.Detail, String> details, boolean egressDefaultPolicy, Integer maxconn, boolean enableKeepAlive, Boolean forVpc,
-                                            Boolean forTungsten, List<Long> domainIds, List<Long> zoneIds, boolean enableOffering, final NetUtils.InternetProtocol internetProtocol);
+                                            Boolean forTungsten, boolean forNsx, NetworkOffering.NetworkMode networkMode, List<Long> domainIds, List<Long> zoneIds, boolean enableOffering, final NetUtils.InternetProtocol internetProtocol,
+                                            NetworkOffering.RoutingMode routingMode, boolean specifyAsNumber);
 
     Vlan createVlanAndPublicIpRange(long zoneId, long networkId, long physicalNetworkId, boolean forVirtualNetwork, boolean forSystemVms, Long podId, String startIP, String endIP,
-        String vlanGateway, String vlanNetmask, String vlanId, boolean bypassVlanOverlapCheck, Domain domain, Account vlanOwner, String startIPv6, String endIPv6, String vlanIp6Gateway, String vlanIp6Cidr)
+        String vlanGateway, String vlanNetmask, String vlanId, boolean bypassVlanOverlapCheck, Domain domain, Account vlanOwner, String startIPv6, String endIPv6, String vlanIp6Gateway, String vlanIp6Cidr, boolean forNsx)
         throws InsufficientCapacityException, ConcurrentOperationException, InvalidParameterValueException;
 
     void createDefaultSystemNetworks(long zoneId) throws ConcurrentOperationException;
