@@ -16,6 +16,7 @@
 // under the License.
 package com.cloud.dc.dao;
 
+import com.cloud.cpu.CPU;
 import com.cloud.dc.ClusterVO;
 import com.cloud.hypervisor.Hypervisor.HypervisorType;
 import com.cloud.utils.db.GenericDao;
@@ -50,4 +51,8 @@ public interface ClusterDao extends GenericDao<ClusterVO, Long> {
     List<Long> listAllClusters(Long zoneId);
 
     boolean getSupportsResigning(long clusterId);
+
+    List<CPU.CPUArch> getClustersArchsByZone(long zoneId);
+
+    List<ClusterVO> listClustersByArchAndZoneId(long zoneId, CPU.CPUArch arch);
 }
