@@ -22,20 +22,22 @@ import java.util.Map;
 
 import javax.inject.Inject;
 
+import org.apache.cloudstack.framework.config.ConfigKey.Scope;
+import org.apache.cloudstack.framework.config.ScopedConfigStorage;
+import org.apache.cloudstack.framework.config.dao.ConfigurationDao;
+import org.apache.cloudstack.framework.config.impl.ConfigurationVO;
+
 import com.cloud.domain.DomainDetailVO;
 import com.cloud.domain.DomainVO;
+import com.cloud.utils.crypt.DBEncryptionUtil;
+import com.cloud.utils.db.GenericDaoBase;
 import com.cloud.utils.db.QueryBuilder;
 import com.cloud.utils.db.SearchBuilder;
 import com.cloud.utils.db.SearchCriteria;
 import com.cloud.utils.db.SearchCriteria.Op;
 import com.cloud.utils.db.TransactionLegacy;
-import org.apache.cloudstack.framework.config.ConfigKey;
-import org.apache.cloudstack.framework.config.ConfigKey.Scope;
-import org.apache.cloudstack.framework.config.ScopedConfigStorage;
-import org.apache.cloudstack.framework.config.dao.ConfigurationDao;
-import org.apache.cloudstack.resourcedetail.ResourceDetailsDaoBase;
 
-public class DomainDetailsDaoImpl extends ResourceDetailsDaoBase<DomainDetailVO> implements DomainDetailsDao, ScopedConfigStorage {
+public class DomainDetailsDaoImpl extends GenericDaoBase<DomainDetailVO, Long> implements DomainDetailsDao, ScopedConfigStorage {
     protected final SearchBuilder<DomainDetailVO> domainSearch;
 
     @Inject
@@ -45,14 +47,14 @@ public class DomainDetailsDaoImpl extends ResourceDetailsDaoBase<DomainDetailVO>
 
     protected DomainDetailsDaoImpl() {
         domainSearch = createSearchBuilder();
-        domainSearch.and("domainId", domainSearch.entity().getResourceId(), Op.EQ);
+        domainSearch.and("domainId", domainSearch.entity().getDomainId(), Op.EQ);
         domainSearch.done();
     }
 
     @Override
     public Map<String, String> findDetails(long domainId) {
         QueryBuilder<DomainDetailVO> sc = QueryBuilder.create(DomainDetailVO.class);
-        sc.and(sc.entity().getResourceId(), Op.EQ, domainId);
+        sc.and(sc.entity().getDomainId(), Op.EQ, domainId);
         List<DomainDetailVO> results = sc.list();
         Map<String, String> details = new HashMap<String, String>(results.size());
         for (DomainDetailVO r : results) {
@@ -78,16 +80,11 @@ public class DomainDetailsDaoImpl extends ResourceDetailsDaoBase<DomainDetailVO>
     @Override
     public DomainDetailVO findDetail(long domainId, String name) {
         QueryBuilder<DomainDetailVO> sc = QueryBuilder.create(DomainDetailVO.class);
-        sc.and(sc.entity().getResourceId(), Op.EQ, domainId);
+        sc.and(sc.entity().getDomainId(), Op.EQ, domainId);
         sc.and(sc.entity().getName(), Op.EQ, name);
         return sc.find();
     }
 
-    @Override
-    public void addDetail(long resourceId, String key, String value, boolean display) {
-        super.addDetail(new DomainDetailVO(resourceId, key, value));
-    }
-
     @Override
     public void deleteDetails(long domainId) {
         SearchCriteria<DomainDetailVO> sc = domainSearch.create();
@@ -111,17 +108,17 @@ public class DomainDetailsDaoImpl extends ResourceDetailsDaoBase<DomainDetailVO>
     }
 
     @Override
-    public String getConfigValue(long id, ConfigKey<?> key) {
+    public String getConfigValue(long id, String key) {
         DomainDetailVO vo = null;
         String enableDomainSettingsForChildDomain = _configDao.getValue("enable.domain.settings.for.child.domain");
         if (!Boolean.parseBoolean(enableDomainSettingsForChildDomain)) {
-            vo = findDetail(id, key.key());
+            vo = findDetail(id, key);
             return vo == null ? null : getActualValue(vo);
         }
         DomainVO domain = _domainDao.findById(id);
         // if value is not configured in domain then check its parent domain till ROOT
         while (domain != null) {
-            vo = findDetail(domain.getId(), key.key());
+            vo = findDetail(domain.getId(), key);
             if (vo != null) {
                 break;
             } else if (domain.getParent() != null) {
@@ -132,4 +129,13 @@ public class DomainDetailsDaoImpl extends ResourceDetailsDaoBase<DomainDetailVO>
         }
         return vo == null ? null : getActualValue(vo);
     }
+
+    @Override
+    public String getActualValue(DomainDetailVO domainDetailVO) {
+        ConfigurationVO configurationVO = _configDao.findByName(domainDetailVO.getName());
+        if (configurationVO != null && configurationVO.isEncrypted()) {
+            return DBEncryptionUtil.decrypt(domainDetailVO.getValue());
+        }
+        return domainDetailVO.getValue();
+    }
 }
