@@ -20,8 +20,6 @@ import java.util.ArrayList;
 import java.util.List;
 
 
-import org.apache.commons.collections4.CollectionUtils;
-import org.apache.log4j.Logger;
 import org.springframework.stereotype.Component;
 
 import com.cloud.utils.db.DB;
@@ -32,7 +30,6 @@ import com.cloud.utils.db.TransactionLegacy;
 
 @Component
 public class FirewallRulesCidrsDaoImpl extends GenericDaoBase<FirewallRulesCidrsVO, Long> implements FirewallRulesCidrsDao {
-    private static final Logger s_logger = Logger.getLogger(FirewallRulesCidrsDaoImpl.class);
     protected final SearchBuilder<FirewallRulesCidrsVO> CidrsSearch;
 
     protected FirewallRulesCidrsDaoImpl() {
@@ -66,27 +63,9 @@ public class FirewallRulesCidrsDaoImpl extends GenericDaoBase<FirewallRulesCidrs
         return results;
     }
 
-    @Override
-    public void updateSourceCidrsForRule(Long firewallRuleId, List<String> sourceCidrList) {
-        TransactionLegacy txn = TransactionLegacy.currentTxn();
-        txn.start();
-
-        SearchCriteria<FirewallRulesCidrsVO> sc = CidrsSearch.create();
-        sc.setParameters("firewallRuleId", firewallRuleId);
-        remove(sc);
-
-        persist(firewallRuleId, sourceCidrList);
-
-        txn.commit();
-    }
-
     @Override
     @DB
     public void persist(long firewallRuleId, List<String> sourceCidrs) {
-        if (CollectionUtils.isEmpty(sourceCidrs)) {
-            return;
-        }
-
         TransactionLegacy txn = TransactionLegacy.currentTxn();
 
         txn.start();
