@@ -50,6 +50,7 @@ public class FirewallRulesDaoImpl extends GenericDaoBase<FirewallRuleVO, Long> i
     protected SearchBuilder<FirewallRuleVO> VmSearch;
     protected final SearchBuilder<FirewallRuleVO> SystemRuleSearch;
     protected final GenericSearchBuilder<FirewallRuleVO, Long> RulesByIpCount;
+    protected final SearchBuilder<FirewallRuleVO> RoutingFirewallRulesSearch;
 
     @Inject
     protected FirewallRulesCidrsDao _firewallRulesCidrsDao;
@@ -104,6 +105,13 @@ public class FirewallRulesDaoImpl extends GenericDaoBase<FirewallRuleVO, Long> i
         RulesByIpCount.and("ipAddressId", RulesByIpCount.entity().getSourceIpAddressId(), Op.EQ);
         RulesByIpCount.and("state", RulesByIpCount.entity().getState(), Op.EQ);
         RulesByIpCount.done();
+
+        RoutingFirewallRulesSearch = createSearchBuilder();
+        RoutingFirewallRulesSearch.and("networkId", RoutingFirewallRulesSearch.entity().getNetworkId(), Op.EQ);
+        RoutingFirewallRulesSearch.and("purpose", RoutingFirewallRulesSearch.entity().getPurpose(), Op.EQ);
+        RoutingFirewallRulesSearch.and("trafficType", RoutingFirewallRulesSearch.entity().getTrafficType(), Op.EQ);
+        RoutingFirewallRulesSearch.and("ipId", RoutingFirewallRulesSearch.entity().getSourceIpAddressId(), Op.NULL);
+        RoutingFirewallRulesSearch.done();
     }
 
     @Override
@@ -243,6 +251,9 @@ public class FirewallRulesDaoImpl extends GenericDaoBase<FirewallRuleVO, Long> i
     }
 
     public void saveSourceCidrs(FirewallRuleVO firewallRule, List<String> cidrList) {
+        if (cidrList == null) {
+            return;
+        }
         _firewallRulesCidrsDao.persist(firewallRule.getId(), cidrList);
     }
 
@@ -383,4 +394,12 @@ public class FirewallRulesDaoImpl extends GenericDaoBase<FirewallRuleVO, Long> i
         rule.setDestinationCidrsList(destCidrs);
     }
 
+    @Override
+    public List<FirewallRuleVO> listRoutingIngressFirewallRules(long networkId) {
+        SearchCriteria<FirewallRuleVO> sc = RoutingFirewallRulesSearch.create();
+        sc.setParameters("networkId", networkId);
+        sc.setParameters("purpose", Purpose.Firewall);
+        sc.setParameters("trafficType", TrafficType.Ingress);
+        return listBy(sc);
+    }
 }
