@@ -33,11 +33,11 @@ import java.util.List;
 
 import javax.inject.Inject;
 
-import com.cloud.upgrade.dao.Upgrade41910to41920;
 import com.cloud.utils.FileUtil;
 import org.apache.cloudstack.utils.CloudStackVersion;
 import org.apache.commons.lang3.StringUtils;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 
 import com.cloud.upgrade.dao.DbUpgrade;
 import com.cloud.upgrade.dao.DbUpgradeSystemVmTemplate;
@@ -87,6 +87,7 @@ import com.cloud.upgrade.dao.Upgrade41720to41800;
 import com.cloud.upgrade.dao.Upgrade41800to41810;
 import com.cloud.upgrade.dao.Upgrade41810to41900;
 import com.cloud.upgrade.dao.Upgrade41900to41910;
+import com.cloud.upgrade.dao.Upgrade41910to42000;
 import com.cloud.upgrade.dao.Upgrade420to421;
 import com.cloud.upgrade.dao.Upgrade421to430;
 import com.cloud.upgrade.dao.Upgrade430to440;
@@ -126,7 +127,7 @@ import com.cloud.utils.exception.CloudRuntimeException;
 import com.google.common.annotations.VisibleForTesting;
 
 public class DatabaseUpgradeChecker implements SystemIntegrityChecker {
-    private static final Logger s_logger = Logger.getLogger(DatabaseUpgradeChecker.class);
+    protected static Logger LOGGER = LogManager.getLogger(DatabaseUpgradeChecker.class);
     private final DatabaseVersionHierarchy hierarchy;
     private static final String VIEWS_DIRECTORY = Paths.get("META-INF", "db", "views").toString();
     private static final String PROCEDURES_DIRECTORY = Paths.get("META-INF", "db", "procedures").toString();
@@ -228,7 +229,7 @@ public class DatabaseUpgradeChecker implements SystemIntegrityChecker {
                 .next("4.18.0.0", new Upgrade41800to41810())
                 .next("4.18.1.0", new Upgrade41810to41900())
                 .next("4.19.0.0", new Upgrade41900to41910())
-                .next("4.19.1.0", new Upgrade41910to41920())
+                .next("4.19.1.0", new Upgrade41910to42000())
                 .build();
     }
 
@@ -238,10 +239,10 @@ public class DatabaseUpgradeChecker implements SystemIntegrityChecker {
             ScriptRunner runner = new ScriptRunner(conn, false, true);
             runner.runScript(reader);
         } catch (IOException e) {
-            s_logger.error("Unable to read upgrade script", e);
+            LOGGER.error("Unable to read upgrade script", e);
             throw new CloudRuntimeException("Unable to read upgrade script", e);
         } catch (SQLException e) {
-            s_logger.error("Unable to execute upgrade script", e);
+            LOGGER.error("Unable to execute upgrade script", e);
             throw new CloudRuntimeException("Unable to execute upgrade script", e);
         }
 
@@ -280,7 +281,7 @@ public class DatabaseUpgradeChecker implements SystemIntegrityChecker {
                         conn = txn.getConnection();
                     } catch (SQLException e) {
                         String errorMessage = "Unable to upgrade the database";
-                        s_logger.error(errorMessage, e);
+                        LOGGER.error(errorMessage, e);
                         throw new CloudRuntimeException(errorMessage, e);
                     }
                     ((DbUpgradeSystemVmTemplate)upgrade).updateSystemVmTemplates(conn);
@@ -288,7 +289,7 @@ public class DatabaseUpgradeChecker implements SystemIntegrityChecker {
                     break;
                 } catch (CloudRuntimeException e) {
                     String errorMessage = "Unable to upgrade the database";
-                    s_logger.error(errorMessage, e);
+                    LOGGER.error(errorMessage, e);
                     throw new CloudRuntimeException(errorMessage, e);
                 } finally {
                     txn.close();
@@ -306,29 +307,29 @@ public class DatabaseUpgradeChecker implements SystemIntegrityChecker {
     }
 
     protected void executeProcedureScripts() {
-        s_logger.info(String.format("Executing Stored Procedure scripts that are under resource directory [%s].", PROCEDURES_DIRECTORY));
+        LOGGER.info(String.format("Executing Stored Procedure scripts that are under resource directory [%s].", PROCEDURES_DIRECTORY));
         List<String> filesPathUnderViewsDirectory = FileUtil.getFilesPathsUnderResourceDirectory(PROCEDURES_DIRECTORY);
 
         try (TransactionLegacy txn = TransactionLegacy.open("execute-procedure-scripts")) {
             Connection conn = txn.getConnection();
 
             for (String filePath : filesPathUnderViewsDirectory) {
-                s_logger.debug(String.format("Executing PROCEDURE script [%s].", filePath));
+                LOGGER.debug(String.format("Executing PROCEDURE script [%s].", filePath));
 
                 InputStream viewScript = Thread.currentThread().getContextClassLoader().getResourceAsStream(filePath);
                 runScript(conn, viewScript);
             }
 
-            s_logger.info(String.format("Finished execution of PROCEDURE scripts that are under resource directory [%s].", PROCEDURES_DIRECTORY));
+            LOGGER.info(String.format("Finished execution of PROCEDURE scripts that are under resource directory [%s].", PROCEDURES_DIRECTORY));
         } catch (SQLException e) {
             String message = String.format("Unable to execute PROCEDURE scripts due to [%s].", e.getMessage());
-            s_logger.error(message, e);
+            LOGGER.error(message, e);
             throw new CloudRuntimeException(message, e);
         }
     }
 
     private DbUpgrade[] executeUpgrades(CloudStackVersion dbVersion, CloudStackVersion currentVersion) {
-        s_logger.info("Database upgrade must be performed from " + dbVersion + " to " + currentVersion);
+        LOGGER.info("Database upgrade must be performed from " + dbVersion + " to " + currentVersion);
 
         final DbUpgrade[] upgrades = calculateUpgradePath(dbVersion, currentVersion);
 
@@ -341,7 +342,7 @@ public class DatabaseUpgradeChecker implements SystemIntegrityChecker {
 
     private VersionVO executeUpgrade(DbUpgrade upgrade) {
         VersionVO version;
-        s_logger.debug("Running upgrade " + upgrade.getClass().getSimpleName() + " to upgrade from " + upgrade.getUpgradableVersionRange()[0] + "-" + upgrade
+        LOGGER.debug("Running upgrade " + upgrade.getClass().getSimpleName() + " to upgrade from " + upgrade.getUpgradableVersionRange()[0] + "-" + upgrade
             .getUpgradableVersionRange()[1] + " to " + upgrade.getUpgradedVersion());
         TransactionLegacy txn = TransactionLegacy.open("Upgrade");
         txn.start();
@@ -351,7 +352,7 @@ public class DatabaseUpgradeChecker implements SystemIntegrityChecker {
                 conn = txn.getConnection();
             } catch (SQLException e) {
                 String errorMessage = "Unable to upgrade the database";
-                s_logger.error(errorMessage, e);
+                LOGGER.error(errorMessage, e);
                 throw new CloudRuntimeException(errorMessage, e);
             }
             InputStream[] scripts = upgrade.getPrepareScripts();
@@ -369,7 +370,7 @@ public class DatabaseUpgradeChecker implements SystemIntegrityChecker {
             txn.commit();
         } catch (CloudRuntimeException e) {
             String errorMessage = "Unable to upgrade the database";
-            s_logger.error(errorMessage, e);
+            LOGGER.error(errorMessage, e);
             throw new CloudRuntimeException(errorMessage, e);
         } finally {
             txn.close();
@@ -382,7 +383,7 @@ public class DatabaseUpgradeChecker implements SystemIntegrityChecker {
         // Run the corresponding '-cleanup.sql' script
         txn = TransactionLegacy.open("Cleanup");
         try {
-            s_logger.info("Cleanup upgrade " + upgrade.getClass().getSimpleName() + " to upgrade from " + upgrade.getUpgradableVersionRange()[0] + "-" + upgrade
+            LOGGER.info("Cleanup upgrade " + upgrade.getClass().getSimpleName() + " to upgrade from " + upgrade.getUpgradableVersionRange()[0] + "-" + upgrade
                 .getUpgradableVersionRange()[1] + " to " + upgrade.getUpgradedVersion());
 
             txn.start();
@@ -390,7 +391,7 @@ public class DatabaseUpgradeChecker implements SystemIntegrityChecker {
             try {
                 conn = txn.getConnection();
             } catch (SQLException e) {
-                s_logger.error("Unable to cleanup the database", e);
+                LOGGER.error("Unable to cleanup the database", e);
                 throw new CloudRuntimeException("Unable to cleanup the database", e);
             }
 
@@ -398,7 +399,7 @@ public class DatabaseUpgradeChecker implements SystemIntegrityChecker {
             if (scripts != null) {
                 for (InputStream script : scripts) {
                     runScript(conn, script);
-                    s_logger.debug("Cleanup script " + upgrade.getClass().getSimpleName() + " is executed successfully");
+                    LOGGER.debug("Cleanup script " + upgrade.getClass().getSimpleName() + " is executed successfully");
                 }
             }
             txn.commit();
@@ -408,30 +409,30 @@ public class DatabaseUpgradeChecker implements SystemIntegrityChecker {
             version.setUpdated(new Date());
             _dao.update(version.getId(), version);
             txn.commit();
-            s_logger.debug("Upgrade completed for version " + version.getVersion());
+            LOGGER.debug("Upgrade completed for version " + version.getVersion());
         } finally {
             txn.close();
         }
     }
 
     protected void executeViewScripts() {
-        s_logger.info(String.format("Executing VIEW scripts that are under resource directory [%s].", VIEWS_DIRECTORY));
+        LOGGER.info(String.format("Executing VIEW scripts that are under resource directory [%s].", VIEWS_DIRECTORY));
         List<String> filesPathUnderViewsDirectory = FileUtil.getFilesPathsUnderResourceDirectory(VIEWS_DIRECTORY);
 
         try (TransactionLegacy txn = TransactionLegacy.open("execute-view-scripts")) {
             Connection conn = txn.getConnection();
 
             for (String filePath : filesPathUnderViewsDirectory) {
-                s_logger.debug(String.format("Executing VIEW script [%s].", filePath));
+                LOGGER.debug(String.format("Executing VIEW script [%s].", filePath));
 
                 InputStream viewScript = Thread.currentThread().getContextClassLoader().getResourceAsStream(filePath);
                 runScript(conn, viewScript);
             }
 
-            s_logger.info(String.format("Finished execution of VIEW scripts that are under resource directory [%s].", VIEWS_DIRECTORY));
+            LOGGER.info(String.format("Finished execution of VIEW scripts that are under resource directory [%s].", VIEWS_DIRECTORY));
         } catch (SQLException e) {
             String message = String.format("Unable to execute VIEW scripts due to [%s].", e.getMessage());
-            s_logger.error(message, e);
+            LOGGER.error(message, e);
             throw new CloudRuntimeException(message, e);
         }
     }
@@ -440,7 +441,7 @@ public class DatabaseUpgradeChecker implements SystemIntegrityChecker {
     public void check() {
         GlobalLock lock = GlobalLock.getInternLock("DatabaseUpgrade");
         try {
-            s_logger.info("Grabbing lock to check for database upgrade.");
+            LOGGER.info("Grabbing lock to check for database upgrade.");
             if (!lock.lock(20 * 60)) {
                 throw new CloudRuntimeException("Unable to acquire lock to check for database integrity.");
             }
@@ -461,14 +462,14 @@ public class DatabaseUpgradeChecker implements SystemIntegrityChecker {
                 SystemVmTemplateRegistration.CS_MAJOR_VERSION  = String.valueOf(sysVmVersion.getMajorRelease()) + "." + String.valueOf(sysVmVersion.getMinorRelease());
                 SystemVmTemplateRegistration.CS_TINY_VERSION = String.valueOf(sysVmVersion.getPatchRelease());
 
-                s_logger.info("DB version = " + dbVersion + " Code Version = " + currentVersion);
+                LOGGER.info("DB version = " + dbVersion + " Code Version = " + currentVersion);
 
                 if (dbVersion.compareTo(currentVersion) > 0) {
                     throw new CloudRuntimeException("Database version " + dbVersion + " is higher than management software version " + currentVersionValue);
                 }
 
                 if (dbVersion.compareTo(currentVersion) == 0) {
-                    s_logger.info("DB version and code version matches so no upgrade needed.");
+                    LOGGER.info("DB version and code version matches so no upgrade needed.");
                     return;
                 }
 
@@ -491,13 +492,13 @@ public class DatabaseUpgradeChecker implements SystemIntegrityChecker {
             decryptInit(conn);
             txn.commit();
         } catch (CloudRuntimeException e) {
-            s_logger.error(e.getMessage());
+            LOGGER.error(e.getMessage());
             errorMessage = String.format("Unable to initialize the database encryptors due to %s. " +
                     "Please check if database encryption key and database encryptor version are correct.", errorMessage);
-            s_logger.error(errorMessage);
+            LOGGER.error(errorMessage);
             throw new CloudRuntimeException(errorMessage, e);
         } catch (SQLException e) {
-            s_logger.error(errorMessage, e);
+            LOGGER.error(errorMessage, e);
             throw new CloudRuntimeException(errorMessage, e);
         } finally {
             txn.close();
@@ -510,7 +511,7 @@ public class DatabaseUpgradeChecker implements SystemIntegrityChecker {
              ResultSet result = pstmt.executeQuery()) {
             if (result.next()) {
                 String init = result.getString(1);
-                s_logger.info("init = " + DBEncryptionUtil.decrypt(init));
+                LOGGER.info("init = " + DBEncryptionUtil.decrypt(init));
             }
         }
     }
@@ -567,7 +568,7 @@ public class DatabaseUpgradeChecker implements SystemIntegrityChecker {
 
         @Override
         public void updateSystemVmTemplates(Connection conn) {
-            s_logger.debug("Updating System Vm template IDs");
+            LOGGER.debug("Updating System Vm template IDs");
             initSystemVmTemplateRegistration();
             try {
                 systemVmTemplateRegistration.updateSystemVmTemplates(conn);
