@@ -59,7 +59,8 @@ import org.apache.cloudstack.storage.datastore.db.TemplateDataStoreDao;
 import org.apache.cloudstack.storage.datastore.db.TemplateDataStoreVO;
 import org.apache.cloudstack.utils.security.DigestHelper;
 import org.apache.commons.lang3.StringUtils;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 import org.ini4j.Ini;
 
 import javax.inject.Inject;
@@ -85,7 +86,8 @@ import java.util.UUID;
 import java.util.stream.Collectors;
 
 public class SystemVmTemplateRegistration {
-    private static final Logger LOGGER = Logger.getLogger(SystemVmTemplateRegistration.class);
+    protected static Logger LOGGER = LogManager.getLogger(SystemVmTemplateRegistration.class);
+    private static final String MOUNT_COMMAND = "sudo mount -t nfs %s %s";
     private static final String UMOUNT_COMMAND = "sudo umount %s";
     private static final String RELATIVE_TEMPLATE_PATH = "./engine/schema/dist/systemvm-templates/";
     private static final String ABSOLUTE_TEMPLATE_PATH = "/usr/share/cloudstack-management/templates/systemvm/";
@@ -332,7 +334,7 @@ public class SystemVmTemplateRegistration {
         }
     };
 
-    public boolean validateIfSeeded(TemplateDataStoreVO templDataStoreVO, String url, String path, String nfsVersion) {
+    public static boolean validateIfSeeded(String url, String path, String nfsVersion) {
         String filePath = null;
         try {
             filePath = Files.createTempDirectory(TEMPORARY_SECONDARY_STORE).toString();
@@ -345,9 +347,6 @@ public class SystemVmTemplateRegistration {
             String templatePath = filePath + File.separator + partialDirPath;
             File templateProps = new File(templatePath + "/template.properties");
             if (templateProps.exists()) {
-                Pair<Long, Long> templateSizes = readTemplatePropertiesSizes(templatePath + "/template.properties");
-                updateSeededTemplateDetails(templDataStoreVO.getTemplateId(), templDataStoreVO.getDataStoreId(),
-                        templateSizes.first(), templateSizes.second());
                 LOGGER.info("SystemVM template already seeded, skipping registration");
                 return true;
             }
@@ -460,7 +459,7 @@ public class SystemVmTemplateRegistration {
     private List<String> fetchAllHypervisors(Long zoneId) {
         List<String> hypervisorList = new ArrayList<>();
         List<Hypervisor.HypervisorType> hypervisorTypes = clusterDao.getAvailableHypervisorInZone(zoneId);
-        hypervisorList = hypervisorTypes.stream().distinct().map(Enum::name).collect(Collectors.toList());
+        hypervisorList = hypervisorTypes.stream().distinct().map(Hypervisor.HypervisorType::name).collect(Collectors.toList());
         return hypervisorList;
     }
 
@@ -543,21 +542,6 @@ public class SystemVmTemplateRegistration {
         }
     }
 
-    public void updateSeededTemplateDetails(long templateId, long storeId, long size, long physicalSize) {
-        VMTemplateVO template = vmTemplateDao.findById(templateId);
-        template.setSize(size);
-        vmTemplateDao.update(template.getId(), template);
-
-        TemplateDataStoreVO templateDataStoreVO = templateDataStoreDao.findByStoreTemplate(storeId, template.getId());
-        templateDataStoreVO.setSize(size);
-        templateDataStoreVO.setPhysicalSize(physicalSize);
-        templateDataStoreVO.setLastUpdated(new Date(DateUtil.currentGMTTime().getTime()));
-        boolean updated = templateDataStoreDao.update(templateDataStoreVO.getId(), templateDataStoreVO);
-        if (!updated) {
-            throw new CloudRuntimeException("Failed to update template_store_ref entry for seeded systemVM template");
-        }
-    }
-
     public void updateSystemVMEntries(Long templateId, Hypervisor.HypervisorType hypervisorType) {
         vmInstanceDao.updateSystemVmTemplateId(templateId, hypervisorType);
     }
@@ -571,7 +555,7 @@ public class SystemVmTemplateRegistration {
         }
     }
 
-    private static Pair<Long, Long> readTemplatePropertiesSizes(String path) {
+    private static void readTemplateProperties(String path, SystemVMTemplateDetails details) {
         File tmpFile = new File(path);
         Long size = null;
         Long physicalSize = 0L;
@@ -590,13 +574,8 @@ public class SystemVmTemplateRegistration {
         } catch (IOException ex) {
             LOGGER.warn("Failed to read from template.properties", ex);
         }
-        return new Pair<>(size, physicalSize);
-    }
-
-    public static void readTemplateProperties(String path, SystemVMTemplateDetails details) {
-        Pair<Long, Long> templateSizes = readTemplatePropertiesSizes(path);
-        details.setSize(templateSizes.first());
-        details.setPhysicalSize(templateSizes.second());
+        details.setSize(size);
+        details.setPhysicalSize(physicalSize);
     }
 
     private void updateTemplateTablesOnFailure(long templateId) {
@@ -754,8 +733,8 @@ public class SystemVmTemplateRegistration {
     }
 
     private void validateTemplates(Set<Hypervisor.HypervisorType> hypervisorsInUse) {
-        Set<String> hypervisors = hypervisorsInUse.stream().map(Enum::name).
-                map(name -> name.toLowerCase(Locale.ROOT)).map(this::getHypervisorName).collect(Collectors.toSet());
+        Set<String> hypervisors = hypervisorsInUse.stream().
+                map(Hypervisor.HypervisorType::name).map(name -> name.toLowerCase(Locale.ROOT)).map(this::getHypervisorName).collect(Collectors.toSet());
         List<String> templates = new ArrayList<>();
         for (Hypervisor.HypervisorType hypervisorType : hypervisorsInUse) {
             templates.add(FileNames.get(hypervisorType));
@@ -817,16 +796,12 @@ public class SystemVmTemplateRegistration {
                                     Long templateId = getRegisteredTemplateId(hypervisorAndTemplateName);
                                     if (templateId != null) {
                                         VMTemplateVO templateVO = vmTemplateDao.findById(templateId);
-                                        TemplateDataStoreVO templateDataStoreVO = templateDataStoreDao.findByStoreTemplate(storeUrlAndId.second(), templateId);
-                                        if (templateDataStoreVO != null) {
-                                            String installPath = templateDataStoreVO.getInstallPath();
-                                            if (validateIfSeeded(templateDataStoreVO, storeUrlAndId.first(), installPath, nfsVersion)) {
-                                                continue;
-                                            }
-                                        }
-                                        if (templateVO != null) {
+                                        TemplateDataStoreVO templateDataStoreVO = templateDataStoreDao.findByTemplate(templateId, DataStoreRole.Image);
+                                        String installPath = templateDataStoreVO.getInstallPath();
+                                        if (validateIfSeeded(storeUrlAndId.first(), installPath, nfsVersion)) {
+                                            continue;
+                                        } else if (templateVO != null) {
                                             registerTemplate(hypervisorAndTemplateName, storeUrlAndId, templateVO, templateDataStoreVO, filePath);
-                                            updateRegisteredTemplateDetails(templateId, hypervisorAndTemplateName);
                                             continue;
                                         }
                                     }
@@ -850,11 +825,6 @@ public class SystemVmTemplateRegistration {
     }
 
     private void updateRegisteredTemplateDetails(Long templateId, Map.Entry<Hypervisor.HypervisorType, String> hypervisorAndTemplateName) {
-        Pair<Hypervisor.HypervisorType, String> entry = new Pair<>(hypervisorAndTemplateName.getKey(), hypervisorAndTemplateName.getValue());
-        updateRegisteredTemplateDetails(templateId, entry);
-    }
-
-    private void updateRegisteredTemplateDetails(Long templateId, Pair<Hypervisor.HypervisorType, String> hypervisorAndTemplateName) {
         VMTemplateVO templateVO = vmTemplateDao.findById(templateId);
         templateVO.setTemplateType(Storage.TemplateType.SYSTEM);
         boolean updated = vmTemplateDao.update(templateVO.getId(), templateVO);
@@ -864,11 +834,11 @@ public class SystemVmTemplateRegistration {
             throw new CloudRuntimeException(errMsg);
         }
 
-        updateSystemVMEntries(templateId, hypervisorAndTemplateName.first());
+        updateSystemVMEntries(templateId, hypervisorAndTemplateName.getKey());
 
         // Change value of global configuration parameter router.template.* for the corresponding hypervisor and minreq.sysvmtemplate.version for the ACS version
         Map<String, String> configParams = new HashMap<>();
-        configParams.put(RouterTemplateConfigurationNames.get(hypervisorAndTemplateName.first()), hypervisorAndTemplateName.second());
+        configParams.put(RouterTemplateConfigurationNames.get(hypervisorAndTemplateName.getKey()), hypervisorAndTemplateName.getValue());
         configParams.put("minreq.sysvmtemplate.version", getSystemVmTemplateVersion());
         updateConfigurationParams(configParams);
     }
