@@ -17,7 +17,7 @@
 
 package com.cloud.upgrade.dao;
 
-public class Upgrade453to460 extends Upgrade452to460 implements DbUpgrade {
+public class Upgrade453to460 extends Upgrade452to460 {
 
     @Override
     public String[] getUpgradableVersionRange() {
