@@ -16,16 +16,17 @@
 // under the License.
 package com.cloud.usage.dao;
 
+import com.cloud.network.Network;
 import com.cloud.usage.UsageNetworksVO;
 import com.cloud.utils.DateUtil;
 import com.cloud.utils.db.GenericDaoBase;
-import com.cloud.utils.db.SearchBuilder;
 import com.cloud.utils.db.SearchCriteria;
 import com.cloud.utils.db.TransactionLegacy;
-import org.apache.log4j.Logger;
-import org.springframework.stereotype.Component;
 
-import javax.annotation.PostConstruct;
+import org.springframework.stereotype.Component;
+import org.apache.logging.log4j.LogManager;
+import org.apache.logging.log4j.Logger;
+
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.util.ArrayList;
@@ -35,19 +36,11 @@ import java.util.TimeZone;
 
 @Component
 public class UsageNetworksDaoImpl extends GenericDaoBase<UsageNetworksVO, Long> implements UsageNetworksDao {
-    private static final Logger LOGGER = Logger.getLogger(UsageNetworksDaoImpl.class);
+    private static final Logger LOGGER = LogManager.getLogger(UsageNetworksDaoImpl.class);
     protected static final String GET_USAGE_RECORDS_BY_ACCOUNT = "SELECT id, network_id, network_offering_id, zone_id, account_id, domain_id, state, created, removed FROM usage_networks WHERE " +
             " account_id = ? AND ((removed IS NULL AND created <= ?) OR (created BETWEEN ? AND ?) OR (removed BETWEEN ? AND ?) " +
             " OR ((created <= ?) AND (removed >= ?)))";
 
-    private SearchBuilder<UsageNetworksVO> usageNetworksSearch;
-
-    @PostConstruct
-    public void init() {
-        usageNetworksSearch = createSearchBuilder();
-        usageNetworksSearch.and("networkId", usageNetworksSearch.entity().getNetworkId(), SearchCriteria.Op.EQ);
-        usageNetworksSearch.done();
-    }
 
     @Override
     public void update(long networkId, long newNetworkOffering, String state) {
@@ -77,10 +70,11 @@ public class UsageNetworksDaoImpl extends GenericDaoBase<UsageNetworksVO, Long>
             SearchCriteria<UsageNetworksVO> sc = this.createSearchCriteria();
             sc.addAnd("networkId", SearchCriteria.Op.EQ, networkId);
             sc.addAnd("removed", SearchCriteria.Op.NULL);
-            List<UsageNetworksVO> usageNetworksVOs = listBy(sc);
-            for (UsageNetworksVO entry : usageNetworksVOs) {
-                entry.setRemoved(removed);
-                update(entry.getId(), entry);
+            UsageNetworksVO vo = findOneBy(sc);
+            if (vo != null) {
+                vo.setRemoved(removed);
+                vo.setState(Network.State.Destroy.name());
+                update(vo.getId(), vo);
             }
         } catch (final Exception e) {
             txn.rollback();
@@ -139,11 +133,4 @@ public class UsageNetworksDaoImpl extends GenericDaoBase<UsageNetworksVO, Long>
 
         return usageRecords;
     }
-
-    @Override
-    public List<UsageNetworksVO> listAll(long networkId) {
-        SearchCriteria<UsageNetworksVO> sc = usageNetworksSearch.create();
-        sc.setParameters("networkId", networkId);
-        return listBy(sc);
-    }
 }
