@@ -50,11 +50,13 @@ public class RoleDaoImpl extends GenericDaoBase<RoleVO, Long> implements RoleDao
         RoleByNameSearch = createSearchBuilder();
         RoleByNameSearch.and("roleName", RoleByNameSearch.entity().getName(), SearchCriteria.Op.LIKE);
         RoleByNameSearch.and("isPublicRole", RoleByNameSearch.entity().isPublicRole(), SearchCriteria.Op.EQ);
+        RoleByNameSearch.and("state", RoleByNameSearch.entity().getState(), SearchCriteria.Op.EQ);
         RoleByNameSearch.done();
 
         RoleByTypeSearch = createSearchBuilder();
         RoleByTypeSearch.and("roleType", RoleByTypeSearch.entity().getRoleType(), SearchCriteria.Op.EQ);
         RoleByTypeSearch.and("isPublicRole", RoleByTypeSearch.entity().isPublicRole(), SearchCriteria.Op.EQ);
+        RoleByTypeSearch.and("state", RoleByTypeSearch.entity().getState(), SearchCriteria.Op.EQ);
         RoleByTypeSearch.done();
 
         RoleByNameAndTypeSearch = createSearchBuilder();
@@ -65,16 +67,17 @@ public class RoleDaoImpl extends GenericDaoBase<RoleVO, Long> implements RoleDao
 
         RoleByIsPublicSearch = createSearchBuilder();
         RoleByIsPublicSearch.and("isPublicRole", RoleByIsPublicSearch.entity().isPublicRole(), SearchCriteria.Op.EQ);
+        RoleByIsPublicSearch.and("state", RoleByIsPublicSearch.entity().getState(), SearchCriteria.Op.EQ);
         RoleByIsPublicSearch.done();
     }
 
     @Override
     public List<RoleVO> findAllByName(final String roleName, boolean showPrivateRole) {
-        return findAllByName(roleName, null, null, null, showPrivateRole).first();
+        return findAllByName(roleName, null, null, null, null, showPrivateRole).first();
     }
 
     @Override
-    public Pair<List<RoleVO>, Integer> findAllByName(final String roleName, String keyword, Long offset, Long limit, boolean showPrivateRole) {
+    public Pair<List<RoleVO>, Integer> findAllByName(final String roleName, String keyword, String state, Long offset, Long limit, boolean showPrivateRole) {
         SearchCriteria<RoleVO> sc = RoleByNameSearch.create();
         filterPrivateRolesIfNeeded(sc, showPrivateRole);
         if (StringUtils.isNotEmpty(roleName)) {
@@ -83,19 +86,25 @@ public class RoleDaoImpl extends GenericDaoBase<RoleVO, Long> implements RoleDao
         if (StringUtils.isNotEmpty(keyword)) {
             sc.setParameters("roleName", "%" + keyword + "%");
         }
+        if (StringUtils.isNotEmpty(state)) {
+            sc.setParameters("state", state);
+        }
 
         return searchAndCount(sc, new Filter(RoleVO.class, "id", true, offset, limit));
     }
 
     @Override
     public List<RoleVO> findAllByRoleType(final RoleType type, boolean showPrivateRole) {
-        return findAllByRoleType(type, null, null, showPrivateRole).first();
+        return findAllByRoleType(type, null, null, null, showPrivateRole).first();
     }
 
-    public Pair<List<RoleVO>, Integer> findAllByRoleType(final RoleType type, Long offset, Long limit, boolean showPrivateRole) {
+    public Pair<List<RoleVO>, Integer> findAllByRoleType(final RoleType type, String state, Long offset, Long limit, boolean showPrivateRole) {
         SearchCriteria<RoleVO> sc = RoleByTypeSearch.create();
         filterPrivateRolesIfNeeded(sc, showPrivateRole);
         sc.setParameters("roleType", type);
+        if (StringUtils.isNotEmpty(state)) {
+            sc.setParameters("state", state);
+        }
         return searchAndCount(sc, new Filter(RoleVO.class, "id", true, offset, limit));
     }
 
@@ -117,8 +126,11 @@ public class RoleDaoImpl extends GenericDaoBase<RoleVO, Long> implements RoleDao
     }
 
     @Override
-    public Pair<List<RoleVO>, Integer> listAllRoles(Long startIndex, Long limit, boolean showPrivateRole) {
+    public Pair<List<RoleVO>, Integer> listAllRoles(String state, Long startIndex, Long limit, boolean showPrivateRole) {
         SearchCriteria<RoleVO> sc = RoleByIsPublicSearch.create();
+        if (StringUtils.isNotEmpty(state)) {
+            sc.setParameters("state", state);
+        }
         filterPrivateRolesIfNeeded(sc, showPrivateRole);
         return searchAndCount(sc, new Filter(RoleVO.class, "id", true, startIndex, limit));
     }
