@@ -70,6 +70,9 @@ public class ApplicationLoadBalancerRuleVO extends FirewallRuleVO implements App
     @Column(name = "scheme")
     Scheme scheme;
 
+    @Column(name = "cidr_list")
+    String cidrList = null;
+
     public ApplicationLoadBalancerRuleVO() {
     }
 
@@ -137,4 +140,9 @@ public class ApplicationLoadBalancerRuleVO extends FirewallRuleVO implements App
         return defaultPortStart;
     }
 
+    @Override
+    public String getCidrList(){
+        return cidrList;
+    }
+
 }
