@@ -22,6 +22,8 @@ import static com.cloud.network.NetworkModel.CONFIGDATA_DIR;
 import static com.cloud.network.NetworkModel.CONFIGDATA_FILE;
 import static com.cloud.network.NetworkModel.PASSWORD_FILE;
 import static com.cloud.network.NetworkModel.USERDATA_FILE;
+import static com.cloud.network.NetworkService.DEFAULT_MTU;
+import static org.apache.cloudstack.storage.configdrive.ConfigDriveUtils.mergeJsonArraysAndUpdateObject;
 
 import java.io.File;
 import java.io.IOException;
@@ -33,11 +35,15 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
+import com.cloud.network.Network;
+import com.cloud.vm.NicProfile;
+import com.googlecode.ipv6.IPv6Network;
 import org.apache.commons.codec.binary.Base64;
 import org.apache.commons.collections.MapUtils;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.lang3.StringUtils;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 import org.joda.time.Duration;
 
 import com.cloud.network.NetworkModel;
@@ -49,7 +55,7 @@ import com.google.gson.JsonObject;
 
 public class ConfigDriveBuilder {
 
-    public static final Logger LOG = Logger.getLogger(ConfigDriveBuilder.class);
+    protected static Logger LOGGER = LogManager.getLogger(ConfigDriveBuilder.class);
 
     /**
      * This is for mocking the File class. We cannot mock the File class directly because Mockito uses it internally.
@@ -80,7 +86,7 @@ public class ConfigDriveBuilder {
 
     /**
      *  Read the content of a {@link File} and convert it to a String in base 64.
-     *  We expect the content of the file to be encoded using {@link StandardCharsets#US_ASC}
+     *  We expect the content of the file to be encoded using {@link StandardCharsets#US_ASCII}
      */
     public static String fileToBase64String(File isoFile) throws IOException {
         byte[] encoded = Base64.encodeBase64(FileUtils.readFileToByteArray(isoFile));
@@ -98,7 +104,7 @@ public class ConfigDriveBuilder {
         try {
             Files.createDirectories(destPath.getParent());
         } catch (final IOException e) {
-            LOG.warn("Exception hit while trying to recreate directory: " + destPath.getParent().toString());
+            LOGGER.warn("Exception hit while trying to recreate directory: " + destPath.getParent().toString());
         }
         return Files.write(destPath, decoded).toFile();
     }
@@ -107,9 +113,9 @@ public class ConfigDriveBuilder {
      *  This method will build the metadata files required by OpenStack driver. Then, an ISO is going to be generated and returned as a String in base 64.
      *  If vmData is null, we throw a {@link CloudRuntimeException}. Moreover, {@link IOException} are captured and re-thrown as {@link CloudRuntimeException}.
      */
-    public static String buildConfigDrive(List<String[]> vmData, String isoFileName, String driveLabel, Map<String, String> customUserdataParams) {
-        if (vmData == null) {
-            throw new CloudRuntimeException("No VM metadata provided");
+    public static String buildConfigDrive(List<NicProfile> nics, List<String[]> vmData, String isoFileName, String driveLabel, Map<String, String> customUserdataParams, Map<Long, List<Network.Service>> supportedServices) {
+        if (vmData == null && nics == null) {
+            throw new CloudRuntimeException("No VM metadata and nic profile provided");
         }
 
         Path tempDir = null;
@@ -120,10 +126,19 @@ public class ConfigDriveBuilder {
 
             File openStackFolder = new File(tempDirName + ConfigDrive.openStackConfigDriveName);
 
-            writeVendorAndNetworkEmptyJsonFile(openStackFolder);
-            writeVmMetadata(vmData, tempDirName, openStackFolder, customUserdataParams);
+            writeVendorEmptyJsonFile(openStackFolder);
+            writeNetworkData(nics, supportedServices, openStackFolder);
+            for (NicProfile nic: nics) {
+                if (supportedServices.get(nic.getId()).contains(Network.Service.UserData)) {
+                    if (vmData == null) {
+                        throw new CloudRuntimeException("No VM metadata provided");
+                    }
+                    writeVmMetadata(vmData, tempDirName, openStackFolder, customUserdataParams);
 
-            linkUserData(tempDirName);
+                    linkUserData(tempDirName);
+                    break;
+                }
+            }
 
             return generateAndRetrieveIsoAsBase64Iso(isoFileName, driveLabel, tempDirName);
         } catch (IOException e) {
@@ -139,7 +154,7 @@ public class ConfigDriveBuilder {
                 FileUtils.deleteDirectory(tempDir.toFile());
             }
         } catch (IOException ioe) {
-            LOG.warn("Failed to delete ConfigDrive temporary directory: " + tempDir.toString(), ioe);
+            LOGGER.warn("Failed to delete ConfigDrive temporary directory: " + tempDir.toString(), ioe);
         }
     }
 
@@ -151,7 +166,7 @@ public class ConfigDriveBuilder {
      */
     static String generateAndRetrieveIsoAsBase64Iso(String isoFileName, String driveLabel, String tempDirName) throws IOException {
         File tmpIsoStore = getFile(tempDirName, isoFileName);
-        Script command = new Script(getProgramToGenerateIso(), Duration.standardSeconds(300), LOG);
+        Script command = new Script(getProgramToGenerateIso(), Duration.standardSeconds(300), LOGGER);
         command.add("-o", tmpIsoStore.getAbsolutePath());
         command.add("-ldots");
         command.add("-allow-lowercase");
@@ -163,11 +178,11 @@ public class ConfigDriveBuilder {
         command.add("-r");
         command.add("-V", driveLabel);
         command.add(tempDirName);
-        LOG.debug("Executing config drive creation command: " + command.toString());
+        LOGGER.debug("Executing config drive creation command: " + command.toString());
         String result = command.execute();
         if (StringUtils.isNotBlank(result)) {
             String errMsg = "Unable to create iso file: " + isoFileName + " due to ge" + result;
-            LOG.warn(errMsg);
+            LOGGER.warn(errMsg);
             throw new CloudRuntimeException(errMsg);
         }
         File tmpIsoFile = getFile(tmpIsoStore.getAbsolutePath());
@@ -211,18 +226,36 @@ public class ConfigDriveBuilder {
     }
 
     /**
-     *  Writes the following empty JSON files:
-     *  <ul>
-     *      <li> vendor_data.json
-     *      <li> network_data.json
-     *  </ul>
-     *
-     *  If the folder does not exist and we cannot create it, we throw a {@link CloudRuntimeException}.
+     * First we generate a JSON object using {@link #getNetworkDataJsonObjectForNic(NicProfile, List)}, then we write it to a file called "network_data.json".
      */
-    static void writeVendorAndNetworkEmptyJsonFile(File openStackFolder) {
+    static void writeNetworkData(List<NicProfile> nics, Map<Long, List<Network.Service>> supportedServices, File openStackFolder) {
+        JsonObject finalNetworkData = new JsonObject();
+        if (needForGeneratingNetworkData(supportedServices)) {
+            for (NicProfile nic : nics) {
+                List<Network.Service> supportedService = supportedServices.get(nic.getId());
+                JsonObject networkData = getNetworkDataJsonObjectForNic(nic, supportedService);
+
+                mergeJsonArraysAndUpdateObject(finalNetworkData, networkData, "links", "id", "type");
+                mergeJsonArraysAndUpdateObject(finalNetworkData, networkData, "networks", "id", "type");
+                mergeJsonArraysAndUpdateObject(finalNetworkData, networkData, "services", "address", "type");
+            }
+        }
+
+        writeFile(openStackFolder, "network_data.json", finalNetworkData.toString());
+    }
+
+    static boolean needForGeneratingNetworkData(Map<Long, List<Network.Service>> supportedServices) {
+        return supportedServices.values().stream().anyMatch(services -> services.contains(Network.Service.Dhcp) || services.contains(Network.Service.Dns));
+    }
+
+    /**
+     *  Writes an empty JSON file named vendor_data.json in openStackFolder
+     *
+     *  If the folder does not exist, and we cannot create it, we throw a {@link CloudRuntimeException}.
+     */
+    static void writeVendorEmptyJsonFile(File openStackFolder) {
         if (openStackFolder.exists() || openStackFolder.mkdirs()) {
             writeFile(openStackFolder, "vendor_data.json", "{}");
-            writeFile(openStackFolder, "network_data.json", "{}");
         } else {
             throw new CloudRuntimeException("Failed to create folder " + openStackFolder);
         }
@@ -242,13 +275,127 @@ public class ConfigDriveBuilder {
             String dataType = item[CONFIGDATA_DIR];
             String fileName = item[CONFIGDATA_FILE];
             String content = item[CONFIGDATA_CONTENT];
-            LOG.debug(String.format("[createConfigDriveIsoForVM] dataType=%s, filename=%s, content=%s", dataType, fileName, (PASSWORD_FILE.equals(fileName) ? "********" : content)));
+            LOGGER.debug(String.format("[createConfigDriveIsoForVM] dataType=%s, filename=%s, content=%s", dataType, fileName, (PASSWORD_FILE.equals(fileName) ? "********" : content)));
 
             createFileInTempDirAnAppendOpenStackMetadataToJsonObject(tempDirName, metaData, dataType, fileName, content, customUserdataParams);
         }
         return metaData;
     }
 
+    /**
+     * Creates the {@link JsonObject} using @param nic's metadata. We expect the JSONObject to have the following entries:
+     * <ul>
+     *     <li> links </li>
+     *     <li> networks </li>
+     *     <li> services </li>
+     * </ul>
+     */
+    static JsonObject getNetworkDataJsonObjectForNic(NicProfile nic, List<Network.Service> supportedServices) {
+        JsonObject networkData = new JsonObject();
+
+        JsonArray links = getLinksJsonArrayForNic(nic);
+        JsonArray networks = getNetworksJsonArrayForNic(nic);
+        if (links.size() > 0) {
+            networkData.add("links", links);
+        }
+        if (networks.size() > 0) {
+            networkData.add("networks", networks);
+        }
+
+        JsonArray services = getServicesJsonArrayForNic(nic);
+        if (services.size() > 0) {
+            networkData.add("services", services);
+        }
+
+        return networkData;
+    }
+
+    static JsonArray getLinksJsonArrayForNic(NicProfile nic) {
+        JsonArray links = new JsonArray();
+        if (StringUtils.isNotBlank(nic.getMacAddress())) {
+            JsonObject link = new JsonObject();
+            link.addProperty("ethernet_mac_address", nic.getMacAddress());
+            link.addProperty("id", String.format("eth%d", nic.getDeviceId()));
+            link.addProperty("mtu", nic.getMtu() != null ? nic.getMtu() : DEFAULT_MTU);
+            link.addProperty("type", "phy");
+            links.add(link);
+        }
+        return links;
+    }
+
+    static JsonArray getNetworksJsonArrayForNic(NicProfile nic) {
+        JsonArray networks = new JsonArray();
+        if (StringUtils.isNotBlank(nic.getIPv4Address())) {
+            JsonObject ipv4Network = new JsonObject();
+            ipv4Network.addProperty("id", String.format("eth%d", nic.getDeviceId()));
+            ipv4Network.addProperty("ip_address", nic.getIPv4Address());
+            ipv4Network.addProperty("link", String.format("eth%d", nic.getDeviceId()));
+            ipv4Network.addProperty("netmask", nic.getIPv4Netmask());
+            ipv4Network.addProperty("network_id", nic.getUuid());
+            ipv4Network.addProperty("type", "ipv4");
+
+            JsonArray ipv4RouteArray = new JsonArray();
+            JsonObject ipv4Route = new JsonObject();
+            ipv4Route.addProperty("gateway", nic.getIPv4Gateway());
+            ipv4Route.addProperty("netmask", "0.0.0.0");
+            ipv4Route.addProperty("network", "0.0.0.0");
+            ipv4RouteArray.add(ipv4Route);
+
+            ipv4Network.add("routes", ipv4RouteArray);
+
+            networks.add(ipv4Network);
+        }
+
+        if (StringUtils.isNotBlank(nic.getIPv6Address())) {
+            JsonObject ipv6Network = new JsonObject();
+            ipv6Network.addProperty("id", String.format("eth%d", nic.getDeviceId()));
+            ipv6Network.addProperty("ip_address", nic.getIPv6Address());
+            ipv6Network.addProperty("link", String.format("eth%d", nic.getDeviceId()));
+            ipv6Network.addProperty("netmask", IPv6Network.fromString(nic.getIPv6Cidr()).getNetmask().toString());
+            ipv6Network.addProperty("network_id", nic.getUuid());
+            ipv6Network.addProperty("type", "ipv6");
+
+            JsonArray ipv6RouteArray = new JsonArray();
+            JsonObject ipv6Route = new JsonObject();
+            ipv6Route.addProperty("gateway", nic.getIPv6Gateway());
+            ipv6Route.addProperty("netmask", "0");
+            ipv6Route.addProperty("network", "::");
+            ipv6RouteArray.add(ipv6Route);
+
+            ipv6Network.add("routes", ipv6RouteArray);
+
+            networks.add(ipv6Network);
+        }
+        return networks;
+    }
+
+    static JsonArray getServicesJsonArrayForNic(NicProfile nic) {
+        JsonArray services = new JsonArray();
+        if (StringUtils.isNotBlank(nic.getIPv4Dns1())) {
+            services.add(getDnsServiceObject(nic.getIPv4Dns1()));
+        }
+
+        if (StringUtils.isNotBlank(nic.getIPv4Dns2())) {
+            services.add(getDnsServiceObject(nic.getIPv4Dns2()));
+        }
+
+        if (StringUtils.isNotBlank(nic.getIPv6Dns1())) {
+            services.add(getDnsServiceObject(nic.getIPv6Dns1()));
+        }
+
+        if (StringUtils.isNotBlank(nic.getIPv6Dns2())) {
+            services.add(getDnsServiceObject(nic.getIPv6Dns2()));
+        }
+        return services;
+    }
+
+    private static JsonObject getDnsServiceObject(String dnsAddress) {
+        JsonObject dnsService = new JsonObject();
+        dnsService.addProperty("address", dnsAddress);
+        dnsService.addProperty("type", "dns");
+        return dnsService;
+    }
+
     static void createFileInTempDirAnAppendOpenStackMetadataToJsonObject(String tempDirName, JsonObject metaData, String dataType, String fileName, String content, Map<String, String> customUserdataParams) {
         if (StringUtils.isBlank(dataType)) {
             return;
@@ -299,10 +446,10 @@ public class ConfigDriveBuilder {
         String userDataFilePath = tempDirName + ConfigDrive.cloudStackConfigDriveName + "userdata/user_data.txt";
         File file = getFile(userDataFilePath);
         if (file.exists()) {
-            Script hardLink = new Script("ln", Duration.standardSeconds(300), LOG);
+            Script hardLink = new Script("ln", Duration.standardSeconds(300), LOGGER);
             hardLink.add(userDataFilePath);
             hardLink.add(tempDirName + ConfigDrive.openStackConfigDriveName + "user_data");
-            LOG.debug("execute command: " + hardLink.toString());
+            LOGGER.debug("execute command: " + hardLink.toString());
 
             String executionResult = hardLink.execute();
             if (StringUtils.isNotBlank(executionResult)) {
