@@ -51,7 +51,8 @@ import org.apache.cloudstack.storage.datastore.db.VolumeDataStoreDao;
 import org.apache.cloudstack.storage.datastore.db.VolumeDataStoreVO;
 import org.apache.cloudstack.storage.image.datastore.ImageStoreEntity;
 import org.apache.cloudstack.storage.to.PrimaryDataStoreTO;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 import org.springframework.stereotype.Component;
 
 import com.cloud.agent.api.Answer;
@@ -81,7 +82,7 @@ import com.cloud.vm.VirtualMachineManager;
 
 @Component
 public class AncientDataMotionStrategy implements DataMotionStrategy {
-    private static final Logger s_logger = Logger.getLogger(AncientDataMotionStrategy.class);
+    protected Logger logger = LogManager.getLogger(getClass());
     private static final String NO_REMOTE_ENDPOINT_SSVM = "No remote endpoint to send command, check if host or ssvm is down?";
     private static final String NO_REMOTE_ENDPOINT_WITH_ENCRYPTION = "No remote endpoint to send command, unable to find a valid endpoint. Requires encryption support: %s";
 
@@ -126,8 +127,8 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
         if (destStoreTO instanceof NfsTO || destStoreTO.getRole() == DataStoreRole.ImageCache) {
             return false;
         }
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("needCacheStorage true, dest at " + destTO.getPath() + " dest role " + destStoreTO.getRole().toString() + srcTO.getPath() + " src role " +
+        if (logger.isDebugEnabled()) {
+            logger.debug("needCacheStorage true, dest at " + destTO.getPath() + " dest role " + destStoreTO.getRole().toString() + srcTO.getPath() + " src role " +
                 srcStoreTO.getRole().toString());
         }
         return true;
@@ -157,7 +158,7 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
         } else if (destScope.getScopeId() != null) {
             selectedScope = getZoneScope(destScope);
         } else {
-            s_logger.warn("Cannot find a zone-wide scope for movement that needs a cache storage");
+            logger.warn("Cannot find a zone-wide scope for movement that needs a cache storage");
         }
         return selectedScope;
     }
@@ -177,7 +178,7 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
                     VirtualMachineManager.ExecuteInSequence.value());
             EndPoint ep = destHost != null ? RemoteHostEndPoint.getHypervisorHostEndPoint(destHost) : selector.select(srcForCopy, destData);
             if (ep == null) {
-                s_logger.error(NO_REMOTE_ENDPOINT_SSVM);
+                logger.error(NO_REMOTE_ENDPOINT_SSVM);
                 answer = new Answer(cmd, false, NO_REMOTE_ENDPOINT_SSVM);
             } else {
                 answer = ep.sendMessage(cmd);
@@ -193,19 +194,19 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
                      destData.getType() == DataObjectType.TEMPLATE)) {
                     // volume transfer from primary to secondary. Volume transfer between primary pools are already handled by copyVolumeBetweenPools
                     // Delete cache in order to certainly transfer a latest image.
-                    if (s_logger.isDebugEnabled()) s_logger.debug("Delete " + cacheType + " cache(id: " + cacheId +
+                    if (logger.isDebugEnabled()) logger.debug("Delete " + cacheType + " cache(id: " + cacheId +
                                    ", uuid: " + cacheUuid + ")");
                     cacheMgr.deleteCacheObject(srcForCopy);
                 } else {
                     // for template, we want to leave it on cache for performance reason
                     if ((answer == null || !answer.getResult()) && srcForCopy.getRefCount() < 2) {
                         // cache object created by this copy, not already there
-                        s_logger.warn("Copy may not be handled correctly by agent(id: " + (ep != null ? ep.getId() : "\"unspecified\"") + ")." +
+                        logger.warn("Copy may not be handled correctly by agent(id: " + (ep != null ? ep.getId() : "\"unspecified\"") + ")." +
                                       " Delete " + cacheType + " cache(id: " + cacheId +
                                       ", uuid: " + cacheUuid + ")");
                         cacheMgr.deleteCacheObject(srcForCopy);
                     } else {
-                        if (s_logger.isDebugEnabled()) s_logger.debug("Decrease reference count of " + cacheType +
+                        if (logger.isDebugEnabled()) logger.debug("Decrease reference count of " + cacheType +
                                        " cache(id: " + cacheId + ", uuid: " + cacheUuid + ")");
                         cacheMgr.releaseCacheObject(srcForCopy);
                     }
@@ -213,7 +214,7 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
             }
             return answer;
         } catch (Exception e) {
-            if (s_logger.isDebugEnabled()) s_logger.debug("copy object failed: ", e);
+            if (logger.isDebugEnabled()) logger.debug("copy object failed: ", e);
             if (cacheData != null) {
                 cacheMgr.deleteCacheObject(cacheData);
             }
@@ -300,7 +301,7 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
 
             Answer answer = null;
             if (ep == null) {
-                s_logger.error(NO_REMOTE_ENDPOINT_SSVM);
+                logger.error(NO_REMOTE_ENDPOINT_SSVM);
                 answer = new Answer(cmd, false, NO_REMOTE_ENDPOINT_SSVM);
             } else {
                 answer = ep.sendMessage(cmd);
@@ -308,7 +309,7 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
 
             return answer;
         } catch (Exception e) {
-            s_logger.error(basicErrMsg, e);
+            logger.error(basicErrMsg, e);
             throw new CloudRuntimeException(basicErrMsg);
         } finally {
             if (!(storTO instanceof NfsTO)) {
@@ -324,14 +325,14 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
             EndPoint ep = selector.select(volume, anyVolumeRequiresEncryption(volume));
             Answer answer = null;
             if (ep == null) {
-                s_logger.error(NO_REMOTE_ENDPOINT_SSVM);
+                logger.error(NO_REMOTE_ENDPOINT_SSVM);
                 answer = new Answer(cmd, false, NO_REMOTE_ENDPOINT_SSVM);
             } else {
                 answer = ep.sendMessage(cmd);
             }
             return answer;
         } catch (Exception e) {
-            if (s_logger.isDebugEnabled()) s_logger.debug("Failed to send to storage pool", e);
+            if (logger.isDebugEnabled()) logger.debug("Failed to send to storage pool", e);
             throw new CloudRuntimeException("Failed to send to storage pool", e);
         }
     }
@@ -364,7 +365,7 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
                 Answer answer = null;
                 if (ep == null) {
                     String errMsg = String.format(NO_REMOTE_ENDPOINT_WITH_ENCRYPTION, encryptionRequired);
-                    s_logger.error(errMsg);
+                    logger.error(errMsg);
                     answer = new Answer(cmd, false, errMsg);
                 } else {
                     answer = ep.sendMessage(cmd);
@@ -388,7 +389,7 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
 
                 if (answer == null || !answer.getResult()) {
                     if (answer != null) {
-                        if (s_logger.isDebugEnabled()) s_logger.debug("copy to image store failed: " + answer.getDetails());
+                        if (logger.isDebugEnabled()) logger.debug("copy to image store failed: " + answer.getDetails());
                     }
                     objOnImageStore.processEvent(Event.OperationFailed);
                     imageStore.delete(objOnImageStore);
@@ -403,7 +404,7 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
                 EndPoint ep = selector.select(objOnImageStore, destData, encryptionRequired);
                 if (ep == null) {
                     String errMsg = String.format(NO_REMOTE_ENDPOINT_WITH_ENCRYPTION, encryptionRequired);
-                    s_logger.error(errMsg);
+                    logger.error(errMsg);
                     answer = new Answer(cmd, false, errMsg);
                 } else {
                     answer = ep.sendMessage(cmd);
@@ -411,7 +412,7 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
 
                 if (answer == null || !answer.getResult()) {
                     if (answer != null) {
-                        if (s_logger.isDebugEnabled()) s_logger.debug("copy to primary store failed: " + answer.getDetails());
+                        if (logger.isDebugEnabled()) logger.debug("copy to primary store failed: " + answer.getDetails());
                     }
                     objOnImageStore.processEvent(Event.OperationFailed);
                     imageStore.delete(objOnImageStore);
@@ -422,7 +423,7 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
                     objOnImageStore.processEvent(Event.OperationFailed);
                     imageStore.delete(objOnImageStore);
                 }
-                s_logger.error("Failed to perform operation: "+ e.getLocalizedMessage());
+                logger.error("Failed to perform operation: "+ e.getLocalizedMessage());
                 throw e;
             }
 
@@ -436,7 +437,7 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
             Answer answer = null;
             if (ep == null) {
                 String errMsg = String.format(NO_REMOTE_ENDPOINT_WITH_ENCRYPTION, encryptionRequired);
-                s_logger.error(errMsg);
+                logger.error(errMsg);
                 answer = new Answer(cmd, false, errMsg);
             } else {
                 answer = ep.sendMessage(cmd);
@@ -468,19 +469,19 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
         Answer answer = null;
         if (ep == null) {
             String errMsg = String.format(NO_REMOTE_ENDPOINT_WITH_ENCRYPTION, encryptionRequired);
-            s_logger.error(errMsg);
+            logger.error(errMsg);
             answer = new Answer(command, false, errMsg);
         } else {
-            if (s_logger.isDebugEnabled()) s_logger.debug("Sending MIGRATE_COPY request to node " + ep);
+            if (logger.isDebugEnabled()) logger.debug("Sending MIGRATE_COPY request to node " + ep);
             answer = ep.sendMessage(command);
-            if (s_logger.isDebugEnabled()) s_logger.debug("Received MIGRATE_COPY response from node with answer: " + answer);
+            if (logger.isDebugEnabled()) logger.debug("Received MIGRATE_COPY response from node with answer: " + answer);
         }
 
         if (answer == null || !answer.getResult()) {
             throw new CloudRuntimeException("Failed to migrate volume " + volume + " to storage pool " + destPool);
         } else {
             // Update the volume details after migration.
-            if (s_logger.isDebugEnabled()) s_logger.debug("MIGRATE_COPY updating volume");
+            if (logger.isDebugEnabled()) logger.debug("MIGRATE_COPY updating volume");
 
             VolumeVO volumeVo = volDao.findById(volume.getId());
             Long oldPoolId = volume.getPoolId();
@@ -500,7 +501,7 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
             }
             volumeVo.setFolder(folder);
             volDao.update(volume.getId(), volumeVo);
-            if (s_logger.isDebugEnabled()) s_logger.debug("MIGRATE_COPY update volume data complete");
+            if (logger.isDebugEnabled()) logger.debug("MIGRATE_COPY update volume data complete");
 
         }
 
@@ -513,7 +514,7 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
         Answer answer = null;
         String errMsg = null;
         try {
-            if (s_logger.isDebugEnabled()) s_logger.debug("copyAsync inspecting src type " + srcData.getType().toString() + " copyAsync inspecting dest type " + destData.getType().toString());
+            if (logger.isDebugEnabled()) logger.debug("copyAsync inspecting src type " + srcData.getType().toString() + " copyAsync inspecting dest type " + destData.getType().toString());
             if (srcData.getType() == DataObjectType.SNAPSHOT && destData.getType() == DataObjectType.VOLUME) {
                 answer = copyVolumeFromSnapshot(srcData, destData);
             } else if (srcData.getType() == DataObjectType.SNAPSHOT && destData.getType() == DataObjectType.TEMPLATE) {
@@ -522,16 +523,16 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
                 answer = cloneVolume(srcData, destData);
             } else if (destData.getType() == DataObjectType.VOLUME && srcData.getType() == DataObjectType.VOLUME &&
                 srcData.getDataStore().getRole() == DataStoreRole.Primary && destData.getDataStore().getRole() == DataStoreRole.Primary) {
-                if (s_logger.isDebugEnabled()) s_logger.debug("About to MIGRATE copy between datasources");
+                if (logger.isDebugEnabled()) logger.debug("About to MIGRATE copy between datasources");
                 if (srcData.getId() == destData.getId()) {
                     // The volume has to be migrated across storage pools.
-                    if (s_logger.isDebugEnabled()) s_logger.debug("MIGRATE copy using migrateVolumeToPool STARTING");
+                    if (logger.isDebugEnabled()) logger.debug("MIGRATE copy using migrateVolumeToPool STARTING");
                     answer = migrateVolumeToPool(srcData, destData);
-                    if (s_logger.isDebugEnabled()) s_logger.debug("MIGRATE copy using migrateVolumeToPool DONE: " + answer.getResult());
+                    if (logger.isDebugEnabled()) logger.debug("MIGRATE copy using migrateVolumeToPool DONE: " + answer.getResult());
                 } else {
-                    if (s_logger.isDebugEnabled()) s_logger.debug("MIGRATE copy using copyVolumeBetweenPools STARTING");
+                    if (logger.isDebugEnabled()) logger.debug("MIGRATE copy using copyVolumeBetweenPools STARTING");
                     answer = copyVolumeBetweenPools(srcData, destData);
-                    if (s_logger.isDebugEnabled()) s_logger.debug("MIGRATE copy using copyVolumeBetweenPools DONE: " + answer.getResult());
+                    if (logger.isDebugEnabled()) logger.debug("MIGRATE copy using copyVolumeBetweenPools DONE: " + answer.getResult());
                 }
             } else if (srcData.getType() == DataObjectType.SNAPSHOT && destData.getType() == DataObjectType.SNAPSHOT) {
                 answer = copySnapshot(srcData, destData);
@@ -543,7 +544,7 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
                 errMsg = answer.getDetails();
             }
         } catch (Exception e) {
-            if (s_logger.isDebugEnabled()) s_logger.debug("copy failed", e);
+            if (logger.isDebugEnabled()) logger.debug("copy failed", e);
             errMsg = e.toString();
         }
         CopyCommandResult result = new CopyCommandResult(null, answer);
@@ -574,7 +575,7 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
         CopyCommand cmd = new CopyCommand(srcData.getTO(), addFullCloneAndDiskprovisiongStrictnessFlagOnVMwareDest(destData.getTO()), _createprivatetemplatefromsnapshotwait, VirtualMachineManager.ExecuteInSequence.value());
         Answer answer = null;
         if (ep == null) {
-            s_logger.error(NO_REMOTE_ENDPOINT_SSVM);
+            logger.error(NO_REMOTE_ENDPOINT_SSVM);
             answer = new Answer(cmd, false, NO_REMOTE_ENDPOINT_SSVM);
         } else {
             answer = ep.sendMessage(cmd);
@@ -614,7 +615,7 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
                 cmd.setOptions(options);
                 EndPoint ep = selector.select(srcData, destData, encryptionRequired);
                 if (ep == null) {
-                    s_logger.error(NO_REMOTE_ENDPOINT_SSVM);
+                    logger.error(NO_REMOTE_ENDPOINT_SSVM);
                     answer = new Answer(cmd, false, NO_REMOTE_ENDPOINT_SSVM);
                 } else {
                     answer = ep.sendMessage(cmd);
@@ -625,7 +626,7 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
                 cmd.setOptions(options);
                 EndPoint ep = selector.select(srcData, destData, StorageAction.BACKUPSNAPSHOT, encryptionRequired);
                 if (ep == null) {
-                    s_logger.error(NO_REMOTE_ENDPOINT_SSVM);
+                    logger.error(NO_REMOTE_ENDPOINT_SSVM);
                     answer = new Answer(cmd, false, NO_REMOTE_ENDPOINT_SSVM);
                 } else {
                     answer = ep.sendMessage(cmd);
@@ -638,7 +639,7 @@ public class AncientDataMotionStrategy implements DataMotionStrategy {
             }
             return answer;
         } catch (Exception e) {
-            if (s_logger.isDebugEnabled()) s_logger.debug("copy snasphot failed: ", e);
+            if (logger.isDebugEnabled()) logger.debug("copy snasphot failed: ", e);
             if (cacheData != null) {
                 cacheMgr.deleteCacheObject(cacheData);
             }
