@@ -23,9 +23,11 @@ import java.util.Map;
 
 import javax.inject.Inject;
 
+import com.cloud.cpu.CPU;
 import com.cloud.storage.StorageManager;
 import com.cloud.user.UserData;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 
 import org.apache.cloudstack.engine.subsystem.api.storage.DataObjectInStore;
 import org.apache.cloudstack.engine.subsystem.api.storage.DataStore;
@@ -60,7 +62,7 @@ import org.apache.commons.lang3.StringUtils;
 
 @SuppressWarnings("serial")
 public class TemplateObject implements TemplateInfo {
-    private static final Logger s_logger = Logger.getLogger(TemplateObject.class);
+    protected Logger logger = LogManager.getLogger(getClass());
     private VMTemplateVO imageVO;
     private DataStore dataStore;
     private String url;
@@ -83,7 +85,7 @@ public class TemplateObject implements TemplateInfo {
     protected void configure(VMTemplateVO template, DataStore dataStore) {
         if (template == null) {
             String msg = String.format("Template Object is not properly initialised %s", this.toString());
-            s_logger.warn(msg);
+            logger.warn(msg);
         }
         imageVO = template;
         this.dataStore = dataStore;
@@ -103,7 +105,7 @@ public class TemplateObject implements TemplateInfo {
     public VMTemplateVO getImage() {
         if (imageVO == null) {
             String msg = String.format("Template Object is not properly initialised %s", this.toString());
-            s_logger.error(msg);
+            logger.error(msg);
         } // somehow the nullpointer is needed : refacter needed!?!
         return imageVO;
     }
@@ -254,10 +256,10 @@ public class TemplateObject implements TemplateInfo {
             }
             objectInStoreMgr.update(this, event);
         } catch (NoTransitionException e) {
-            s_logger.debug("failed to update state", e);
+            logger.debug("failed to update state", e);
             throw new CloudRuntimeException("Failed to update state" + e.toString());
         } catch (Exception ex) {
-            s_logger.debug("failed to process event and answer", ex);
+            logger.debug("failed to process event and answer", ex);
             objectInStoreMgr.delete(this);
             throw new CloudRuntimeException("Failed to process event", ex);
         } finally {
@@ -349,6 +351,11 @@ public class TemplateObject implements TemplateInfo {
         return imageVO.getUserDataOverridePolicy();
     }
 
+    @Override
+    public CPU.CPUArch getArch() {
+        return imageVO.getArch();
+    }
+
     @Override
     public DataTO getTO() {
         DataTO to = null;
@@ -409,7 +416,7 @@ public class TemplateObject implements TemplateInfo {
         // Marking downloaded templates for deletion, but might skip any deletion handled for failed templates.
         // Only templates not downloaded and in error state (with no install path) cannot be deleted from the datastore, so doesn't impact last behavior for templates with other states
         if (downloadStatus == null  || downloadStatus == Status.NOT_DOWNLOADED || (downloadStatus == Status.DOWNLOAD_ERROR && downloadPercent == 0)) {
-            s_logger.debug("Template: " + getId() + " cannot be deleted from the store: " + getDataStore().getId());
+            logger.debug("Template: " + getId() + " cannot be deleted from the store: " + getDataStore().getId());
             return false;
         }
 
