@@ -57,7 +57,8 @@ import org.apache.cloudstack.storage.datastore.db.SnapshotDataStoreVO;
 import org.apache.cloudstack.storage.heuristics.HeuristicRuleHelper;
 import org.apache.cloudstack.storage.image.datastore.ImageStoreEntity;
 import org.apache.cloudstack.storage.to.SnapshotObjectTO;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 
 import com.cloud.agent.api.Answer;
 import com.cloud.configuration.Config;
@@ -79,7 +80,7 @@ import com.cloud.utils.exception.CloudRuntimeException;
 import com.cloud.utils.fsm.NoTransitionException;
 
 public class SnapshotServiceImpl implements SnapshotService {
-    private static final Logger s_logger = Logger.getLogger(SnapshotServiceImpl.class);
+    protected Logger logger = LogManager.getLogger(getClass());
     @Inject
     protected SnapshotDao _snapshotDao;
     @Inject
@@ -176,7 +177,7 @@ public class SnapshotServiceImpl implements SnapshotService {
             _sslCopy = Boolean.parseBoolean(sslCfg);
         }
         if(_sslCopy && (_ssvmUrlDomain == null || _ssvmUrlDomain.isEmpty())){
-            s_logger.warn("Empty secondary storage url domain, ignoring SSL");
+            logger.warn("Empty secondary storage url domain, ignoring SSL");
             _sslCopy = false;
         }
         if (_sslCopy) {
@@ -197,12 +198,12 @@ public class SnapshotServiceImpl implements SnapshotService {
         AsyncCallFuture<SnapshotResult> future = context.future;
         SnapshotResult snapResult = new SnapshotResult(snapshot, result.getAnswer());
         if (result.isFailed()) {
-            s_logger.debug("create snapshot " + context.snapshot.getName() + " failed: " + result.getResult());
+            logger.debug("create snapshot " + context.snapshot.getName() + " failed: " + result.getResult());
             try {
                 snapshot.processEvent(Snapshot.Event.OperationFailed);
                 snapshot.processEvent(Event.OperationFailed);
             } catch (Exception e) {
-                s_logger.debug("Failed to update snapshot state due to " + e.getMessage());
+                logger.debug("Failed to update snapshot state due to " + e.getMessage());
             }
 
             snapResult.setResult(result.getResult());
@@ -214,12 +215,12 @@ public class SnapshotServiceImpl implements SnapshotService {
             snapshot.processEvent(Event.OperationSuccessed, result.getAnswer());
             snapshot.processEvent(Snapshot.Event.OperationSucceeded);
         } catch (Exception e) {
-            s_logger.debug("Failed to create snapshot: ", e);
+            logger.debug("Failed to create snapshot: ", e);
             snapResult.setResult(e.toString());
             try {
                 snapshot.processEvent(Snapshot.Event.OperationFailed);
             } catch (NoTransitionException e1) {
-                s_logger.debug("Failed to change snapshot state: " + e1.toString());
+                logger.debug("Failed to change snapshot state: " + e1.toString());
             }
         }
 
@@ -235,25 +236,25 @@ public class SnapshotServiceImpl implements SnapshotService {
         try {
             snapshotOnPrimary = (SnapshotObject)snap.getDataStore().create(snapshot);
         } catch (Exception e) {
-            s_logger.debug("Failed to create snapshot state on data store due to " + e.getMessage());
+            logger.debug("Failed to create snapshot state on data store due to " + e.getMessage());
             throw new CloudRuntimeException(e);
         }
 
         try {
             snapshotOnPrimary.processEvent(Snapshot.Event.CreateRequested);
         } catch (NoTransitionException e) {
-            s_logger.debug("Failed to change snapshot state: " + e.toString());
+            logger.debug("Failed to change snapshot state: " + e.toString());
             throw new CloudRuntimeException(e);
         }
 
         try {
             snapshotOnPrimary.processEvent(Event.CreateOnlyRequested);
         } catch (Exception e) {
-            s_logger.debug("Failed to change snapshot state: " + e.toString());
+            logger.debug("Failed to change snapshot state: " + e.toString());
             try {
                 snapshotOnPrimary.processEvent(Snapshot.Event.OperationFailed);
             } catch (NoTransitionException e1) {
-                s_logger.debug("Failed to change snapshot state: " + e1.toString());
+                logger.debug("Failed to change snapshot state: " + e1.toString());
             }
             throw new CloudRuntimeException(e);
         }
@@ -266,12 +267,12 @@ public class SnapshotServiceImpl implements SnapshotService {
             PrimaryDataStoreDriver primaryStore = (PrimaryDataStoreDriver)snapshotOnPrimary.getDataStore().getDriver();
             primaryStore.takeSnapshot(snapshot, caller);
         } catch (Exception e) {
-            s_logger.debug("Failed to take snapshot: " + snapshot.getId(), e);
+            logger.debug("Failed to take snapshot: " + snapshot.getId(), e);
             try {
                 snapshot.processEvent(Snapshot.Event.OperationFailed);
                 snapshot.processEvent(Event.OperationFailed);
             } catch (NoTransitionException e1) {
-                s_logger.debug("Failed to change state for event: OperationFailed", e);
+                logger.debug("Failed to change state for event: OperationFailed", e);
             }
             throw new CloudRuntimeException("Failed to take snapshot" + snapshot.getId());
         }
@@ -284,10 +285,10 @@ public class SnapshotServiceImpl implements SnapshotService {
                     snap.getName(), null, null, snapshotOnPrimary.getSize(), snapshotOnPrimary.getSize(), snap.getClass().getName(), snap.getUuid());
             return result;
         } catch (InterruptedException e) {
-            s_logger.debug("Failed to create snapshot", e);
+            logger.debug("Failed to create snapshot", e);
             throw new CloudRuntimeException("Failed to create snapshot", e);
         } catch (ExecutionException e) {
-            s_logger.debug("Failed to create snapshot", e);
+            logger.debug("Failed to create snapshot", e);
             throw new CloudRuntimeException("Failed to create snapshot", e);
         }
     }
@@ -360,7 +361,7 @@ public class SnapshotServiceImpl implements SnapshotService {
             caller.setCallback(caller.getTarget().copySnapshotAsyncCallback(null, null)).setContext(context);
             motionSrv.copyAsync(snapshot, snapshotOnImageStore, caller);
         } catch (Exception e) {
-            s_logger.debug("Failed to copy snapshot", e);
+            logger.debug("Failed to copy snapshot", e);
             result.setResult("Failed to copy snapshot:" + e.toString());
             try {
                 // When error archiving an already existing snapshot, emit OperationNotPerformed.
@@ -371,7 +372,7 @@ public class SnapshotServiceImpl implements SnapshotService {
                     snapObj.processEvent(Snapshot.Event.OperationFailed);
                 }
             } catch (NoTransitionException e1) {
-                s_logger.debug("Failed to change state: " + e1.toString());
+                logger.debug("Failed to change state: " + e1.toString());
             }
             future.complete(result);
         }
@@ -384,10 +385,10 @@ public class SnapshotServiceImpl implements SnapshotService {
             SnapshotInfo destSnapshot = res.getSnapshot();
             return destSnapshot;
         } catch (InterruptedException e) {
-            s_logger.debug("failed copy snapshot", e);
+            logger.debug("failed copy snapshot", e);
             throw new CloudRuntimeException("Failed to copy snapshot", e);
         } catch (ExecutionException e) {
-            s_logger.debug("Failed to copy snapshot", e);
+            logger.debug("Failed to copy snapshot", e);
             throw new CloudRuntimeException("Failed to copy snapshot", e);
         }
 
@@ -413,7 +414,7 @@ public class SnapshotServiceImpl implements SnapshotService {
                     cleanupOnSnapshotBackupFailure(context.srcSnapshot);
                 }
             } catch (SnapshotBackupException e) {
-                s_logger.debug("Failed to create backup: " + e.toString());
+                logger.debug("Failed to create backup: " + e.toString());
             }
             snapResult.setResult(result.getResult());
             future.complete(snapResult);
@@ -427,7 +428,7 @@ public class SnapshotServiceImpl implements SnapshotService {
             snapResult = new SnapshotResult(_snapshotFactory.getSnapshot(destSnapshot.getId(), destSnapshot.getDataStore()), copyCmdAnswer);
             future.complete(snapResult);
         } catch (Exception e) {
-            s_logger.debug("Failed to update snapshot state", e);
+            logger.debug("Failed to update snapshot state", e);
             snapResult.setResult(e.toString());
             future.complete(snapResult);
         }
@@ -451,7 +452,7 @@ public class SnapshotServiceImpl implements SnapshotService {
             snapResult = new SnapshotResult(_snapshotFactory.getSnapshot(destSnapshot.getId(), destSnapshot.getDataStore()), answer);
             future.complete(snapResult);
         } catch (Exception e) {
-            s_logger.debug("Failed to update snapshot state", e);
+            logger.debug("Failed to update snapshot state", e);
             snapResult.setResult(e.toString());
             future.complete(snapResult);
         }
@@ -485,7 +486,7 @@ public class SnapshotServiceImpl implements SnapshotService {
         SnapshotResult res = null;
         try {
             if (result.isFailed()) {
-                s_logger.debug(String.format("Failed to delete snapshot [%s] due to: [%s].", snapshot.getUuid(), result.getResult()));
+                logger.debug(String.format("Failed to delete snapshot [%s] due to: [%s].", snapshot.getUuid(), result.getResult()));
                 snapshot.processEvent(ObjectInDataStoreStateMachine.Event.OperationFailed);
                 res = new SnapshotResult(context.snapshot, null);
                 res.setResult(result.getResult());
@@ -494,8 +495,8 @@ public class SnapshotServiceImpl implements SnapshotService {
                 res = new SnapshotResult(context.snapshot, null);
             }
         } catch (Exception e) {
-            s_logger.error(String.format("An exception occurred while processing an event in delete snapshot callback from snapshot [%s].", snapshot.getUuid()));
-            s_logger.debug(String.format("Exception while processing an event in delete snapshot callback from snapshot [%s].", snapshot.getUuid()), e);
+            logger.error(String.format("An exception occurred while processing an event in delete snapshot callback from snapshot [%s].", snapshot.getUuid()));
+            logger.debug(String.format("Exception while processing an event in delete snapshot callback from snapshot [%s].", snapshot.getUuid()), e);
             res.setResult(e.toString());
         }
         future.complete(res);
@@ -509,14 +510,14 @@ public class SnapshotServiceImpl implements SnapshotService {
         SnapshotResult res = null;
         try {
             if (result.isFailed()) {
-                s_logger.debug("revert snapshot failed" + result.getResult());
+                logger.debug("revert snapshot failed" + result.getResult());
                 res = new SnapshotResult(context.snapshot, null);
                 res.setResult(result.getResult());
             } else {
                 res = new SnapshotResult(context.snapshot, null);
             }
         } catch (Exception e) {
-            s_logger.debug("Failed to in revertSnapshotCallback", e);
+            logger.debug("Failed to in revertSnapshotCallback", e);
             res.setResult(e.toString());
         }
         future.complete(res);
@@ -540,11 +541,11 @@ public class SnapshotServiceImpl implements SnapshotService {
             if (result.isFailed()) {
                 throw new CloudRuntimeException(result.getResult());
             }
-            s_logger.debug(String.format("Successfully deleted snapshot [%s] with ID [%s].", snapInfo.getName(), snapInfo.getUuid()));
+            logger.debug(String.format("Successfully deleted snapshot [%s] with ID [%s].", snapInfo.getName(), snapInfo.getUuid()));
             return true;
         } catch (InterruptedException | ExecutionException e) {
-            s_logger.error(String.format("Failed to delete snapshot [%s] due to: [%s].", snapInfo.getUuid(), e.getMessage()));
-            s_logger.debug(String.format("Failed to delete snapshot [%s].", snapInfo.getUuid()), e);
+            logger.error(String.format("Failed to delete snapshot [%s] due to: [%s].", snapInfo.getUuid(), e.getMessage()));
+            logger.debug(String.format("Failed to delete snapshot [%s].", snapInfo.getUuid()), e);
         }
 
         return false;
@@ -555,7 +556,7 @@ public class SnapshotServiceImpl implements SnapshotService {
         PrimaryDataStore store = null;
         SnapshotInfo snapshotOnPrimaryStore = _snapshotFactory.getSnapshotOnPrimaryStore(snapshot.getId());
         if (snapshotOnPrimaryStore == null) {
-            s_logger.warn("Cannot find an entry for snapshot " + snapshot.getId() + " on primary storage pools, searching with volume's primary storage pool");
+            logger.warn("Cannot find an entry for snapshot " + snapshot.getId() + " on primary storage pools, searching with volume's primary storage pool");
             VolumeInfo volumeInfo = volFactory.getVolume(snapshot.getVolumeId(), DataStoreRole.Primary);
             store = (PrimaryDataStore)volumeInfo.getDataStore();
         } else {
@@ -577,9 +578,9 @@ public class SnapshotServiceImpl implements SnapshotService {
             }
             return true;
         } catch (InterruptedException e) {
-            s_logger.debug("revert snapshot is failed: " + e.toString());
+            logger.debug("revert snapshot is failed: " + e.toString());
         } catch (ExecutionException e) {
-            s_logger.debug("revert snapshot is failed: " + e.toString());
+            logger.debug("revert snapshot is failed: " + e.toString());
         }
 
         return false;
@@ -608,13 +609,13 @@ public class SnapshotServiceImpl implements SnapshotService {
             if (snaphsot.getState() != Snapshot.State.BackedUp) {
                 List<SnapshotDataStoreVO> snapshotDataStoreVOs = _snapshotStoreDao.findBySnapshotId(snapshotId);
                 for (SnapshotDataStoreVO snapshotDataStoreVO : snapshotDataStoreVOs) {
-                    s_logger.debug("Remove snapshot " + snapshotId + ", status " + snapshotDataStoreVO.getState() +
+                    logger.debug("Remove snapshot " + snapshotId + ", status " + snapshotDataStoreVO.getState() +
                             " on snapshot_store_ref table with id: " + snapshotDataStoreVO.getId());
 
                     _snapshotStoreDao.remove(snapshotDataStoreVO.getId());
                 }
 
-                s_logger.debug("Remove snapshot " + snapshotId + " status " + snaphsot.getState() + " from snapshot table");
+                logger.debug("Remove snapshot " + snapshotId + " status " + snaphsot.getState() + " from snapshot table");
                 _snapshotDao.remove(snapshotId);
             }
         }
@@ -631,8 +632,8 @@ public class SnapshotServiceImpl implements SnapshotService {
             throw new CloudRuntimeException("Cannot find an entry in snapshot_store_ref for snapshot " + snapshotId + " on region store: " + store.getName());
         }
         if (snapOnStore.getPath() == null || snapOnStore.getPath().length() == 0) {
-            if (s_logger.isDebugEnabled()) {
-                s_logger.debug("sync snapshot " + snapshotId + " from cache to object store...");
+            if (logger.isDebugEnabled()) {
+                logger.debug("sync snapshot " + snapshotId + " from cache to object store...");
             }
             // snapshot is not on region store yet, sync to region store
             SnapshotInfo srcSnapshot = _snapshotFactory.getReadySnapshotOnCache(snapshotId);
@@ -688,7 +689,7 @@ public class SnapshotServiceImpl implements SnapshotService {
             }
             future.complete(res);
         } catch (Exception e) {
-            s_logger.debug("Failed to process sync snapshot callback", e);
+            logger.debug("Failed to process sync snapshot callback", e);
             res.setResult(e.toString());
             future.complete(res);
         }
@@ -702,7 +703,7 @@ public class SnapshotServiceImpl implements SnapshotService {
         try {
             object.processEvent(event);
         } catch (NoTransitionException e) {
-            s_logger.debug("Unable to update the state " + e.toString());
+            logger.debug("Unable to update the state " + e.toString());
         }
     }
 
@@ -721,7 +722,7 @@ public class SnapshotServiceImpl implements SnapshotService {
                     _snapshotDetailsDao.removeDetail(srcSnapshot.getId(), AsyncJob.Constants.MS_ID);
                     _snapshotDao.remove(srcSnapshot.getId());
                 } catch (NoTransitionException ex) {
-                    s_logger.debug("Failed to create backup " + ex.toString());
+                    logger.debug("Failed to create backup " + ex.toString());
                     throw new CloudRuntimeException("Failed to backup snapshot" + snapshot.getId());
                 }
             }
@@ -734,16 +735,16 @@ public class SnapshotServiceImpl implements SnapshotService {
         SnapshotObject snapshotForCopy = (SnapshotObject)_snapshotFactory.getSnapshot(snapshot, store);
         snapshotForCopy.setUrl(copyUrl);
 
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Mark snapshot_store_ref entry as Creating");
+        if (logger.isDebugEnabled()) {
+            logger.debug("Mark snapshot_store_ref entry as Creating");
         }
         AsyncCallFuture<SnapshotResult> future = new AsyncCallFuture<SnapshotResult>();
         DataObject snapshotOnStore = store.create(snapshotForCopy);
         ((SnapshotObject)snapshotOnStore).setUrl(copyUrl);
         snapshotOnStore.processEvent(Event.CreateOnlyRequested);
 
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Invoke datastore driver createAsync to create snapshot on destination store");
+        if (logger.isDebugEnabled()) {
+            logger.debug("Invoke datastore driver createAsync to create snapshot on destination store");
         }
         try {
             CopySnapshotContext<CommandResult> context = new CopySnapshotContext<>(null, (SnapshotObject)snapshotOnStore, snapshotForCopy, future);
@@ -768,7 +769,7 @@ public class SnapshotServiceImpl implements SnapshotService {
         AsyncCallFuture<CreateCmdResult> future = new AsyncCallFuture<>();
         EndPoint ep = epSelector.select(snapshot);
         if (ep == null) {
-            s_logger.error(String.format("Failed to find endpoint for generating copy URL for snapshot %d with store %d", snapshot.getId(), snapshot.getDataStore().getId()));
+            logger.error(String.format("Failed to find endpoint for generating copy URL for snapshot %d with store %d", snapshot.getId(), snapshot.getDataStore().getId()));
             throw new ResourceUnavailableException("No secondary VM in running state in source snapshot zone", DataCenter.class, snapshot.getDataCenterId());
         }
         DataStore store = snapshot.getDataStore();
