@@ -38,7 +38,6 @@ import org.apache.cloudstack.storage.datastore.db.StoragePoolVO;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.cloudstack.utils.reflectiontostringbuilderutils.ReflectionToStringBuilderUtils;
 import org.apache.commons.collections.CollectionUtils;
-import org.apache.log4j.Logger;
 
 import com.cloud.utils.Pair;
 import org.apache.cloudstack.engine.subsystem.api.storage.DataStoreManager;
@@ -66,7 +65,6 @@ import com.cloud.vm.DiskProfile;
 import com.cloud.vm.VirtualMachineProfile;
 
 public abstract class AbstractStoragePoolAllocator extends AdapterBase implements StoragePoolAllocator {
-    private static final Logger s_logger = Logger.getLogger(AbstractStoragePoolAllocator.class);
 
     protected BigDecimal storageOverprovisioningFactor = new BigDecimal(1);
     protected String allocationAlgorithm = "random";
@@ -126,27 +124,21 @@ public abstract class AbstractStoragePoolAllocator extends AdapterBase implement
     protected List<StoragePool> reorderPoolsByCapacity(DeploymentPlan plan, List<StoragePool> pools) {
         Long zoneId = plan.getDataCenterId();
         Long clusterId = plan.getClusterId();
+        short capacityType;
 
         if (CollectionUtils.isEmpty(pools)) {
             return null;
         }
 
-        short capacityType = Capacity.CAPACITY_TYPE_LOCAL_STORAGE;
-        String storageType = "local";
-        StoragePool storagePool = pools.get(0);
-        if (storagePool.isShared()) {
+        if (pools.get(0).getPoolType().isShared()) {
             capacityType = Capacity.CAPACITY_TYPE_STORAGE_ALLOCATED;
-            storageType = "shared";
+        } else {
+            capacityType = Capacity.CAPACITY_TYPE_LOCAL_STORAGE;
         }
 
-        s_logger.debug(String.format(
-                "Filtering storage pools by capacity type [%s] as the first storage pool of the list, with name [%s] and ID [%s], is a [%s] storage.",
-                capacityType, storagePool.getName(), storagePool.getUuid(), storageType
-        ));
-
         List<Long> poolIdsByCapacity = capacityDao.orderHostsByFreeCapacity(zoneId, clusterId, capacityType);
 
-        s_logger.debug(String.format("List of pools in descending order of available capacity [%s].", poolIdsByCapacity));
+        logger.debug(String.format("List of pools in descending order of available capacity [%s].", poolIdsByCapacity));
 
 
       //now filter the given list of Pools by this ordered list
@@ -175,7 +167,7 @@ public abstract class AbstractStoragePoolAllocator extends AdapterBase implement
         Long clusterId = plan.getClusterId();
 
         List<Long> poolIdsByVolCount = volumeDao.listPoolIdsByVolumeCount(dcId, podId, clusterId, account.getAccountId());
-        s_logger.debug(String.format("List of pools in ascending order of number of volumes for account [%s] is [%s].", account, poolIdsByVolCount));
+        logger.debug(String.format("List of pools in ascending order of number of volumes for account [%s] is [%s].", account, poolIdsByVolCount));
 
         // now filter the given list of Pools by this ordered list
         Map<Long, StoragePool> poolMap = new HashMap<>();
@@ -196,15 +188,15 @@ public abstract class AbstractStoragePoolAllocator extends AdapterBase implement
 
     @Override
     public List<StoragePool> reorderPools(List<StoragePool> pools, VirtualMachineProfile vmProfile, DeploymentPlan plan, DiskProfile dskCh) {
-        if (s_logger.isTraceEnabled()) {
-            s_logger.trace("reordering pools");
+        if (logger.isTraceEnabled()) {
+            logger.trace("reordering pools");
         }
         if (pools == null) {
-            s_logger.trace("There are no pools to reorder; returning null.");
+            logger.trace("There are no pools to reorder; returning null.");
             return null;
         }
-        if (s_logger.isTraceEnabled()) {
-            s_logger.trace(String.format("reordering %d pools", pools.size()));
+        if (logger.isTraceEnabled()) {
+            logger.trace(String.format("reordering %d pools", pools.size()));
         }
         Account account = null;
         if (vmProfile.getVirtualMachine() != null) {
@@ -214,8 +206,8 @@ public abstract class AbstractStoragePoolAllocator extends AdapterBase implement
         pools = reorderStoragePoolsBasedOnAlgorithm(pools, plan, account);
 
         if (vmProfile.getVirtualMachine() == null) {
-            if (s_logger.isTraceEnabled()) {
-                s_logger.trace("The VM is null, skipping pools reordering by disk provisioning type.");
+            if (logger.isTraceEnabled()) {
+                logger.trace("The VM is null, skipping pools reordering by disk provisioning type.");
             }
             return pools;
         }
@@ -229,13 +221,11 @@ public abstract class AbstractStoragePoolAllocator extends AdapterBase implement
     }
 
     List<StoragePool> reorderStoragePoolsBasedOnAlgorithm(List<StoragePool> pools, DeploymentPlan plan, Account account) {
-        s_logger.debug(String.format("Using allocation algorithm [%s] to reorder pools.", allocationAlgorithm));
-
         if (allocationAlgorithm.equals("random") || allocationAlgorithm.equals("userconcentratedpod_random") || (account == null)) {
             reorderRandomPools(pools);
         } else if (StringUtils.equalsAny(allocationAlgorithm, "userdispersing", "firstfitleastconsumed")) {
-            if (s_logger.isTraceEnabled()) {
-                s_logger.trace(String.format("Using reordering algorithm [%s]", allocationAlgorithm));
+            if (logger.isTraceEnabled()) {
+                logger.trace(String.format("Using reordering algorithm [%s]", allocationAlgorithm));
             }
 
             if (allocationAlgorithm.equals("userdispersing")) {
@@ -248,13 +238,13 @@ public abstract class AbstractStoragePoolAllocator extends AdapterBase implement
     }
 
     void reorderRandomPools(List<StoragePool> pools) {
-        StorageUtil.traceLogStoragePools(pools, s_logger, "pools to choose from: ");
-        if (s_logger.isTraceEnabled()) {
-            s_logger.trace(String.format("Shuffle this so that we don't check the pools in the same order. Algorithm == '%s' (or no account?)", allocationAlgorithm));
+        StorageUtil.traceLogStoragePools(pools, logger, "pools to choose from: ");
+        if (logger.isTraceEnabled()) {
+            logger.trace(String.format("Shuffle this so that we don't check the pools in the same order. Algorithm == '%s' (or no account?)", allocationAlgorithm));
         }
-        StorageUtil.traceLogStoragePools(pools, s_logger, "pools to shuffle: ");
+        StorageUtil.traceLogStoragePools(pools, logger, "pools to shuffle: ");
         Collections.shuffle(pools, secureRandom);
-        StorageUtil.traceLogStoragePools(pools, s_logger, "shuffled list of pools to choose from: ");
+        StorageUtil.traceLogStoragePools(pools, logger, "shuffled list of pools to choose from: ");
     }
 
     private List<StoragePool> reorderPoolsByDiskProvisioningType(List<StoragePool> pools, DiskProfile diskProfile) {
@@ -279,15 +269,15 @@ public abstract class AbstractStoragePoolAllocator extends AdapterBase implement
     }
 
     protected boolean filter(ExcludeList avoid, StoragePool pool, DiskProfile dskCh, DeploymentPlan plan) {
-        s_logger.debug(String.format("Checking if storage pool [%s] is suitable to disk [%s].", pool, dskCh));
+        logger.debug(String.format("Checking if storage pool [%s] is suitable to disk [%s].", pool, dskCh));
         if (avoid.shouldAvoid(pool)) {
-            s_logger.debug(String.format("StoragePool [%s] is in avoid set, skipping this pool to allocation of disk [%s].", pool, dskCh));
+            logger.debug(String.format("StoragePool [%s] is in avoid set, skipping this pool to allocation of disk [%s].", pool, dskCh));
             return false;
         }
 
         if (dskCh.requiresEncryption() && !pool.getPoolType().supportsEncryption()) {
-            if (s_logger.isDebugEnabled()) {
-                s_logger.debug(String.format("Storage pool type '%s' doesn't support encryption required for volume, skipping this pool", pool.getPoolType()));
+            if (logger.isDebugEnabled()) {
+                logger.debug(String.format("Storage pool type '%s' doesn't support encryption required for volume, skipping this pool", pool.getPoolType()));
             }
             return false;
         }
@@ -296,20 +286,20 @@ public abstract class AbstractStoragePoolAllocator extends AdapterBase implement
         if (clusterId != null) {
             ClusterVO cluster = clusterDao.findById(clusterId);
             if (!(cluster.getHypervisorType() == dskCh.getHypervisorType())) {
-                if (s_logger.isDebugEnabled()) {
-                    s_logger.debug("StoragePool's Cluster does not have required hypervisorType, skipping this pool");
+                if (logger.isDebugEnabled()) {
+                    logger.debug("StoragePool's Cluster does not have required hypervisorType, skipping this pool");
                 }
                 return false;
             }
         } else if (pool.getHypervisor() != null && !pool.getHypervisor().equals(HypervisorType.Any) && !(pool.getHypervisor() == dskCh.getHypervisorType())) {
-            if (s_logger.isDebugEnabled()) {
-                s_logger.debug("StoragePool does not have required hypervisorType, skipping this pool");
+            if (logger.isDebugEnabled()) {
+                logger.debug("StoragePool does not have required hypervisorType, skipping this pool");
             }
             return false;
         }
 
         if (!checkDiskProvisioningSupport(dskCh, pool)) {
-            s_logger.debug(String.format("Storage pool [%s] does not have support to disk provisioning of disk [%s].", pool, ReflectionToStringBuilderUtils.reflectOnlySelectedFields(dskCh,
+            logger.debug(String.format("Storage pool [%s] does not have support to disk provisioning of disk [%s].", pool, ReflectionToStringBuilderUtils.reflectOnlySelectedFields(dskCh,
                     "type", "name", "diskOfferingId", "templateId", "volumeId", "provisioningType", "hyperType")));
             return false;
         }
@@ -318,14 +308,18 @@ public abstract class AbstractStoragePoolAllocator extends AdapterBase implement
             return false;
         }
 
-        Volume volume = volumeDao.findById(dskCh.getVolumeId());
-        if(!storageMgr.storagePoolCompatibleWithVolumePool(pool, volume)) {
-            s_logger.debug(String.format("Pool [%s] is not compatible with volume [%s], skipping it.", pool, volume));
-            return false;
+        Volume volume = null;
+        boolean isTempVolume = dskCh.getVolumeId() == Volume.DISK_OFFERING_SUITABILITY_CHECK_VOLUME_ID;
+        if (!isTempVolume) {
+            volume = volumeDao.findById(dskCh.getVolumeId());
+            if (!storageMgr.storagePoolCompatibleWithVolumePool(pool, volume)) {
+                logger.debug(String.format("Pool [%s] is not compatible with volume [%s], skipping it.", pool, volume));
+                return false;
+            }
         }
 
         if (pool.isManaged() && !storageUtil.managedStoragePoolCanScale(pool, plan.getClusterId(), plan.getHostId())) {
-            s_logger.debug(String.format("Cannot allocate pool [%s] to volume [%s] because the max number of managed clustered filesystems has been exceeded.", pool, volume));
+            logger.debug(String.format("Cannot allocate pool [%s] to volume [%s] because the max number of managed clustered filesystems has been exceeded.", pool, volume));
             return false;
         }
 
@@ -334,29 +328,35 @@ public abstract class AbstractStoragePoolAllocator extends AdapterBase implement
         requestVolumeDiskProfilePairs.add(new Pair<>(volume, dskCh));
         if (dskCh.getHypervisorType() == HypervisorType.VMware) {
             if (pool.getPoolType() == Storage.StoragePoolType.DatastoreCluster && storageMgr.isStoragePoolDatastoreClusterParent(pool)) {
-                s_logger.debug(String.format("Skipping allocation of pool [%s] to volume [%s] because this pool is a parent datastore cluster.", pool, volume));
+                logger.debug(String.format("Skipping allocation of pool [%s] to volume [%s] because this pool is a parent datastore cluster.", pool, volume));
                 return false;
             }
             if (pool.getParent() != 0L) {
                 StoragePoolVO datastoreCluster = storagePoolDao.findById(pool.getParent());
                 if (datastoreCluster == null || (datastoreCluster != null && datastoreCluster.getStatus() != StoragePoolStatus.Up)) {
-                    s_logger.debug(String.format("Skipping allocation of pool [%s] to volume [%s] because this pool is not in [%s] state.", datastoreCluster, volume, StoragePoolStatus.Up));
+                    logger.debug(String.format("Skipping allocation of pool [%s] to volume [%s] because this pool is not in [%s] state.", datastoreCluster, volume, StoragePoolStatus.Up));
                     return false;
                 }
             }
 
             try {
-                boolean isStoragePoolStoragepolicyComplaince = storageMgr.isStoragePoolCompliantWithStoragePolicy(requestVolumeDiskProfilePairs, pool);
-                if (!isStoragePoolStoragepolicyComplaince) {
-                    s_logger.debug(String.format("Skipping allocation of pool [%s] to volume [%s] because this pool is not compliant with the storage policy required by the volume.", pool, volume));
+                boolean isStoragePoolStoragePolicyCompliance = isTempVolume ?
+                        storageMgr.isStoragePoolCompliantWithStoragePolicy(dskCh.getDiskOfferingId(), pool) :
+                        storageMgr.isStoragePoolCompliantWithStoragePolicy(requestVolumeDiskProfilePairs, pool);
+                if (!isStoragePoolStoragePolicyCompliance) {
+                    logger.debug(String.format("Skipping allocation of pool [%s] to volume [%s] because this pool is not compliant with the storage policy required by the volume.", pool, volume));
                     return false;
                 }
             } catch (StorageUnavailableException e) {
-                s_logger.warn(String.format("Could not verify storage policy complaince against storage pool %s due to exception %s", pool.getUuid(), e.getMessage()));
+                logger.warn(String.format("Could not verify storage policy complaince against storage pool %s due to exception %s", pool.getUuid(), e.getMessage()));
                 return false;
             }
         }
-        return storageMgr.storagePoolHasEnoughIops(requestVolumeDiskProfilePairs, pool) && storageMgr.storagePoolHasEnoughSpace(requestVolumeDiskProfilePairs, pool, plan.getClusterId());
+        return isTempVolume ?
+                (storageMgr.storagePoolHasEnoughIops(dskCh.getMinIops(), pool) &&
+                        storageMgr.storagePoolHasEnoughSpace(dskCh.getSize(), pool)):
+                (storageMgr.storagePoolHasEnoughIops(requestVolumeDiskProfilePairs, pool) &&
+                        storageMgr.storagePoolHasEnoughSpace(requestVolumeDiskProfilePairs, pool, plan.getClusterId()));
     }
 
     private boolean checkDiskProvisioningSupport(DiskProfile dskCh, StoragePool pool) {
@@ -380,13 +380,13 @@ public abstract class AbstractStoragePoolAllocator extends AdapterBase implement
                 //LXC ROOT disks supports NFS and local storage pools only
                 if(!(Storage.StoragePoolType.NetworkFilesystem.equals(poolType) ||
                         Storage.StoragePoolType.Filesystem.equals(poolType)) ){
-                    s_logger.debug("StoragePool does not support LXC ROOT disk, skipping this pool");
+                    logger.debug("StoragePool does not support LXC ROOT disk, skipping this pool");
                     return false;
                 }
             } else if (Volume.Type.DATADISK.equals(volType)){
                 //LXC DATA disks supports RBD storage pool only
                 if(!Storage.StoragePoolType.RBD.equals(poolType)){
-                    s_logger.debug("StoragePool does not support LXC DATA disk, skipping this pool");
+                    logger.debug("StoragePool does not support LXC DATA disk, skipping this pool");
                     return false;
                 }
             }
@@ -397,18 +397,18 @@ public abstract class AbstractStoragePoolAllocator extends AdapterBase implement
     protected void logDisabledStoragePools(long dcId, Long podId, Long clusterId, ScopeType scope) {
         List<StoragePoolVO> disabledPools = storagePoolDao.findDisabledPoolsByScope(dcId, podId, clusterId, scope);
         if (disabledPools != null && !disabledPools.isEmpty()) {
-            s_logger.trace(String.format("Ignoring pools [%s] as they are in disabled state.", ReflectionToStringBuilderUtils.reflectOnlySelectedFields(disabledPools)));
+            logger.trace(String.format("Ignoring pools [%s] as they are in disabled state.", ReflectionToStringBuilderUtils.reflectOnlySelectedFields(disabledPools)));
         }
     }
 
     protected void logStartOfSearch(DiskProfile dskCh, VirtualMachineProfile vmProfile, DeploymentPlan plan, int returnUpTo,
             boolean bypassStorageTypeCheck){
-        s_logger.trace(String.format("%s is looking for storage pools that match the VM's disk profile [%s], virtual machine profile [%s] and "
+        logger.trace(String.format("%s is looking for storage pools that match the VM's disk profile [%s], virtual machine profile [%s] and "
                 + "deployment plan [%s]. Returning up to [%d] and bypassStorageTypeCheck [%s].", this.getClass().getSimpleName(), dskCh, vmProfile, plan, returnUpTo, bypassStorageTypeCheck));
     }
 
     protected void logEndOfSearch(List<StoragePool> storagePoolList) {
-        s_logger.debug(String.format("%s is returning [%s] suitable storage pools [%s].", this.getClass().getSimpleName(), storagePoolList.size(),
+        logger.debug(String.format("%s is returning [%s] suitable storage pools [%s].", this.getClass().getSimpleName(), storagePoolList.size(),
                 Arrays.toString(storagePoolList.toArray())));
     }
 
