@@ -22,15 +22,9 @@ import java.util.List;
 
 import javax.inject.Inject;
 
-import com.cloud.storage.VMTemplateStoragePoolVO;
-import com.cloud.storage.VMTemplateStorageResourceAssoc;
-import com.cloud.template.TemplateManager;
 import org.apache.cloudstack.engine.subsystem.api.storage.ClusterScope;
 import org.apache.cloudstack.engine.subsystem.api.storage.DataStore;
-import org.apache.cloudstack.storage.datastore.db.PrimaryDataStoreDao;
-import org.apache.cloudstack.storage.datastore.db.StoragePoolVO;
 import org.apache.cloudstack.storage.volume.datastore.PrimaryDataStoreHelper;
-import org.apache.log4j.Logger;
 
 import com.cloud.agent.AgentManager;
 import com.cloud.agent.api.Answer;
@@ -44,9 +38,12 @@ import com.cloud.storage.StoragePool;
 import com.cloud.storage.StoragePoolHostVO;
 import com.cloud.storage.dao.StoragePoolHostDao;
 import com.cloud.utils.Pair;
+import org.apache.logging.log4j.LogManager;
+import org.apache.logging.log4j.Logger;
 
 public class BasePrimaryDataStoreLifeCycleImpl {
-    private static final Logger s_logger = Logger.getLogger(BasePrimaryDataStoreLifeCycleImpl.class);
+    protected Logger logger = LogManager.getLogger(getClass());
+
     @Inject
     AgentManager agentMgr;
     @Inject
@@ -59,10 +56,6 @@ public class BasePrimaryDataStoreLifeCycleImpl {
     protected HostDao hostDao;
     @Inject
     protected StoragePoolHostDao storagePoolHostDao;
-    @Inject
-    private PrimaryDataStoreDao primaryDataStoreDao;
-    @Inject
-    private TemplateManager templateMgr;
 
     private List<HostVO> getPoolHostsList(ClusterScope clusterScope, HypervisorType hypervisorType) {
         List<HostVO> hosts;
@@ -79,13 +72,13 @@ public class BasePrimaryDataStoreLifeCycleImpl {
 
     public void changeStoragePoolScopeToZone(DataStore store, ClusterScope clusterScope, HypervisorType hypervisorType) {
         List<HostVO> hosts = getPoolHostsList(clusterScope, hypervisorType);
-        s_logger.debug("Changing scope of the storage pool to Zone");
+        logger.debug("Changing scope of the storage pool to Zone");
         if (hosts != null) {
             for (HostVO host : hosts) {
                 try {
                     storageMgr.connectHostToSharedPool(host.getId(), store.getId());
                 } catch (Exception e) {
-                    s_logger.warn("Unable to establish a connection between " + host + " and " + store, e);
+                    logger.warn("Unable to establish a connection between " + host + " and " + store, e);
                 }
             }
         }
@@ -94,7 +87,7 @@ public class BasePrimaryDataStoreLifeCycleImpl {
 
     public void changeStoragePoolScopeToCluster(DataStore store, ClusterScope clusterScope, HypervisorType hypervisorType) {
         Pair<List<StoragePoolHostVO>, Integer> hostPoolRecords = storagePoolHostDao.listByPoolIdNotInCluster(clusterScope.getScopeId(), store.getId());
-        s_logger.debug("Changing scope of the storage pool to Cluster");
+        logger.debug("Changing scope of the storage pool to Cluster");
         if (hostPoolRecords.second() > 0) {
             StoragePool pool = (StoragePool) store;
             for (StoragePoolHostVO host : hostPoolRecords.first()) {
@@ -103,7 +96,7 @@ public class BasePrimaryDataStoreLifeCycleImpl {
 
                 if (answer != null) {
                     if (!answer.getResult()) {
-                        s_logger.debug("Failed to delete storage pool: " + answer.getResult());
+                        logger.debug("Failed to delete storage pool: " + answer.getResult());
                     } else if (HypervisorType.KVM != hypervisorType) {
                         break;
                     }
@@ -112,42 +105,4 @@ public class BasePrimaryDataStoreLifeCycleImpl {
         }
         dataStoreHelper.switchToCluster(store, clusterScope);
     }
-
-    private void evictTemplates(StoragePoolVO storagePoolVO) {
-        List<VMTemplateStoragePoolVO> unusedTemplatesInPool = templateMgr.getUnusedTemplatesInPool(storagePoolVO);
-        for (VMTemplateStoragePoolVO templatePoolVO : unusedTemplatesInPool) {
-            if (templatePoolVO.getDownloadState() == VMTemplateStorageResourceAssoc.Status.DOWNLOADED) {
-                templateMgr.evictTemplateFromStoragePool(templatePoolVO);
-            }
-        }
-    }
-
-    private void deleteAgentStoragePools(StoragePool storagePool) {
-        List<StoragePoolHostVO> poolHostVOs = storagePoolHostDao.listByPoolId(storagePool.getId());
-        for (StoragePoolHostVO poolHostVO : poolHostVOs) {
-            DeleteStoragePoolCommand deleteStoragePoolCommand = new DeleteStoragePoolCommand(storagePool);
-            final Answer answer = agentMgr.easySend(poolHostVO.getHostId(), deleteStoragePoolCommand);
-            if (answer != null && answer.getResult()) {
-                s_logger.info("Successfully deleted storage pool: " + storagePool.getId() + " from host: " + poolHostVO.getHostId());
-            } else {
-                if (answer != null) {
-                    s_logger.error("Failed to delete storage pool: " + storagePool.getId() + " from host: " + poolHostVO.getHostId() + " , result: " + answer.getResult());
-                } else {
-                    s_logger.error("Failed to delete storage pool: " + storagePool.getId() + " from host: " + poolHostVO.getHostId());
-                }
-            }
-        }
-    }
-
-    protected boolean cleanupDatastore(DataStore store) {
-        StoragePool storagePool = (StoragePool)store;
-        StoragePoolVO storagePoolVO = primaryDataStoreDao.findById(storagePool.getId());
-        if (storagePoolVO == null) {
-            return false;
-        }
-
-        evictTemplates(storagePoolVO);
-        deleteAgentStoragePools(storagePool);
-        return true;
-    }
 }
