@@ -46,7 +46,6 @@ import org.apache.cloudstack.framework.config.Configurable;
 import org.apache.cloudstack.managed.context.ManagedContextRunnable;
 import org.apache.cloudstack.management.ManagementServerHost;
 import org.apache.cloudstack.utils.identity.ManagementServerNode;
-import org.apache.log4j.Logger;
 
 import com.cloud.cluster.dao.ManagementServerHostDao;
 import com.cloud.cluster.dao.ManagementServerHostPeerDao;
@@ -70,7 +69,6 @@ import com.cloud.utils.mgmt.JmxUtil;
 import com.cloud.utils.net.NetUtils;
 
 public class ClusterManagerImpl extends ManagerBase implements ClusterManager, Configurable {
-    private static final Logger s_logger = Logger.getLogger(ClusterManagerImpl.class);
 
     private static final int EXECUTOR_SHUTDOWN_TIMEOUT = 1000; // 1 second
     private static final int DEFAULT_OUTGOING_WORKERS = 5;
@@ -176,7 +174,7 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
         }
 
         for (final ClusterServiceRequestPdu pdu : candidates) {
-            s_logger.warn("Cancel cluster request PDU to peer: " + strPeer + ", pdu: " + pdu.getJsonPackage());
+            logger.warn("Cancel cluster request PDU to peer: " + strPeer + ", pdu: " + pdu.getJsonPackage());
             synchronized (pdu) {
                 pdu.notifyAll();
             }
@@ -260,13 +258,13 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
                     try {
                         peerService = getPeerService(pdu.getDestPeer());
                     } catch (final RemoteException e) {
-                        s_logger.error("Unable to get cluster service on peer : " + pdu.getDestPeer());
+                        logger.error("Unable to get cluster service on peer : " + pdu.getDestPeer());
                     }
 
                     if (peerService != null) {
                         try {
-                            if (s_logger.isDebugEnabled()) {
-                                s_logger.debug("Cluster PDU " + getSelfPeerName() + " -> " + pdu.getDestPeer() + ". agent: " + pdu.getAgentId() + ", pdu seq: " +
+                            if (logger.isDebugEnabled()) {
+                                logger.debug("Cluster PDU " + getSelfPeerName() + " -> " + pdu.getDestPeer() + ". agent: " + pdu.getAgentId() + ", pdu seq: " +
                                         pdu.getSequenceId() + ", pdu ack seq: " + pdu.getAckSequenceId() + ", json: " + pdu.getJsonPackage());
                             }
 
@@ -276,8 +274,8 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
                             final String strResult = peerService.execute(pdu);
                             profiler.stop();
 
-                            if (s_logger.isDebugEnabled()) {
-                                s_logger.debug("Cluster PDU " + getSelfPeerName() + " -> " + pdu.getDestPeer() + " completed. time: " +
+                            if (logger.isDebugEnabled()) {
+                                logger.debug("Cluster PDU " + getSelfPeerName() + " -> " + pdu.getDestPeer() + " completed. time: " +
                                         profiler.getDurationInMillis() + "ms. agent: " + pdu.getAgentId() + ", pdu seq: " + pdu.getSequenceId() +
                                         ", pdu ack seq: " + pdu.getAckSequenceId() + ", json: " + pdu.getJsonPackage());
                             }
@@ -288,15 +286,15 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
 
                         } catch (final RemoteException e) {
                             invalidatePeerService(pdu.getDestPeer());
-                            if (s_logger.isInfoEnabled()) {
-                                s_logger.info("Exception on remote execution, peer: " + pdu.getDestPeer() + ", iteration: " + i + ", exception message :" +
+                            if (logger.isInfoEnabled()) {
+                                logger.info("Exception on remote execution, peer: " + pdu.getDestPeer() + ", iteration: " + i + ", exception message :" +
                                         e.getMessage());
                             }
                         }
                     }
                 }
             } catch (final Throwable e) {
-                s_logger.error("Unexcpeted exception: ", e);
+                logger.error("Unexpected exception: ", e);
             }
         }
     }
@@ -320,11 +318,11 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
                                     requestPdu.notifyAll();
                                 }
                             } else {
-                                s_logger.warn("Original request has already been cancelled. pdu: " + pdu.getJsonPackage());
+                                logger.warn("Original request has already been cancelled. pdu: " + pdu.getJsonPackage());
                             }
                         } else if (pdu.getPduType() == ClusterServicePdu.PDU_TYPE_STATUS_UPDATE) {
                             if (statusAdministrator == null) {
-                                s_logger.warn("No status administration to report a status update too.");
+                                logger.warn("No status administration to report a status update too.");
                             } else {
                                 statusAdministrator.newStatus(pdu);
                             }
@@ -348,7 +346,7 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
                     }
                 });
             } catch (final Throwable e) {
-                s_logger.error("Unexcpeted exception: ", e);
+                logger.error("Unexpected exception: ", e);
             }
         }
     }
@@ -381,12 +379,12 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
                 continue; // Skip myself.
             }
             try {
-                if (s_logger.isDebugEnabled()) {
-                    s_logger.debug("Forwarding " + cmds + " to " + peer.getMsid());
+                if (logger.isDebugEnabled()) {
+                    logger.debug("Forwarding " + cmds + " to " + peer.getMsid());
                 }
                 executeAsync(peerName, agentId, cmds, true);
             } catch (final Exception e) {
-                s_logger.warn("Caught exception while talkign to " + peer.getMsid());
+                logger.warn("Caught exception while talking to " + peer.getMsid());
             }
         }
     }
@@ -409,14 +407,14 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
         for (final ManagementServerHostVO peer : peers) {
             final String peerName = Long.toString(peer.getMsid());
             try {
-                if (s_logger.isDebugEnabled()) {
-                    s_logger.debug("Forwarding " + status + " to " + peer.getMsid());
+                if (logger.isDebugEnabled()) {
+                    logger.debug("Forwarding " + status + " to " + peer.getMsid());
                 }
                 sendStatus(peerName, status);
             } catch (final Exception e) {
                 String msg = String.format("Caught exception while talking to %d", peer.getMsid());
-                s_logger.warn(msg);
-                s_logger.debug(msg, e);
+                logger.warn(msg);
+                logger.debug(msg, e);
             }
         }
     }
@@ -434,8 +432,8 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
 
     @Override
     public String execute(final String strPeer, final long agentId, final String cmds, final boolean stopOnError) {
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug(getSelfPeerName() + " -> " + strPeer + "." + agentId + " " + cmds);
+        if (logger.isDebugEnabled()) {
+            logger.debug(getSelfPeerName() + " -> " + strPeer + "." + agentId + " " + cmds);
         }
 
         final ClusterServiceRequestPdu pdu = new ClusterServiceRequestPdu();
@@ -454,8 +452,8 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
             }
         }
 
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug(getSelfPeerName() + " -> " + strPeer + "." + agentId + " completed. result: " + pdu.getResponseResult());
+        if (logger.isDebugEnabled()) {
+            logger.debug(getSelfPeerName() + " -> " + strPeer + "." + agentId + " completed. result: " + pdu.getResponseResult());
         }
 
         if (pdu.getResponseResult() != null && pdu.getResponseResult().length() > 0) {
@@ -485,7 +483,7 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
         // Note : we don't check duplicates
         synchronized (_listeners) {
 
-            s_logger.info("register cluster listener " + listener.getClass());
+            logger.info("register cluster listener " + listener.getClass());
 
             _listeners.add(listener);
         }
@@ -494,18 +492,18 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
     @Override
     public void unregisterListener(final ClusterManagerListener listener) {
         synchronized (_listeners) {
-            s_logger.info("unregister cluster listener " + listener.getClass());
+            logger.info("unregister cluster listener " + listener.getClass());
 
             _listeners.remove(listener);
         }
     }
 
     public void notifyNodeJoined(final List<ManagementServerHostVO> nodeList) {
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Notify management server node join to listeners.");
+        if (logger.isDebugEnabled()) {
+            logger.debug("Notify management server node join to listeners.");
 
             for (final ManagementServerHostVO mshost : nodeList) {
-                s_logger.debug("Joining node, IP: " + mshost.getServiceIP() + ", msid: " + mshost.getMsid());
+                logger.debug("Joining node, IP: " + mshost.getServiceIP() + ", msid: " + mshost.getMsid());
             }
         }
 
@@ -519,13 +517,13 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
     }
 
     public void notifyNodeLeft(final List<ManagementServerHostVO> nodeList) {
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Notify management server node left to listeners.");
+        if (logger.isDebugEnabled()) {
+            logger.debug("Notify management server node left to listeners.");
         }
 
         for (final ManagementServerHostVO mshost : nodeList) {
-            if (s_logger.isDebugEnabled()) {
-                s_logger.debug("Leaving node, IP: " + mshost.getServiceIP() + ", msid: " + mshost.getMsid());
+            if (logger.isDebugEnabled()) {
+                logger.debug("Leaving node, IP: " + mshost.getServiceIP() + ", msid: " + mshost.getMsid());
             }
             cancelClusterRequestToPeer(String.valueOf(mshost.getMsid()));
         }
@@ -540,8 +538,8 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
     }
 
     public void notifyNodeIsolated() {
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Notify management server node isolation to listeners");
+        if (logger.isDebugEnabled()) {
+            logger.debug("Notify management server node isolation to listeners");
         }
 
         synchronized (_listeners) {
@@ -596,16 +594,16 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
 
                         profilerHeartbeatUpdate.start();
                         txn.transitToAutoManagedConnection(TransactionLegacy.CLOUD_DB);
-                        if (s_logger.isTraceEnabled()) {
-                            s_logger.trace("Cluster manager heartbeat update, id:" + _mshostId);
+                        if (logger.isTraceEnabled()) {
+                            logger.trace("Cluster manager heartbeat update, id:" + _mshostId);
                         }
 
                         _mshostDao.update(_mshostId, _runId, DateUtil.currentGMTTime());
                         profilerHeartbeatUpdate.stop();
 
                         profilerPeerScan.start();
-                        if (s_logger.isTraceEnabled()) {
-                            s_logger.trace("Cluster manager peer-scan, id:" + _mshostId);
+                        if (logger.isTraceEnabled()) {
+                            logger.trace("Cluster manager peer-scan, id:" + _mshostId);
                         }
 
                         if (!_peerScanInited) {
@@ -620,18 +618,18 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
                         profiler.stop();
 
                         if (profiler.getDurationInMillis() >= HeartbeatInterval.value()) {
-                            if (s_logger.isDebugEnabled()) {
-                                s_logger.debug("Management server heartbeat takes too long to finish. profiler: " + profiler.toString() + ", profilerHeartbeatUpdate: " +
+                            if (logger.isDebugEnabled()) {
+                                logger.debug("Management server heartbeat takes too long to finish. profiler: " + profiler.toString() + ", profilerHeartbeatUpdate: " +
                                         profilerHeartbeatUpdate.toString() + ", profilerPeerScan: " + profilerPeerScan.toString());
                             }
                         }
                     }
 
                 } catch (final CloudRuntimeException e) {
-                    s_logger.error("Runtime DB exception ", e.getCause());
+                    logger.error("Runtime DB exception ", e.getCause());
 
                     if (e.getCause() instanceof ClusterInvalidSessionException) {
-                        s_logger.error("Invalid cluster session found, fence it");
+                        logger.error("Invalid cluster session found, fence it");
                         queueNotification(new ClusterManagerMessage(ClusterManagerMessage.MessageType.nodeIsolated));
                     }
 
@@ -641,7 +639,7 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
                 } catch (final ActiveFencingException e) {
                     queueNotification(new ClusterManagerMessage(ClusterManagerMessage.MessageType.nodeIsolated));
                 } catch (final Throwable e) {
-                    s_logger.error("Unexpected exception in cluster heartbeat", e);
+                    logger.error("Unexpected exception in cluster heartbeat", e);
                     if (isRootCauseConnectionRelated(e.getCause())) {
                         invalidHeartbeatConnection();
                     }
@@ -670,7 +668,7 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
             if (conn != null) {
                 _heartbeatConnection.reset(conn);
             } else {
-                s_logger.error("DB communication problem detected, fence it");
+                logger.error("DB communication problem detected, fence it");
                 queueNotification(new ClusterManagerMessage(ClusterManagerMessage.MessageType.nodeIsolated));
             }
             // The stand-alone connection does not have to be closed here because there will be another reference to it.
@@ -703,11 +701,11 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
 
                                     profiler.stop();
                                     if (profiler.getDurationInMillis() > 1000) {
-                                        if (s_logger.isDebugEnabled()) {
-                                            s_logger.debug("Notifying management server join event took " + profiler.getDurationInMillis() + " ms");
+                                        if (logger.isDebugEnabled()) {
+                                            logger.debug("Notifying management server join event took " + profiler.getDurationInMillis() + " ms");
                                         }
                                     } else {
-                                        s_logger.warn("Notifying management server join event took " + profiler.getDurationInMillis() + " ms");
+                                        logger.warn("Notifying management server join event took " + profiler.getDurationInMillis() + " ms");
                                     }
                                 }
                                 break;
@@ -721,11 +719,11 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
 
                                     profiler.stop();
                                     if (profiler.getDurationInMillis() > 1000) {
-                                        if (s_logger.isDebugEnabled()) {
-                                            s_logger.debug("Notifying management server leave event took " + profiler.getDurationInMillis() + " ms");
+                                        if (logger.isDebugEnabled()) {
+                                            logger.debug("Notifying management server leave event took " + profiler.getDurationInMillis() + " ms");
                                         }
                                     } else {
-                                        s_logger.warn("Notifying management server leave event took " + profiler.getDurationInMillis() + " ms");
+                                        logger.warn("Notifying management server leave event took " + profiler.getDurationInMillis() + " ms");
                                     }
                                 }
                                 break;
@@ -740,7 +738,7 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
                             }
 
                         } catch (final Throwable e) {
-                            s_logger.warn("Unexpected exception during cluster notification. ", e);
+                            logger.warn("Unexpected exception during cluster notification. ", e);
                         }
                     }
 
@@ -807,18 +805,18 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
         if (orphanList.size() > 0) {
             for (final Long orphanMsid : orphanList) {
                 // construct fake ManagementServerHostVO based on orphan MSID
-                s_logger.info("Add orphan management server msid found in host table to initial clustering notification, orphan msid: " + orphanMsid);
+                logger.info("Add orphan management server msid found in host table to initial clustering notification, orphan msid: " + orphanMsid);
                 inactiveList.add(new ManagementServerHostVO(orphanMsid, 0, "orphan", 0, new Date()));
             }
         } else {
-            s_logger.info("We are good, no orphan management server msid in host table is found");
+            logger.info("We are good, no orphan management server msid in host table is found");
         }
 
         if (inactiveList.size() > 0) {
-            if (s_logger.isInfoEnabled()) {
-                s_logger.info("Found " + inactiveList.size() + " inactive management server node based on timestamp");
+            if (logger.isInfoEnabled()) {
+                logger.info("Found " + inactiveList.size() + " inactive management server node based on timestamp");
                 for (final ManagementServerHostVO host : inactiveList) {
-                    s_logger.info("management server node msid: " + host.getMsid() + ", name: " + host.getName() + ", service ip: " + host.getServiceIP() +
+                    logger.info("management server node msid: " + host.getMsid() + ", name: " + host.getName() + ", service ip: " + host.getServiceIP() +
                             ", version: " + host.getVersion());
                 }
             }
@@ -826,7 +824,7 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
             final List<ManagementServerHostVO> downHostList = new ArrayList<ManagementServerHostVO>();
             for (final ManagementServerHostVO host : inactiveList) {
                 if (!pingManagementNode(host)) {
-                    s_logger.warn("Management node " + host.getId() + " is detected inactive by timestamp and also not pingable");
+                    logger.warn("Management node " + host.getId() + " is detected inactive by timestamp and also not pingable");
                     downHostList.add(host);
                 }
             }
@@ -835,7 +833,7 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
                 queueNotification(new ClusterManagerMessage(ClusterManagerMessage.MessageType.nodeRemoved, downHostList));
             }
         } else {
-            s_logger.info("No inactive management server node found");
+            logger.info("No inactive management server node found");
         }
     }
 
@@ -860,7 +858,7 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
             if (_mshostPeerDao.countStateSeenInPeers(_mshostId, _runId, ManagementServerHost.State.Down) > 0) {
                 final String msg =
                         "We have detected that at least one management server peer reports that this management server is down, perform active fencing to avoid split-brain situation";
-                s_logger.error(msg);
+                logger.error(msg);
                 throw new ActiveFencingException(msg);
             }
 
@@ -870,24 +868,24 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
                 final ManagementServerHostVO current = getInListById(entry.getKey(), currentList);
                 if (current == null) {
                     if (entry.getKey().longValue() != _mshostId.longValue()) {
-                        if (s_logger.isDebugEnabled()) {
-                            s_logger.debug("Detected management node left, id:" + entry.getKey() + ", nodeIP:" + entry.getValue().getServiceIP());
+                        if (logger.isDebugEnabled()) {
+                            logger.debug("Detected management node left, id:" + entry.getKey() + ", nodeIP:" + entry.getValue().getServiceIP());
                         }
                         removedNodeList.add(entry.getValue());
                     }
                 } else {
                     if (current.getRunid() == 0) {
                         if (entry.getKey().longValue() != _mshostId.longValue()) {
-                            if (s_logger.isDebugEnabled()) {
-                                s_logger.debug("Detected management node left because of invalidated session, id:" + entry.getKey() + ", nodeIP:" +
+                            if (logger.isDebugEnabled()) {
+                                logger.debug("Detected management node left because of invalidated session, id:" + entry.getKey() + ", nodeIP:" +
                                         entry.getValue().getServiceIP());
                             }
                             invalidatedNodeList.add(entry.getValue());
                         }
                     } else {
                         if (entry.getValue().getRunid() != current.getRunid()) {
-                            if (s_logger.isDebugEnabled()) {
-                                s_logger.debug("Detected management node left and rejoined quickly, id:" + entry.getKey() + ", nodeIP:" + entry.getValue().getServiceIP());
+                            if (logger.isDebugEnabled()) {
+                                logger.debug("Detected management node left and rejoined quickly, id:" + entry.getKey() + ", nodeIP:" + entry.getValue().getServiceIP());
                             }
 
                             entry.getValue().setRunid(current.getRunid());
@@ -907,7 +905,7 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
                 try {
                     JmxUtil.unregisterMBean("ClusterManager", "Node " + mshost.getId());
                 } catch (final Exception e) {
-                    s_logger.warn("Unable to deregiester cluster node from JMX monitoring due to exception " + e.toString());
+                    logger.warn("Unable to deregiester cluster node from JMX monitoring due to exception " + e.toString());
                 }
             }
 
@@ -922,15 +920,15 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
         while (it.hasNext()) {
             final ManagementServerHostVO mshost = it.next();
             if (!pingManagementNode(mshost)) {
-                s_logger.warn("Management node " + mshost.getId() + " is detected inactive by timestamp and also not pingable");
+                logger.warn("Management node " + mshost.getId() + " is detected inactive by timestamp and also not pingable");
                 _activePeers.remove(mshost.getId());
                 try {
                     JmxUtil.unregisterMBean("ClusterManager", "Node " + mshost.getId());
                 } catch (final Exception e) {
-                    s_logger.warn("Unable to deregiester cluster node from JMX monitoring due to exception " + e.toString());
+                    logger.warn("Unable to deregiester cluster node from JMX monitoring due to exception " + e.toString());
                 }
             } else {
-                s_logger.info("Management node " + mshost.getId() + " is detected inactive by timestamp but is pingable");
+                logger.info("Management node " + mshost.getId() + " is detected inactive by timestamp but is pingable");
                 it.remove();
             }
         }
@@ -945,15 +943,15 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
             if (!_activePeers.containsKey(mshost.getId())) {
                 _activePeers.put(mshost.getId(), mshost);
 
-                if (s_logger.isDebugEnabled()) {
-                    s_logger.debug("Detected management node joined, id:" + mshost.getId() + ", nodeIP:" + mshost.getServiceIP());
+                if (logger.isDebugEnabled()) {
+                    logger.debug("Detected management node joined, id:" + mshost.getId() + ", nodeIP:" + mshost.getServiceIP());
                 }
                 newNodeList.add(mshost);
 
                 try {
                     JmxUtil.registerMBean("ClusterManager", "Node " + mshost.getId(), new ClusterManagerMBeanImpl(this, mshost));
                 } catch (final Exception e) {
-                    s_logger.warn("Unable to register cluster node into JMX monitoring due to exception " + ExceptionUtil.toString(e));
+                    logger.warn("Unable to register cluster node into JMX monitoring due to exception " + ExceptionUtil.toString(e));
                 }
             }
         }
@@ -965,8 +963,8 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
         profiler.stop();
 
         if (profiler.getDurationInMillis() >= HeartbeatInterval.value()) {
-            if (s_logger.isDebugEnabled()) {
-                s_logger.debug("Peer scan takes too long to finish. profiler: " + profiler.toString() + ", profilerQueryActiveList: " +
+            if (logger.isDebugEnabled()) {
+                logger.debug("Peer scan takes too long to finish. profiler: " + profiler.toString() + ", profilerQueryActiveList: " +
                         profilerQueryActiveList.toString() + ", profilerSyncClusterInfo: " + profilerSyncClusterInfo.toString() + ", profilerInvalidatedNodeList: " +
                         profilerInvalidatedNodeList.toString() + ", profilerRemovedList: " + profilerRemovedList.toString());
             }
@@ -985,8 +983,8 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
     @Override
     @DB
     public boolean start() {
-        if (s_logger.isInfoEnabled()) {
-            s_logger.info("Starting Cluster manager, msid : " + _msId);
+        if (logger.isInfoEnabled()) {
+            logger.info("Starting Cluster manager, msid : " + _msId);
         }
 
         final ManagementServerHostVO mshost = Transaction.execute(new TransactionCallback<ManagementServerHostVO>() {
@@ -1011,14 +1009,14 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
                     mshost.setState(ManagementServerHost.State.Up);
                     mshost.setUuid(UUID.randomUUID().toString());
                     _mshostDao.persist(mshost);
-                    if (s_logger.isInfoEnabled()) {
-                        s_logger.info("New instance of management server msid " + _msId + ", runId " + _runId + " is being started");
+                    if (logger.isInfoEnabled()) {
+                        logger.info("New instance of management server msid " + _msId + ", runId " + _runId + " is being started");
                     }
                 } else {
                     _mshostDao.update(mshost.getId(), _runId, NetUtils.getCanonicalHostName(), version, _clusterNodeIP, _currentServiceAdapter.getServicePort(),
                             DateUtil.currentGMTTime());
-                    if (s_logger.isInfoEnabled()) {
-                        s_logger.info("Management server " + _msId + ", runId " + _runId + " is being started");
+                    if (logger.isInfoEnabled()) {
+                        logger.info("Management server " + _msId + ", runId " + _runId + " is being started");
                     }
                 }
 
@@ -1027,8 +1025,8 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
         });
 
         _mshostId = mshost.getId();
-        if (s_logger.isInfoEnabled()) {
-            s_logger.info("Management server (host id : " + _mshostId + ") is being started at " + _clusterNodeIP + ":" + _currentServiceAdapter.getServicePort());
+        if (logger.isInfoEnabled()) {
+            logger.info("Management server (host id : " + _mshostId + ") is being started at " + _clusterNodeIP + ":" + _currentServiceAdapter.getServicePort());
         }
 
         _mshostPeerDao.clearPeerInfo(_mshostId);
@@ -1037,8 +1035,8 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
         _heartbeatScheduler.scheduleAtFixedRate(getHeartbeatTask(), HeartbeatInterval.value(), HeartbeatInterval.value(), TimeUnit.MILLISECONDS);
         _notificationExecutor.submit(getNotificationTask());
 
-        if (s_logger.isInfoEnabled()) {
-            s_logger.info("Cluster manager was started successfully");
+        if (logger.isInfoEnabled()) {
+            logger.info("Cluster manager was started successfully");
         }
 
         return true;
@@ -1047,29 +1045,17 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
     @Override
     @DB
     public boolean stop() {
-        if (s_logger.isInfoEnabled()) {
-            s_logger.info("Stopping Cluster manager, msid : " + _msId);
+        if (logger.isInfoEnabled()) {
+            logger.info("Stopping Cluster manager, msid : " + _msId);
         }
 
         if (_mshostId != null) {
-            ManagementServerHostVO mshost = _mshostDao.findByMsid(_msId);
-            if (mshost != null) {
-                ManagementServerStatusVO mshostStatus = mshostStatusDao.findByMsId(mshost.getUuid());
-                if (mshostStatus != null) {
-                    mshost.setState(ManagementServerHost.State.Down);
-                    mshostStatus.setLastJvmStop(new Date());
-                    _mshostDao.update(_mshostId, mshost);
-                    mshostStatusDao.update(mshostStatus.getId(), mshostStatus);
-                } else {
-                    s_logger.warn(String.format("Found a management server host [%s] without a status. This should never happen!", mshost));
-                    mshostStatus = new ManagementServerStatusVO();
-                    mshostStatus.setMsId(mshost.getUuid());
-                    mshostStatus.setLastSystemBoot(new Date());
-                    mshostStatus.setLastJvmStart(new Date());
-                    mshostStatus.setUpdated(new Date());
-                    mshostStatusDao.persist(mshostStatus);
-                }
-            }
+            final ManagementServerHostVO mshost = _mshostDao.findByMsid(_msId);
+            final ManagementServerStatusVO mshostStatus = mshostStatusDao.findByMsId(mshost.getUuid());
+            mshost.setState(ManagementServerHost.State.Down);
+            mshostStatus.setLastJvmStop(new Date());
+            _mshostDao.update(_mshostId, mshost);
+            mshostStatusDao.update(mshostStatus.getId(), mshostStatus);
         }
 
         _heartbeatScheduler.shutdownNow();
@@ -1081,8 +1067,8 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
         } catch (final InterruptedException e) {
         }
 
-        if (s_logger.isInfoEnabled()) {
-            s_logger.info("Cluster manager is stopped");
+        if (logger.isInfoEnabled()) {
+            logger.info("Cluster manager is stopped");
         }
 
         return true;
@@ -1090,8 +1076,8 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
 
     @Override
     public boolean configure(final String name, final Map<String, Object> params) throws ConfigurationException {
-        if (s_logger.isInfoEnabled()) {
-            s_logger.info("Start configuring cluster manager : " + name);
+        if (logger.isInfoEnabled()) {
+            logger.info("Start configuring cluster manager : " + name);
         }
 
         final Properties dbProps = DbProperties.getDbProperties();
@@ -1101,8 +1087,8 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
         }
         _clusterNodeIP = _clusterNodeIP.trim();
 
-        if (s_logger.isInfoEnabled()) {
-            s_logger.info("Cluster node IP : " + _clusterNodeIP);
+        if (logger.isInfoEnabled()) {
+            logger.info("Cluster node IP : " + _clusterNodeIP);
         }
 
         if (!NetUtils.isLocalAddress(_clusterNodeIP)) {
@@ -1127,8 +1113,8 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
 
         checkConflicts();
 
-        if (s_logger.isInfoEnabled()) {
-            s_logger.info("Cluster manager is configured.");
+        if (logger.isInfoEnabled()) {
+            logger.info("Cluster manager is configured.");
         }
         return true;
     }
@@ -1186,7 +1172,7 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
 
         final String targetIp = mshost.getServiceIP();
         if ("127.0.0.1".equals(targetIp) || "0.0.0.0".equals(targetIp)) {
-            s_logger.info("ping management node cluster service can not be performed on self");
+            logger.info("ping management node cluster service can not be performed on self");
             return false;
         }
 
@@ -1194,7 +1180,7 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
         while (--retry > 0) {
             SocketChannel sch = null;
             try {
-                s_logger.info("Trying to connect to " + targetIp);
+                logger.info("Trying to connect to " + targetIp);
                 sch = SocketChannel.open();
                 sch.configureBlocking(true);
                 sch.socket().setSoTimeout(5000);
@@ -1204,9 +1190,9 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
                 return true;
             } catch (final IOException e) {
                 if (e instanceof ConnectException) {
-                    s_logger.error("Unable to ping management server at " + targetIp + ":" + mshost.getServicePort() + " due to ConnectException");
-                    if (s_logger.isDebugEnabled()) {
-                        s_logger.debug("Unable to ping management server at " + targetIp + ":" + mshost.getServicePort() + " due to ConnectException", e);
+                    logger.error("Unable to ping management server at " + targetIp + ":" + mshost.getServicePort() + " due to ConnectException");
+                    if (logger.isDebugEnabled()) {
+                        logger.debug("Unable to ping management server at " + targetIp + ":" + mshost.getServicePort() + " due to ConnectException", e);
                     }
                     return false;
                 }
@@ -1225,7 +1211,7 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
             }
         }
 
-        s_logger.error("Unable to ping management server at " + targetIp + ":" + mshost.getServicePort() + " after retries");
+        logger.error("Unable to ping management server at " + targetIp + ":" + mshost.getServicePort() + " after retries");
         return false;
     }
 
@@ -1242,25 +1228,25 @@ public class ClusterManagerImpl extends ManagerBase implements ClusterManager, C
                 if ("127.0.0.1".equals(_clusterNodeIP)) {
                     if (pingManagementNode(peer.getMsid())) {
                         final String msg = "Detected another management node with localhost IP is already running, please check your cluster configuration";
-                        s_logger.error(msg);
+                        logger.error(msg);
                         throw new ConfigurationException(msg);
                     } else {
                         final String msg =
                                 "Detected another management node with localhost IP is considered as running in DB, however it is not pingable, we will continue cluster initialization with this management server node";
-                        s_logger.info(msg);
+                        logger.info(msg);
                     }
                 } else {
                     if (pingManagementNode(peer.getMsid())) {
                         final String msg =
                                 "Detected that another management node with the same IP " + peer.getServiceIP() +
                                 " is already running, please check your cluster configuration";
-                        s_logger.error(msg);
+                        logger.error(msg);
                         throw new ConfigurationException(msg);
                     } else {
                         final String msg =
                                 "Detected that another management node with the same IP " + peer.getServiceIP() +
                                 " is considered as running in DB, however it is not pingable, we will continue cluster initialization with this management server node";
-                        s_logger.info(msg);
+                        logger.info(msg);
                     }
                 }
             }
