@@ -19,7 +19,6 @@ package org.apache.cloudstack.framework.config;
 import java.sql.Date;
 
 import org.apache.cloudstack.framework.config.impl.ConfigDepotImpl;
-import org.apache.cloudstack.framework.config.impl.ConfigurationVO;
 
 import com.cloud.utils.Pair;
 import com.cloud.utils.Ternary;
@@ -41,7 +40,7 @@ public class ConfigKey<T> {
     }
 
     public enum Kind {
-        CSV, Order, Select
+        CSV, Order, Select, WhitespaceSeparatedListWithOptions
     }
 
     private final String _category;
@@ -136,6 +135,10 @@ public class ConfigKey<T> {
         this(type, name, category, defaultValue, description, isDynamic, Scope.Global, null);
     }
 
+    public ConfigKey(String category, Class<T> type, String name, String defaultValue, String description, boolean isDynamic, Kind kind, String options) {
+        this(type, name, category, defaultValue, description, isDynamic, Scope.Global, null, null, null, null, null, kind, options);
+    }
+
     public ConfigKey(String category, Class<T> type, String name, String defaultValue, String description, boolean isDynamic, String parent) {
         this(type, name, category, defaultValue, description, isDynamic, Scope.Global, null, null, parent, null, null, null, null);
     }
@@ -211,42 +214,38 @@ public class ConfigKey<T> {
 
     public T value() {
         if (_value == null || isDynamic()) {
-            ConfigurationVO vo = s_depot != null ? s_depot.global().findById(key()) : null;
-            final String value = (vo != null && vo.getValue() != null) ? vo.getValue() : defaultValue();
-            _value = ((value == null) ? (T)defaultValue() : valueOf(value));
+            String value = s_depot != null ? s_depot.getConfigStringValue(_name, Scope.Global, null) : null;
+            _value = valueOf((value == null) ? defaultValue() : value);
         }
 
         return _value;
     }
 
-    public T valueIn(Long id) {
+    protected T valueInScope(Scope scope, Long id) {
         if (id == null) {
             return value();
         }
 
-        String value = s_depot != null ? s_depot.findScopedConfigStorage(this).getConfigValue(id, this) : null;
+        String value = s_depot != null ? s_depot.getConfigStringValue(_name, scope, id) : null;
         if (value == null) {
             return value();
-        } else {
-            return valueOf(value);
         }
+        return valueOf(value);
+    }
+
+    public T valueIn(Long id) {
+        return valueInScope(_scope, id);
     }
 
     public T valueInDomain(Long domainId) {
-        if (domainId == null) {
-            return value();
-        }
-
-        String value = s_depot != null ? s_depot.getDomainScope(this).getConfigValue(domainId, this) : null;
-        if (value == null) {
-            return value();
-        } else {
-            return valueOf(value);
-        }
+        return valueInScope(Scope.Domain, domainId);
     }
 
     @SuppressWarnings("unchecked")
     protected T valueOf(String value) {
+        if (value == null) {
+            return null;
+        }
         Number multiplier = 1;
         if (multiplier() != null) {
             multiplier = (Number)multiplier();
