@@ -29,7 +29,6 @@ import javax.management.MalformedObjectNameException;
 import javax.management.NotCompliantMBeanException;
 import javax.naming.ConfigurationException;
 
-import org.apache.log4j.Logger;
 
 import com.cloud.utils.component.ComponentLifecycle;
 import com.cloud.utils.component.SystemIntegrityChecker;
@@ -39,7 +38,6 @@ import com.cloud.utils.mgmt.ManagementBean;
 
 public class CloudStackExtendedLifeCycle extends AbstractBeanCollector {
 
-    private static final Logger log = Logger.getLogger(CloudStackExtendedLifeCycle.class);
 
     Map<Integer, Set<ComponentLifecycle>> sorted = new TreeMap<Integer, Set<ComponentLifecycle>>();
 
@@ -59,22 +57,23 @@ public class CloudStackExtendedLifeCycle extends AbstractBeanCollector {
 
     protected void checkIntegrity() {
         for (SystemIntegrityChecker checker : getBeans(SystemIntegrityChecker.class)) {
-            log.info("Running system integrity checker " + checker);
+            logger.info("Running system integrity checker " + checker);
 
             checker.check();
         }
     }
 
     public void startBeans() {
-        log.info("Starting CloudStack Components");
+        logger.info("Starting CloudStack Components");
 
         with(new WithComponentLifeCycle() {
             @Override
             public void with(ComponentLifecycle lifecycle) {
+                logger.info("starting bean {}.", lifecycle.getName());
                 try {
                     lifecycle.start();
-                } catch (Throwable e) {
-                    log.warn("Unable to start component: " + lifecycle.getName(), e);
+                } catch (Exception e) {
+                    logger.error("Error on starting bean {} - {}", lifecycle.getName(), e.getMessage(), e);
                 }
 
                 if (lifecycle instanceof ManagementBean) {
@@ -82,51 +81,59 @@ public class CloudStackExtendedLifeCycle extends AbstractBeanCollector {
                     try {
                         JmxUtil.registerMBean(mbean);
                     } catch (MalformedObjectNameException e) {
-                        log.warn("Unable to register MBean: " + mbean.getName(), e);
+                        logger.warn("Unable to register MBean: " + mbean.getName(), e);
                     } catch (InstanceAlreadyExistsException e) {
-                        log.warn("Unable to register MBean: " + mbean.getName(), e);
+                        logger.warn("Unable to register MBean: " + mbean.getName(), e);
                     } catch (MBeanRegistrationException e) {
-                        log.warn("Unable to register MBean: " + mbean.getName(), e);
+                        logger.warn("Unable to register MBean: " + mbean.getName(), e);
                     } catch (NotCompliantMBeanException e) {
-                        log.warn("Unable to register MBean: " + mbean.getName(), e);
+                        logger.warn("Unable to register MBean: " + mbean.getName(), e);
                     }
-                    log.info("Registered MBean: " + mbean.getName());
+                    logger.info("Registered MBean: " + mbean.getName());
                 }
             }
         });
 
-        log.info("Done Starting CloudStack Components");
+        logger.info("Done Starting CloudStack Components");
     }
 
     public void stopBeans() {
+        logger.info("Stopping CloudStack Components");
+
         with(new WithComponentLifeCycle() {
             @Override
             public void with(ComponentLifecycle lifecycle) {
-                log.info("stopping bean " + lifecycle.getName());
-                lifecycle.stop();
+                logger.info("stopping bean {}.", lifecycle.getName());
+                try {
+                    lifecycle.stop();
+                } catch (Exception e) {
+                    logger.error("Error on stopping bean {} - {}", lifecycle.getName(), e.getMessage(), e);
+                }
             }
         });
+
+        logger.info("Done Stopping CloudStack Components");
     }
 
     private void configure() {
-        log.info("Configuring CloudStack Components");
+        logger.info("Configuring CloudStack Components");
 
         with(new WithComponentLifeCycle() {
             @Override
             public void with(ComponentLifecycle lifecycle) {
                 try {
+                    logger.info("configuring bean {}.", lifecycle.getName());
                     lifecycle.configure(lifecycle.getName(), lifecycle.getConfigParams());
                 } catch (ConfigurationException e) {
-                    log.error("Failed to configure " +  lifecycle.getName(), e);
-                    throw new CloudRuntimeException(e);
-                } catch (Throwable e) {
-                    log.error("Failed to configure " +  lifecycle.getName(), e);
+                    logger.error("Failed to configure " +  lifecycle.getName(), e);
                     throw new CloudRuntimeException(e);
+                } catch (Exception e) {
+                    logger.error("Error on configuring bean {} - {}", lifecycle.getName(), e.getMessage(), e);
                 }
             }
         });
 
-        log.info("Done Configuring CloudStack Components");
+        logger.info("Done Configuring CloudStack Components");
     }
 
     private void sortBeans() {
