@@ -39,7 +39,6 @@ import org.apache.cloudstack.framework.config.ConfigKey;
 import org.apache.cloudstack.framework.config.Configurable;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang3.BooleanUtils;
-import org.apache.log4j.Logger;
 
 import com.cloud.agent.AgentManager;
 import com.cloud.agent.api.Answer;
@@ -65,7 +64,6 @@ import com.cloud.vm.dao.VMInstanceDao;
 
 public class VeeamBackupProvider extends AdapterBase implements BackupProvider, Configurable {
 
-    private static final Logger LOG = Logger.getLogger(VeeamBackupProvider.class);
     public static final String BACKUP_IDENTIFIER = "-CSBKP-";
 
     public ConfigKey<String> VeeamUrl = new ConfigKey<>("Advanced", String.class,
@@ -120,7 +118,7 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
         } catch (URISyntaxException e) {
             throw new CloudRuntimeException("Failed to parse Veeam API URL: " + e.getMessage());
         } catch (NoSuchAlgorithmException | KeyManagementException e) {
-            LOG.error("Failed to build Veeam API client due to: ", e);
+            logger.error("Failed to build Veeam API client due to: ", e);
         }
         throw new CloudRuntimeException("Failed to build Veeam API client");
     }
@@ -175,7 +173,7 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
         final String clonedJobName = getGuestBackupName(vm.getInstanceName(), vm.getUuid());
 
         if (!client.cloneVeeamJob(parentJob, clonedJobName)) {
-            LOG.error("Failed to clone pre-defined Veeam job (backup offering) for backup offering ID: " + backupOffering.getExternalId() + " but will check the list of jobs again if it was eventually succeeded.");
+            logger.error("Failed to clone pre-defined Veeam job (backup offering) for backup offering ID: " + backupOffering.getExternalId() + " but will check the list of jobs again if it was eventually succeeded.");
         }
 
         for (final BackupOffering job : client.listJobs()) {
@@ -184,7 +182,7 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
                 if (BooleanUtils.isTrue(clonedJob.getScheduleConfigured()) && !clonedJob.getScheduleEnabled()) {
                     client.toggleJobSchedule(clonedJob.getId());
                 }
-                LOG.debug("Veeam job (backup offering) for backup offering ID: " + backupOffering.getExternalId() + " found, now trying to assign the VM to the job.");
+                logger.debug("Veeam job (backup offering) for backup offering ID: " + backupOffering.getExternalId() + " found, now trying to assign the VM to the job.");
                 final VmwareDatacenter vmwareDC = findVmwareDatacenterForVM(vm);
                 if (client.addVMToVeeamJob(job.getExternalId(), vm.getInstanceName(), vmwareDC.getVcenterHost())) {
                     ((VMInstanceVO) vm).setBackupExternalId(job.getExternalId());
@@ -199,20 +197,17 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
     public boolean removeVMFromBackupOffering(final VirtualMachine vm) {
         final VeeamClient client = getClient(vm.getDataCenterId());
         final VmwareDatacenter vmwareDC = findVmwareDatacenterForVM(vm);
-        if (vm.getBackupExternalId() == null) {
-            throw new CloudRuntimeException("The VM does not have a backup job assigned.");
-        }
         try {
             if (!client.removeVMFromVeeamJob(vm.getBackupExternalId(), vm.getInstanceName(), vmwareDC.getVcenterHost())) {
-                LOG.warn("Failed to remove VM from Veeam Job id: " + vm.getBackupExternalId());
+                logger.warn("Failed to remove VM from Veeam Job id: " + vm.getBackupExternalId());
             }
         } catch (Exception e) {
-            LOG.debug("VM was removed from the job so could not remove again, trying to delete the veeam job now.", e);
+            logger.debug("VM was removed from the job so could not remove again, trying to delete the veeam job now.", e);
         }
 
         final String clonedJobName = getGuestBackupName(vm.getInstanceName(), vm.getUuid());
         if (!client.deleteJobAndBackup(clonedJobName)) {
-            LOG.warn("Failed to remove Veeam job and backup for job: " + clonedJobName);
+            logger.warn("Failed to remove Veeam job and backup for job: " + clonedJobName);
             throw new CloudRuntimeException("Failed to delete Veeam B&R job and backup, an operation may be in progress. Please try again after some time.");
         }
         client.syncBackupRepository();
@@ -237,7 +232,7 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
             throw new CloudRuntimeException(String.format("Could not find any VM associated with the Backup [uuid: %s, externalId: %s].", backup.getUuid(), backup.getExternalId()));
         }
         if (!forced) {
-            LOG.debug(String.format("Veeam backup provider does not have a safe way to remove a single restore point, which results in all backup chain being removed. "
+            logger.debug(String.format("Veeam backup provider does not have a safe way to remove a single restore point, which results in all backup chain being removed. "
                     + "More information about this limitation can be found in the links: [%s, %s].", "https://forums.veeam.com/powershell-f26/removing-a-single-restorepoint-t21061.html",
                     "https://helpcenter.veeam.com/docs/backup/vsphere/retention_separate_vms.html?ver=110"));
             throw new CloudRuntimeException("Veeam backup provider does not have a safe way to remove a single restore point, which results in all backup chain being removed. "
@@ -266,7 +261,7 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
         try {
             return getClient(vm.getDataCenterId()).restoreFullVM(vm.getInstanceName(), restorePointId);
         } catch (Exception ex) {
-            LOG.error(String.format("Failed to restore Full VM due to: %s. Retrying after some preparation", ex.getMessage()));
+            logger.error(String.format("Failed to restore Full VM due to: %s. Retrying after some preparation", ex.getMessage()));
             prepareForBackupRestoration(vm);
             return getClient(vm.getDataCenterId()).restoreFullVM(vm.getInstanceName(), restorePointId);
         }
@@ -276,7 +271,7 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
         if (!Hypervisor.HypervisorType.VMware.equals(vm.getHypervisorType())) {
             return;
         }
-        LOG.info("Preparing for restoring VM " + vm);
+        logger.info("Preparing for restoring VM " + vm);
         PrepareForBackupRestorationCommand command = new PrepareForBackupRestorationCommand(vm.getInstanceName());
         Long hostId = virtualMachineManager.findClusterAndHostIdForVm(vm.getId()).second();
         if (hostId == null) {
@@ -285,7 +280,7 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
         try {
             Answer answer = agentMgr.easySend(hostId, command);
             if (answer != null && answer.getResult()) {
-                LOG.info("Succeeded to prepare for restoring VM " + vm);
+                logger.info("Succeeded to prepare for restoring VM " + vm);
             } else {
                 throw new CloudRuntimeException(String.format("Failed to prepare for restoring VM %s. details: %s", vm,
                         (answer != null ? answer.getDetails() : null)));
@@ -296,7 +291,7 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
     }
 
     @Override
-    public Pair<Boolean, String> restoreBackedUpVolume(Backup backup, String volumeUuid, String hostIp, String dataStoreUuid) {
+    public Pair<Boolean, String> restoreBackedUpVolume(Backup backup, String volumeUuid, String hostIp, String dataStoreUuid, Pair<String, VirtualMachine.State> vmNameAndState) {
         final Long zoneId = backup.getZoneId();
         final String restorePointId = backup.getExternalId();
         return getClient(zoneId).restoreVMToDifferentLocation(restorePointId, hostIp, dataStoreUuid);
@@ -306,12 +301,12 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
     public Map<VirtualMachine, Backup.Metric> getBackupMetrics(final Long zoneId, final List<VirtualMachine> vms) {
         final Map<VirtualMachine, Backup.Metric> metrics = new HashMap<>();
         if (CollectionUtils.isEmpty(vms)) {
-            LOG.warn("Unable to get VM Backup Metrics because the list of VMs is empty.");
+            logger.warn("Unable to get VM Backup Metrics because the list of VMs is empty.");
             return metrics;
         }
 
         List<String> vmUuids = vms.stream().filter(Objects::nonNull).map(VirtualMachine::getUuid).collect(Collectors.toList());
-        LOG.debug(String.format("Get Backup Metrics for VMs: [%s].", String.join(", ", vmUuids)));
+        logger.debug(String.format("Get Backup Metrics for VMs: [%s].", String.join(", ", vmUuids)));
 
         final Map<String, Backup.Metric> backendMetrics = getClient(zoneId).getBackupMetrics();
         for (final VirtualMachine vm : vms) {
@@ -320,7 +315,7 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
             }
 
             Metric metric = backendMetrics.get(vm.getUuid());
-            LOG.debug(String.format("Metrics for VM [uuid: %s, name: %s] is [backup size: %s, data size: %s].", vm.getUuid(),
+            logger.debug(String.format("Metrics for VM [uuid: %s, name: %s] is [backup size: %s, data size: %s].", vm.getUuid(),
                     vm.getInstanceName(), metric.getBackupSize(), metric.getDataSize()));
             metrics.put(vm, metric);
         }
@@ -336,7 +331,7 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
         for (final Backup backup : backupsInDb) {
             if (restorePoint.getId().equals(backup.getExternalId())) {
                 if (metric != null) {
-                    LOG.debug(String.format("Update backup with [uuid: %s, external id: %s] from [size: %s, protected size: %s] to [size: %s, protected size: %s].",
+                    logger.debug(String.format("Update backup with [uuid: %s, external id: %s] from [size: %s, protected size: %s] to [size: %s, protected size: %s].",
                             backup.getUuid(), backup.getExternalId(), backup.getSize(), backup.getProtectedSize(), metric.getBackupSize(), metric.getDataSize()));
 
                     ((BackupVO) backup).setSize(metric.getBackupSize());
@@ -353,7 +348,7 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
     public void syncBackups(VirtualMachine vm, Backup.Metric metric) {
         List<Backup.RestorePoint> restorePoints = listRestorePoints(vm);
         if (CollectionUtils.isEmpty(restorePoints)) {
-            LOG.debug(String.format("Can't find any restore point to VM: [uuid: %s, name: %s].", vm.getUuid(), vm.getInstanceName()));
+            logger.debug(String.format("Can't find any restore point to VM: [uuid: %s, name: %s].", vm.getUuid(), vm.getInstanceName()));
             return;
         }
         Transaction.execute(new TransactionCallbackNoReturn() {
@@ -384,7 +379,7 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
                         backup.setDomainId(vm.getDomainId());
                         backup.setZoneId(vm.getDataCenterId());
 
-                        LOG.debug(String.format("Creating a new entry in backups: [uuid: %s, vm_id: %s, external_id: %s, type: %s, date: %s, backup_offering_id: %s, account_id: %s, "
+                        logger.debug(String.format("Creating a new entry in backups: [uuid: %s, vm_id: %s, external_id: %s, type: %s, date: %s, backup_offering_id: %s, account_id: %s, "
                                         + "domain_id: %s, zone_id: %s].", backup.getUuid(), backup.getVmId(), backup.getExternalId(), backup.getType(), backup.getDate(),
                                 backup.getBackupOfferingId(), backup.getAccountId(), backup.getDomainId(), backup.getZoneId()));
                         backupDao.persist(backup);
@@ -395,7 +390,7 @@ public class VeeamBackupProvider extends AdapterBase implements BackupProvider,
                     }
                 }
                 for (final Long backupIdToRemove : removeList) {
-                    LOG.warn(String.format("Removing backup with ID: [%s].", backupIdToRemove));
+                    logger.warn(String.format("Removing backup with ID: [%s].", backupIdToRemove));
                     backupDao.remove(backupIdToRemove);
                 }
             }
