@@ -79,7 +79,8 @@ import org.apache.http.conn.ssl.NoopHostnameVerifier;
 import org.apache.http.conn.ssl.SSLConnectionSocketFactory;
 import org.apache.http.entity.StringEntity;
 import org.apache.http.impl.client.HttpClientBuilder;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 
 import com.cloud.utils.NumbersUtil;
 import com.cloud.utils.Pair;
@@ -93,7 +94,7 @@ import com.fasterxml.jackson.dataformat.xml.ser.ToXmlGenerator;
 import org.apache.commons.lang3.StringUtils;
 
 public class VeeamClient {
-    private static final Logger LOG = Logger.getLogger(VeeamClient.class);
+    protected Logger logger = LogManager.getLogger(getClass());
     private static final String FAILED_TO_DELETE = "Failed to delete";
 
     private final URI apiURI;
@@ -193,24 +194,24 @@ public class VeeamClient {
         );
         Pair<Boolean, String> response = executePowerShellCommands(cmds);
         if (response == null || !response.first() || response.second() == null || StringUtils.isBlank(response.second().trim())) {
-            LOG.error("Failed to get veeam server version, using default version");
+            logger.error("Failed to get veeam server version, using default version");
             return 0;
         } else {
             Integer majorVersion = NumbersUtil.parseInt(response.second().trim().split("\\.")[0], 0);
-            LOG.info(String.format("Veeam server full version is %s, major version is %s", response.second().trim(), majorVersion));
+            logger.info(String.format("Veeam server full version is %s, major version is %s", response.second().trim(), majorVersion));
             return majorVersion;
         }
     }
 
     private void checkResponseOK(final HttpResponse response) {
         if (response.getStatusLine().getStatusCode() == HttpStatus.SC_NO_CONTENT) {
-            LOG.debug("Requested Veeam resource does not exist");
+            logger.debug("Requested Veeam resource does not exist");
             return;
         }
         if (!(response.getStatusLine().getStatusCode() == HttpStatus.SC_OK ||
                 response.getStatusLine().getStatusCode() == HttpStatus.SC_ACCEPTED) &&
                 response.getStatusLine().getStatusCode() != HttpStatus.SC_NO_CONTENT) {
-            LOG.debug(String.format("HTTP request failed, status code is [%s], response is: [%s].", response.getStatusLine().getStatusCode(), response.toString()));
+            logger.debug(String.format("HTTP request failed, status code is [%s], response is: [%s].", response.getStatusLine().getStatusCode(), response.toString()));
             throw new ServerApiException(ApiErrorCode.INTERNAL_ERROR, "Got invalid API status code returned by the Veeam server");
         }
     }
@@ -228,7 +229,7 @@ public class VeeamClient {
         final HttpResponse response = httpClient.execute(request);
         checkAuthFailure(response);
 
-        LOG.debug(String.format("Response received in GET request is: [%s] for URL: [%s].", response.toString(), url));
+        logger.debug(String.format("Response received in GET request is: [%s] for URL: [%s].", response.toString(), url));
         return response;
     }
 
@@ -254,7 +255,7 @@ public class VeeamClient {
         final HttpResponse response = httpClient.execute(request);
         checkAuthFailure(response);
 
-        LOG.debug(String.format("Response received in POST request with body [%s] is: [%s] for URL [%s].", xml, response.toString(), url));
+        logger.debug(String.format("Response received in POST request with body [%s] is: [%s] for URL [%s].", xml, response.toString(), url));
         return response;
     }
 
@@ -265,7 +266,7 @@ public class VeeamClient {
         final HttpResponse response = httpClient.execute(request);
         checkAuthFailure(response);
 
-        LOG.debug(String.format("Response received in DELETE request is: [%s] for URL [%s].", response.toString(), url));
+        logger.debug(String.format("Response received in DELETE request is: [%s] for URL [%s].", response.toString(), url));
         return response;
     }
 
@@ -274,7 +275,7 @@ public class VeeamClient {
     ///////////////////////////////////////////////////////////////////
 
     private String findDCHierarchy(final String vmwareDcName) {
-        LOG.debug("Trying to find hierarchy ID for vmware datacenter: " + vmwareDcName);
+        logger.debug("Trying to find hierarchy ID for vmware datacenter: " + vmwareDcName);
 
         try {
             final HttpResponse response = get("/hierarchyRoots");
@@ -287,14 +288,14 @@ public class VeeamClient {
                 }
             }
         } catch (final IOException e) {
-            LOG.error("Failed to list Veeam jobs due to:", e);
+            logger.error("Failed to list Veeam jobs due to:", e);
             checkResponseTimeOut(e);
         }
         throw new CloudRuntimeException("Failed to find hierarchy reference for VMware datacenter " + vmwareDcName + " in Veeam, please ask administrator to check Veeam B&R manager configuration");
     }
 
     private String lookupVM(final String hierarchyId, final String vmName) {
-        LOG.debug("Trying to lookup VM from veeam hierarchy:" + hierarchyId + " for vm name:" + vmName);
+        logger.debug("Trying to lookup VM from veeam hierarchy:" + hierarchyId + " for vm name:" + vmName);
 
         try {
             final HttpResponse response = get(String.format("/lookup?host=%s&type=Vm&name=%s", hierarchyId, vmName));
@@ -310,7 +311,7 @@ public class VeeamClient {
                 }
             }
         } catch (final IOException e) {
-            LOG.error("Failed to list Veeam jobs due to:", e);
+            logger.error("Failed to list Veeam jobs due to:", e);
             checkResponseTimeOut(e);
         }
         throw new CloudRuntimeException("Failed to lookup VM " + vmName + " in Veeam, please ask administrator to check Veeam B&R manager configuration");
@@ -336,7 +337,7 @@ public class VeeamClient {
             if (polledTask.getState().equals("Finished")) {
                 final HttpResponse taskDeleteResponse = delete("/tasks/" + task.getTaskId());
                 if (taskDeleteResponse.getStatusLine().getStatusCode() != HttpStatus.SC_NO_CONTENT) {
-                    LOG.warn("Operation failed for veeam task id=" + task.getTaskId());
+                    logger.warn("Operation failed for veeam task id=" + task.getTaskId());
                 }
                 if (polledTask.getResult().getSuccess().equals("true")) {
                     Pair<String, String> pair = getRelatedLinkPair(polledTask.getLink());
@@ -355,7 +356,7 @@ public class VeeamClient {
             try {
                 Thread.sleep(this.taskPollInterval * 1000);
             } catch (InterruptedException e) {
-                LOG.debug("Failed to sleep while polling for Veeam task status due to: ", e);
+                logger.debug("Failed to sleep while polling for Veeam task status due to: ", e);
             }
         }
         return false;
@@ -377,17 +378,17 @@ public class VeeamClient {
 
             if (session.getResult().equalsIgnoreCase("Failed")) {
                 String sessionUid = session.getUid();
-                LOG.error(String.format("Failed to restore backup [%s] of VM [%s] due to [%s].",
+                logger.error(String.format("Failed to restore backup [%s] of VM [%s] due to [%s].",
                         sessionUid, session.getVmDisplayName(),
                         getRestoreVmErrorDescription(StringUtils.substringAfterLast(sessionUid, ":"))));
                 throw new CloudRuntimeException(String.format("Restore job [%s] failed.", sessionUid));
             }
-            LOG.debug(String.format("Waiting %s seconds, out of a total of %s seconds, for the restore backup process to finish.", j, restoreTimeout));
+            logger.debug(String.format("Waiting %s seconds, out of a total of %s seconds, for the restore backup process to finish.", j, restoreTimeout));
 
             try {
                 Thread.sleep(1000);
             } catch (InterruptedException ignored) {
-                LOG.trace(String.format("Ignoring InterruptedException [%s] when waiting for restore session finishes.", ignored.getMessage()));
+                logger.trace(String.format("Ignoring InterruptedException [%s] when waiting for restore session finishes.", ignored.getMessage()));
             }
         }
         throw new CloudRuntimeException("Related job type: " + type + " was not successful");
@@ -407,7 +408,7 @@ public class VeeamClient {
     ////////////////////////////////////////////////////////
 
     public Ref listBackupRepository(final String backupServerId, final String backupName) {
-        LOG.debug(String.format("Trying to list backup repository for backup job [name: %s] in server [id: %s].", backupName, backupServerId));
+        logger.debug(String.format("Trying to list backup repository for backup job [name: %s] in server [id: %s].", backupName, backupServerId));
         try {
             String repositoryName = getRepositoryNameFromJob(backupName);
             final HttpResponse response = get(String.format("/backupServers/%s/repositories", backupServerId));
@@ -420,7 +421,7 @@ public class VeeamClient {
                 }
             }
         } catch (final IOException e) {
-            LOG.error(String.format("Failed to list Veeam backup repository used by backup job [name: %s] due to: [%s].", backupName, e.getMessage()), e);
+            logger.error(String.format("Failed to list Veeam backup repository used by backup job [name: %s] due to: [%s].", backupName, e.getMessage()), e);
             checkResponseTimeOut(e);
         }
         return null;
@@ -445,23 +446,23 @@ public class VeeamClient {
     }
 
     public void listAllBackups() {
-        LOG.debug("Trying to list Veeam backups");
+        logger.debug("Trying to list Veeam backups");
         try {
             final HttpResponse response = get("/backups");
             checkResponseOK(response);
             final ObjectMapper objectMapper = new XmlMapper();
             final EntityReferences entityReferences = objectMapper.readValue(response.getEntity().getContent(), EntityReferences.class);
             for (final Ref ref : entityReferences.getRefs()) {
-                LOG.debug("Veeam Backup found, name: " + ref.getName() + ", uid: " + ref.getUid() + ", type: " + ref.getType());
+                logger.debug("Veeam Backup found, name: " + ref.getName() + ", uid: " + ref.getUid() + ", type: " + ref.getType());
             }
         } catch (final IOException e) {
-            LOG.error("Failed to list Veeam backups due to:", e);
+            logger.error("Failed to list Veeam backups due to:", e);
             checkResponseTimeOut(e);
         }
     }
 
     public List<BackupOffering> listJobs() {
-        LOG.debug("Trying to list backup policies that are Veeam jobs");
+        logger.debug("Trying to list backup policies that are Veeam jobs");
         try {
             final HttpResponse response = get("/jobs");
             checkResponseOK(response);
@@ -476,14 +477,14 @@ public class VeeamClient {
             }
             return policies;
         } catch (final IOException e) {
-            LOG.error("Failed to list Veeam jobs due to:", e);
+            logger.error("Failed to list Veeam jobs due to:", e);
             checkResponseTimeOut(e);
         }
         return new ArrayList<>();
     }
 
     public Job listJob(final String jobId) {
-        LOG.debug("Trying to list veeam job id: " + jobId);
+        logger.debug("Trying to list veeam job id: " + jobId);
         try {
             final HttpResponse response = get(String.format("/jobs/%s?format=Entity",
                     jobId.replace("urn:veeam:Job:", "")));
@@ -492,40 +493,40 @@ public class VeeamClient {
             objectMapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
             return objectMapper.readValue(response.getEntity().getContent(), Job.class);
         } catch (final IOException e) {
-            LOG.error("Failed to list Veeam jobs due to:", e);
+            logger.error("Failed to list Veeam jobs due to:", e);
             checkResponseTimeOut(e);
         } catch (final ServerApiException e) {
-            LOG.error(e);
+            logger.error(e);
         }
         return null;
     }
 
     public boolean toggleJobSchedule(final String jobId) {
-        LOG.debug("Trying to toggle schedule for Veeam job: " + jobId);
+        logger.debug("Trying to toggle schedule for Veeam job: " + jobId);
         try {
             final HttpResponse response = post(String.format("/jobs/%s?action=toggleScheduleEnabled", jobId), null);
             return checkTaskStatus(response);
         } catch (final IOException e) {
-            LOG.error("Failed to toggle Veeam job schedule due to:", e);
+            logger.error("Failed to toggle Veeam job schedule due to:", e);
             checkResponseTimeOut(e);
         }
         return false;
     }
 
     public boolean startBackupJob(final String jobId) {
-        LOG.debug("Trying to start ad-hoc backup for Veeam job: " + jobId);
+        logger.debug("Trying to start ad-hoc backup for Veeam job: " + jobId);
         try {
             final HttpResponse response = post(String.format("/jobs/%s?action=start", jobId), null);
             return checkTaskStatus(response);
         } catch (final IOException e) {
-            LOG.error("Failed to list Veeam jobs due to:", e);
+            logger.error("Failed to list Veeam jobs due to:", e);
             checkResponseTimeOut(e);
         }
         return false;
     }
 
     public boolean cloneVeeamJob(final Job parentJob, final String clonedJobName) {
-        LOG.debug("Trying to clone veeam job: " + parentJob.getUid() + " with backup uuid: " + clonedJobName);
+        logger.debug("Trying to clone veeam job: " + parentJob.getUid() + " with backup uuid: " + clonedJobName);
         try {
             final Ref repositoryRef = listBackupRepository(parentJob.getBackupServerId(), parentJob.getName());
             if (repositoryRef == null) {
@@ -541,13 +542,13 @@ public class VeeamClient {
             final HttpResponse response = post(String.format("/jobs/%s?action=clone", parentJob.getId()), cloneSpec);
             return checkTaskStatus(response);
         } catch (final Exception e) {
-            LOG.warn("Exception caught while trying to clone Veeam job:", e);
+            logger.warn("Exception caught while trying to clone Veeam job:", e);
         }
         return false;
     }
 
     public boolean addVMToVeeamJob(final String jobId, final String vmwareInstanceName, final String vmwareDcName) {
-        LOG.debug("Trying to add VM to backup offering that is Veeam job: " + jobId);
+        logger.debug("Trying to add VM to backup offering that is Veeam job: " + jobId);
         try {
             final String heirarchyId = findDCHierarchy(vmwareDcName);
             final String veeamVmRefId = lookupVM(heirarchyId, vmwareInstanceName);
@@ -557,14 +558,14 @@ public class VeeamClient {
             final HttpResponse response = post(String.format("/jobs/%s/includes", jobId), vmToBackupJob);
             return checkTaskStatus(response);
         } catch (final IOException e) {
-            LOG.error("Failed to add VM to Veeam job due to:", e);
+            logger.error("Failed to add VM to Veeam job due to:", e);
             checkResponseTimeOut(e);
         }
         throw new CloudRuntimeException("Failed to add VM to backup offering likely due to timeout, please check Veeam tasks");
     }
 
     public boolean removeVMFromVeeamJob(final String jobId, final String vmwareInstanceName, final String vmwareDcName) {
-        LOG.debug("Trying to remove VM from backup offering that is a Veeam job: " + jobId);
+        logger.debug("Trying to remove VM from backup offering that is a Veeam job: " + jobId);
         try {
             final String hierarchyId = findDCHierarchy(vmwareDcName);
             final String veeamVmRefId = lookupVM(hierarchyId, vmwareInstanceName);
@@ -574,7 +575,7 @@ public class VeeamClient {
             objectMapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
             final ObjectsInJob jobObjects = objectMapper.readValue(response.getEntity().getContent(), ObjectsInJob.class);
             if (jobObjects == null || jobObjects.getObjects() == null) {
-                LOG.warn("No objects found in the Veeam job " + jobId);
+                logger.warn("No objects found in the Veeam job " + jobId);
                 return false;
             }
             for (final ObjectInJob jobObject : jobObjects.getObjects()) {
@@ -583,22 +584,22 @@ public class VeeamClient {
                     return checkTaskStatus(deleteResponse);
                 }
             }
-            LOG.warn(vmwareInstanceName + " VM was not found to be attached to Veaam job (backup offering): " + jobId);
+            logger.warn(vmwareInstanceName + " VM was not found to be attached to Veaam job (backup offering): " + jobId);
             return false;
         } catch (final IOException e) {
-            LOG.error("Failed to list Veeam jobs due to:", e);
+            logger.error("Failed to list Veeam jobs due to:", e);
             checkResponseTimeOut(e);
         }
         return false;
     }
 
     public boolean restoreFullVM(final String vmwareInstanceName, final String restorePointId) {
-        LOG.debug("Trying to restore full VM: " + vmwareInstanceName + " from backup");
+        logger.debug("Trying to restore full VM: " + vmwareInstanceName + " from backup");
         try {
             final HttpResponse response = post(String.format("/vmRestorePoints/%s?action=restore", restorePointId), null);
             return checkTaskStatus(response);
         } catch (final IOException e) {
-            LOG.error("Failed to restore full VM due to: ", e);
+            logger.error("Failed to restore full VM due to: ", e);
             checkResponseTimeOut(e);
         }
         throw new CloudRuntimeException("Failed to restore full VM from backup");
@@ -636,9 +637,9 @@ public class VeeamClient {
                     commands, 120000, 120000, 3600000);
 
             if (response == null || !response.first()) {
-                LOG.error(String.format("Veeam PowerShell commands [%s] failed due to: [%s].", commands, response != null ? response.second() : "no PowerShell output returned"));
+                logger.error(String.format("Veeam PowerShell commands [%s] failed due to: [%s].", commands, response != null ? response.second() : "no PowerShell output returned"));
             } else {
-                LOG.debug(String.format("Veeam response for PowerShell commands [%s] is: [%s].", commands, response.second()));
+                logger.debug(String.format("Veeam response for PowerShell commands [%s] is: [%s].", commands, response.second()));
             }
 
             return response;
@@ -666,7 +667,7 @@ public class VeeamClient {
     }
 
     public boolean deleteBackup(final String restorePointId) {
-        LOG.debug(String.format("Trying to delete restore point [name: %s].", restorePointId));
+        logger.debug(String.format("Trying to delete restore point [name: %s].", restorePointId));
         Pair<Boolean, String> result = executePowerShellCommands(Arrays.asList(
                 String.format("$restorePoint = Get-VBRRestorePoint ^| Where-Object { $_.Id -eq '%s' }", restorePointId),
                 "if ($restorePoint) { Remove-VBRRestorePoint -Oib $restorePoint -Confirm:$false",
@@ -679,13 +680,13 @@ public class VeeamClient {
     }
 
     public boolean syncBackupRepository() {
-        LOG.debug("Trying to sync backup repository.");
+        logger.debug("Trying to sync backup repository.");
         Pair<Boolean, String> result = executePowerShellCommands(Arrays.asList(
                 "$repo = Get-VBRBackupRepository",
                 "$Syncs = Sync-VBRBackupRepository -Repository $repo",
                 "while ((Get-VBRSession -ID $Syncs.ID).Result -ne 'Success') { Start-Sleep -Seconds 10 }"
         ));
-        LOG.debug("Done syncing backup repository.");
+        logger.debug("Done syncing backup repository.");
         return result != null && result.first();
     }
 
@@ -698,14 +699,14 @@ public class VeeamClient {
     }
 
     public Map<String, Backup.Metric> getBackupMetricsViaVeeamAPI() {
-        LOG.debug("Trying to get backup metrics via Veeam B&R API");
+        logger.debug("Trying to get backup metrics via Veeam B&R API");
 
         try {
             final HttpResponse response = get(String.format("/backupFiles?format=Entity"));
             checkResponseOK(response);
             return processHttpResponseForBackupMetrics(response.getEntity().getContent());
         } catch (final IOException e) {
-            LOG.error("Failed to get backup metrics via Veeam B&R API due to:", e);
+            logger.error("Failed to get backup metrics via Veeam B&R API due to:", e);
             checkResponseTimeOut(e);
         }
         return new HashMap<>();
@@ -756,7 +757,7 @@ public class VeeamClient {
                 metrics.put(vmUuid, new Backup.Metric(usedSize, dataSize));
             }
         } catch (final IOException e) {
-            LOG.error("Failed to process response to get backup metrics via Veeam B&R API due to:", e);
+            logger.error("Failed to process response to get backup metrics via Veeam B&R API due to:", e);
             checkResponseTimeOut(e);
         }
         return metrics;
@@ -794,7 +795,7 @@ public class VeeamClient {
     }
 
     protected Map<String, Backup.Metric> processPowerShellResultForBackupMetrics(final String result) {
-        LOG.debug("Processing powershell result: " + result);
+        logger.debug("Processing powershell result: " + result);
 
         final String separator = "=====";
         final Map<String, Backup.Metric> sizes = new HashMap<>();
@@ -813,7 +814,7 @@ public class VeeamClient {
     }
 
     private Backup.RestorePoint getRestorePointFromBlock(String[] parts) {
-        LOG.debug(String.format("Processing block of restore points: [%s].", StringUtils.join(parts, ", ")));
+        logger.debug(String.format("Processing block of restore points: [%s].", StringUtils.join(parts, ", ")));
         String id = null;
         Date created = null;
         String type = null;
@@ -852,7 +853,7 @@ public class VeeamClient {
             if (block.isEmpty()) {
                 continue;
             }
-            LOG.debug(String.format("Found restore points from [backupName: %s, vmInternalName: %s] which is: [%s].", backupName, vmInternalName, block));
+            logger.debug(String.format("Found restore points from [backupName: %s, vmInternalName: %s] which is: [%s].", backupName, vmInternalName, block));
             final String[] parts = block.split("\r\n");
             restorePoints.add(getRestorePointFromBlock(parts));
         }
@@ -868,14 +869,14 @@ public class VeeamClient {
     }
 
     public List<Backup.RestorePoint> listVmRestorePointsViaVeeamAPI(String vmInternalName) {
-        LOG.debug(String.format("Trying to list VM restore points via Veeam B&R API for VM %s: ", vmInternalName));
+        logger.debug(String.format("Trying to list VM restore points via Veeam B&R API for VM %s: ", vmInternalName));
 
         try {
             final HttpResponse response = get(String.format("/vmRestorePoints?format=Entity"));
             checkResponseOK(response);
             return processHttpResponseForVmRestorePoints(response.getEntity().getContent(), vmInternalName);
         } catch (final IOException e) {
-            LOG.error("Failed to list VM restore points via Veeam B&R API due to:", e);
+            logger.error("Failed to list VM restore points via Veeam B&R API due to:", e);
             checkResponseTimeOut(e);
         }
         return new ArrayList<>();
@@ -890,7 +891,7 @@ public class VeeamClient {
                 throw new CloudRuntimeException("Could not get VM restore points via Veeam B&R API");
             }
             for (final VmRestorePoint vmRestorePoint : vmRestorePoints.getVmRestorePoints()) {
-                LOG.debug(String.format("Processing VM restore point Name=%s, VmDisplayName=%s for vm name=%s",
+                logger.debug(String.format("Processing VM restore point Name=%s, VmDisplayName=%s for vm name=%s",
                         vmRestorePoint.getName(), vmRestorePoint.getVmDisplayName(), vmInternalName));
                 if (!vmInternalName.equals(vmRestorePoint.getVmDisplayName())) {
                     continue;
@@ -899,7 +900,7 @@ public class VeeamClient {
                 List<Link> links = vmRestorePoint.getLink();
                 for (Link link : links) {
                     if (Arrays.asList(BACKUP_FILE_REFERENCE, RESTORE_POINT_REFERENCE).contains(link.getType()) && !link.getRel().equals("Up")) {
-                        LOG.info(String.format("The VM restore point is not ready. Reference: %s, state: %s", link.getType(), link.getRel()));
+                        logger.info(String.format("The VM restore point is not ready. Reference: %s, state: %s", link.getType(), link.getRel()));
                         isReady = false;
                         break;
                     }
@@ -910,11 +911,11 @@ public class VeeamClient {
                 String vmRestorePointId = vmRestorePoint.getUid().substring(vmRestorePoint.getUid().lastIndexOf(':') + 1);
                 Date created = formatDate(vmRestorePoint.getCreationTimeUtc());
                 String type = vmRestorePoint.getPointType();
-                LOG.debug(String.format("Adding restore point %s, %s, %s", vmRestorePointId, created, type));
+                logger.debug(String.format("Adding restore point %s, %s, %s", vmRestorePointId, created, type));
                 vmRestorePointList.add(new Backup.RestorePoint(vmRestorePointId, created, type));
             }
         } catch (final IOException | ParseException e) {
-            LOG.error("Failed to process response to get VM restore points via Veeam B&R API due to:", e);
+            logger.error("Failed to process response to get VM restore points via Veeam B&R API due to:", e);
             checkResponseTimeOut(e);
         }
         return vmRestorePointList;
@@ -948,7 +949,7 @@ public class VeeamClient {
      * @return the description found in Veeam about the cause of error in the restore process.
      */
     protected String getRestoreVmErrorDescription(String uid) {
-        LOG.debug(String.format("Trying to find the cause of error in the restore process [%s].", uid));
+        logger.debug(String.format("Trying to find the cause of error in the restore process [%s].", uid));
         List<String> cmds = Arrays.asList(
                 String.format("$restoreUid = '%s'", uid),
                 "$restore = Get-VBRRestoreSession -Id $restoreUid",
