@@ -16,11 +16,15 @@
 //under the License.
 package org.apache.cloudstack.api.response;
 
+import java.lang.reflect.Field;
+import java.lang.reflect.Modifier;
+import java.lang.reflect.ParameterizedType;
 import java.math.BigDecimal;
 import java.math.RoundingMode;
 import java.time.LocalDate;
 import java.time.ZoneId;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Calendar;
 import java.util.Collection;
 import java.util.Collections;
@@ -31,38 +35,55 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.ListIterator;
 import java.util.function.Consumer;
+import java.util.stream.Collectors;
 
 import javax.inject.Inject;
 
+import com.cloud.utils.DateUtil;
 import org.apache.cloudstack.api.ApiErrorCode;
 import org.apache.cloudstack.api.ServerApiException;
 import org.apache.cloudstack.api.command.QuotaBalanceCmd;
+import org.apache.cloudstack.api.command.QuotaConfigureEmailCmd;
 import org.apache.cloudstack.api.command.QuotaEmailTemplateListCmd;
 import org.apache.cloudstack.api.command.QuotaEmailTemplateUpdateCmd;
+import org.apache.cloudstack.api.command.QuotaPresetVariablesListCmd;
 import org.apache.cloudstack.api.command.QuotaStatementCmd;
 import org.apache.cloudstack.api.command.QuotaTariffCreateCmd;
 import org.apache.cloudstack.api.command.QuotaTariffListCmd;
 import org.apache.cloudstack.api.command.QuotaTariffUpdateCmd;
 import org.apache.cloudstack.context.CallContext;
+import org.apache.cloudstack.discovery.ApiDiscoveryService;
 import org.apache.cloudstack.quota.QuotaManager;
+import org.apache.cloudstack.quota.QuotaManagerImpl;
 import org.apache.cloudstack.quota.QuotaService;
 import org.apache.cloudstack.quota.QuotaStatement;
+import org.apache.cloudstack.quota.activationrule.presetvariables.ComputingResources;
+import org.apache.cloudstack.quota.activationrule.presetvariables.GenericPresetVariable;
+import org.apache.cloudstack.quota.activationrule.presetvariables.PresetVariableDefinition;
+import org.apache.cloudstack.quota.activationrule.presetvariables.PresetVariables;
+import org.apache.cloudstack.quota.activationrule.presetvariables.Value;
 import org.apache.cloudstack.quota.constant.QuotaConfig;
 import org.apache.cloudstack.quota.constant.QuotaTypes;
 import org.apache.cloudstack.quota.dao.QuotaAccountDao;
 import org.apache.cloudstack.quota.dao.QuotaBalanceDao;
 import org.apache.cloudstack.quota.dao.QuotaCreditsDao;
+import org.apache.cloudstack.quota.dao.QuotaEmailConfigurationDao;
 import org.apache.cloudstack.quota.dao.QuotaEmailTemplatesDao;
 import org.apache.cloudstack.quota.dao.QuotaTariffDao;
-import org.apache.cloudstack.quota.dao.QuotaUsageDao;
 import org.apache.cloudstack.quota.vo.QuotaAccountVO;
+import org.apache.cloudstack.quota.dao.QuotaUsageDao;
 import org.apache.cloudstack.quota.vo.QuotaBalanceVO;
 import org.apache.cloudstack.quota.vo.QuotaCreditsVO;
+import org.apache.cloudstack.quota.vo.QuotaEmailConfigurationVO;
 import org.apache.cloudstack.quota.vo.QuotaEmailTemplatesVO;
 import org.apache.cloudstack.quota.vo.QuotaTariffVO;
 import org.apache.cloudstack.quota.vo.QuotaUsageVO;
 import org.apache.cloudstack.utils.reflectiontostringbuilderutils.ReflectionToStringBuilderUtils;
-import org.apache.log4j.Logger;
+import org.apache.commons.lang3.StringUtils;
+import org.apache.commons.lang3.reflect.FieldUtils;
+import org.apache.commons.lang3.ObjectUtils;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 import org.springframework.stereotype.Component;
 
 import com.cloud.domain.DomainVO;
@@ -81,7 +102,7 @@ import com.cloud.event.EventTypes;
 
 @Component
 public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
-    private static final Logger s_logger = Logger.getLogger(QuotaResponseBuilderImpl.class);
+    protected Logger logger = LogManager.getLogger(getClass());
 
     @Inject
     private QuotaTariffDao _quotaTariffDao;
@@ -101,7 +122,7 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
     @Inject
     private AccountDao _accountDao;
     @Inject
-    private QuotaAccountDao _quotaAccountDao;
+    private QuotaAccountDao quotaAccountDao;
     @Inject
     private DomainDao _domainDao;
     @Inject
@@ -110,9 +131,16 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
     private QuotaStatement _statement;
     @Inject
     private QuotaManager _quotaManager;
+    @Inject
+    private QuotaEmailConfigurationDao quotaEmailConfigurationDao;
+
+    private final Class<?>[] assignableClasses = {GenericPresetVariable.class, ComputingResources.class};
+
+    @Inject
+    private ApiDiscoveryService apiDiscoveryService;
 
     @Override
-    public QuotaTariffResponse createQuotaTariffResponse(QuotaTariffVO tariff) {
+    public QuotaTariffResponse createQuotaTariffResponse(QuotaTariffVO tariff, boolean returnActivationRule) {
         final QuotaTariffResponse response = new QuotaTariffResponse();
         response.setUsageType(tariff.getUsageType());
         response.setUsageName(tariff.getUsageName());
@@ -122,12 +150,15 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
         response.setEffectiveOn(tariff.getEffectiveOn());
         response.setUsageTypeDescription(tariff.getUsageTypeDescription());
         response.setCurrency(QuotaConfig.QuotaCurrencySymbol.value());
-        response.setActivationRule(tariff.getActivationRule());
         response.setName(tariff.getName());
         response.setEndDate(tariff.getEndDate());
         response.setDescription(tariff.getDescription());
-        response.setUuid(tariff.getUuid());
+        response.setId(tariff.getUuid());
         response.setRemoved(tariff.getRemoved());
+        response.setPosition(tariff.getPosition());
+        if (returnActivationRule) {
+            response.setActivationRule(tariff.getActivationRule());
+        }
         return response;
     }
 
@@ -162,7 +193,7 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
                 result.add(qr);
             }
         } else {
-            Pair<List<QuotaAccountVO>, Integer> data = _quotaAccountDao.listAllQuotaAccount(startIndex, pageSize);
+            Pair<List<QuotaAccountVO>, Integer> data = quotaAccountDao.listAllQuotaAccount(startIndex, pageSize);
             count = data.second();
             for (final QuotaAccountVO quotaAccount : data.first()) {
                 AccountVO account = _accountDao.findById(quotaAccount.getId());
@@ -203,6 +234,11 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
         }
     }
 
+    public boolean isUserAllowedToSeeActivationRules(User user) {
+        List<ApiDiscoveryResponse> apiList = (List<ApiDiscoveryResponse>) apiDiscoveryService.listApis(user, null).getResponses();
+        return apiList.stream().anyMatch(response -> StringUtils.equalsAny(response.getName(), "quotaTariffCreate", "quotaTariffUpdate"));
+    }
+
     @Override
     public QuotaBalanceResponse createQuotaBalanceResponse(List<QuotaBalanceVO> quotaBalance, Date startDate, Date endDate) {
         if (quotaBalance == null || quotaBalance.isEmpty()) {
@@ -233,8 +269,8 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
             // Iterate in reverse.
             while (li.hasPrevious()) {
                 QuotaBalanceVO entry = li.previous();
-                if (s_logger.isDebugEnabled()) {
-                    s_logger.debug("createQuotaBalanceResponse: Entry=" + entry);
+                if (logger.isDebugEnabled()) {
+                    logger.debug("createQuotaBalanceResponse: Entry=" + entry);
                 }
                 if (entry.getCreditsId() > 0) {
                     li.remove();
@@ -250,8 +286,8 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
         boolean consecutive = true;
         for (Iterator<QuotaBalanceVO> it = quotaBalance.iterator(); it.hasNext();) {
             QuotaBalanceVO entry = it.next();
-            if (s_logger.isDebugEnabled()) {
-                s_logger.debug("createQuotaBalanceResponse: All Credit Entry=" + entry);
+            if (logger.isDebugEnabled()) {
+                logger.debug("createQuotaBalanceResponse: All Credit Entry=" + entry);
             }
             if (entry.getCreditsId() > 0) {
                 if (consecutive) {
@@ -271,9 +307,9 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
             resp.setStartDate(startDate);
             resp.setStartQuota(startItem.getCreditBalance());
             resp.setEndDate(endDate);
-            if (s_logger.isDebugEnabled()) {
-                s_logger.debug("createQuotaBalanceResponse: Start Entry=" + startItem);
-                s_logger.debug("createQuotaBalanceResponse: End Entry=" + endItem);
+            if (logger.isDebugEnabled()) {
+                logger.debug("createQuotaBalanceResponse: Start Entry=" + startItem);
+                logger.debug("createQuotaBalanceResponse: End Entry=" + endItem);
             }
             resp.setEndQuota(endItem.getCreditBalance().add(lastCredits));
         } else if (quota_activity > 0) {
@@ -313,8 +349,8 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
             quotaUsage.add(dummy);
         }
 
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug(
+        if (logger.isDebugEnabled()) {
+            logger.debug(
                     "createQuotaStatementResponse Type=" + quotaUsage.get(0).getUsageType() + " usage=" + quotaUsage.get(0).getQuotaUsed().setScale(2, RoundingMode.HALF_EVEN)
                     + " rec.id=" + quotaUsage.get(0).getUsageItemId() + " SD=" + quotaUsage.get(0).getStartDate() + " ED=" + quotaUsage.get(0).getEndDate());
         }
@@ -336,8 +372,8 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
         BigDecimal totalUsage = new BigDecimal(0);
         quotaUsage.add(new QuotaUsageVO());// boundary
         QuotaUsageVO prev = quotaUsage.get(0);
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("createQuotaStatementResponse record count=" + quotaUsage.size());
+        if (logger.isDebugEnabled()) {
+            logger.debug("createQuotaStatementResponse record count=" + quotaUsage.size());
         }
         for (final QuotaUsageVO quotaRecord : quotaUsage) {
             if (type != quotaRecord.getUsageType()) {
@@ -368,18 +404,21 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
 
     @Override
     public Pair<List<QuotaTariffVO>, Integer> listQuotaTariffPlans(final QuotaTariffListCmd cmd) {
-        Date startDate = _quotaService.computeAdjustedTime(cmd.getEffectiveDate());
-        Date endDate = _quotaService.computeAdjustedTime(cmd.getEndDate());
+        Date startDate = cmd.getEffectiveDate();
+        Date endDate = cmd.getEndDate();
         Integer usageType = cmd.getUsageType();
         String name = cmd.getName();
         boolean listAll = cmd.isListAll();
         Long startIndex = cmd.getStartIndex();
         Long pageSize = cmd.getPageSizeVal();
+        String uuid = cmd.getId();
+        boolean listOnlyRemoved = cmd.isListOnlyRemoved();
+        String keyword = cmd.getKeyword();
 
-        s_logger.debug(String.format("Listing quota tariffs for parameters [%s].", ReflectionToStringBuilderUtils.reflectOnlySelectedFields(cmd, "effectiveDate",
-                "endDate", "listAll", "name", "page", "pageSize", "usageType")));
+        logger.debug("Listing quota tariffs for parameters [{}].", ReflectionToStringBuilderUtils.reflectOnlySelectedFields(cmd, "effectiveDate",
+                "endDate", "listAll", "name", "page", "pageSize", "usageType", "uuid", "listOnlyRemoved", "keyword"));
 
-        return _quotaTariffDao.listQuotaTariffs(startDate, endDate, usageType, name, null, listAll, startIndex, pageSize);
+        return _quotaTariffDao.listQuotaTariffs(startDate, endDate, usageType, name, uuid, listAll, listOnlyRemoved, startIndex, pageSize, keyword);
     }
 
     @Override
@@ -387,10 +426,11 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
     public QuotaTariffVO updateQuotaTariffPlan(QuotaTariffUpdateCmd cmd) {
         String name = cmd.getName();
         Double value = cmd.getValue();
-        Date endDate = _quotaService.computeAdjustedTime(cmd.getEndDate());
+        Date endDate = cmd.getEndDate();
         String description = cmd.getDescription();
         String activationRule = cmd.getActivationRule();
-        Date now = _quotaService.computeAdjustedTime(new Date());
+        Date now = new Date();
+        Integer position = cmd.getPosition();
 
         warnQuotaTariffUpdateDeprecatedFields(cmd);
 
@@ -405,7 +445,7 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
         currentQuotaTariff.setRemoved(now);
 
         QuotaTariffVO newQuotaTariff = persistNewQuotaTariff(currentQuotaTariff, name, 0, currentQuotaTariffStartDate, cmd.getEntityOwnerId(), endDate, value, description,
-                activationRule);
+                activationRule, position);
         _quotaTariffDao.updateQuotaTariff(currentQuotaTariff);
 
         CallContext.current().setEventResourceId(newQuotaTariff.getId());
@@ -417,16 +457,16 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
         String warnMessage = "The parameter 's%s' for API 'quotaTariffUpdate' is no longer needed and it will be removed in future releases.";
 
         if (cmd.getStartDate() != null) {
-            s_logger.warn(String.format(warnMessage,"startdate"));
+            logger.warn(String.format(warnMessage,"startdate"));
         }
 
         if (cmd.getUsageType() != null) {
-            s_logger.warn(String.format(warnMessage,"usagetype"));
+            logger.warn(String.format(warnMessage,"usagetype"));
         }
     }
 
     protected QuotaTariffVO persistNewQuotaTariff(QuotaTariffVO currentQuotaTariff, String name, int usageType, Date startDate, Long entityOwnerId, Date endDate, Double value,
-            String description, String activationRule) {
+            String description, String activationRule, Integer position) {
 
         QuotaTariffVO newQuotaTariff = getNewQuotaTariffObject(currentQuotaTariff, name, usageType);
 
@@ -438,6 +478,7 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
         validateValueOnCreatingNewQuotaTariff(newQuotaTariff, value);
         validateStringsOnCreatingNewQuotaTariff(newQuotaTariff::setDescription, description);
         validateStringsOnCreatingNewQuotaTariff(newQuotaTariff::setActivationRule, activationRule);
+        validatePositionOnCreatingNewQuotaTariff(newQuotaTariff, position);
 
         _quotaTariffDao.addQuotaTariff(newQuotaTariff);
         return newQuotaTariff;
@@ -458,6 +499,13 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
         return newQuotaTariff;
     }
 
+    protected void validatePositionOnCreatingNewQuotaTariff(QuotaTariffVO newQuotaTariff, Integer position) {
+        if (position != null) {
+            newQuotaTariff.setPosition(position);
+        }
+    }
+
+
     protected void validateStringsOnCreatingNewQuotaTariff(Consumer<String> method, String value){
         if (value != null) {
             method.accept(value.isBlank() ? null : value);
@@ -476,12 +524,14 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
         }
 
         if (endDate.compareTo(startDate) < 0) {
-            throw new InvalidParameterValueException(String.format("The quota tariff's end date [%s] cannot be less than the start date [%s]", endDate, startDate));
+            throw new InvalidParameterValueException(String.format("The quota tariff's end date [%s] cannot be less than the start date [%s].",
+                    endDate, startDate));
         }
 
-        Date now = _quotaService.computeAdjustedTime(new Date());
+        Date now = new Date();
         if (endDate.compareTo(now) < 0) {
-            throw new InvalidParameterValueException(String.format("The quota tariff's end date [%s] cannot be less than now [%s].", endDate, now));
+            throw new InvalidParameterValueException(String.format("The quota tariff's end date [%s] cannot be less than now [%s].",
+                    endDate, now));
         }
 
         newQuotaTariff.setEndDate(endDate);
@@ -489,11 +539,12 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
 
     @Override
     public QuotaCreditsResponse addQuotaCredits(Long accountId, Long domainId, Double amount, Long updatedBy, Boolean enforce) {
-        Date despositedOn = _quotaService.computeAdjustedTime(new Date());
+        Date despositedOn = new Date();
         QuotaBalanceVO qb = _quotaBalanceDao.findLaterBalanceEntry(accountId, domainId, despositedOn);
 
         if (qb != null) {
-            throw new InvalidParameterValueException("Incorrect deposit date: " + despositedOn + " there are balance entries after this date");
+            throw new InvalidParameterValueException(String.format("Incorrect deposit date [%s], as there are balance entries after this date.",
+                    despositedOn));
         }
 
         QuotaCreditsVO credits = new QuotaCreditsVO(accountId, domainId, new BigDecimal(amount), updatedBy);
@@ -506,20 +557,19 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
         }
         final boolean lockAccountEnforcement = "true".equalsIgnoreCase(QuotaConfig.QuotaEnableEnforcement.value());
         final BigDecimal currentAccountBalance = _quotaBalanceDao.lastQuotaBalance(accountId, domainId, startOfNextDay(new Date(despositedOn.getTime())));
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("AddQuotaCredits: Depositing " + amount + " on adjusted date " + despositedOn + ", current balance " + currentAccountBalance);
-        }
+        logger.debug("Depositing [{}] credits on adjusted date [{}]; current balance is [{}].", amount,
+                DateUtil.displayDateInTimezone(QuotaManagerImpl.getUsageAggregationTimeZone(), despositedOn), currentAccountBalance);
         // update quota account with the balance
         _quotaService.saveQuotaAccount(account, currentAccountBalance, despositedOn);
         if (lockAccountEnforcement) {
             if (currentAccountBalance.compareTo(new BigDecimal(0)) >= 0) {
                 if (account.getState() == Account.State.LOCKED) {
-                    s_logger.info("UnLocking account " + account.getAccountName() + " , due to positive balance " + currentAccountBalance);
+                    logger.info("UnLocking account " + account.getAccountName() + " , due to positive balance " + currentAccountBalance);
                     _accountMgr.enableAccount(account.getAccountName(), domainId, accountId);
                 }
             } else { // currentAccountBalance < 0 then lock the account
                 if (_quotaManager.isLockable(account) && account.getState() == Account.State.ENABLED && enforce) {
-                    s_logger.info("Locking account " + account.getAccountName() + " , due to negative balance " + currentAccountBalance);
+                    logger.info("Locking account " + account.getAccountName() + " , due to negative balance " + currentAccountBalance);
                     _accountMgr.lockAccount(account.getAccountName(), domainId, accountId);
                 }
             }
@@ -587,9 +637,10 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
         QuotaBalanceResponse resp = new QuotaBalanceResponse();
         BigDecimal lastCredits = new BigDecimal(0);
         for (QuotaBalanceVO entry : quotaBalance) {
-            if (s_logger.isDebugEnabled()) {
-                s_logger.debug("createQuotaLastBalanceResponse Date=" + entry.getUpdatedOn() + " balance=" + entry.getCreditBalance() + " credit=" + entry.getCreditsId());
-            }
+            logger.debug("createQuotaLastBalanceResponse Date={} balance={} credit={}",
+                    DateUtil.displayDateInTimezone(QuotaManagerImpl.getUsageAggregationTimeZone(), entry.getUpdatedOn()),
+                    entry.getCreditBalance(), entry.getCreditsId());
+
             lastCredits = lastCredits.add(entry.getCreditBalance());
         }
         resp.setStartQuota(lastCredits);
@@ -632,11 +683,12 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
         int usageType = cmd.getUsageType();
         Date startDate = cmd.getStartDate();
         Date now = new Date();
-        startDate = _quotaService.computeAdjustedTime(startDate == null ? now : startDate);
-        Date endDate = _quotaService.computeAdjustedTime(cmd.getEndDate());
+        startDate = startDate == null ? now : startDate;
+        Date endDate = cmd.getEndDate();
         Double value = cmd.getValue();
         String description = cmd.getDescription();
         String activationRule = cmd.getActivationRule();
+        Integer position = ObjectUtils.defaultIfNull(cmd.getPosition(), 1);
 
         QuotaTariffVO currentQuotaTariff = _quotaTariffDao.findByName(name);
 
@@ -645,10 +697,11 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
         }
 
         if (startDate.compareTo(now) < 0) {
-            throw new InvalidParameterValueException(String.format("The quota tariff's start date [%s] cannot be less than now [%s]", startDate, now));
+            throw new InvalidParameterValueException(String.format("The value passed as Quota tariff's start date is in the past: [%s]. " +
+                    "Please, inform a date in the future or do not pass the parameter to use the current date and time.", startDate));
         }
 
-        QuotaTariffVO newQuotaTariff = persistNewQuotaTariff(null, name, usageType, startDate, cmd.getEntityOwnerId(), endDate, value, description, activationRule);
+        QuotaTariffVO newQuotaTariff = persistNewQuotaTariff(null, name, usageType, startDate, cmd.getEntityOwnerId(), endDate, value, description, activationRule, position);
 
         CallContext.current().setEventResourceId(newQuotaTariff.getId());
 
@@ -663,10 +716,216 @@ public class QuotaResponseBuilderImpl implements QuotaResponseBuilder {
             throw new ServerApiException(ApiErrorCode.PARAM_ERROR, "Quota tariff with the provided UUID does not exist.");
         }
 
-        quotaTariff.setRemoved(_quotaService.computeAdjustedTime(new Date()));
-
+        quotaTariff.setRemoved(new Date());
         CallContext.current().setEventResourceId(quotaTariff.getId());
-
         return _quotaTariffDao.updateQuotaTariff(quotaTariff);
     }
+
+    @Override
+    public List<QuotaPresetVariablesItemResponse> listQuotaPresetVariables(QuotaPresetVariablesListCmd cmd) {
+        List<QuotaPresetVariablesItemResponse> response;
+        List<Pair<String, String>> variables = new ArrayList<>();
+
+        QuotaTypes quotaType = cmd.getQuotaType();
+        addAllPresetVariables(PresetVariables.class, quotaType, variables, null);
+        response = createQuotaPresetVariablesResponse(variables);
+
+        return response;
+    }
+
+    /**
+     * Adds all preset variables for the given quota type. It recursively finds all presets variables for the given {@link Class} and puts it in a {@link List}. Each item in the
+     * list is a {@link Pair} that consists of the variable name and its description.
+     *
+     * @param clazz used to find the non-transient fields. If it is equal to the {@link Value} class, then it only gets the declared fields, otherwise, it gets all fields,
+     *              including its parent's fields.
+     * @param quotaType used to check if the field supports the quota resource type. It uses the annotation method {@link PresetVariableDefinition#supportedTypes()} for this
+     *                  verification.
+     * @param variables the {@link List} which contains the {@link Pair} of the preset variable and its description.
+     * @param recursiveVariableName {@link String} used for recursively building the preset variable string.
+     */
+    public void addAllPresetVariables(Class<?> clazz, QuotaTypes quotaType, List<Pair<String, String>> variables, String recursiveVariableName) {
+        Field[] allFields = Value.class.equals(clazz) ? clazz.getDeclaredFields() : FieldUtils.getAllFields(clazz);
+        List<Field> fieldsNonTransients = Arrays.stream(allFields).filter(field -> !Modifier.isTransient(field.getModifiers())).collect(Collectors.toList());
+        for (Field field : fieldsNonTransients) {
+            PresetVariableDefinition presetVariableDefinitionAnnotation = field.getAnnotation(PresetVariableDefinition.class);
+            Class<?> fieldClass = getClassOfField(field);
+            String presetVariableName = field.getName();
+
+            if (presetVariableDefinitionAnnotation == null) {
+                continue;
+            }
+
+            if (StringUtils.isNotEmpty(recursiveVariableName)) {
+                presetVariableName = String.format("%s.%s", recursiveVariableName, field.getName());
+            }
+            filterSupportedTypes(variables, quotaType, presetVariableDefinitionAnnotation, fieldClass, presetVariableName);
+        }
+    }
+
+    /**
+     * Returns the class of the {@link Field} depending on its type. This method is required for retrieving the Class of Generic Types, i.e. {@link List}.
+     */
+    protected Class<?> getClassOfField(Field field){
+        if (field.getGenericType() instanceof ParameterizedType) {
+            ParameterizedType genericType = (ParameterizedType) field.getGenericType();
+            return (Class<?>) genericType.getActualTypeArguments()[0];
+        }
+
+        return field.getType();
+    }
+
+    /**
+     * Checks if the {@link PresetVariableDefinition} supports the given {@link QuotaTypes}. If it supports it, it adds the preset variable to the {@link List} recursively
+     * if it is from the one of the classes in the {@link QuotaResponseBuilderImpl#assignableClasses} array or directly if not.
+     *
+     * @param variables {@link List} of the {@link Pair} of the preset variable and its description.
+     * @param quotaType the given {@link QuotaTypes} to filter.
+     * @param presetVariableDefinitionAnnotation used to check if the quotaType is supported.
+     * @param fieldClass class of the field used to verify if it is from the {@link GenericPresetVariable} or {@link ComputingResources} classes. If it is, then it calls
+     *                   {@link QuotaResponseBuilderImpl#addAllPresetVariables(Class, QuotaTypes, List, String)} to add the preset variable. Otherwise, the {@link Pair} is
+     *                   added directly to the variables {@link List}.
+     * @param presetVariableName {@link String} that contains the recursive created preset variable name.
+     */
+    public void filterSupportedTypes(List<Pair<String, String>> variables, QuotaTypes quotaType, PresetVariableDefinition presetVariableDefinitionAnnotation, Class<?> fieldClass,
+                                     String presetVariableName) {
+        if (Arrays.stream(presetVariableDefinitionAnnotation.supportedTypes()).noneMatch(supportedType ->
+                supportedType == quotaType.getQuotaType() || supportedType == 0)) {
+            return;
+        }
+
+        String presetVariableDescription = presetVariableDefinitionAnnotation.description();
+
+        Pair<String, String> pair = new Pair<>(presetVariableName, presetVariableDescription);
+        variables.add(pair);
+
+        if (isRecursivePresetVariable(fieldClass)) {
+            addAllPresetVariables(fieldClass, quotaType, variables, presetVariableName);
+        }
+    }
+
+    /**
+     * Returns true if the {@link Class} of the {@link Field} is from one of the classes in the array {@link QuotaResponseBuilderImpl#assignableClasses}, i.e., it is a recursive
+     * {@link PresetVariables}, returns false otherwise.
+     */
+    private boolean isRecursivePresetVariable(Class<?> fieldClass) {
+        for (Class<?> clazz : assignableClasses) {
+            if (clazz.isAssignableFrom(fieldClass)) {
+                return true;
+            }
+        }
+        return false;
+    }
+
+    public List<QuotaPresetVariablesItemResponse> createQuotaPresetVariablesResponse(List<Pair<String, String>> variables) {
+        final List<QuotaPresetVariablesItemResponse> responses = new ArrayList<>();
+
+        for (Pair<String, String> variable : variables) {
+            responses.add(createPresetVariablesItemResponse(variable));
+        }
+
+        return responses;
+    }
+
+    public QuotaPresetVariablesItemResponse createPresetVariablesItemResponse(Pair<String, String> variable) {
+        QuotaPresetVariablesItemResponse response = new QuotaPresetVariablesItemResponse();
+        response.setVariable(variable.first());
+        response.setDescription(variable.second());
+        return response;
+    }
+
+    @Override
+    public Pair<QuotaEmailConfigurationVO, Double> configureQuotaEmail(QuotaConfigureEmailCmd cmd) {
+        validateQuotaConfigureEmailCmdParameters(cmd);
+
+        Double minBalance = cmd.getMinBalance();
+
+        if (minBalance != null) {
+            _quotaService.setMinBalance(cmd.getAccountId(), cmd.getMinBalance());
+        }
+
+        QuotaEmailConfigurationVO configurationVO = getQuotaEmailConfigurationVo(cmd);
+        return new Pair<>(configurationVO, minBalance);
+    }
+
+    protected QuotaEmailConfigurationVO getQuotaEmailConfigurationVo(QuotaConfigureEmailCmd cmd) {
+        if (cmd.getTemplateName() == null) {
+            return null;
+        }
+
+        List<QuotaEmailTemplatesVO> templateVO = _quotaEmailTemplateDao.listAllQuotaEmailTemplates(cmd.getTemplateName());
+        if (templateVO.isEmpty()) {
+            throw new InvalidParameterValueException(String.format("Could not find template with name [%s].", cmd.getTemplateName()));
+        }
+        long templateId = templateVO.get(0).getId();
+        QuotaEmailConfigurationVO configurationVO = quotaEmailConfigurationDao.findByAccountIdAndEmailTemplateId(cmd.getAccountId(), templateId);
+
+        if (configurationVO == null) {
+            configurationVO = new QuotaEmailConfigurationVO(cmd.getAccountId(), templateId, cmd.getEnable());
+            quotaEmailConfigurationDao.persistQuotaEmailConfiguration(configurationVO);
+            return configurationVO;
+        }
+
+        configurationVO.setEnabled(cmd.getEnable());
+        return quotaEmailConfigurationDao.updateQuotaEmailConfiguration(configurationVO);
+    }
+
+    protected void validateQuotaConfigureEmailCmdParameters(QuotaConfigureEmailCmd cmd) {
+        if (quotaAccountDao.findByIdQuotaAccount(cmd.getAccountId()) == null) {
+            throw new InvalidParameterValueException("You must have the quota enabled for this account to configure quota emails.");
+        }
+
+        if (cmd.getTemplateName() == null && cmd.getMinBalance() == null) {
+            throw new InvalidParameterValueException("You should inform at least the 'minbalance' or both the 'templatename' and 'enable' parameters.");
+        }
+
+        if ((cmd.getTemplateName() != null && cmd.getEnable() == null) || (cmd.getTemplateName() == null && cmd.getEnable() != null)) {
+            throw new InvalidParameterValueException("Parameter 'enable' must be informed along with 'templatename'.");
+        }
+    }
+
+    public QuotaConfigureEmailResponse createQuotaConfigureEmailResponse(QuotaEmailConfigurationVO quotaEmailConfigurationVO, Double minBalance, long accountId) {
+        QuotaConfigureEmailResponse quotaConfigureEmailResponse = new QuotaConfigureEmailResponse();
+
+        Account account = _accountDao.findByIdIncludingRemoved(accountId);
+        if (quotaEmailConfigurationVO != null) {
+            QuotaEmailTemplatesVO templateVO = _quotaEmailTemplateDao.findById(quotaEmailConfigurationVO.getEmailTemplateId());
+
+            quotaConfigureEmailResponse.setAccountId(account.getUuid());
+            quotaConfigureEmailResponse.setTemplateName(templateVO.getTemplateName());
+            quotaConfigureEmailResponse.setEnabled(quotaEmailConfigurationVO.isEnabled());
+        }
+
+        quotaConfigureEmailResponse.setMinBalance(minBalance);
+
+        return quotaConfigureEmailResponse;
+    }
+
+    @Override
+    public List<QuotaConfigureEmailResponse> listEmailConfiguration(long accountId) {
+        List<QuotaEmailConfigurationVO> emailConfigurationVOList = quotaEmailConfigurationDao.listByAccount(accountId);
+        Account account = _accountDao.findById(accountId);
+        QuotaAccountVO quotaAccountVO = quotaAccountDao.findByIdQuotaAccount(accountId);
+
+        List<QuotaConfigureEmailResponse> quotaConfigureEmailResponseList = new ArrayList<>();
+        for (QuotaEmailConfigurationVO quotaEmailConfigurationVO : emailConfigurationVOList) {
+            quotaConfigureEmailResponseList.add(createQuotaConfigureEmailResponse(quotaEmailConfigurationVO, account, quotaAccountVO));
+        }
+
+        return quotaConfigureEmailResponseList;
+    }
+
+    protected QuotaConfigureEmailResponse createQuotaConfigureEmailResponse(QuotaEmailConfigurationVO quotaEmailConfigurationVO, Account account, QuotaAccountVO quotaAccountVO) {
+        QuotaConfigureEmailResponse quotaConfigureEmailResponse = new QuotaConfigureEmailResponse();
+
+        QuotaEmailTemplatesVO templateVO = _quotaEmailTemplateDao.findById(quotaEmailConfigurationVO.getEmailTemplateId());
+
+        quotaConfigureEmailResponse.setAccountId(account.getUuid());
+        quotaConfigureEmailResponse.setTemplateName(templateVO.getTemplateName());
+        quotaConfigureEmailResponse.setEnabled(quotaEmailConfigurationVO.isEnabled());
+
+        quotaConfigureEmailResponse.setMinBalance(quotaAccountVO.getQuotaMinBalance().doubleValue());
+
+        return quotaConfigureEmailResponse;
+    }
 }
