@@ -18,7 +18,6 @@ package org.apache.cloudstack.quota;
 
 import java.math.BigDecimal;
 import java.util.ArrayList;
-import java.util.Calendar;
 import java.util.Date;
 import java.util.List;
 import java.util.Map;
@@ -28,10 +27,13 @@ import javax.inject.Inject;
 import javax.naming.ConfigurationException;
 
 import org.apache.cloudstack.api.command.QuotaBalanceCmd;
+import org.apache.cloudstack.api.command.QuotaConfigureEmailCmd;
 import org.apache.cloudstack.api.command.QuotaCreditsCmd;
 import org.apache.cloudstack.api.command.QuotaEmailTemplateListCmd;
 import org.apache.cloudstack.api.command.QuotaEmailTemplateUpdateCmd;
 import org.apache.cloudstack.api.command.QuotaEnabledCmd;
+import org.apache.cloudstack.api.command.QuotaListEmailConfigurationCmd;
+import org.apache.cloudstack.api.command.QuotaPresetVariablesListCmd;
 import org.apache.cloudstack.api.command.QuotaStatementCmd;
 import org.apache.cloudstack.api.command.QuotaSummaryCmd;
 import org.apache.cloudstack.api.command.QuotaTariffCreateCmd;
@@ -51,8 +53,7 @@ import org.apache.cloudstack.quota.dao.QuotaUsageDao;
 import org.apache.cloudstack.quota.vo.QuotaAccountVO;
 import org.apache.cloudstack.quota.vo.QuotaBalanceVO;
 import org.apache.cloudstack.quota.vo.QuotaUsageVO;
-import org.apache.cloudstack.utils.usage.UsageUtils;
-import org.apache.log4j.Logger;
+import org.apache.commons.lang3.ObjectUtils;
 import org.springframework.stereotype.Component;
 
 import com.cloud.configuration.Config;
@@ -67,7 +68,6 @@ import com.cloud.utils.db.Filter;
 
 @Component
 public class QuotaServiceImpl extends ManagerBase implements QuotaService, Configurable, QuotaConfig {
-    private static final Logger s_logger = Logger.getLogger(QuotaServiceImpl.class);
 
     @Inject
     private AccountDao _accountDao;
@@ -85,7 +85,6 @@ public class QuotaServiceImpl extends ManagerBase implements QuotaService, Confi
     private QuotaResponseBuilder _respBldr;
 
     private TimeZone _usageTimezone;
-    private int _aggregationDuration = 0;
 
     public QuotaServiceImpl() {
         super();
@@ -94,21 +93,10 @@ public class QuotaServiceImpl extends ManagerBase implements QuotaService, Confi
     @Override
     public boolean configure(String name, Map<String, Object> params) throws ConfigurationException {
         super.configure(name, params);
-        String timeZoneStr = _configDao.getValue(Config.UsageAggregationTimezone.toString());
-        String aggregationRange = _configDao.getValue(Config.UsageStatsJobAggregationRange.toString());
-        if (timeZoneStr == null) {
-            timeZoneStr = "GMT";
-        }
+
+        String timeZoneStr = ObjectUtils.defaultIfNull(_configDao.getValue(Config.UsageAggregationTimezone.toString()), "GMT");
         _usageTimezone = TimeZone.getTimeZone(timeZoneStr);
 
-        _aggregationDuration = Integer.parseInt(aggregationRange);
-        if (_aggregationDuration < UsageUtils.USAGE_AGGREGATION_RANGE_MIN) {
-            s_logger.warn("Usage stats job aggregation range is to small, using the minimum value of " + UsageUtils.USAGE_AGGREGATION_RANGE_MIN);
-            _aggregationDuration = UsageUtils.USAGE_AGGREGATION_RANGE_MIN;
-        }
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Usage timezone = " + _usageTimezone + " AggregationDuration=" + _aggregationDuration);
-        }
         return true;
     }
 
@@ -130,6 +118,9 @@ public class QuotaServiceImpl extends ManagerBase implements QuotaService, Confi
         cmdList.add(QuotaEmailTemplateUpdateCmd.class);
         cmdList.add(QuotaTariffCreateCmd.class);
         cmdList.add(QuotaTariffDeleteCmd.class);
+        cmdList.add(QuotaConfigureEmailCmd.class);
+        cmdList.add(QuotaListEmailConfigurationCmd.class);
+        cmdList.add(QuotaPresetVariablesListCmd.class);
         return cmdList;
     }
 
@@ -142,7 +133,7 @@ public class QuotaServiceImpl extends ManagerBase implements QuotaService, Confi
     public ConfigKey<?>[] getConfigKeys() {
         return new ConfigKey<?>[] {QuotaPluginEnabled, QuotaEnableEnforcement, QuotaCurrencySymbol, QuotaCurrencyLocale, QuotaStatementPeriod, QuotaSmtpHost, QuotaSmtpPort, QuotaSmtpTimeout,
                 QuotaSmtpUser, QuotaSmtpPassword, QuotaSmtpAuthType, QuotaSmtpSender, QuotaSmtpEnabledSecurityProtocols, QuotaSmtpUseStartTLS, QuotaActivationRuleTimeout, QuotaAccountEnabled,
-                QuotaEmailHeader, QuotaEmailFooter};
+                QuotaEmailHeader, QuotaEmailFooter, QuotaEnableEmails};
     }
 
     @Override
@@ -175,36 +166,32 @@ public class QuotaServiceImpl extends ManagerBase implements QuotaService, Confi
 
         if (endDate == null) {
             // adjust start date to end of day as there is no end date
-            Date adjustedStartDate = computeAdjustedTime(_respBldr.startOfNextDay(startDate));
-            if (s_logger.isDebugEnabled()) {
-                s_logger.debug("getQuotaBalance1: Getting quota balance records for account: " + accountId + ", domainId: " + domainId + ", on or before " + adjustedStartDate);
+            startDate = _respBldr.startOfNextDay(startDate);
+            if (logger.isDebugEnabled()) {
+                logger.debug("getQuotaBalance1: Getting quota balance records for account: " + accountId + ", domainId: " + domainId + ", on or before " + startDate);
             }
-            List<QuotaBalanceVO> qbrecords = _quotaBalanceDao.lastQuotaBalanceVO(accountId, domainId, adjustedStartDate);
-            if (s_logger.isDebugEnabled()) {
-                s_logger.debug("Found records size=" + qbrecords.size());
+            List<QuotaBalanceVO> qbrecords = _quotaBalanceDao.lastQuotaBalanceVO(accountId, domainId, startDate);
+            if (logger.isDebugEnabled()) {
+                logger.debug("Found records size=" + qbrecords.size());
             }
             if (qbrecords.isEmpty()) {
-                s_logger.info("Incorrect Date there are no quota records before this date " + adjustedStartDate);
+                logger.info("Incorrect Date there are no quota records before this date " + startDate);
                 return qbrecords;
             } else {
                 return qbrecords;
             }
         } else {
-            Date adjustedStartDate = computeAdjustedTime(startDate);
-            if (endDate.after(_respBldr.startOfNextDay())) {
-                throw new InvalidParameterValueException("Incorrect Date Range. End date:" + endDate + " should not be in future. ");
-            } else if (startDate.before(endDate)) {
-                Date adjustedEndDate = computeAdjustedTime(endDate);
-                if (s_logger.isDebugEnabled()) {
-                    s_logger.debug("getQuotaBalance2: Getting quota balance records for account: " + accountId + ", domainId: " + domainId + ", between " + adjustedStartDate
-                            + " and " + adjustedEndDate);
+            if (startDate.before(endDate)) {
+                if (logger.isDebugEnabled()) {
+                    logger.debug("getQuotaBalance2: Getting quota balance records for account: " + accountId + ", domainId: " + domainId + ", between " + startDate
+                            + " and " + endDate);
                 }
-                List<QuotaBalanceVO> qbrecords = _quotaBalanceDao.findQuotaBalance(accountId, domainId, adjustedStartDate, adjustedEndDate);
-                if (s_logger.isDebugEnabled()) {
-                    s_logger.debug("getQuotaBalance3: Found records size=" + qbrecords.size());
+                List<QuotaBalanceVO> qbrecords = _quotaBalanceDao.findQuotaBalance(accountId, domainId, startDate, endDate);
+                if (logger.isDebugEnabled()) {
+                    logger.debug("getQuotaBalance3: Found records size=" + qbrecords.size());
                 }
                 if (qbrecords.isEmpty()) {
-                    s_logger.info("There are no quota records between these dates start date " + adjustedStartDate + " and end date:" + endDate);
+                    logger.info("There are no quota records between these dates start date " + startDate + " and end date:" + endDate);
                     return qbrecords;
                 } else {
                     return qbrecords;
@@ -240,44 +227,11 @@ public class QuotaServiceImpl extends ManagerBase implements QuotaService, Confi
         if (startDate.after(endDate)) {
             throw new InvalidParameterValueException("Incorrect Date Range. Start date: " + startDate + " is after end date:" + endDate);
         }
-        if (endDate.after(_respBldr.startOfNextDay())) {
-            throw new InvalidParameterValueException("Incorrect Date Range. End date:" + endDate + " should not be in future. ");
-        }
-        Date adjustedEndDate = computeAdjustedTime(endDate);
-        Date adjustedStartDate = computeAdjustedTime(startDate);
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Getting quota records for account: " + accountId + ", domainId: " + domainId + ", between " + adjustedStartDate + " and " + adjustedEndDate);
-        }
-        return _quotaUsageDao.findQuotaUsage(accountId, domainId, usageType, adjustedStartDate, adjustedEndDate);
-    }
 
-    @Override
-    public Date computeAdjustedTime(final Date date) {
-        if (date == null) {
-            return null;
-        }
+        logger.debug("Getting quota records of type [{}] for account [{}] in domain [{}], between [{}] and [{}].",
+                usageType, accountId, domainId, startDate, endDate);
 
-        Calendar cal = Calendar.getInstance();
-        cal.setTime(date);
-        TimeZone localTZ = cal.getTimeZone();
-        int timezoneOffset = cal.get(Calendar.ZONE_OFFSET);
-        if (localTZ.inDaylightTime(date)) {
-            timezoneOffset += (60 * 60 * 1000);
-        }
-        cal.add(Calendar.MILLISECOND, timezoneOffset);
-
-        Date newTime = cal.getTime();
-
-        Calendar calTS = Calendar.getInstance(_usageTimezone);
-        calTS.setTime(newTime);
-        timezoneOffset = calTS.get(Calendar.ZONE_OFFSET);
-        if (_usageTimezone.inDaylightTime(date)) {
-            timezoneOffset += (60 * 60 * 1000);
-        }
-
-        calTS.add(Calendar.MILLISECOND, -1 * timezoneOffset);
-
-        return calTS.getTime();
+        return _quotaUsageDao.findQuotaUsage(accountId, domainId, usageType, startDate, endDate);
     }
 
     @Override
@@ -302,16 +256,16 @@ public class QuotaServiceImpl extends ManagerBase implements QuotaService, Confi
             quota_account = new QuotaAccountVO(account.getAccountId());
             quota_account.setQuotaBalance(aggrUsage);
             quota_account.setQuotaBalanceDate(endDate);
-            if (s_logger.isDebugEnabled()) {
-                s_logger.debug(quota_account);
+            if (logger.isDebugEnabled()) {
+                logger.debug(quota_account);
             }
             _quotaAcc.persistQuotaAccount(quota_account);
             return true;
         } else {
             quota_account.setQuotaBalance(aggrUsage);
             quota_account.setQuotaBalanceDate(endDate);
-            if (s_logger.isDebugEnabled()) {
-                s_logger.debug(quota_account);
+            if (logger.isDebugEnabled()) {
+                logger.debug(quota_account);
             }
             return _quotaAcc.updateQuotaAccount(account.getAccountId(), quota_account);
         }
