@@ -31,7 +31,6 @@ import java.util.concurrent.TimeUnit;
 import org.apache.cloudstack.utils.qemu.QemuImg;
 import org.apache.cloudstack.utils.qemu.QemuImg.PhysicalDiskFormat;
 import org.apache.cloudstack.utils.qemu.QemuImgFile;
-import org.joda.time.Duration;
 
 import com.cloud.storage.Storage;
 import com.cloud.storage.StorageManager;
@@ -40,10 +39,12 @@ import com.cloud.utils.exception.CloudRuntimeException;
 import com.cloud.utils.script.OutputInterpreter;
 import com.cloud.utils.script.Script;
 import org.apache.commons.lang3.StringUtils;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
+import org.apache.logging.log4j.Logger;
+import org.joda.time.Duration;
 
 public abstract class MultipathSCSIAdapterBase implements StorageAdaptor {
-    static final Logger LOGGER = Logger.getLogger(MultipathSCSIAdapterBase.class);
+    protected static Logger LOGGER = LogManager.getLogger(MultipathSCSIAdapterBase.class);
     static final Map<String, KVMStoragePool> MapStorageUuidToStoragePool = new HashMap<>();
 
     /**
@@ -160,13 +161,6 @@ public abstract class MultipathSCSIAdapterBase implements StorageAdaptor {
         KVMPhysicalDisk disk = new KVMPhysicalDisk(address.getPath(), address.toString(), pool);
         disk.setFormat(QemuImg.PhysicalDiskFormat.RAW);
 
-        // validate we have a connection, if not we need to connect first.
-        if (!isConnected(address.getPath())) {
-            if (!connectPhysicalDisk(address, pool, null)) {
-                throw new CloudRuntimeException("Unable to connect to volume " + address.getPath());
-            }
-        }
-
         long diskSize = getPhysicalDiskSize(address.getPath());
         disk.setSize(diskSize);
         disk.setVirtualSize(diskSize);
@@ -188,7 +182,7 @@ public abstract class MultipathSCSIAdapterBase implements StorageAdaptor {
     }
 
    @Override
-    public boolean connectPhysicalDisk(String volumePath, KVMStoragePool pool, Map<String, String> details, boolean isVMMigrate) {
+    public boolean connectPhysicalDisk(String volumePath, KVMStoragePool pool, Map<String, String> details) {
         LOGGER.info("connectPhysicalDisk called for [" + volumePath + "]");
 
         if (StringUtils.isEmpty(volumePath)) {
@@ -204,10 +198,6 @@ public abstract class MultipathSCSIAdapterBase implements StorageAdaptor {
         // we expect WWN values in the volumePath so need to convert it to an actual physical path
         AddressInfo address = this.parseAndValidatePath(volumePath);
 
-        return connectPhysicalDisk(address, pool, details);
-    }
-
-    private boolean connectPhysicalDisk(AddressInfo address, KVMStoragePool pool, Map<String, String> details) {
         // validate we have a connection id - we can't proceed without that
         if (address.getConnectionId() == null) {
             LOGGER.error("Unable to connect volume with address [" + address.getPath() + "] of the storage pool: " + pool.getUuid() + " - connection id is not set in provided path");
@@ -519,18 +509,6 @@ public abstract class MultipathSCSIAdapterBase implements StorageAdaptor {
         return false;
     }
 
-    boolean isConnected(String path) {
-        // run a command to test if this is a binary device at this path
-        Script blockTest = new Script("/bin/test", LOGGER);
-        blockTest.add("-b", path);
-        blockTest.execute();
-        int rc = blockTest.getExitValue();
-        if (rc == 0) {
-            return true;
-        }
-        return false;
-    }
-
     long getPhysicalDiskSize(String diskPath) {
         if (StringUtils.isEmpty(diskPath)) {
             return 0;
@@ -592,7 +570,7 @@ public abstract class MultipathSCSIAdapterBase implements StorageAdaptor {
         synchronized(CLEANUP_LOCK) {
             long start = System.currentTimeMillis();
             ScriptResult result = runScript(cleanupScript, cleanupTimeoutSecs * 1000);
-            LOGGER.debug("Multipath Cleanup Job elapsed time (ms): "+ (System.currentTimeMillis() - start) + "; result: " + result.getExitCode(), null);
+            LOGGER.debug("Multipath Cleanup Job elapsed time (ms): "+ (System.currentTimeMillis() - start) + "; result: " + result.getExitCode());
         }
     }
 
