@@ -38,11 +38,11 @@ import org.apache.cloudstack.utils.qemu.QemuImgException;
 import org.apache.cloudstack.utils.qemu.QemuImgFile;
 import org.apache.cloudstack.utils.qemu.QemuObject;
 import org.apache.commons.io.filefilter.WildcardFileFilter;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 import org.libvirt.LibvirtException;
 
 import com.cloud.storage.Storage;
-import com.cloud.storage.StorageLayer;
 import com.cloud.storage.StorageManager;
 import com.cloud.utils.Pair;
 import com.cloud.utils.Ternary;
@@ -51,28 +51,31 @@ import com.cloud.utils.script.OutputInterpreter;
 import com.cloud.utils.script.Script;
 import org.apache.commons.lang3.StringUtils;
 
-@StorageAdaptorInfo(storagePoolType= Storage.StoragePoolType.PowerFlex)
 public class ScaleIOStorageAdaptor implements StorageAdaptor {
-    private static final Logger LOGGER = Logger.getLogger(ScaleIOStorageAdaptor.class);
+    protected Logger logger = LogManager.getLogger(getClass());
     private static final Map<String, KVMStoragePool> MapStorageUuidToStoragePool = new HashMap<>();
     private static final int DEFAULT_DISK_WAIT_TIME_IN_SECS = 60;
-    private StorageLayer storageLayer;
 
-    public ScaleIOStorageAdaptor(StorageLayer storagelayer) {
-        storageLayer = storagelayer;
+    public ScaleIOStorageAdaptor() {
+
     }
 
     @Override
     public KVMStoragePool getStoragePool(String uuid) {
         KVMStoragePool pool = MapStorageUuidToStoragePool.get(uuid);
         if (pool == null) {
-            LOGGER.error("Pool: " + uuid + " not found, probably sdc not connected on agent start");
+            logger.error("Pool: " + uuid + " not found, probably sdc not connected on agent start");
             throw new CloudRuntimeException("Pool: " + uuid + " not found, reconnect sdc and restart agent if sdc not connected on agent start");
         }
 
         return pool;
     }
 
+    @Override
+    public Storage.StoragePoolType getStoragePoolType() {
+        return Storage.StoragePoolType.PowerFlex;
+    }
+
     @Override
     public KVMStoragePool getStoragePool(String uuid, boolean refreshInfo) {
         return getStoragePool(uuid);
@@ -81,7 +84,7 @@ public class ScaleIOStorageAdaptor implements StorageAdaptor {
     @Override
     public KVMPhysicalDisk getPhysicalDisk(String volumePath, KVMStoragePool pool) {
         if (StringUtils.isEmpty(volumePath) || pool == null) {
-            LOGGER.error("Unable to get physical disk, volume path or pool not specified");
+            logger.error("Unable to get physical disk, volume path or pool not specified");
             return null;
         }
 
@@ -96,18 +99,18 @@ public class ScaleIOStorageAdaptor implements StorageAdaptor {
                 diskFilePath = ScaleIOUtil.DISK_PATH + File.separator + diskFileName;
                 final File diskFile = new File(diskFilePath);
                 if (!diskFile.exists()) {
-                    LOGGER.debug("Physical disk file: " + diskFilePath + " doesn't exists on the storage pool: " + pool.getUuid());
+                    logger.debug("Physical disk file: " + diskFilePath + " doesn't exists on the storage pool: " + pool.getUuid());
                     return null;
                 }
             } else {
-                LOGGER.debug("Try with wildcard filter to get the physical disk: " + volumeId + " on the storage pool: " + pool.getUuid());
+                logger.debug("Try with wildcard filter to get the physical disk: " + volumeId + " on the storage pool: " + pool.getUuid());
                 final File dir = new File(ScaleIOUtil.DISK_PATH);
                 final FileFilter fileFilter = new WildcardFileFilter(ScaleIOUtil.DISK_NAME_PREFIX_FILTER + volumeId);
                 final File[] files = dir.listFiles(fileFilter);
                 if (files != null && files.length == 1) {
                     diskFilePath = files[0].getAbsolutePath();
                 } else {
-                    LOGGER.debug("Unable to find the physical disk: " + volumeId + " on the storage pool: " + pool.getUuid());
+                    logger.debug("Unable to find the physical disk: " + volumeId + " on the storage pool: " + pool.getUuid());
                     return null;
                 }
             }
@@ -137,7 +140,7 @@ public class ScaleIOStorageAdaptor implements StorageAdaptor {
 
             return disk;
         } catch (Exception e) {
-            LOGGER.error("Failed to get the physical disk: " + volumePath + " on the storage pool: " + pool.getUuid() + " due to " + e.getMessage());
+            logger.error("Failed to get the physical disk: " + volumePath + " on the storage pool: " + pool.getUuid() + " due to " + e.getMessage());
             throw new CloudRuntimeException("Failed to get the physical disk: " + volumePath + " on the storage pool: " + pool.getUuid());
         }
     }
@@ -178,7 +181,7 @@ public class ScaleIOStorageAdaptor implements StorageAdaptor {
             return null;
         }
 
-        if(!connectPhysicalDisk(name, pool, null, false)) {
+        if(!connectPhysicalDisk(name, pool, null)) {
             throw new CloudRuntimeException(String.format("Failed to ensure disk %s was present", name));
         }
 
@@ -202,7 +205,7 @@ public class ScaleIOStorageAdaptor implements StorageAdaptor {
                 qemuObjects.add(QemuObject.prepareSecretForQemuImg(disk.getFormat(), disk.getQemuEncryptFormat(), keyFile.toString(), "sec0", options));
                 QemuImgFile file = new QemuImgFile(disk.getPath(), formattedSize, disk.getFormat());
                 qemuImg.create(file, null, options, qemuObjects);
-                LOGGER.debug(String.format("Successfully formatted %s as encrypted QCOW2", file.getFileName()));
+                logger.debug(String.format("Successfully formatted %s as encrypted QCOW2", file.getFileName()));
             } catch (QemuImgException | LibvirtException | IOException ex) {
                 throw new CloudRuntimeException("Failed to set up encrypted QCOW on block device " + disk.getPath(), ex);
             }
@@ -221,9 +224,9 @@ public class ScaleIOStorageAdaptor implements StorageAdaptor {
     }
 
     @Override
-    public boolean connectPhysicalDisk(String volumePath, KVMStoragePool pool, Map<String, String> details, boolean isMigration) {
+    public boolean connectPhysicalDisk(String volumePath, KVMStoragePool pool, Map<String, String> details) {
         if (StringUtils.isEmpty(volumePath) || pool == null) {
-            LOGGER.error("Unable to connect physical disk due to insufficient data");
+            logger.error("Unable to connect physical disk due to insufficient data");
             throw new CloudRuntimeException("Unable to connect physical disk due to insufficient data");
         }
 
@@ -240,7 +243,7 @@ public class ScaleIOStorageAdaptor implements StorageAdaptor {
     }
 
     private boolean waitForDiskToBecomeAvailable(String volumePath, KVMStoragePool pool, int waitTimeInSec) {
-        LOGGER.debug("Waiting for the volume with id: " + volumePath + " of the storage pool: " + pool.getUuid() + " to become available for " + waitTimeInSec + " secs");
+        logger.debug("Waiting for the volume with id: " + volumePath + " of the storage pool: " + pool.getUuid() + " to become available for " + waitTimeInSec + " secs");
         int timeBetweenTries = 1000; // Try more frequently (every sec) and return early if disk is found
         KVMPhysicalDisk physicalDisk = null;
 
@@ -250,7 +253,7 @@ public class ScaleIOStorageAdaptor implements StorageAdaptor {
         while (waitTimeInSec > 0) {
             physicalDisk = getPhysicalDisk(volumePath, pool);
             if (physicalDisk != null && physicalDisk.getSize() > 0) {
-                LOGGER.debug("Found the volume with id: " + volumePath + " of the storage pool: " + pool.getUuid());
+                logger.debug("Found the volume with id: " + volumePath + " of the storage pool: " + pool.getUuid());
                 return true;
             }
 
@@ -265,11 +268,11 @@ public class ScaleIOStorageAdaptor implements StorageAdaptor {
 
         physicalDisk = getPhysicalDisk(volumePath, pool);
         if (physicalDisk != null && physicalDisk.getSize() > 0) {
-            LOGGER.debug("Found the volume using id: " + volumePath + " of the storage pool: " + pool.getUuid());
+            logger.debug("Found the volume using id: " + volumePath + " of the storage pool: " + pool.getUuid());
             return true;
         }
 
-        LOGGER.debug("Unable to find the volume with id: " + volumePath + " of the storage pool: " + pool.getUuid());
+        logger.debug("Unable to find the volume with id: " + volumePath + " of the storage pool: " + pool.getUuid());
         return false;
     }
 
@@ -278,17 +281,17 @@ public class ScaleIOStorageAdaptor implements StorageAdaptor {
             return 0;
         }
 
-        Script diskCmd = new Script("blockdev", LOGGER);
+        Script diskCmd = new Script("blockdev", logger);
         diskCmd.add("--getsize64", diskPath);
 
         OutputInterpreter.OneLineParser parser = new OutputInterpreter.OneLineParser();
         String result = diskCmd.execute(parser);
 
         if (result != null) {
-            LOGGER.warn("Unable to get the disk size at path: " + diskPath);
+            logger.warn("Unable to get the disk size at path: " + diskPath);
             return 0;
         } else {
-            LOGGER.info("Able to retrieve the disk size at path:" + diskPath);
+            logger.info("Able to retrieve the disk size at path:" + diskPath);
         }
 
         return Long.parseLong(parser.getLine());
@@ -337,7 +340,7 @@ public class ScaleIOStorageAdaptor implements StorageAdaptor {
     @Override
     public KVMPhysicalDisk copyPhysicalDisk(KVMPhysicalDisk disk, String name, KVMStoragePool destPool, int timeout, byte[] srcPassphrase, byte[]dstPassphrase, Storage.ProvisioningType provisioningType) {
         if (StringUtils.isEmpty(name) || disk == null || destPool == null) {
-            LOGGER.error("Unable to copy physical disk due to insufficient data");
+            logger.error("Unable to copy physical disk due to insufficient data");
             throw new CloudRuntimeException("Unable to copy physical disk due to insufficient data");
         }
 
@@ -345,11 +348,11 @@ public class ScaleIOStorageAdaptor implements StorageAdaptor {
             provisioningType = Storage.ProvisioningType.THIN;
         }
 
-        LOGGER.debug("Copy physical disk with size: " + disk.getSize() + ", virtualsize: " + disk.getVirtualSize()+ ", format: " + disk.getFormat());
+        logger.debug("Copy physical disk with size: " + disk.getSize() + ", virtualsize: " + disk.getVirtualSize()+ ", format: " + disk.getFormat());
 
         KVMPhysicalDisk destDisk = destPool.getPhysicalDisk(name);
         if (destDisk == null) {
-            LOGGER.error("Failed to find the disk: " + name + " of the storage pool: " + destPool.getUuid());
+            logger.error("Failed to find the disk: " + name + " of the storage pool: " + destPool.getUuid());
             throw new CloudRuntimeException("Failed to find the disk: " + name + " of the storage pool: " + destPool.getUuid());
         }
 
@@ -400,33 +403,33 @@ public class ScaleIOStorageAdaptor implements StorageAdaptor {
             }
 
             boolean forceSourceFormat = srcQemuFile.getFormat() == QemuImg.PhysicalDiskFormat.RAW;
-            LOGGER.debug(String.format("Starting copy from source disk %s(%s) to PowerFlex volume %s(%s), forcing source format is %b", srcQemuFile.getFileName(), srcQemuFile.getFormat(), destQemuFile.getFileName(), destQemuFile.getFormat(), forceSourceFormat));
+            logger.debug(String.format("Starting copy from source disk %s(%s) to PowerFlex volume %s(%s), forcing source format is %b", srcQemuFile.getFileName(), srcQemuFile.getFormat(), destQemuFile.getFileName(), destQemuFile.getFormat(), forceSourceFormat));
             qemuImageOpts.setImageOptsFlag(true);
             qemu.convert(srcQemuFile, destQemuFile, options, qemuObjects, qemuImageOpts,null, forceSourceFormat);
-            LOGGER.debug("Successfully converted source disk image " + srcQemuFile.getFileName() + " to PowerFlex volume: " + destDisk.getPath());
+            logger.debug("Successfully converted source disk image " + srcQemuFile.getFileName() + " to PowerFlex volume: " + destDisk.getPath());
 
             if (destQemuFile.getFormat() == QemuImg.PhysicalDiskFormat.QCOW2 && !disk.useAsTemplate()) {
                 QemuImageOptions resizeOptions = new QemuImageOptions(destQemuFile.getFormat(), destPath, destKeyName);
                 resizeQcow2ToVolume(destPath, resizeOptions, qemuObjects, timeout);
-                LOGGER.debug("Resized volume at " + destPath);
+                logger.debug("Resized volume at " + destPath);
             }
         }  catch (QemuImgException | LibvirtException | IOException e) {
             try {
                 Map<String, String> srcInfo = qemu.info(srcQemuFile);
-                LOGGER.debug("Source disk info: " + Arrays.asList(srcInfo));
+                logger.debug("Source disk info: " + Arrays.asList(srcInfo));
             } catch (Exception ignored) {
-                LOGGER.warn("Unable to get info from source disk: " + disk.getName());
+                logger.warn("Unable to get info from source disk: " + disk.getName());
             }
 
             String errMsg = String.format("Unable to convert/copy from %s to %s, due to: %s", disk.getName(), name, ((StringUtils.isEmpty(e.getMessage())) ? "an unknown error" : e.getMessage()));
-            LOGGER.error(errMsg);
+            logger.error(errMsg);
             throw new CloudRuntimeException(errMsg, e);
         } finally {
             if (cryptSetup != null) {
                 try {
                     cryptSetup.close(name);
                 } catch (CryptSetupException ex) {
-                    LOGGER.warn("Failed to clean up LUKS disk after copying disk", ex);
+                    logger.warn("Failed to clean up LUKS disk after copying disk", ex);
                 }
             }
         }
@@ -464,11 +467,11 @@ public class ScaleIOStorageAdaptor implements StorageAdaptor {
     @Override
     public KVMPhysicalDisk createTemplateFromDirectDownloadFile(String templateFilePath, String destTemplatePath, KVMStoragePool destPool, Storage.ImageFormat format, int timeout) {
         if (StringUtils.isAnyEmpty(templateFilePath, destTemplatePath) || destPool == null) {
-            LOGGER.error("Unable to create template from direct download template file due to insufficient data");
+            logger.error("Unable to create template from direct download template file due to insufficient data");
             throw new CloudRuntimeException("Unable to create template from direct download template file due to insufficient data");
         }
 
-        LOGGER.debug("Create template from direct download template - file path: " + templateFilePath + ", dest path: " + destTemplatePath + ", format: " + format.toString());
+        logger.debug("Create template from direct download template - file path: " + templateFilePath + ", dest path: " + destTemplatePath + ", format: " + format.toString());
 
         File sourceFile = new File(templateFilePath);
         if (!sourceFile.exists()) {
@@ -476,7 +479,7 @@ public class ScaleIOStorageAdaptor implements StorageAdaptor {
         }
 
         if (destTemplatePath == null || destTemplatePath.isEmpty()) {
-            LOGGER.error("Failed to create template, target template disk path not provided");
+            logger.error("Failed to create template, target template disk path not provided");
             throw new CloudRuntimeException("Target template disk path not provided");
         }
 
@@ -485,7 +488,7 @@ public class ScaleIOStorageAdaptor implements StorageAdaptor {
         }
 
         if (Storage.ImageFormat.RAW.equals(format) && Storage.ImageFormat.QCOW2.equals(format)) {
-            LOGGER.error("Failed to create template, unsupported template format: " + format.toString());
+            logger.error("Failed to create template, unsupported template format: " + format.toString());
             throw new CloudRuntimeException("Unsupported template format: " + format.toString());
         }
 
@@ -497,13 +500,13 @@ public class ScaleIOStorageAdaptor implements StorageAdaptor {
             QemuImg qemu = new QemuImg(timeout, true, false);
             destDisk = destPool.getPhysicalDisk(destTemplatePath);
             if (destDisk == null) {
-                LOGGER.error("Failed to find the disk: " + destTemplatePath + " of the storage pool: " + destPool.getUuid());
+                logger.error("Failed to find the disk: " + destTemplatePath + " of the storage pool: " + destPool.getUuid());
                 throw new CloudRuntimeException("Failed to find the disk: " + destTemplatePath + " of the storage pool: " + destPool.getUuid());
             }
 
             if (isTemplateExtractable(templateFilePath)) {
                 srcTemplateFilePath = sourceFile.getParent() + "/" + UUID.randomUUID().toString();
-                LOGGER.debug("Extract the downloaded template " + templateFilePath + " to " + srcTemplateFilePath);
+                logger.debug("Extract the downloaded template " + templateFilePath + " to " + srcTemplateFilePath);
                 String extractCommand = getExtractCommandForDownloadedFile(templateFilePath, srcTemplateFilePath);
                 Script.runSimpleBashScript(extractCommand);
                 Script.runSimpleBashScript("rm -f " + templateFilePath);
@@ -526,12 +529,12 @@ public class ScaleIOStorageAdaptor implements StorageAdaptor {
             destFile = new QemuImgFile(destDisk.getPath(), QemuImg.PhysicalDiskFormat.QCOW2);
             destFile.setSize(srcFile.getSize());
 
-            LOGGER.debug("Starting copy from source downloaded template " + srcFile.getFileName() + " to PowerFlex template volume: " + destDisk.getPath());
+            logger.debug("Starting copy from source downloaded template " + srcFile.getFileName() + " to PowerFlex template volume: " + destDisk.getPath());
             qemu.create(destFile);
             qemu.convert(srcFile, destFile);
-            LOGGER.debug("Successfully converted source downloaded template " + srcFile.getFileName() + " to PowerFlex template volume: " + destDisk.getPath());
+            logger.debug("Successfully converted source downloaded template " + srcFile.getFileName() + " to PowerFlex template volume: " + destDisk.getPath());
         }  catch (QemuImgException | LibvirtException e) {
-            LOGGER.error("Failed to convert. The error was: " + e.getMessage(), e);
+            logger.error("Failed to convert. The error was: " + e.getMessage(), e);
             destDisk = null;
         } finally {
             Script.runSimpleBashScript("rm -f " + srcTemplateFilePath);
@@ -566,12 +569,12 @@ public class ScaleIOStorageAdaptor implements StorageAdaptor {
 
     public Ternary<Boolean, Map<String, String>, String> prepareStorageClient(Storage.StoragePoolType type, String uuid, Map<String, String> details) {
         if (!ScaleIOUtil.isSDCServiceInstalled()) {
-            LOGGER.debug("SDC service not installed on host, preparing the SDC client not possible");
+            logger.debug("SDC service not installed on host, preparing the SDC client not possible");
             return new Ternary<>(false, null, "SDC service not installed on host");
         }
 
         if (!ScaleIOUtil.isSDCServiceEnabled()) {
-            LOGGER.debug("SDC service not enabled on host, enabling it");
+            logger.debug("SDC service not enabled on host, enabling it");
             if (!ScaleIOUtil.enableSDCService()) {
                 return new Ternary<>(false, null, "SDC service not enabled on host");
             }
@@ -590,12 +593,12 @@ public class ScaleIOStorageAdaptor implements StorageAdaptor {
 
     public Pair<Boolean, String> unprepareStorageClient(Storage.StoragePoolType type, String uuid) {
         if (!ScaleIOUtil.isSDCServiceInstalled()) {
-            LOGGER.debug("SDC service not installed on host, no need to unprepare the SDC client");
+            logger.debug("SDC service not installed on host, no need to unprepare the SDC client");
             return new Pair<>(true, "SDC service not installed on host, no need to unprepare the SDC client");
         }
 
         if (!ScaleIOUtil.isSDCServiceEnabled()) {
-            LOGGER.debug("SDC service not enabled on host, no need to unprepare the SDC client");
+            logger.debug("SDC service not enabled on host, no need to unprepare the SDC client");
             return new Pair<>(true, "SDC service not enabled on host, no need to unprepare the SDC client");
         }
 
