@@ -29,6 +29,8 @@ import com.cloud.utils.Ternary;
 
 public interface StorageAdaptor {
 
+    StoragePoolType getStoragePoolType();
+
     public KVMStoragePool getStoragePool(String uuid);
 
     // Get the storage pool from libvirt, but control if libvirt should refresh the pool (can take a long time)
@@ -50,15 +52,8 @@ public interface StorageAdaptor {
     public KVMPhysicalDisk createPhysicalDisk(String name, KVMStoragePool pool,
             PhysicalDiskFormat format, Storage.ProvisioningType provisioningType, long size, byte[] passphrase);
 
-    /**
-     * given disk path (per database) and pool, prepare disk on host
-     * @param volumePath volume path
-     * @param pool storage pool the disk is part of
-     * @param details disk details map
-     * @param isVMMigrate Indicates if request is while VM is migration
-     * @return true if connect was a success
-     */
-    public boolean connectPhysicalDisk(String volumePath, KVMStoragePool pool, Map<String, String> details, boolean isVMMigrate);
+    // given disk path (per database) and pool, prepare disk on host
+    public boolean connectPhysicalDisk(String volumePath, KVMStoragePool pool, Map<String, String> details);
 
     // given disk path (per database) and pool, clean up disk on host
     public boolean disconnectPhysicalDisk(String volumePath, KVMStoragePool pool);
@@ -116,6 +111,13 @@ public interface StorageAdaptor {
      */
     KVMPhysicalDisk createTemplateFromDirectDownloadFile(String templateFilePath, String destTemplatePath, KVMStoragePool destPool, Storage.ImageFormat format, int timeout);
 
+    /**
+     * Returns true if storage adaptor supports physical disk copy functionality.
+     */
+    default boolean supportsPhysicalDiskCopy(StoragePoolType type) {
+        return StoragePoolType.PowerFlex == type;
+    }
+
     /**
      * Prepares the storage client.
      * @param type type of the storage pool
