@@ -22,10 +22,7 @@ import java.lang.annotation.Retention;
 import java.lang.annotation.RetentionPolicy;
 import java.lang.annotation.Target;
 
-import com.cloud.storage.Storage.StoragePoolType;
-
 @Retention(RetentionPolicy.RUNTIME)
 @Target({ TYPE })
 public @interface StorageAdaptorInfo {
-    StoragePoolType storagePoolType();
 }
