@@ -280,6 +280,57 @@ public class LibvirtVMDefTest extends TestCase {
         assertEquals(expectedXML, disk.toString());
     }
 
+    @Test
+    public void testDiskDefWithBlockIO() {
+        String filePath = "/var/lib/libvirt/images/disk.qcow2";
+        String diskLabel = "vda";
+
+        DiskDef disk = new DiskDef();
+        DiskDef.DiskBus bus = DiskDef.DiskBus.VIRTIO;
+        DiskDef.DiskFmtType type = DiskDef.DiskFmtType.QCOW2;
+        DiskDef.DiskCacheMode cacheMode = DiskDef.DiskCacheMode.WRITEBACK;
+
+        disk.defFileBasedDisk(filePath, diskLabel, bus, type);
+        disk.setCacheMode(cacheMode);
+        disk.setLogicalBlockIOSize(DiskDef.BlockIOSize.SIZE_4K);
+
+        assertEquals(filePath, disk.getDiskPath());
+        assertEquals(diskLabel, disk.getDiskLabel());
+        assertEquals(bus, disk.getBusType());
+        assertEquals(DiskDef.DeviceType.DISK, disk.getDeviceType());
+
+        String expectedXmlLogical = "<disk  device='disk' type='file'>\n<driver name='qemu' type='" + type.toString() + "' cache='" + cacheMode.toString() + "' />\n" +
+                "<source file='" + filePath + "'/>\n<target dev='" + diskLabel + "' bus='" + bus.toString() + "'/>\n<blockio logical_block_size='4096' />\n</disk>\n";
+
+        assertEquals(expectedXmlLogical, disk.toString());
+
+        String expectedXmlPhysical = "<disk  device='disk' type='file'>\n<driver name='qemu' type='" + type.toString() + "' cache='" + cacheMode.toString() + "' />\n" +
+                "<source file='" + filePath + "'/>\n<target dev='" + diskLabel + "' bus='" + bus.toString() + "'/>\n<blockio physical_block_size='4096' />\n</disk>\n";
+
+        disk.setLogicalBlockIOSize(null);
+        disk.setPhysicalBlockIOSize(DiskDef.BlockIOSize.SIZE_4K);
+        assertEquals(expectedXmlPhysical, disk.toString());
+
+        disk.setLogicalBlockIOSize(DiskDef.BlockIOSize.SIZE_512);
+        String expectedXml = "<disk  device='disk' type='file'>\n<driver name='qemu' type='" + type.toString() + "' cache='" + cacheMode.toString() + "' />\n" +
+                "<source file='" + filePath + "'/>\n<target dev='" + diskLabel + "' bus='" + bus.toString() + "'/>\n<blockio logical_block_size='512' physical_block_size='4096' />\n</disk>\n";
+        assertEquals(expectedXml, disk.toString());
+    }
+
+    @Test
+    public void testDiskDefWithGeometry() {
+        DiskDef disk = new DiskDef();
+        disk.defBlockBasedDisk("disk1", 1, DiskDef.DiskBus.VIRTIO);
+        disk.setGeometry(new DiskDef.DiskGeometry(16383, 16, 63));
+        String expectedXML = "<disk  device='disk' type='block'>\n" +
+                "<driver name='qemu' type='raw' cache='none' />\n" +
+                "<source dev='disk1'/>\n" +
+                "<target dev='vdb' bus='virtio'/>\n" +
+                "<geometry cyls='16383' heads='16' secs='63'/>\n" +
+                "</disk>\n";
+        assertEquals(expectedXML, disk.toString());
+    }
+
     @Test
     public void testDiskDefWithMultipleHosts() {
         String path = "/mnt/primary1";
@@ -496,4 +547,17 @@ public class LibvirtVMDefTest extends TestCase {
                 "</controller>\n";
         assertEquals(expected, str);
     }
+
+    @Test
+    public void testTopology() {
+        LibvirtVMDef.CpuModeDef cpuModeDef = new LibvirtVMDef.CpuModeDef();
+        cpuModeDef.setTopology(2, 1, 4);
+        assertEquals("<cpu><topology sockets='4' cores='2' threads='1' /></cpu>", cpuModeDef.toString());
+    }
+
+    public void testTopologyNoInfo() {
+        LibvirtVMDef.CpuModeDef cpuModeDef = new LibvirtVMDef.CpuModeDef();
+        cpuModeDef.setTopology(-1, -1, 4);
+        assertEquals("<cpu></cpu>", cpuModeDef.toString());
+    }
 }
