@@ -56,7 +56,8 @@ import org.apache.cloudstack.storage.to.SnapshotObjectTO;
 import org.apache.cloudstack.storage.to.TemplateObjectTO;
 import org.apache.cloudstack.storage.to.VolumeObjectTO;
 import org.apache.commons.lang3.BooleanUtils;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 import org.apache.xmlrpc.XmlRpcException;
 
 import com.cloud.agent.api.Answer;
@@ -89,7 +90,7 @@ import com.xensource.xenapi.VDI;
 import com.xensource.xenapi.VM;
 
 public class XenServerStorageProcessor implements StorageProcessor {
-    private static final Logger s_logger = Logger.getLogger(XenServerStorageProcessor.class);
+    protected Logger logger = LogManager.getLogger(getClass());
     protected CitrixResourceBase hypervisorResource;
     protected String BaseMountPointOnHost = "/var/run/cloud_mount";
 
@@ -156,7 +157,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
             return snapshotAndCopyAnswer;
         }
         catch (final Exception ex) {
-            s_logger.warn("Failed to take and copy snapshot: " + ex.toString(), ex);
+            logger.warn("Failed to take and copy snapshot: " + ex.toString(), ex);
 
             return new SnapshotAndCopyAnswer(ex.getMessage());
         }
@@ -195,7 +196,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
             return resignatureAnswer;
         }
         catch (final Exception ex) {
-            s_logger.warn("Failed to resignature: " + ex.toString(), ex);
+            logger.warn("Failed to resignature: " + ex.toString(), ex);
 
             return new ResignatureAnswer(ex.getMessage());
         }
@@ -219,13 +220,13 @@ public class XenServerStorageProcessor implements StorageProcessor {
 
     @Override
     public Answer checkDataStoreStoragePolicyCompliance(CheckDataStoreStoragePolicyComplainceCommand cmd) {
-        s_logger.info("'CheckDataStoreStoragePolicyComplainceCommand' not applicable used for XenServerStorageProcessor");
+        logger.info("'CheckDataStoreStoragePolicyComplainceCommand' not applicable used for XenServerStorageProcessor");
         return new Answer(cmd,false,"Not applicable used for XenServerStorageProcessor");
     }
 
     @Override
     public Answer syncVolumePath(SyncVolumePathCommand cmd) {
-        s_logger.info("SyncVolumePathCommand not currently applicable for XenServerStorageProcessor");
+        logger.info("SyncVolumePathCommand not currently applicable for XenServerStorageProcessor");
         return new Answer(cmd, false, "Not currently applicable for XenServerStorageProcessor");
     }
 
@@ -241,7 +242,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
             isoURL = iso.getName();
         } else {
             if (!(store instanceof NfsTO)) {
-                s_logger.debug("Can't attach a iso which is not created on nfs: ");
+                logger.debug("Can't attach a iso which is not created on nfs: ");
                 return new AttachAnswer("Can't attach a iso which is not created on nfs: ");
             }
             final NfsTO nfsStore = (NfsTO) store;
@@ -286,10 +287,10 @@ public class XenServerStorageProcessor implements StorageProcessor {
             return new AttachAnswer(disk);
 
         } catch (final XenAPIException e) {
-            s_logger.warn("Failed to attach iso" + ": " + e.toString(), e);
+            logger.warn("Failed to attach iso" + ": " + e.toString(), e);
             return new AttachAnswer(e.toString());
         } catch (final Exception e) {
-            s_logger.warn("Failed to attach iso" + ": " + e.toString(), e);
+            logger.warn("Failed to attach iso" + ": " + e.toString(), e);
             return new AttachAnswer(e.toString());
         }
     }
@@ -377,7 +378,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
         } catch (final Exception e) {
             final String msg = "Failed to attach volume for uuid: " + data.getPath() + " due to "  + e.toString();
 
-            s_logger.warn(msg, e);
+            logger.warn(msg, e);
 
             return new AttachAnswer(msg);
         }
@@ -395,7 +396,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
             isoURL = iso.getName();
         } else {
             if (!(store instanceof NfsTO)) {
-                s_logger.debug("Can't detach a iso which is not created on nfs: ");
+                logger.debug("Can't detach a iso which is not created on nfs: ");
                 return new AttachAnswer("Can't detach a iso which is not created on nfs: ");
             }
             final NfsTO nfsStore = (NfsTO) store;
@@ -438,11 +439,11 @@ public class XenServerStorageProcessor implements StorageProcessor {
             return new DettachAnswer(disk);
         } catch (final XenAPIException e) {
             final String msg = "Failed to detach volume" + " for uuid: " + data.getPath() + "  due to " + e.toString();
-            s_logger.warn(msg, e);
+            logger.warn(msg, e);
             return new DettachAnswer(msg);
         } catch (final Exception e) {
             final String msg = "Failed to detach volume" + " for uuid: " + data.getPath() + "  due to " + e.getMessage();
-            s_logger.warn(msg, e);
+            logger.warn(msg, e);
             return new DettachAnswer(msg);
         }
     }
@@ -501,7 +502,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
 
             return new DettachAnswer(disk);
         } catch (final Exception e) {
-            s_logger.warn("Failed dettach volume: " + data.getPath());
+            logger.warn("Failed dettach volume: " + data.getPath());
             return new DettachAnswer("Failed dettach volume: " + data.getPath() + ", due to " + e.toString());
         }
     }
@@ -558,7 +559,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
                         snapshotUUID = preSnapshotUUID;
                     }
                 } catch (final Exception e) {
-                    s_logger.debug("Failed to get parent snapshot", e);
+                    logger.debug("Failed to get parent snapshot", e);
                 }
             }
             final SnapshotObjectTO newSnapshot = new SnapshotObjectTO();
@@ -566,10 +567,10 @@ public class XenServerStorageProcessor implements StorageProcessor {
             return new CreateObjectAnswer(newSnapshot);
         } catch (final XenAPIException e) {
             details += ", reason: " + e.toString();
-            s_logger.warn(details, e);
+            logger.warn(details, e);
         } catch (final Exception e) {
             details += ", reason: " + e.toString();
-            s_logger.warn(details, e);
+            logger.warn(details, e);
         }
 
         return new CreateObjectAnswer(details);
@@ -588,13 +589,13 @@ public class XenServerStorageProcessor implements StorageProcessor {
             deleteVDI(conn, vdi);
             return new Answer(null);
         } catch (final BadServerResponse e) {
-            s_logger.debug("Failed to delete volume", e);
+            logger.debug("Failed to delete volume", e);
             errorMsg = e.toString();
         } catch (final XenAPIException e) {
-            s_logger.debug("Failed to delete volume", e);
+            logger.debug("Failed to delete volume", e);
             errorMsg = e.toString();
         } catch (final XmlRpcException e) {
-            s_logger.debug("Failed to delete volume", e);
+            logger.debug("Failed to delete volume", e);
             errorMsg = e.toString();
         }
         return new Answer(null, false, errorMsg);
@@ -625,7 +626,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
         if (hypervisorResource.killCopyProcess(conn, source)) {
             destroyVDIbyNameLabel(conn, nameLabel);
         }
-        s_logger.warn(errMsg);
+        logger.warn(errMsg);
         throw new CloudRuntimeException(errMsg);
     }
 
@@ -633,7 +634,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
         try {
             final Set<VDI> vdis = VDI.getByNameLabel(conn, nameLabel);
             if (vdis.size() != 1) {
-                s_logger.warn("destroyVDIbyNameLabel failed due to there are " + vdis.size() + " VDIs with name " + nameLabel);
+                logger.warn("destroyVDIbyNameLabel failed due to there are " + vdis.size() + " VDIs with name " + nameLabel);
                 return;
             }
             for (final VDI vdi : vdis) {
@@ -651,7 +652,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
             return VDI.getByUuid(conn, uuid);
         } catch (final Exception e) {
             final String msg = "Catch Exception " + e.getClass().getName() + " :VDI getByUuid for uuid: " + uuid + " failed due to " + e.toString();
-            s_logger.debug(msg);
+            logger.debug(msg);
             throw new CloudRuntimeException(msg, e);
         }
     }
@@ -662,7 +663,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
                         "isISCSI", isISCSI.toString());
 
         if (parentUuid == null || parentUuid.isEmpty() || parentUuid.equalsIgnoreCase("None")) {
-            s_logger.debug("Unable to get parent of VHD " + snapshotUuid + " in SR " + primaryStorageSRUuid);
+            logger.debug("Unable to get parent of VHD " + snapshotUuid + " in SR " + primaryStorageSRUuid);
             // errString is already logged.
             return null;
         }
@@ -733,7 +734,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
                     if (srs.size() != 1) {
                         final String msg = "There are " + srs.size() + " SRs with same name: " + srName;
 
-                        s_logger.warn(msg);
+                        logger.warn(msg);
 
                         return new CopyCmdAnswer(msg);
                     } else {
@@ -785,7 +786,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
         } catch (final Exception e) {
             final String msg = "Catch Exception " + e.getClass().getName() + " for template + " + " due to " + e.toString();
 
-            s_logger.warn(msg, e);
+            logger.warn(msg, e);
 
             return new CopyCmdAnswer(msg);
         }
@@ -825,7 +826,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
 
             return new CreateObjectAnswer(newVol);
         } catch (final Exception e) {
-            s_logger.debug("create volume failed: " + e.toString());
+            logger.debug("create volume failed: " + e.toString());
             return new CreateObjectAnswer(e.toString());
         }
     }
@@ -844,16 +845,16 @@ public class XenServerStorageProcessor implements StorageProcessor {
             vdi = tmpltvdi.createClone(conn, new HashMap<String, String>());
             Long virtualSize  = vdi.getVirtualSize(conn);
             if (volume.getSize() > virtualSize) {
-                s_logger.debug("Overriding provided template's size with new size " + toHumanReadableSize(volume.getSize()) + " for volume: " + volume.getName());
+                logger.debug("Overriding provided template's size with new size " + toHumanReadableSize(volume.getSize()) + " for volume: " + volume.getName());
                 vdi.resize(conn, volume.getSize());
             } else {
-                s_logger.debug("Using templates disk size of " + toHumanReadableSize(virtualSize) + " for volume: " + volume.getName() + " since size passed was " + toHumanReadableSize(volume.getSize()));
+                logger.debug("Using templates disk size of " + toHumanReadableSize(virtualSize) + " for volume: " + volume.getName() + " since size passed was " + toHumanReadableSize(volume.getSize()));
             }
             vdi.setNameLabel(conn, volume.getName());
 
             VDI.Record vdir;
             vdir = vdi.getRecord(conn);
-            s_logger.debug("Successfully created VDI: Uuid = " + vdir.uuid);
+            logger.debug("Successfully created VDI: Uuid = " + vdir.uuid);
 
             final VolumeObjectTO newVol = new VolumeObjectTO();
             newVol.setName(vdir.nameLabel);
@@ -862,7 +863,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
 
             return new CopyCmdAnswer(newVol);
         } catch (final Exception e) {
-            s_logger.warn("Unable to create volume; Pool=" + destData + "; Disk: ", e);
+            logger.warn("Unable to create volume; Pool=" + destData + "; Disk: ", e);
             return new CopyCmdAnswer(e.toString());
         }
     }
@@ -894,12 +895,12 @@ public class XenServerStorageProcessor implements StorageProcessor {
                 return new CopyCmdAnswer(newVol);
             } catch (final Exception e) {
                 final String msg = "Catch Exception " + e.getClass().getName() + " due to " + e.toString();
-                s_logger.warn(msg, e);
+                logger.warn(msg, e);
                 return new CopyCmdAnswer(e.toString());
             }
         }
 
-        s_logger.debug("unsupported protocol");
+        logger.debug("unsupported protocol");
         return new CopyCmdAnswer("unsupported protocol");
     }
 
@@ -935,7 +936,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
                 newVol.setSize(srcVolume.getSize());
                 return new CopyCmdAnswer(newVol);
             } catch (final Exception e) {
-                s_logger.debug("Failed to copy volume to secondary: " + e.toString());
+                logger.debug("Failed to copy volume to secondary: " + e.toString());
                 return new CopyCmdAnswer("Failed to copy volume to secondary: " + e.toString());
             } finally {
                 hypervisorResource.removeSR(conn, secondaryStorage);
@@ -953,7 +954,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
             String result = hypervisorResource.callHostPluginAsync(conn, "swiftxenserver", "swift", wait, params.toArray(new String[params.size()]));
             return BooleanUtils.toBoolean(result);
         } catch (final Exception e) {
-            s_logger.warn("swift upload failed due to " + e.toString(), e);
+            logger.warn("swift upload failed due to " + e.toString(), e);
         }
         return false;
     }
@@ -1043,7 +1044,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
             return null;
 
         } catch (final Exception e) {
-            s_logger.error(String.format("S3 upload failed of snapshot %1$s due to %2$s.", snapshotUuid, e.toString()), e);
+            logger.error(String.format("S3 upload failed of snapshot %1$s due to %2$s.", snapshotUuid, e.toString()), e);
         }
 
         return null;
@@ -1089,7 +1090,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
             // So we don't rely on status value but return backupSnapshotUuid as an
             // indicator of success.
             if (status != null && status.equalsIgnoreCase("1") && backupSnapshotUuid != null) {
-                s_logger.debug("Successfully copied backupUuid: " + backupSnapshotUuid + " to secondary storage");
+                logger.debug("Successfully copied backupUuid: " + backupSnapshotUuid + " to secondary storage");
                 return results;
             } else {
                 errMsg =
@@ -1099,7 +1100,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
         }
         final String source = backupUuid + ".vhd";
         hypervisorResource.killCopyProcess(conn, source);
-        s_logger.warn(errMsg);
+        logger.warn(errMsg);
         throw new CloudRuntimeException(errMsg);
     }
 
@@ -1122,17 +1123,17 @@ public class XenServerStorageProcessor implements StorageProcessor {
                     }
                 } catch (final Exception e) {
                     final String msg = "Destroying snapshot: " + snapshot + " on primary storage failed due to " + e.toString();
-                    s_logger.warn(msg, e);
+                    logger.warn(msg, e);
                 }
             }
-            s_logger.debug("Successfully destroyed snapshot on volume: " + volumeUuid + " execept this current snapshot " + avoidSnapshotUuid);
+            logger.debug("Successfully destroyed snapshot on volume: " + volumeUuid + " execept this current snapshot " + avoidSnapshotUuid);
             return true;
         } catch (final XenAPIException e) {
             final String msg = "Destroying snapshot on volume: " + volumeUuid + " execept this current snapshot " + avoidSnapshotUuid + " failed due to " + e.toString();
-            s_logger.error(msg, e);
+            logger.error(msg, e);
         } catch (final Exception e) {
             final String msg = "Destroying snapshot on volume: " + volumeUuid + " execept this current snapshot " + avoidSnapshotUuid + " failed due to " + e.toString();
-            s_logger.warn(msg, e);
+            logger.warn(msg, e);
         }
 
         return false;
@@ -1143,17 +1144,17 @@ public class XenServerStorageProcessor implements StorageProcessor {
             final VDI snapshot = getVDIbyUuid(conn, lastSnapshotUuid);
             if (snapshot == null) {
                 // since this is just used to cleanup leftover bad snapshots, no need to throw exception
-                s_logger.warn("Could not destroy snapshot " + lastSnapshotUuid + " due to can not find it");
+                logger.warn("Could not destroy snapshot " + lastSnapshotUuid + " due to can not find it");
                 return false;
             }
             snapshot.destroy(conn);
             return true;
         } catch (final XenAPIException e) {
             final String msg = "Destroying snapshot: " + lastSnapshotUuid + " failed due to " + e.toString();
-            s_logger.error(msg, e);
+            logger.error(msg, e);
         } catch (final Exception e) {
             final String msg = "Destroying snapshot: " + lastSnapshotUuid + " failed due to " + e.toString();
-            s_logger.warn(msg, e);
+            logger.warn(msg, e);
         }
         return false;
     }
@@ -1222,7 +1223,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
                         }
                     }
                 } catch (final Exception e) {
-                    s_logger.debug("Failed to get parent snapshots, take full snapshot", e);
+                    logger.debug("Failed to get parent snapshots, take full snapshot", e);
                     fullbackup = true;
                 }
             }
@@ -1239,7 +1240,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
 
                 if (!hypervisorResource.createSecondaryStorageFolder(conn, secondaryStorageMountPath, folder, nfsVersion)) {
                     details = " Filed to create folder " + folder + " in secondary storage";
-                    s_logger.warn(details);
+                    logger.warn(details);
                     return new CopyCmdAnswer(details);
                 }
                 final String snapshotMountpoint = secondaryStorageUrl + "/" + folder;
@@ -1261,7 +1262,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
                             try {
                                 deleteSnapshotBackup(conn, localMountPoint, folder, secondaryStorageMountPath, snapshotBackupUuid);
                             } catch (final Exception e) {
-                                s_logger.debug("Failed to delete snapshot on cache storages", e);
+                                logger.debug("Failed to delete snapshot on cache storages", e);
                             }
                         }
 
@@ -1275,7 +1276,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
                             try {
                                 deleteSnapshotBackup(conn, localMountPoint, folder, secondaryStorageMountPath, snapshotBackupUuid);
                             } catch (final Exception e) {
-                                s_logger.debug("Failed to delete snapshot on cache storages", e);
+                                logger.debug("Failed to delete snapshot on cache storages", e);
                             }
                         }
                         // finalPath = folder + File.separator + snapshotBackupUuid;
@@ -1326,17 +1327,17 @@ public class XenServerStorageProcessor implements StorageProcessor {
             return new CopyCmdAnswer(newSnapshot);
         } catch (final XenAPIException e) {
             details = "BackupSnapshot Failed due to " + e.toString();
-            s_logger.warn(details, e);
+            logger.warn(details, e);
         } catch (final Exception e) {
             details = "BackupSnapshot Failed due to " + e.getMessage();
-            s_logger.warn(details, e);
+            logger.warn(details, e);
         } finally {
             if (!result) {
                 // remove last bad primary snapshot when exception happens
                 try {
                     destroySnapshotOnPrimaryStorage(conn, snapshotUuid);
                 } catch (final Exception e) {
-                    s_logger.debug("clean up snapshot failed", e);
+                    logger.debug("clean up snapshot failed", e);
                 }
             }
         }
@@ -1369,7 +1370,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
             installPath = template.getPath();
             if (!hypervisorResource.createSecondaryStorageFolder(conn, secondaryStorageMountPath, installPath, nfsVersion)) {
                 details = " Filed to create folder " + installPath + " in secondary storage";
-                s_logger.warn(details);
+                logger.warn(details);
                 return new CopyCmdAnswer(details);
             }
 
@@ -1417,7 +1418,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
                 hypervisorResource.deleteSecondaryStorageFolder(conn, secondaryStorageMountPath, installPath, nfsVersion);
             }
             details = "Creating template from volume " + volumeUUID + " failed due to " + e.toString();
-            s_logger.error(details, e);
+            logger.error(details, e);
         }
         return new CopyCmdAnswer(details);
     }
@@ -1443,7 +1444,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
 
             destUri = new URI(destStore.getUrl());
         } catch (final Exception ex) {
-            s_logger.debug("Invalid URI", ex);
+            logger.debug("Invalid URI", ex);
 
             return new CopyCmdAnswer("Invalid URI: " + ex.toString());
         }
@@ -1472,7 +1473,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
             if (!hypervisorResource.createSecondaryStorageFolder(conn, destNfsPath, destDir, destNfsVersion)) {
                 final String details = " Failed to create folder " + destDir + " in secondary storage";
 
-                s_logger.warn(details);
+                logger.warn(details);
 
                 return new CopyCmdAnswer(details);
             }
@@ -1523,7 +1524,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
 
             return new CopyCmdAnswer(newTemplate);
         } catch (final Exception ex) {
-            s_logger.error("Failed to create a template from a snapshot", ex);
+            logger.error("Failed to create a template from a snapshot", ex);
 
             return new CopyCmdAnswer("Failed to create a template from a snapshot: " + ex.toString());
         } finally {
@@ -1532,7 +1533,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
                     try {
                         destVdi.destroy(conn);
                     } catch (final Exception e) {
-                        s_logger.debug("Cleaned up leftover VDI on destination storage due to failure: ", e);
+                        logger.debug("Cleaned up leftover VDI on destination storage due to failure: ", e);
                     }
                 }
             }
@@ -1648,16 +1649,16 @@ public class XenServerStorageProcessor implements StorageProcessor {
         } catch (final XenAPIException e) {
             details = "Exception due to " + e.toString();
 
-            s_logger.warn(details, e);
+            logger.warn(details, e);
         } catch (final Exception e) {
             details = "Exception due to " + e.getMessage();
 
-            s_logger.warn(details, e);
+            logger.warn(details, e);
         }
 
         if (!result) {
             // Is this logged at a higher level?
-            s_logger.error(details);
+            logger.error(details);
         }
 
         // In all cases return something.
@@ -1703,7 +1704,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
             return new CopyCmdAnswer(newVol);
         }
         catch (final Exception ex) {
-            s_logger.warn("Failed to copy snapshot to volume: " + ex.toString(), ex);
+            logger.warn("Failed to copy snapshot to volume: " + ex.toString(), ex);
 
             return new CopyCmdAnswer(ex.getMessage());
         }
@@ -1743,7 +1744,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
             return new CopyCmdAnswer(newVol);
         }
         catch (Exception ex) {
-            s_logger.warn("Failed to copy snapshot to volume: " + ex.toString(), ex);
+            logger.warn("Failed to copy snapshot to volume: " + ex.toString(), ex);
 
             return new CopyCmdAnswer(ex.getMessage());
         }
@@ -1768,13 +1769,13 @@ public class XenServerStorageProcessor implements StorageProcessor {
             try {
                 deleteVDI(conn, snapshotVdi);
             } catch (final BadServerResponse e) {
-                s_logger.debug("delete snapshot failed:" + e.toString());
+                logger.debug("delete snapshot failed:" + e.toString());
                 errMsg = e.toString();
             } catch (final XenAPIException e) {
-                s_logger.debug("delete snapshot failed:" + e.toString());
+                logger.debug("delete snapshot failed:" + e.toString());
                 errMsg = e.toString();
             } catch (final XmlRpcException e) {
-                s_logger.debug("delete snapshot failed:" + e.toString());
+                logger.debug("delete snapshot failed:" + e.toString());
                 errMsg = e.toString();
             }
             return new Answer(cmd, false, errMsg);
@@ -1791,7 +1792,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
             poolSr.scan(conn);
             return new IntroduceObjectAnswer(cmd.getDataTO());
         } catch (final Exception e) {
-            s_logger.debug("Failed to introduce object", e);
+            logger.debug("Failed to introduce object", e);
             return new Answer(cmd, false, e.toString());
         }
     }
@@ -1805,7 +1806,7 @@ public class XenServerStorageProcessor implements StorageProcessor {
             vdi.forget(conn);
             return new IntroduceObjectAnswer(cmd.getDataTO());
         } catch (final Exception e) {
-            s_logger.debug("Failed to forget object", e);
+            logger.debug("Failed to forget object", e);
             return new Answer(cmd, false, e.toString());
         }
     }
