@@ -18,6 +18,7 @@ package com.cloud.kubernetes.cluster;
 
 import java.lang.reflect.Field;
 import java.lang.reflect.Modifier;
+import java.util.Objects;
 
 import javax.inject.Inject;
 
@@ -25,31 +26,30 @@ import org.apache.cloudstack.acl.ControlledEntity;
 import org.apache.cloudstack.api.ApiCommandResourceType;
 import org.apache.cloudstack.framework.config.ConfigKey;
 import org.apache.cloudstack.framework.config.Configurable;
-import org.apache.commons.lang3.ObjectUtils;
-import org.apache.log4j.Logger;
-import org.springframework.stereotype.Component;
 
 import com.cloud.event.EventTypes;
 import com.cloud.kubernetes.cluster.dao.KubernetesClusterDao;
 import com.cloud.kubernetes.cluster.dao.KubernetesClusterVmMapDao;
 import com.cloud.kubernetes.version.KubernetesSupportedVersion;
 import com.cloud.kubernetes.version.KubernetesVersionEventTypes;
-import com.cloud.user.Account;
 import com.cloud.uservm.UserVm;
 import com.cloud.utils.component.AdapterBase;
 import com.cloud.utils.exception.CloudRuntimeException;
 import com.cloud.vm.UserVmManager;
 
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
+import org.apache.commons.lang3.ObjectUtils;
+import org.springframework.stereotype.Component;
+
 @Component
 public class KubernetesServiceHelperImpl extends AdapterBase implements KubernetesServiceHelper, Configurable {
-    private static final Logger logger = Logger.getLogger(KubernetesServiceHelperImpl.class);
+    private static final Logger logger = LogManager.getLogger(KubernetesServiceHelperImpl.class);
 
     @Inject
     private KubernetesClusterDao kubernetesClusterDao;
     @Inject
     private KubernetesClusterVmMapDao kubernetesClusterVmMapDao;
-    @Inject
-    KubernetesClusterService kubernetesClusterService;
 
     protected void setEventTypeEntityDetails(Class<?> eventTypeDefinedClass, Class<?> entityClass) {
         Field[] declaredFields = eventTypeDefinedClass.getDeclaredFields();
@@ -74,6 +74,15 @@ public class KubernetesServiceHelperImpl extends AdapterBase implements Kubernet
         return kubernetesClusterDao.findByUuid(uuid);
     }
 
+    @Override
+    public ControlledEntity findByVmId(long vmId) {
+        KubernetesClusterVmMapVO clusterVmMapVO = kubernetesClusterVmMapDao.getClusterMapFromVmId(vmId);
+        if (Objects.isNull(clusterVmMapVO)) {
+            return null;
+        }
+        return kubernetesClusterDao.findById(clusterVmMapVO.getClusterId());
+    }
+
     @Override
     public void checkVmCanBeDestroyed(UserVm userVm) {
         if (!UserVmManager.CKS_NODE.equals(userVm.getUserVmType())) {
@@ -97,11 +106,6 @@ public class KubernetesServiceHelperImpl extends AdapterBase implements Kubernet
         throw new CloudRuntimeException(msg);
     }
 
-    @Override
-    public void cleanupForAccount(Account account) {
-        kubernetesClusterService.cleanupForAccount(account);
-    }
-
     @Override
     public String getConfigComponentName() {
         return KubernetesServiceHelper.class.getSimpleName();
