@@ -33,7 +33,6 @@ import net.juniper.contrail.api.types.VirtualNetworkPolicyType;
 import net.juniper.contrail.api.types.VnSubnetsType;
 
 import org.apache.cloudstack.network.contrail.management.ContrailManager;
-import org.apache.log4j.Logger;
 
 import com.cloud.dc.VlanVO;
 import com.cloud.dc.dao.VlanDao;
@@ -44,7 +43,6 @@ import com.cloud.utils.exception.CloudRuntimeException;
 import com.cloud.utils.net.NetUtils;
 
 public class VirtualNetworkModel extends ModelObjectBase {
-    private static final Logger s_logger = Logger.getLogger(VirtualNetworkModel.class);
 
     private String _uuid;
     private long _id;
@@ -141,7 +139,7 @@ public class VirtualNetworkModel extends ModelObjectBase {
         try {
             api.delete(VirtualNetwork.class, _uuid);
         } catch (IOException ex) {
-            s_logger.warn("virtual-network delete", ex);
+            logger.warn("virtual-network delete", ex);
         }
     }
 
@@ -182,7 +180,7 @@ public class VirtualNetworkModel extends ModelObjectBase {
             try {
                 _uuid = manager.findVirtualNetworkId(network);
             } catch (IOException ex) {
-                s_logger.warn("Unable to read virtual-network", ex);
+                logger.warn("Unable to read virtual-network", ex);
             }
         }
 
@@ -191,7 +189,7 @@ public class VirtualNetworkModel extends ModelObjectBase {
         try {
             _projectId = manager.getProjectId(network.getDomainId(), network.getAccountId());
         } catch (IOException ex) {
-            s_logger.warn("project read", ex);
+            logger.warn("project read", ex);
             throw new CloudRuntimeException(ex);
         }
 
@@ -223,7 +221,7 @@ public class VirtualNetworkModel extends ModelObjectBase {
                     try {
                         project = (Project)api.findById(Project.class, _projectId);
                     } catch (IOException ex) {
-                        s_logger.debug("project read", ex);
+                        logger.debug("project read", ex);
                         throw new CloudRuntimeException("Failed to read project", ex);
                     }
                     vn.setParent(project);
@@ -248,16 +246,16 @@ public class VirtualNetworkModel extends ModelObjectBase {
             try {
                 String ipam_id = api.findByName(NetworkIpam.class, null, "default-network-ipam");
                 if (ipam_id == null) {
-                    s_logger.debug("could not find default-network-ipam");
+                    logger.debug("could not find default-network-ipam");
                     return;
                 }
                 ipam = (NetworkIpam)api.findById(NetworkIpam.class, ipam_id);
                 if (ipam == null) {
-                    s_logger.debug("could not find NetworkIpam with ipam_id: " + ipam_id);
+                    logger.debug("could not find NetworkIpam with ipam_id: " + ipam_id);
                     return;
                 }
             } catch (IOException ex) {
-                s_logger.error(ex);
+                logger.error(ex);
                 return;
             }
             _ipam = ipam;
@@ -287,7 +285,7 @@ public class VirtualNetworkModel extends ModelObjectBase {
             try {
                 api.create(vn);
             } catch (Exception ex) {
-                s_logger.debug("virtual-network create", ex);
+                logger.debug("virtual-network create", ex);
                 throw new CloudRuntimeException("Failed to create virtual-network", ex);
             }
             _vn = vn;
@@ -295,7 +293,7 @@ public class VirtualNetworkModel extends ModelObjectBase {
             try {
                 api.update(vn);
             } catch (IOException ex) {
-                s_logger.warn("virtual-network update", ex);
+                logger.warn("virtual-network update", ex);
                 throw new CloudRuntimeException("Unable to update virtual-network object", ex);
             }
         }
@@ -321,16 +319,16 @@ public class VirtualNetworkModel extends ModelObjectBase {
             try {
                 String ipam_id = api.findByName(NetworkIpam.class, null, "default-network-ipam");
                 if (ipam_id == null) {
-                    s_logger.debug("could not find default-network-ipam");
+                    logger.debug("could not find default-network-ipam");
                     return;
                 }
                 ipam = (NetworkIpam)api.findById(NetworkIpam.class, ipam_id);
                 if (ipam == null) {
-                    s_logger.debug("could not find NetworkIpam with ipam_id: " + ipam_id);
+                    logger.debug("could not find NetworkIpam with ipam_id: " + ipam_id);
                     return;
                 }
             } catch (IOException ex) {
-                s_logger.error(ex);
+                logger.error(ex);
                 return;
             }
             _ipam = ipam;
@@ -415,7 +413,7 @@ public class VirtualNetworkModel extends ModelObjectBase {
     diff.removeAll(vncSubnets);
 
     if (!diff.isEmpty()) {
-        s_logger.debug("Subnets changed, network: " + _name + "; db: " + dbSubnets + ", vnc: " + vncSubnets + ", diff: " + diff);
+        logger.debug("Subnets changed, network: " + _name + "; db: " + dbSubnets + ", vnc: " + vncSubnets + ", diff: " + diff);
         return false;
     }
 
@@ -451,7 +449,7 @@ public class VirtualNetworkModel extends ModelObjectBase {
         try {
             latest = (VirtualNetworkModel)o;
         } catch (ClassCastException ex) {
-            s_logger.warn("Invalid model object is passed to cast to VirtualNetworkModel");
+            logger.warn("Invalid model object is passed to cast to VirtualNetworkModel");
             return false;
         }
 
@@ -469,7 +467,7 @@ public class VirtualNetworkModel extends ModelObjectBase {
         List<String> newSubnets = new ArrayList<String>();
 
         if ((currentIpamRefs == null && newIpamRefs != null) || (currentIpamRefs != null && newIpamRefs == null)) {  //Check for existence only
-            s_logger.debug("ipams differ: current=" + currentIpamRefs + ", new=" + newIpamRefs);
+            logger.debug("ipams differ: current=" + currentIpamRefs + ", new=" + newIpamRefs);
             return false;
         }
         if (currentIpamRefs == null) {
@@ -502,7 +500,7 @@ public class VirtualNetworkModel extends ModelObjectBase {
         diff.removeAll(newSubnets);
 
         if (!diff.isEmpty()) {
-            s_logger.debug("Subnets differ, network: " + _name + "; db: " + currentSubnets + ", vnc: " + newSubnets + ", diff: " + diff);
+            logger.debug("Subnets differ, network: " + _name + "; db: " + currentSubnets + ", vnc: " + newSubnets + ", diff: " + diff);
             return false;
         }
 
