@@ -35,7 +35,6 @@ import org.apache.cloudstack.engine.orchestration.service.NetworkOrchestrationSe
 import org.apache.cloudstack.framework.config.dao.ConfigurationDao;
 import org.apache.cloudstack.network.ExternalNetworkDeviceManager.NetworkDevice;
 import org.apache.cloudstack.region.gslb.GslbServiceProvider;
-import org.apache.log4j.Logger;
 import org.json.JSONException;
 import org.json.JSONObject;
 
@@ -159,7 +158,6 @@ public class NetscalerElement extends ExternalLoadBalancerDeviceManagerImpl
 implements LoadBalancingServiceProvider, NetscalerLoadBalancerElementService, ExternalLoadBalancerDeviceManager,
 IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
 
-    private static final Logger s_logger = Logger.getLogger(NetscalerElement.class);
 
     @Inject
     NetworkModel _networkManager;
@@ -224,7 +222,7 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
                 && config.getGuestType() == Network.GuestType.Shared && config.getTrafficType() == TrafficType.Guest);
 
         if (!(handleInAdvanceZone || handleInBasicZone)) {
-            s_logger.trace("Not handling network with Type  " + config.getGuestType() + " and traffic type "
+            logger.trace("Not handling network with Type  " + config.getGuestType() + " and traffic type "
                     + config.getTrafficType() + " in zone of type " + zone.getNetworkType());
             return false;
         }
@@ -250,7 +248,7 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
 
         if (_ntwkSrvcDao.canProviderSupportServiceInNetwork(guestConfig.getId(), Service.StaticNat,
                 Network.Provider.Netscaler) && !isBasicZoneNetwok(guestConfig)) {
-            s_logger.error("NetScaler provider can not be Static Nat service provider for the network "
+            logger.error("NetScaler provider can not be Static Nat service provider for the network "
                     + guestConfig.getGuestType() + " and traffic type " + guestConfig.getTrafficType());
             return false;
         }
@@ -312,7 +310,7 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
                     throws ResourceUnavailableException, InsufficientCapacityException, ConfigurationException {
 
         if (guestConfig.getTrafficType() != TrafficType.Guest) {
-            s_logger.trace("External load balancer can only be used for guest networks.");
+            logger.trace("External load balancer can only be used for guest networks.");
             return false;
         }
 
@@ -331,13 +329,13 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
                 if (lbDeviceVO == null) {
                     String msg = "failed to allocate Netscaler ControlCenter Resource for the zone in the network "
                             + guestConfig.getId();
-                    s_logger.error(msg);
+                    logger.error(msg);
                     throw new InsufficientNetworkCapacityException(msg, DataCenter.class,
                             guestConfig.getDataCenterId());
                 }
             }
             netscalerControlCenter = _hostDao.findById(lbDeviceVO.getId());
-            s_logger.debug("Allocated Netscaler Control Center device:" + lbDeviceVO.getId() + " for the network: "
+            logger.debug("Allocated Netscaler Control Center device:" + lbDeviceVO.getId() + " for the network: "
                     + guestConfig.getId());
         } else {
             // find the load balancer device allocated for the network
@@ -346,7 +344,7 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
             // on restart network, device could have been allocated already, skip allocation if a device is assigned
             lbDeviceVO = getNetScalerControlCenterForNetwork(guestConfig);
             if (lbDeviceVO == null) {
-                s_logger.warn(
+                logger.warn(
                         "Network shutdwon requested on external load balancer element, which did not implement the network."
                                 + " Either network implement failed half way through or already network shutdown is completed. So just returning.");
                 return true;
@@ -371,7 +369,7 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
             selfIp = _ipAddrMgr.acquireGuestIpAddress(guestConfig, null);
             if (selfIp == null) {
                 String msg = "failed to acquire guest IP address so not implementing the network on the NetscalerControlCenter";
-                s_logger.error(msg);
+                logger.error(msg);
                 throw new InsufficientNetworkCapacityException(msg, Network.class, guestConfig.getId());
             }
             networkDetails.put("snip", selfIp);
@@ -585,7 +583,7 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
         } catch (Exception e) {
             String msg = "Error parsing the url parameter specified in addNetscalerLoadBalancer command due to "
                     + e.getMessage();
-            s_logger.debug(msg);
+            logger.debug(msg);
             throw new InvalidParameterValueException(msg);
         }
         Map<String, String> configParams = new HashMap<String, String>();
@@ -595,7 +593,7 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
 
                 if (dedicatedUse && !deviceName.equals(NetworkDevice.NetscalerVPXLoadBalancer.getName())) {
                     String msg = "Only Netscaler VPX load balancers can be specified for dedicated use";
-                    s_logger.debug(msg);
+                    logger.debug(msg);
                     throw new InvalidParameterValueException(msg);
                 }
 
@@ -604,13 +602,13 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
                     if (!deviceName.equals(NetworkDevice.NetscalerVPXLoadBalancer.getName())
                             && !deviceName.equals(NetworkDevice.NetscalerMPXLoadBalancer.getName())) {
                         String msg = "Only Netscaler VPX or MPX load balancers can be specified as GSLB service provider";
-                        s_logger.debug(msg);
+                        logger.debug(msg);
                         throw new InvalidParameterValueException(msg);
                     }
 
                     if (cmd.getSitePublicIp() == null || cmd.getSitePrivateIp() == null) {
                         String msg = "Public and Privae IP needs to provided for NetScaler that will be GSLB provider";
-                        s_logger.debug(msg);
+                        logger.debug(msg);
                         throw new InvalidParameterValueException(msg);
                     }
 
@@ -762,7 +760,7 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
         try {
             _agentMgr.reconnect(host.getId());
         } catch (AgentUnavailableException e) {
-            s_logger.warn("failed to reconnect host " + host, e);
+            logger.warn("failed to reconnect host " + host, e);
         }
         return lbDeviceVo;
     }
@@ -927,7 +925,7 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
                     _hostDao.update(ncc.getId(), ncc);
                     _resourceMgr.deleteHost(ncc.getId(), false, false);
                 } catch (Exception e) {
-                    s_logger.debug(e);
+                    logger.debug(e);
                     return false;
                 }
             }
@@ -1049,7 +1047,7 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
 
         // NetScaler can only act as Lb and Static Nat service provider
         if (services != null && !services.isEmpty() && !netscalerServices.containsAll(services)) {
-            s_logger.warn(
+            logger.warn(
                     "NetScaler network element can only support LB and Static NAT services and service combination "
                             + services + " is not supported.");
 
@@ -1058,10 +1056,10 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
                 buff.append(service.getName());
                 buff.append(" ");
             }
-            s_logger.warn(
+            logger.warn(
                     "NetScaler network element can only support LB and Static NAT services and service combination "
                             + buff.toString() + " is not supported.");
-            s_logger.warn(
+            logger.warn(
                     "NetScaler network element can only support LB and Static NAT services and service combination "
                             + services + " is not supported.");
             return false;
@@ -1103,14 +1101,14 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
             } catch (Exception e) {
                 errMsg = "Could not allocate a NetSclaer load balancer for configuring elastic load balancer rules due to "
                         + e.getMessage();
-                s_logger.error(errMsg);
+                logger.error(errMsg);
                 throw new ResourceUnavailableException(errMsg, this.getClass(), 0);
             }
         }
 
         if (!isNetscalerDevice(lbDeviceVO.getDeviceName())) {
             errMsg = "There are no NetScaler load balancer assigned for this network. So NetScaler element can not be handle elastic load balancer rules.";
-            s_logger.error(errMsg);
+            logger.error(errMsg);
             throw new ResourceUnavailableException(errMsg, this.getClass(), 0);
         }
 
@@ -1148,7 +1146,7 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
                 String details = (answer != null) ? answer.getDetails() : "details unavailable";
                 String msg = "Unable to apply elastic load balancer rules to the external load balancer appliance in zone "
                         + network.getDataCenterId() + " due to: " + details + ".";
-                s_logger.error(msg);
+                logger.error(msg);
                 throw new ResourceUnavailableException(msg, DataCenter.class, network.getDataCenterId());
             }
         }
@@ -1177,14 +1175,14 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
                     } catch (Exception e) {
                         errMsg = "Could not allocate a NetSclaer load balancer for configuring static NAT rules due to"
                                 + e.getMessage();
-                        s_logger.error(errMsg);
+                        logger.error(errMsg);
                         throw new ResourceUnavailableException(errMsg, this.getClass(), 0);
                     }
                 }
 
                 if (!isNetscalerDevice(lbDevice.getDeviceName())) {
                     errMsg = "There are no NetScaler load balancer assigned for this network. So NetScaler element will not be handling the static nat rules.";
-                    s_logger.error(errMsg);
+                    logger.error(errMsg);
                     throw new ResourceUnavailableException(errMsg, this.getClass(), 0);
                 }
                 SetStaticNatRulesAnswer answer = null;
@@ -1214,7 +1212,7 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
                         if (lbDevice == null) {
                             String errMsg = "There is no NetScaler device configured to perform EIP to guest IP address: "
                                     + rule.getDestIpAddress();
-                            s_logger.error(errMsg);
+                            logger.error(errMsg);
                             throw new ResourceUnavailableException(errMsg, this.getClass(), 0);
                         }
 
@@ -1231,7 +1229,7 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
                                 cmd);
                         if (answer == null) {
                             String errMsg = "Failed to configure INAT rule on NetScaler device " + lbDevice.getHostId();
-                            s_logger.error(errMsg);
+                            logger.error(errMsg);
                             throw new ResourceUnavailableException(errMsg, this.getClass(), 0);
                         }
                     }
@@ -1240,7 +1238,7 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
             }
             return true;
         } catch (Exception e) {
-            s_logger.error("Failed to configure StaticNat rule due to " + e.getMessage());
+            logger.error("Failed to configure StaticNat rule due to " + e.getMessage());
             return false;
         }
     }
@@ -1278,14 +1276,14 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
         ExternalLoadBalancerDeviceVO lbDeviceVO = getExternalLoadBalancerForNetwork(network);
 
         if (lbDeviceVO == null) {
-            s_logger.warn(
+            logger.warn(
                     "There is no external load balancer device assigned to this network either network is not implement are already shutdown so just returning");
             return null;
         }
 
         if (!isNetscalerDevice(lbDeviceVO.getDeviceName())) {
             errMsg = "There are no NetScaler load balancer assigned for this network. So NetScaler element can not be handle elastic load balancer rules.";
-            s_logger.error(errMsg);
+            logger.error(errMsg);
             throw new ResourceUnavailableException(errMsg, this.getClass(), 0);
         }
 
@@ -1332,10 +1330,10 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
                     return getLBHealthChecks(network, lbrules);
                 }
             } catch (ResourceUnavailableException e) {
-                s_logger.error("Error in getting the LB Rules from NetScaler " + e);
+                logger.error("Error in getting the LB Rules from NetScaler " + e);
             }
         } else {
-            s_logger.error("Network cannot handle to LB service ");
+            logger.error("Network cannot handle to LB service ");
         }
         return null;
     }
@@ -1377,7 +1375,7 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
         ExternalLoadBalancerDeviceVO nsGslbProvider = findGslbProvider(zoneId, physicalNetworkId);
         if (nsGslbProvider == null) {
             String msg = "Unable to find a NetScaler configured as gslb service provider in zone " + zoneId;
-            s_logger.debug(msg);
+            logger.debug(msg);
             throw new ResourceUnavailableException(msg, DataCenter.class, zoneId);
         }
 
@@ -1389,7 +1387,7 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
         Answer answer = _agentMgr.easySend(zoneGslbProviderHosId, gslbConfigCmd);
         if (answer == null || !answer.getResult()) {
             String msg = "Unable to apply global load balancer rule to the gslb service provider in zone " + zoneId;
-            s_logger.debug(msg);
+            logger.debug(msg);
             throw new ResourceUnavailableException(msg, DataCenter.class, zoneId);
         }
 
@@ -1449,7 +1447,7 @@ IpDeployer, StaticNatServiceProvider, GslbServiceProvider {
             if (schemeCaps != null) {
                 for (LoadBalancingRule rule : rules) {
                     if (!schemeCaps.contains(rule.getScheme().toString())) {
-                        s_logger.debug("Scheme " + rules.get(0).getScheme() + " is not supported by the provider "
+                        logger.debug("Scheme " + rules.get(0).getScheme() + " is not supported by the provider "
                                 + getName());
                         return false;
                     }
