@@ -47,7 +47,6 @@ import org.apache.cloudstack.api.ServerApiException;
 import org.apache.cloudstack.api.response.PhysicalNetworkResponse;
 import org.apache.cloudstack.api.response.SuccessResponse;
 import org.apache.cloudstack.api.response.ZoneResponse;
-import org.apache.log4j.Logger;
 
 import java.util.HashMap;
 import java.util.List;
@@ -58,7 +57,6 @@ import javax.inject.Inject;
 @APICommand(name = ConfigTungstenFabricServiceCmd.APINAME, description = "config Tungsten-Fabric service",
     responseObject = SuccessResponse.class, requestHasSensitiveInfo = false, responseHasSensitiveInfo = false)
 public class ConfigTungstenFabricServiceCmd extends BaseCmd {
-    public static final Logger s_logger = Logger.getLogger(ConfigTungstenFabricServiceCmd.class.getName());
     public static final String APINAME = "configTungstenFabricService";
     public static final String NETWORKOFFERING = "DefaultTungstenFarbicNetworkOffering";
 
@@ -139,18 +137,18 @@ public class ConfigTungstenFabricServiceCmd extends BaseCmd {
             private void persistNetworkServiceMapAvoidingDuplicates(Network network,
                                                                     NetworkServiceMapVO mapVO) {
                 if (mapVO == null) {
-                    s_logger.error("Expected a network-service-provider mapping entity to be persisted");
+                    logger.error("Expected a network-service-provider mapping entity to be persisted");
                     return;
                 }
                 Network.Service service = Network.Service.getService(mapVO.getService());
                 Network.Provider provider = Network.Provider.getProvider(mapVO.getProvider());
                 if (service == null || provider == null) {
-                    s_logger.error(String.format("Could not obtain the service or the provider " +
+                    logger.error(String.format("Could not obtain the service or the provider " +
                             "from the network-service-provider map with ID = %s", mapVO.getId()));
                     return;
                 }
                 if (networkServiceMapDao.canProviderSupportServiceInNetwork(network.getId(), service, provider)) {
-                    s_logger.debug(String.format("A mapping between the network, service and provider (%s, %s, %s) " +
+                    logger.debug(String.format("A mapping between the network, service and provider (%s, %s, %s) " +
                                     "already exists, skipping duplicated entry",
                             network.getId(), service.getName(), provider.getName()));
                     return;
