@@ -135,7 +135,6 @@ import org.apache.cloudstack.network.tungsten.dao.TungstenFabricLBHealthMonitorV
 import org.apache.cloudstack.network.tungsten.model.TungstenLoadBalancerMember;
 import org.apache.cloudstack.network.tungsten.model.TungstenRule;
 import org.apache.commons.lang3.StringUtils;
-import org.apache.log4j.Logger;
 import org.springframework.stereotype.Component;
 
 import java.util.ArrayList;
@@ -154,7 +153,6 @@ public class TungstenElement extends AdapterBase
     implements StaticNatServiceProvider, IpDeployer, FirewallServiceProvider,
     LoadBalancingServiceProvider, PortForwardingServiceProvider, ResourceStateAdapter, DnsServiceProvider, Listener,
     StateListener<VirtualMachine.State, VirtualMachine.Event, VirtualMachine>, NetworkMigrationResponder {
-    private static final Logger s_logger = Logger.getLogger(TungstenElement.class);
 
     private static final String NETWORK = "network";
 
@@ -273,11 +271,11 @@ public class TungstenElement extends AdapterBase
     }
 
     protected boolean canHandle(Network network, Network.Service service) {
-        s_logger.debug("Checking if TungstenElement can handle service " + service.getName() + " on network "
+        logger.debug("Checking if TungstenElement can handle service " + service.getName() + " on network "
             + network.getDisplayText());
 
         if (!networkModel.isProviderForNetwork(getProvider(), network.getId())) {
-            s_logger.debug("TungstenElement is not a provider for network " + network.getDisplayText());
+            logger.debug("TungstenElement is not a provider for network " + network.getDisplayText());
             return false;
         }
 
