@@ -81,7 +81,6 @@ import org.apache.cloudstack.network.tungsten.agent.api.SetupTungstenVRouterComm
 import org.apache.cloudstack.network.tungsten.agent.api.TungstenAnswer;
 import org.apache.cloudstack.network.tungsten.agent.api.TungstenCommand;
 import org.apache.cloudstack.network.tungsten.model.TungstenRule;
-import org.apache.log4j.Logger;
 
 import java.util.ArrayList;
 import java.util.List;
@@ -90,8 +89,6 @@ import javax.inject.Inject;
 
 public class TungstenGuestNetworkGuru extends GuestNetworkGuru implements NetworkMigrationResponder {
 
-    private static final Logger s_logger = Logger.getLogger(TungstenGuestNetworkGuru.class);
-
     @Inject
     NetworkDao networkDao;
     @Inject
@@ -147,17 +144,17 @@ public class TungstenGuestNetworkGuru extends GuestNetworkGuru implements Networ
     }
 
     @Override
-    public Network design(NetworkOffering offering, DeploymentPlan plan, Network userSpecified, Account owner) {
+    public Network design(NetworkOffering offering, DeploymentPlan plan, Network userSpecified, String name, Long vpcId, Account owner) {
 
         PhysicalNetworkVO physnet = _physicalNetworkDao.findById(plan.getPhysicalNetworkId());
         DataCenter dc = _dcDao.findById(plan.getDataCenterId());
 
         if (!canHandle(offering, dc.getNetworkType(), physnet)) {
-            s_logger.debug("Refusing to design this network");
+            logger.debug("Refusing to design this network");
             return null;
         }
 
-        NetworkVO network = (NetworkVO) super.design(offering, plan, userSpecified, owner);
+        NetworkVO network = (NetworkVO) super.design(offering, plan, userSpecified, name, vpcId, owner);
 
         if (network == null) {
             return null;
