@@ -28,7 +28,6 @@ import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
-import static org.powermock.api.mockito.PowerMockito.mockStatic;
 
 import com.cloud.agent.AgentManager;
 import com.cloud.api.ApiDBUtils;
@@ -110,24 +109,24 @@ import org.apache.cloudstack.network.tungsten.agent.api.ReleaseTungstenFloatingI
 import org.apache.cloudstack.network.tungsten.agent.api.SetupTungstenVRouterCommand;
 import org.apache.cloudstack.network.tungsten.agent.api.TungstenAnswer;
 import org.apache.cloudstack.network.tungsten.agent.api.UpdateTungstenLoadBalancerHealthMonitorCommand;
-import org.apache.cloudstack.network.tungsten.agent.api.UpdateTungstenLoadBalancerListenerCommand;
 import org.apache.cloudstack.network.tungsten.agent.api.UpdateTungstenLoadBalancerMemberCommand;
 import org.apache.cloudstack.network.tungsten.agent.api.UpdateTungstenLoadBalancerPoolCommand;
 import org.apache.cloudstack.network.tungsten.dao.TungstenFabricLBHealthMonitorDao;
 import org.apache.cloudstack.network.tungsten.dao.TungstenFabricLBHealthMonitorVO;
+import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.mockito.Mock;
+import org.mockito.MockedStatic;
+import org.mockito.Mockito;
 import org.mockito.MockitoAnnotations;
-import org.powermock.core.classloader.annotations.PrepareForTest;
-import org.powermock.modules.junit4.PowerMockRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
 import java.util.Arrays;
 import java.util.List;
 
-@RunWith(PowerMockRunner.class)
-@PrepareForTest({ApiDBUtils.class, EncryptionUtil.class})
+@RunWith(MockitoJUnitRunner.class)
 public class TungstenElementTest {
     @Mock
     TungstenFabricUtils tungstenFabricUtils;
@@ -182,9 +181,15 @@ public class TungstenElementTest {
 
     TungstenElement tungstenElement;
 
+    MockedStatic<ApiDBUtils> apiDBUtilsMocked;
+
+    MockedStatic<EncryptionUtil> encryptionUtilMocked;
+
+    AutoCloseable closeable;
+
     @Before
     public void setup() {
-        MockitoAnnotations.initMocks(this);
+        closeable = MockitoAnnotations.openMocks(this);
         tungstenElement = new TungstenElement();
         tungstenElement.tungstenFabricUtils = tungstenFabricUtils;
         tungstenElement.networkModel = networkModel;
@@ -212,12 +217,19 @@ public class TungstenElementTest {
         tungstenElement.tungstenFabricLBHealthMonitorDao = tungstenFabricLBHealthMonitorDao;
         tungstenElement.loadBalancerCertMapDao = loadBalancerCertMapDao;
 
-        mockStatic(ApiDBUtils.class);
-        mockStatic(EncryptionUtil.class);
+        apiDBUtilsMocked = Mockito.mockStatic(ApiDBUtils.class);
+        encryptionUtilMocked = Mockito.mockStatic(EncryptionUtil.class);
 
         when(tungstenService.getTungstenProjectFqn(any())).thenReturn("default-domain:default-project");
     }
 
+    @After
+    public void tearDown() throws Exception {
+        apiDBUtilsMocked.close();
+        encryptionUtilMocked.close();
+        closeable.close();
+    }
+
     @Test
     public void canHandleSuccessTest() {
         Network network = mock(Network.class);
@@ -244,13 +256,12 @@ public class TungstenElementTest {
         StaticNatImpl staticNat = mock(StaticNatImpl.class);
         IPAddressVO ipAddressVO = mock(IPAddressVO.class);
         VMInstanceVO vmInstanceVO = mock(VMInstanceVO.class);
-        TungstenAnswer assignFloatingIpAnswer = mock(TungstenAnswer.class);
+        TungstenAnswer assignFloatingIpAnswer = MockTungstenAnswerFactory.get(true);
         Nic nic = mock(Nic.class);
         Network publicNetwork = mock(Network.class);
         List<StaticNatImpl> staticNatList = List.of(staticNat);
 
         when(staticNat.isForRevoke()).thenReturn(false);
-        when(assignFloatingIpAnswer.getResult()).thenReturn(true);
         when(ipAddressDao.findByIdIncludingRemoved(anyLong())).thenReturn(ipAddressVO);
         when(vmInstanceDao.findByIdIncludingRemoved(anyLong())).thenReturn(vmInstanceVO);
         when(networkModel.getNicInNetworkIncludingRemoved(anyLong(), anyLong())).thenReturn(nic);
@@ -266,13 +277,12 @@ public class TungstenElementTest {
         StaticNatImpl staticNat = mock(StaticNatImpl.class);
         IPAddressVO ipAddressVO = mock(IPAddressVO.class);
         VMInstanceVO vmInstanceVO = mock(VMInstanceVO.class);
-        TungstenAnswer assignFloatingIpAnswer = mock(TungstenAnswer.class);
+        TungstenAnswer assignFloatingIpAnswer = MockTungstenAnswerFactory.get(false);
         Nic nic = mock(Nic.class);
         Network publicNetwork = mock(Network.class);
         List<StaticNatImpl> staticNatList = List.of(staticNat);
 
         when(staticNat.isForRevoke()).thenReturn(false);
-        when(assignFloatingIpAnswer.getResult()).thenReturn(false);
         when(ipAddressDao.findByIdIncludingRemoved(anyLong())).thenReturn(ipAddressVO);
         when(vmInstanceDao.findByIdIncludingRemoved(anyLong())).thenReturn(vmInstanceVO);
         when(networkModel.getNicInNetworkIncludingRemoved(anyLong(), anyLong())).thenReturn(nic);
@@ -288,13 +298,12 @@ public class TungstenElementTest {
         StaticNatImpl staticNat = mock(StaticNatImpl.class);
         IPAddressVO ipAddressVO = mock(IPAddressVO.class);
         VMInstanceVO vmInstanceVO = mock(VMInstanceVO.class);
-        TungstenAnswer releaseFloatingIpAnswer = mock(TungstenAnswer.class);
+        TungstenAnswer releaseFloatingIpAnswer = MockTungstenAnswerFactory.get(true);
         Nic nic = mock(Nic.class);
         Network publicNetwork = mock(Network.class);
         List<StaticNatImpl> staticNatList = List.of(staticNat);
 
         when(staticNat.isForRevoke()).thenReturn(true);
-        when(releaseFloatingIpAnswer.getResult()).thenReturn(true);
         when(ipAddressDao.findByIdIncludingRemoved(anyLong())).thenReturn(ipAddressVO);
         when(vmInstanceDao.findByIdIncludingRemoved(anyLong())).thenReturn(vmInstanceVO);
         when(networkModel.getNicInNetworkIncludingRemoved(anyLong(), anyLong())).thenReturn(nic);
@@ -310,13 +319,12 @@ public class TungstenElementTest {
         StaticNatImpl staticNat = mock(StaticNatImpl.class);
         IPAddressVO ipAddressVO = mock(IPAddressVO.class);
         VMInstanceVO vmInstanceVO = mock(VMInstanceVO.class);
-        TungstenAnswer releaseFloatingIpAnswer = mock(TungstenAnswer.class);
+        TungstenAnswer releaseFloatingIpAnswer = MockTungstenAnswerFactory.get(false);
         Nic nic = mock(Nic.class);
         Network publicNetwork = mock(Network.class);
         List<StaticNatImpl> staticNatList = List.of(staticNat);
 
         when(staticNat.isForRevoke()).thenReturn(true);
-        when(releaseFloatingIpAnswer.getResult()).thenReturn(false);
         when(ipAddressDao.findByIdIncludingRemoved(anyLong())).thenReturn(ipAddressVO);
         when(vmInstanceDao.findByIdIncludingRemoved(anyLong())).thenReturn(vmInstanceVO);
         when(networkModel.getNicInNetworkIncludingRemoved(anyLong(), anyLong())).thenReturn(nic);
@@ -343,18 +351,15 @@ public class TungstenElementTest {
         TungstenFabricLBHealthMonitorVO tungstenFabricLBHealthMonitorVO = mock(TungstenFabricLBHealthMonitorVO.class);
         IPAddressVO ipAddressVO = mock(IPAddressVO.class);
         TungstenGuestNetworkIpAddressVO tungstenGuestNetworkIpAddressVO = mock(TungstenGuestNetworkIpAddressVO.class);
-        TungstenAnswer createTungstenNetworkLoadbalancerAnswer = mock(TungstenAnswer.class);
-        TungstenAnswer updateTungstenLoadBalancerPoolAnswer = mock(TungstenAnswer.class);
-        TungstenAnswer updateTungstenLoadBalancerMemberAnswer = mock(TungstenAnswer.class);
-        TungstenAnswer updateTungstenLoadBalancerListenerAnswer = mock(TungstenAnswer.class);
-        TungstenAnswer updateTungstenHealthMonitorAnswer = mock(TungstenAnswer.class);
+        TungstenAnswer createTungstenNetworkLoadbalancerAnswer = MockTungstenAnswerFactory.get(true);
+        TungstenAnswer updateTungstenLoadBalancerPoolAnswer = MockTungstenAnswerFactory.get(true);
+        TungstenAnswer updateTungstenLoadBalancerMemberAnswer = MockTungstenAnswerFactory.get(true);
+        TungstenAnswer updateTungstenLoadBalancerListenerAnswer = MockTungstenAnswerFactory.get(true);
+        TungstenAnswer updateTungstenHealthMonitorAnswer = MockTungstenAnswerFactory.get(true);
         LoadBalancingRule.LbSslCert lbSslCert = mock(LoadBalancingRule.LbSslCert.class);
         when(lbStickinessPolicy.getMethodName()).thenReturn("AppCookie");
         List<Pair<String, String>> pairList = List.of(new Pair<>("cookieName", "cookieValue"));
 
-        when(accountMgr.getActiveUser(anyLong())).thenReturn(caller);
-        when(caller.getApiKey()).thenReturn("apikey");
-        when(caller.getSecretKey()).thenReturn("secreatekey");
         when(lbStickinessPolicy.getParams()).thenReturn(pairList);
         when(loadBalancingRule1.getId()).thenReturn(1L);
         when(loadBalancingRule1.getState()).thenReturn(FirewallRule.State.Add);
@@ -363,8 +368,6 @@ public class TungstenElementTest {
         when(loadBalancingRule1.getDefaultPortStart()).thenReturn(443);
         when(loadBalancingRule1.getStickinessPolicies()).thenReturn(lbStickinessPolicyList);
         when(loadBalancingRule1.getSourceIp()).thenReturn(ip);
-        when(loadBalancingRule1.getLbSslCert()).thenReturn(lbSslCert);
-        when(loadBalancingRule1.getUuid()).thenReturn("loadbalancingruleuuid");
         when(networkModel.getSystemNetworkByZoneAndTrafficType(anyLong(), any())).thenReturn(publicNetwork);
         when(ipAddressDao.findByIpAndDcId(anyLong(), anyString())).thenReturn(ipAddressVO);
         when(ipAddressVO.getAddress()).thenReturn(ip);
@@ -372,19 +375,11 @@ public class TungstenElementTest {
         when(tungstenGuestNetworkIpAddressVO.getGuestIpAddress()).thenReturn(ip);
         when(ip.addr()).thenReturn("10.10.10.10");
         when(tungstenGuestNetworkIpAddressDao.findByNetworkIdAndPublicIp(anyLong(), anyString())).thenReturn(tungstenGuestNetworkIpAddressVO);
-        when(ipAddressMgr.acquireGuestIpAddress(any(), any())).thenReturn("192.168.100.100");
         when(tungstenFabricUtils.sendTungstenCommand(any(CreateTungstenNetworkLoadbalancerCommand.class), anyLong())).thenReturn(createTungstenNetworkLoadbalancerAnswer);
         when(tungstenFabricUtils.sendTungstenCommand(any(UpdateTungstenLoadBalancerPoolCommand.class), anyLong())).thenReturn(updateTungstenLoadBalancerPoolAnswer);
         when(tungstenFabricUtils.sendTungstenCommand(any(UpdateTungstenLoadBalancerMemberCommand.class), anyLong())).thenReturn(updateTungstenLoadBalancerMemberAnswer);
-        when(tungstenFabricUtils.sendTungstenCommand(any(UpdateTungstenLoadBalancerListenerCommand.class), anyLong())).thenReturn(updateTungstenLoadBalancerListenerAnswer);
-        when(createTungstenNetworkLoadbalancerAnswer.getResult()).thenReturn(true);
-        when(updateTungstenLoadBalancerPoolAnswer.getResult()).thenReturn(true);
-        when(updateTungstenLoadBalancerMemberAnswer.getResult()).thenReturn(true);
-        when(updateTungstenLoadBalancerListenerAnswer.getResult()).thenReturn(true);
-        when(updateTungstenHealthMonitorAnswer.getResult()).thenReturn(true);
         when(configDao.getValue(Config.NetworkLBHaproxyStatsVisbility.key())).thenReturn("enabled");
         when(tungstenService.updateLoadBalancer(any(), any())).thenReturn(true);
-        when(lbDao.listByIpAddress(anyLong())).thenReturn(loadBalancerVOList);
         when(EncryptionUtil.generateSignature(anyString(), anyString())).thenReturn("generatedString");
         when(tungstenFabricLBHealthMonitorDao.findByLbId(anyLong())).thenReturn(tungstenFabricLBHealthMonitorVO);
         when(tungstenFabricUtils.sendTungstenCommand(any(UpdateTungstenLoadBalancerHealthMonitorCommand.class), anyLong())).thenReturn(updateTungstenHealthMonitorAnswer);
@@ -407,10 +402,10 @@ public class TungstenElementTest {
         List<LoadBalancerVO> loadBalancerVOList = List.of(loadBalancerVO);
         IPAddressVO ipAddressVO = mock(IPAddressVO.class);
         TungstenGuestNetworkIpAddressVO tungstenGuestNetworkIpAddressVO = mock(TungstenGuestNetworkIpAddressVO.class);
-        TungstenAnswer createTungstenNetworkLoadbalancerAnswer = mock(TungstenAnswer.class);
-        TungstenAnswer updateTungstenLoadBalancerPoolAnswer = mock(TungstenAnswer.class);
-        TungstenAnswer updateTungstenLoadBalancerMemberAnswer = mock(TungstenAnswer.class);
-        TungstenAnswer updateTungstenHealthMonitorAnswer = mock(TungstenAnswer.class);
+        TungstenAnswer createTungstenNetworkLoadbalancerAnswer = MockTungstenAnswerFactory.get(true);
+        TungstenAnswer updateTungstenLoadBalancerPoolAnswer = MockTungstenAnswerFactory.get(true);
+        TungstenAnswer updateTungstenLoadBalancerMemberAnswer = MockTungstenAnswerFactory.get(true);
+        TungstenAnswer updateTungstenHealthMonitorAnswer = MockTungstenAnswerFactory.get(true);
         List<Pair<String, String>> pairList = List.of(new Pair<>("cookieName", "cookieValue"));
         TungstenFabricLBHealthMonitorVO tungstenFabricLBHealthMonitorVO = mock(TungstenFabricLBHealthMonitorVO.class);
 
@@ -427,20 +422,13 @@ public class TungstenElementTest {
         when(ipAddressDao.findByIpAndDcId(anyLong(), anyString())).thenReturn(ipAddressVO);
         when(ipAddressVO.getAddress()).thenReturn(ip);
         when(lbVmMapDao.listByLoadBalancerId(anyLong(), anyBoolean())).thenReturn(loadBalancerVMMapVOList);
-        when(tungstenGuestNetworkIpAddressVO.getGuestIpAddress()).thenReturn(ip);
         when(ip.addr()).thenReturn("10.10.10.10");
         when(ipAddressMgr.acquireGuestIpAddress(any(), any())).thenReturn("192.168.100.100");
         when(tungstenFabricUtils.sendTungstenCommand(any(CreateTungstenNetworkLoadbalancerCommand.class), anyLong())).thenReturn(createTungstenNetworkLoadbalancerAnswer);
         when(tungstenFabricUtils.sendTungstenCommand(any(UpdateTungstenLoadBalancerPoolCommand.class), anyLong())).thenReturn(updateTungstenLoadBalancerPoolAnswer);
         when(tungstenFabricUtils.sendTungstenCommand(any(UpdateTungstenLoadBalancerMemberCommand.class), anyLong())).thenReturn(updateTungstenLoadBalancerMemberAnswer);
-        when(createTungstenNetworkLoadbalancerAnswer.getResult()).thenReturn(true);
-        when(updateTungstenLoadBalancerPoolAnswer.getResult()).thenReturn(true);
-        when(updateTungstenLoadBalancerMemberAnswer.getResult()).thenReturn(true);
         when(configDao.getValue(Config.NetworkLBHaproxyStatsVisbility.key())).thenReturn("disabled");
-        when(tungstenService.updateLoadBalancerSsl(any(), any())).thenReturn(false);
-        when(lbDao.listByIpAddress(anyLong())).thenReturn(loadBalancerVOList);
         when(tungstenFabricLBHealthMonitorDao.findByLbId(anyLong())).thenReturn(tungstenFabricLBHealthMonitorVO);
-        when(updateTungstenHealthMonitorAnswer.getResult()).thenReturn(true);
         when(tungstenFabricUtils.sendTungstenCommand(any(UpdateTungstenLoadBalancerHealthMonitorCommand.class), anyLong())).thenReturn(updateTungstenHealthMonitorAnswer);
 
         assertFalse(tungstenElement.applyLBRules(network, loadBalancingRuleList1));
@@ -457,8 +445,8 @@ public class TungstenElementTest {
         List<LoadBalancingRule> loadBalancingRuleList1 = List.of(loadBalancingRule1);
         List<LoadBalancerVO> loadBalancerVOList1 = List.of(loadBalancerVO1);
         TungstenGuestNetworkIpAddressVO tungstenGuestNetworkIpAddressVO = mock(TungstenGuestNetworkIpAddressVO.class);
-        TungstenAnswer deleteTungstenLoadBalancerListenerAnswer = mock(TungstenAnswer.class);
-        TungstenAnswer deleteTungstenLoadBalancerCommand = mock(TungstenAnswer.class);
+        TungstenAnswer deleteTungstenLoadBalancerListenerAnswer = MockTungstenAnswerFactory.get(true);
+        TungstenAnswer deleteTungstenLoadBalancerCommand = MockTungstenAnswerFactory.get(true);
 
         when(networkModel.getSystemNetworkByZoneAndTrafficType(anyLong(), any())).thenReturn(publicNetwork);
         when(loadBalancingRule1.getSourceIp()).thenReturn(ip1);
@@ -466,11 +454,7 @@ public class TungstenElementTest {
         when(ipAddressDao.findByIpAndDcId(anyLong(), anyString())).thenReturn(ipAddressVO);
         when(ipAddressVO.getAddress()).thenReturn(ip1);
         when(ip1.addr()).thenReturn("10.10.10.10");
-        when(tungstenFabricUtils.sendTungstenCommand(any(DeleteTungstenLoadBalancerListenerCommand.class), anyLong())).thenReturn(deleteTungstenLoadBalancerListenerAnswer);
         when(tungstenFabricUtils.sendTungstenCommand(any(DeleteTungstenLoadBalancerCommand.class), anyLong())).thenReturn(deleteTungstenLoadBalancerCommand);
-        when(deleteTungstenLoadBalancerListenerAnswer.getResult()).thenReturn(true);
-        when(deleteTungstenLoadBalancerCommand.getResult()).thenReturn(true);
-        when(tungstenService.updateLoadBalancerSsl(any(), any())).thenReturn(false);
         when(lbDao.listByIpAddress(anyLong())).thenReturn(loadBalancerVOList1);
         when(tungstenGuestNetworkIpAddressDao.findByNetworkIdAndPublicIp(anyLong(),anyString())).thenReturn(tungstenGuestNetworkIpAddressVO);
         when(tungstenGuestNetworkIpAddressDao.remove(anyLong())).thenReturn(false);
@@ -488,8 +472,8 @@ public class TungstenElementTest {
         LoadBalancerVO loadBalancerVO1 = mock(LoadBalancerVO.class);
         LoadBalancerVO loadBalancerVO2 = mock(LoadBalancerVO.class);
         TungstenGuestNetworkIpAddressVO tungstenGuestNetworkIpAddressVO = mock(TungstenGuestNetworkIpAddressVO.class);
-        TungstenAnswer deleteTungstenLoadBalancerListenerAnswer = mock(TungstenAnswer.class);
-        TungstenAnswer deleteTungstenLoadBalancerCommand = mock(TungstenAnswer.class);
+        TungstenAnswer deleteTungstenLoadBalancerListenerAnswer = MockTungstenAnswerFactory.get(true);
+        TungstenAnswer deleteTungstenLoadBalancerCommand = MockTungstenAnswerFactory.get(true);
         List<LoadBalancingRule> loadBalancingRuleList = List.of(loadBalancingRule);
         List<LoadBalancerVO> loadBalancerVOList = Arrays.asList(loadBalancerVO1, loadBalancerVO2);
 
@@ -497,15 +481,10 @@ public class TungstenElementTest {
         when(loadBalancingRule.getSourceIp()).thenReturn(ip);
         when(loadBalancingRule.getState()).thenReturn(FirewallRule.State.Revoke);
         when(ipAddressDao.findByIpAndDcId(anyLong(), anyString())).thenReturn(ipAddressVO);
-        when(ipAddressVO.getAddress()).thenReturn(ip);
         when(ip.addr()).thenReturn("10.10.10.10");
         when(tungstenFabricUtils.sendTungstenCommand(any(DeleteTungstenLoadBalancerListenerCommand.class), anyLong())).thenReturn(deleteTungstenLoadBalancerListenerAnswer);
-        when(tungstenFabricUtils.sendTungstenCommand(any(DeleteTungstenLoadBalancerCommand.class), anyLong())).thenReturn(deleteTungstenLoadBalancerCommand);
-        when(deleteTungstenLoadBalancerListenerAnswer.getResult()).thenReturn(true);
-        when(deleteTungstenLoadBalancerCommand.getResult()).thenReturn(true);
         when(tungstenService.updateLoadBalancer(any(), any())).thenReturn(true);
         when(lbDao.listByIpAddress(anyLong())).thenReturn(loadBalancerVOList);
-        when(tungstenGuestNetworkIpAddressDao.findByNetworkIdAndPublicIp(anyLong(),anyString())).thenReturn(tungstenGuestNetworkIpAddressVO);
 
         assertTrue(tungstenElement.applyLBRules(network, loadBalancingRuleList));
     }
@@ -518,7 +497,7 @@ public class TungstenElementTest {
         IPAddressVO ipAddressVO = mock(IPAddressVO.class);
         UserVm userVm = mock(UserVm.class);
         Nic nic = mock(Nic.class);
-        TungstenAnswer applyTungstenPortForwardingAnswer = mock(TungstenAnswer.class);
+        TungstenAnswer applyTungstenPortForwardingAnswer = MockTungstenAnswerFactory.get(true);
         List<PortForwardingRule> portForwardingRuleList = List.of(portForwardingRule);
 
         when(portForwardingRule.getState()).thenReturn(FirewallRule.State.Add);
@@ -527,7 +506,6 @@ public class TungstenElementTest {
         when(ApiDBUtils.findUserVmById(anyLong())).thenReturn(userVm);
         when(networkModel.getNicInNetwork(anyLong(), anyLong())).thenReturn(nic);
         when(tungstenFabricUtils.sendTungstenCommand(any(ApplyTungstenPortForwardingCommand.class), anyLong())).thenReturn(applyTungstenPortForwardingAnswer);
-        when(applyTungstenPortForwardingAnswer.getResult()).thenReturn(true);
 
         assertTrue(tungstenElement.applyPFRules(network, portForwardingRuleList));
     }
@@ -540,7 +518,7 @@ public class TungstenElementTest {
         IPAddressVO ipAddressVO = mock(IPAddressVO.class);
         UserVm userVm = mock(UserVm.class);
         Nic nic = mock(Nic.class);
-        TungstenAnswer applyTungstenPortForwardingAnswer = mock(TungstenAnswer.class);
+        TungstenAnswer applyTungstenPortForwardingAnswer = MockTungstenAnswerFactory.get(false);
         List<PortForwardingRule> portForwardingRuleList = List.of(portForwardingRule);
 
         when(portForwardingRule.getState()).thenReturn(FirewallRule.State.Add);
@@ -549,7 +527,6 @@ public class TungstenElementTest {
         when(ApiDBUtils.findUserVmById(anyLong())).thenReturn(userVm);
         when(networkModel.getNicInNetwork(anyLong(), anyLong())).thenReturn(nic);
         when(tungstenFabricUtils.sendTungstenCommand(any(ApplyTungstenPortForwardingCommand.class), anyLong())).thenReturn(applyTungstenPortForwardingAnswer);
-        when(applyTungstenPortForwardingAnswer.getResult()).thenReturn(false);
 
         assertFalse(tungstenElement.applyPFRules(network, portForwardingRuleList));
     }
@@ -562,7 +539,7 @@ public class TungstenElementTest {
         IPAddressVO ipAddressVO = mock(IPAddressVO.class);
         UserVm userVm = mock(UserVm.class);
         Nic nic = mock(Nic.class);
-        TungstenAnswer applyTungstenPortForwardingAnswer = mock(TungstenAnswer.class);
+        TungstenAnswer applyTungstenPortForwardingAnswer = MockTungstenAnswerFactory.get(true);
         List<PortForwardingRule> portForwardingRuleList = List.of(portForwardingRule);
 
         when(portForwardingRule.getState()).thenReturn(FirewallRule.State.Revoke);
@@ -571,7 +548,6 @@ public class TungstenElementTest {
         when(ApiDBUtils.findUserVmById(anyLong())).thenReturn(userVm);
         when(networkModel.getNicInNetwork(anyLong(), anyLong())).thenReturn(nic);
         when(tungstenFabricUtils.sendTungstenCommand(any(ApplyTungstenPortForwardingCommand.class), anyLong())).thenReturn(applyTungstenPortForwardingAnswer);
-        when(applyTungstenPortForwardingAnswer.getResult()).thenReturn(true);
 
         assertTrue(tungstenElement.applyPFRules(network, portForwardingRuleList));
     }
@@ -584,7 +560,7 @@ public class TungstenElementTest {
         IPAddressVO ipAddressVO = mock(IPAddressVO.class);
         UserVm userVm = mock(UserVm.class);
         Nic nic = mock(Nic.class);
-        TungstenAnswer applyTungstenPortForwardingAnswer = mock(TungstenAnswer.class);
+        TungstenAnswer applyTungstenPortForwardingAnswer = MockTungstenAnswerFactory.get(false);
         List<PortForwardingRule> portForwardingRuleList = List.of(portForwardingRule);
 
         when(portForwardingRule.getState()).thenReturn(FirewallRule.State.Revoke);
@@ -593,7 +569,6 @@ public class TungstenElementTest {
         when(ApiDBUtils.findUserVmById(anyLong())).thenReturn(userVm);
         when(networkModel.getNicInNetwork(anyLong(), anyLong())).thenReturn(nic);
         when(tungstenFabricUtils.sendTungstenCommand(any(ApplyTungstenPortForwardingCommand.class), anyLong())).thenReturn(applyTungstenPortForwardingAnswer);
-        when(applyTungstenPortForwardingAnswer.getResult()).thenReturn(false);
 
         assertFalse(tungstenElement.applyPFRules(network, portForwardingRuleList));
     }
@@ -607,9 +582,9 @@ public class TungstenElementTest {
         ReservationContext reservationContext = mock(ReservationContext.class);
         VMInstanceVO vmInstanceVO = mock(VMInstanceVO.class);
         HostVO host = mock(HostVO.class);
-        TungstenAnswer createTungstenVMAnswer = mock(TungstenAnswer.class);
+        TungstenAnswer createTungstenVMAnswer = MockTungstenAnswerFactory.get(true);
         IPAddressVO ipAddressVO = mock(IPAddressVO.class);
-        TungstenAnswer createTungstenNetworkPolicyAnswer = mock(TungstenAnswer.class);
+        TungstenAnswer createTungstenNetworkPolicyAnswer = MockTungstenAnswerFactory.get(true);
 
         nicProfile.setIPv4Address("192.168.100.100");
         when(network.getTrafficType()).thenReturn(Networks.TrafficType.Public);
@@ -619,8 +594,6 @@ public class TungstenElementTest {
         when(ipAddressDao.findByIpAndDcId(anyLong(), anyString())).thenReturn(ipAddressVO);
         when(tungstenFabricUtils.sendTungstenCommand(any(CreateTungstenNetworkPolicyCommand.class), anyLong())).thenReturn(createTungstenNetworkPolicyAnswer);
         when(virtualMachineProfile.getType()).thenReturn(VirtualMachine.Type.ConsoleProxy);
-        when(createTungstenVMAnswer.getResult()).thenReturn(true);
-        when(createTungstenNetworkPolicyAnswer.getResult()).thenReturn(true);
 
         assertTrue(tungstenElement.prepare(network, nicProfile, virtualMachineProfile, deployDestination, reservationContext));
         assertEquals(Nic.ReservationStrategy.Create, nicProfile.getReservationStrategy());
@@ -638,7 +611,7 @@ public class TungstenElementTest {
         ReservationContext reservationContext = mock(ReservationContext.class);
         VMInstanceVO vmInstanceVO = mock(VMInstanceVO.class);
         HostVO host = mock(HostVO.class);
-        TungstenAnswer createTungstenVMAnswer = mock(TungstenAnswer.class);
+        TungstenAnswer createTungstenVMAnswer = MockTungstenAnswerFactory.get(true);
 
         nicProfile.setIPv4Address("192.168.100.100");
         when(network.getTrafficType()).thenReturn(Networks.TrafficType.Management);
@@ -646,7 +619,6 @@ public class TungstenElementTest {
         when(hostDao.findById(anyLong())).thenReturn(host);
         when(tungstenFabricUtils.sendTungstenCommand(any(CreateTungstenVirtualMachineCommand.class), anyLong())).thenReturn(createTungstenVMAnswer);
         when(virtualMachineProfile.getType()).thenReturn(VirtualMachine.Type.SecondaryStorageVm);
-        when(createTungstenVMAnswer.getResult()).thenReturn(true);
 
         assertTrue(tungstenElement.prepare(network, nicProfile, virtualMachineProfile, deployDestination, reservationContext));
         assertEquals(Nic.ReservationStrategy.Create, nicProfile.getReservationStrategy());
@@ -700,10 +672,6 @@ public class TungstenElementTest {
         when(tungstenFabricUtils.sendTungstenCommand(any(DeleteTungstenVmInterfaceCommand.class), anyLong())).thenReturn(deleteVmiAnswer);
         when(tungstenFabricUtils.sendTungstenCommand(any(DeleteTungstenVmCommand.class), anyLong())).thenReturn(deleteVmAnswer);
         when(tungstenFabricUtils.sendTungstenCommand(any(DeleteTungstenNetworkPolicyCommand.class), anyLong())).thenReturn(deleteTungstenNetworkPolicyAnswer);
-        when(deleteTungstenVRouterPortAnswer.getResult()).thenReturn(true);
-        when(deleteVmiAnswer.getResult()).thenReturn(true);
-        when(deleteVmAnswer.getResult()).thenReturn(true);
-        when(deleteTungstenNetworkPolicyAnswer.getResult()).thenReturn(true);
 
         assertTrue(tungstenElement.release(network, nicProfile, virtualMachineProfile, reservationContext));
     }
@@ -720,7 +688,6 @@ public class TungstenElementTest {
         TungstenAnswer deleteVmiAnswer = mock(TungstenAnswer.class);
         TungstenAnswer deleteVmAnswer = mock(TungstenAnswer.class);
 
-        when(nicProfile.getIPv4Address()).thenReturn("192.168.100.100");
         when(network.getTrafficType()).thenReturn(Networks.TrafficType.Management);
         when(vmInstanceDao.findById(anyLong())).thenReturn(vmInstanceVO);
         when(hostDao.findById(anyLong())).thenReturn(host);
@@ -728,9 +695,6 @@ public class TungstenElementTest {
         when(tungstenFabricUtils.sendTungstenCommand(any(DeleteTungstenVRouterPortCommand.class), anyLong())).thenReturn(deleteTungstenVRouterPortAnswer);
         when(tungstenFabricUtils.sendTungstenCommand(any(DeleteTungstenVmInterfaceCommand.class), anyLong())).thenReturn(deleteVmiAnswer);
         when(tungstenFabricUtils.sendTungstenCommand(any(DeleteTungstenVmCommand.class), anyLong())).thenReturn(deleteVmAnswer);
-        when(deleteTungstenVRouterPortAnswer.getResult()).thenReturn(true);
-        when(deleteVmiAnswer.getResult()).thenReturn(true);
-        when(deleteVmAnswer.getResult()).thenReturn(true);
 
         assertTrue(tungstenElement.release(network, nicProfile, virtualMachineProfile, reservationContext));
     }
@@ -746,7 +710,6 @@ public class TungstenElementTest {
         TungstenAnswer deleteTungstenVRouterPortAnswer = mock(TungstenAnswer.class);
         TungstenAnswer deleteVmiAnswer = mock(TungstenAnswer.class);
 
-        when(nicProfile.getIPv4Address()).thenReturn("192.168.100.100");
         when(network.getTrafficType()).thenReturn(Networks.TrafficType.Management);
         when(vmInstanceDao.findById(anyLong())).thenReturn(vmInstanceVO);
         when(hostDao.findById(anyLong())).thenReturn(host);
@@ -754,8 +717,6 @@ public class TungstenElementTest {
         when(tungstenFabricUtils.sendTungstenCommand(any(DeleteTungstenVRouterPortCommand.class), anyLong())).thenReturn(deleteTungstenVRouterPortAnswer);
         when(tungstenFabricUtils.sendTungstenCommand(any(DeleteTungstenVmInterfaceCommand.class), anyLong())).thenReturn(deleteVmiAnswer);
         when(tungstenFabricUtils.sendTungstenCommand(any(DeleteTungstenVmCommand.class), anyLong())).thenThrow(IllegalArgumentException.class);
-        when(deleteTungstenVRouterPortAnswer.getResult()).thenReturn(true);
-        when(deleteVmiAnswer.getResult()).thenReturn(true);
 
         tungstenElement.release(network, nicProfile, virtualMachineProfile, reservationContext);
     }
@@ -767,14 +728,12 @@ public class TungstenElementTest {
         Network network = mock(Network.class);
         ReservationContext reservationContext = mock(ReservationContext.class);
         List<IPAddressVO> ipAddressVOList = Arrays.asList(ipAddressVO1, ipAddressVO2);
-        TungstenAnswer tungstenDeleteFIPAnswer = mock(TungstenAnswer.class);
-        TungstenAnswer tungstenDeleteNPAnswer = mock(TungstenAnswer.class);
+        TungstenAnswer tungstenDeleteFIPAnswer = MockTungstenAnswerFactory.get(true);
+        TungstenAnswer tungstenDeleteNPAnswer = MockTungstenAnswerFactory.get(true);
 
         when(ipAddressDao.listByAssociatedNetwork(anyLong(), anyBoolean())).thenReturn(ipAddressVOList);
         when(tungstenFabricUtils.sendTungstenCommand(any(DeleteTungstenFloatingIpCommand.class), anyLong())).thenReturn(tungstenDeleteFIPAnswer);
         when(tungstenFabricUtils.sendTungstenCommand(any(DeleteTungstenNetworkPolicyCommand.class), anyLong())).thenReturn(tungstenDeleteNPAnswer);
-        when(tungstenDeleteFIPAnswer.getResult()).thenReturn(true);
-        when(tungstenDeleteNPAnswer.getResult()).thenReturn(true);
 
         assertTrue(tungstenElement.destroy(network, reservationContext));
     }
@@ -916,8 +875,8 @@ public class TungstenElementTest {
         Network network = mock(Network.class);
         FirewallRuleVO firewallRuleVO = mock(FirewallRuleVO.class);
         Network publicNetwork = mock(Network.class);
-        TungstenAnswer createNetworkPolicyAnswer = mock(TungstenAnswer.class);
-        TungstenAnswer applyNetworkPolicyAnswer = mock(TungstenAnswer.class);
+        TungstenAnswer createNetworkPolicyAnswer = MockTungstenAnswerFactory.get(true);
+        TungstenAnswer applyNetworkPolicyAnswer = MockTungstenAnswerFactory.get(true);
 
         when(firewallRuleVO.getState()).thenReturn(FirewallRule.State.Add);
         when(firewallRuleVO.getSourceCidrList()).thenReturn(List.of("192.168.100.0/24"));
@@ -927,8 +886,6 @@ public class TungstenElementTest {
         when(firewallRuleVO.getTrafficType()).thenReturn(FirewallRule.TrafficType.Egress);
         when(tungstenFabricUtils.sendTungstenCommand(any(CreateTungstenNetworkPolicyCommand.class), anyLong())).thenReturn(createNetworkPolicyAnswer);
         when(tungstenFabricUtils.sendTungstenCommand(any(ApplyTungstenNetworkPolicyCommand.class), anyLong())).thenReturn(applyNetworkPolicyAnswer);
-        when(createNetworkPolicyAnswer.getResult()).thenReturn(true);
-        when(applyNetworkPolicyAnswer.getResult()).thenReturn(true);
 
         assertTrue(tungstenElement.applyFWRules(network, List.of(firewallRuleVO)));
     }
@@ -938,8 +895,8 @@ public class TungstenElementTest {
         Network network = mock(Network.class);
         FirewallRuleVO firewallRuleVO = mock(FirewallRuleVO.class);
         Network publicNetwork = mock(Network.class);
-        TungstenAnswer createNetworkPolicyAnswer = mock(TungstenAnswer.class);
-        TungstenAnswer applyNetworkPolicyAnswer = mock(TungstenAnswer.class);
+        TungstenAnswer createNetworkPolicyAnswer = MockTungstenAnswerFactory.get(true);
+        TungstenAnswer applyNetworkPolicyAnswer = MockTungstenAnswerFactory.get(true);
         IPAddressVO ipAddressVO = mock(IPAddressVO.class);
         Ip ip = mock(Ip.class);
 
@@ -953,8 +910,6 @@ public class TungstenElementTest {
         when(firewallRuleVO.getTrafficType()).thenReturn(FirewallRule.TrafficType.Ingress);
         when(tungstenFabricUtils.sendTungstenCommand(any(CreateTungstenNetworkPolicyCommand.class), anyLong())).thenReturn(createNetworkPolicyAnswer);
         when(tungstenFabricUtils.sendTungstenCommand(any(ApplyTungstenNetworkPolicyCommand.class), anyLong())).thenReturn(applyNetworkPolicyAnswer);
-        when(createNetworkPolicyAnswer.getResult()).thenReturn(true);
-        when(applyNetworkPolicyAnswer.getResult()).thenReturn(true);
 
         assertTrue(tungstenElement.applyFWRules(network, List.of(firewallRuleVO)));
     }
@@ -971,7 +926,6 @@ public class TungstenElementTest {
         when(firewallRuleVO.getPurpose()).thenReturn(FirewallRule.Purpose.Firewall);
         when(firewallRuleVO.getTrafficType()).thenReturn(FirewallRule.TrafficType.Ingress);
         when(tungstenFabricUtils.sendTungstenCommand(any(DeleteTungstenNetworkPolicyCommand.class), anyLong())).thenReturn(deleteNetworkPolicyAnswer);
-        when(deleteNetworkPolicyAnswer.getResult()).thenReturn(true);
 
         assertTrue(tungstenElement.applyFWRules(network, List.of(firewallRuleVO)));
     }
@@ -1011,14 +965,13 @@ public class TungstenElementTest {
         ReservationContext context = mock(ReservationContext.class);
         VMInstanceVO vmInstanceVO = mock(VMInstanceVO.class);
         HostVO hostVO = mock(HostVO.class);
-        TungstenAnswer tungstenAnswer = mock(TungstenAnswer.class);
+        TungstenAnswer tungstenAnswer = MockTungstenAnswerFactory.get(true);
 
         when(vm.getType()).thenReturn(VirtualMachine.Type.ConsoleProxy);
         when(network.getTrafficType()).thenReturn(Networks.TrafficType.Public);
         when(vmInstanceDao.findById(anyLong())).thenReturn(vmInstanceVO);
         when(hostDao.findById(anyLong())).thenReturn(hostVO);
         when(tungstenFabricUtils.sendTungstenCommand(any(CreateTungstenVirtualMachineCommand.class), anyLong())).thenReturn(tungstenAnswer);
-        when(tungstenAnswer.getResult()).thenReturn(true);
 
         assertTrue(tungstenElement.prepareMigration(nic, network, vm, dest, context));
     }
