@@ -35,7 +35,8 @@ import org.apache.cloudstack.utils.qemu.QemuImg;
 import org.apache.cloudstack.utils.qemu.QemuImgException;
 import org.apache.cloudstack.utils.qemu.QemuImgFile;
 import org.apache.commons.io.FileUtils;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
+import org.apache.logging.log4j.Logger;
 import org.joda.time.Duration;
 import org.libvirt.LibvirtException;
 
@@ -43,19 +44,13 @@ import org.libvirt.LibvirtException;
 public final class LinstorBackupSnapshotCommandWrapper
     extends CommandWrapper<LinstorBackupSnapshotCommand, CopyCmdAnswer, LibvirtComputingResource>
 {
-    private static final Logger s_logger = Logger.getLogger(LinstorBackupSnapshotCommandWrapper.class);
-
-    private static String zfsDatasetName(String zfsFullSnapshotUrl) {
-        String zfsFullPath = zfsFullSnapshotUrl.substring(6);
-        int atPos = zfsFullPath.indexOf('@');
-        return atPos >= 0 ? zfsFullPath.substring(0, atPos) : zfsFullPath;
-    }
+    protected static Logger LOGGER = LogManager.getLogger(LinstorBackupSnapshotCommandWrapper.class);
 
     private String zfsSnapdev(boolean hide, String zfsUrl) {
-        Script script = new Script("zfs", Duration.millis(5000));
+        Script script = new Script("/usr/bin/zfs", Duration.millis(5000));
         script.add("set");
         script.add("snapdev=" + (hide ? "hidden" : "visible"));
-        script.add(zfsDatasetName(zfsUrl));  // cutting zfs:// and @snapshotname
+        script.add(zfsUrl.substring(6));  // cutting zfs://
         return script.execute();
     }
 
@@ -73,7 +68,7 @@ public final class LinstorBackupSnapshotCommandWrapper
             try {
                 secondaryPool.delete();
             } catch (final Exception e) {
-                s_logger.debug("Failed to delete secondary storage", e);
+                LOGGER.debug("Failed to delete secondary storage", e);
             }
         }
     }
@@ -96,29 +91,24 @@ public final class LinstorBackupSnapshotCommandWrapper
         // NOTE: the qemu img will also contain the drbd metadata at the end
         final QemuImg qemu = new QemuImg(waitMilliSeconds);
         qemu.convert(srcFile, dstFile);
-        s_logger.info(String.format("Backup snapshot '%s' to '%s'", srcPath, dstPath));
+        LOGGER.info("Backup snapshot " + srcFile + " to " + dstPath);
         return dstPath;
     }
 
     private SnapshotObjectTO setCorrectSnapshotSize(final SnapshotObjectTO dst, final String dstPath) {
         final File snapFile = new File(dstPath);
-        long size;
-        if (snapFile.exists()) {
-            size = snapFile.length();
-        } else {
-            s_logger.warn(String.format("Snapshot file %s does not exist. Reporting size 0", dstPath));
-            size = 0;
-        }
+        final long size = snapFile.exists() ? snapFile.length() : 0;
 
-        dst.setPath(dst.getPath() + File.separator + dst.getName());
-        dst.setPhysicalSize(size);
-        return dst;
+        final SnapshotObjectTO snapshot = new SnapshotObjectTO();
+        snapshot.setPath(dst.getPath() + File.separator + dst.getName());
+        snapshot.setPhysicalSize(size);
+        return snapshot;
     }
 
     @Override
     public CopyCmdAnswer execute(LinstorBackupSnapshotCommand cmd, LibvirtComputingResource serverResource)
     {
-        s_logger.debug("LinstorBackupSnapshotCommandWrapper: " + cmd.getSrcTO().getPath() + " -> " + cmd.getDestTO().getPath());
+        LOGGER.debug("LinstorBackupSnapshotCommandWrapper: " + cmd.getSrcTO().getPath() + " -> " + cmd.getDestTO().getPath());
         final SnapshotObjectTO src = (SnapshotObjectTO) cmd.getSrcTO();
         final SnapshotObjectTO dst = (SnapshotObjectTO) cmd.getDestTO();
         KVMStoragePool secondaryPool = null;
@@ -141,13 +131,13 @@ public final class LinstorBackupSnapshotCommandWrapper
             // provide the linstor snapshot block device
             // on lvm thin this should already be there in /dev/mapper/vg-snapshotname
             // on zfs we need to unhide the snapshot block device
-            s_logger.info("Src: " + srcPath + " | " + src.getName());
+            LOGGER.info("Src: " + srcPath + " | " + src.getName());
             if (srcPath.startsWith("zfs://")) {
                 zfsHidden = true;
-                if (zfsSnapdev(false, src.getPath()) != null) {
+                if (zfsSnapdev(false, srcPath) != null) {
                     return new CopyCmdAnswer("Unable to unhide zfs snapshot device.");
                 }
-                srcPath = "/dev/zvol/" + srcPath.substring(6);
+                srcPath = "/dev/" + srcPath.substring(6);
             }
 
             secondaryPool = storagePoolMgr.getStoragePoolByURI(dstDataStore.getUrl());
@@ -159,15 +149,14 @@ public final class LinstorBackupSnapshotCommandWrapper
             if (result != null) {
                 return new CopyCmdAnswer("qemu-img shrink failed: " + result);
             }
-            s_logger.info("Backup shrunk " + dstPath + " to actual size " + src.getVolume().getSize());
+            LOGGER.info("Backup shrunk " + dstPath + " to actual size " + src.getVolume().getSize());
 
             SnapshotObjectTO snapshot = setCorrectSnapshotSize(dst, dstPath);
-            s_logger.info(String.format("Actual file size for '%s' is %d", dstPath, snapshot.getPhysicalSize()));
             return new CopyCmdAnswer(snapshot);
         } catch (final Exception e) {
             final String error = String.format("Failed to backup snapshot with id [%s] with a pool %s, due to %s",
                 cmd.getSrcTO().getId(), cmd.getSrcTO().getDataStore().getUuid(), e.getMessage());
-            s_logger.error(error);
+            LOGGER.error(error);
             return new CopyCmdAnswer(cmd, e);
         } finally {
             cleanupSecondaryPool(secondaryPool);
