@@ -34,11 +34,12 @@ import com.google.gson.JsonObject;
 import com.google.gson.JsonParser;
 import com.google.gson.JsonSyntaxException;
 import org.apache.cloudstack.utils.qemu.QemuImg;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
+import org.apache.logging.log4j.Logger;
 import org.joda.time.Duration;
 
 public class LinstorStoragePool implements KVMStoragePool {
-    private static final Logger s_logger = Logger.getLogger(LinstorStoragePool.class);
+    private static final Logger LOGGER = LogManager.getLogger(LinstorStoragePool.class);
     private final String _uuid;
     private final String _sourceHost;
     private final int _sourcePort;
@@ -74,7 +75,7 @@ public class LinstorStoragePool implements KVMStoragePool {
     @Override
     public boolean connectPhysicalDisk(String volumeUuid, Map<String, String> details)
     {
-        return _storageAdaptor.connectPhysicalDisk(volumeUuid, this, details, false);
+        return _storageAdaptor.connectPhysicalDisk(volumeUuid, this, details);
     }
 
     @Override
@@ -226,12 +227,12 @@ public class LinstorStoragePool implements KVMStoragePool {
     @Override
     public String createHeartBeatCommand(HAStoragePool pool, String hostPrivateIp,
             boolean hostValidation) {
-        s_logger.trace(String.format("Linstor.createHeartBeatCommand: %s, %s, %b", pool.getPoolIp(), hostPrivateIp, hostValidation));
+        LOGGER.trace(String.format("Linstor.createHeartBeatCommand: %s, %s, %b", pool.getPoolIp(), hostPrivateIp, hostValidation));
         boolean isStorageNodeUp = checkingHeartBeat(pool, null);
         if (!isStorageNodeUp && !hostValidation) {
             //restart the host
-            s_logger.debug(String.format("The host [%s] will be restarted because the health check failed for the storage pool [%s]", hostPrivateIp, pool.getPool().getType()));
-            Script cmd = new Script(pool.getPool().getHearthBeatPath(), Duration.millis(HeartBeatUpdateTimeout), s_logger);
+            LOGGER.debug(String.format("The host [%s] will be restarted because the health check failed for the storage pool [%s]", hostPrivateIp, pool.getPool().getType()));
+            Script cmd = new Script(pool.getPool().getHearthBeatPath(), Duration.millis(HeartBeatUpdateTimeout), LOGGER);
             cmd.add("-c");
             cmd.execute();
             return "Down";
@@ -247,7 +248,7 @@ public class LinstorStoragePool implements KVMStoragePool {
 
     static String getHostname() {
         OutputInterpreter.AllLinesParser parser = new OutputInterpreter.AllLinesParser();
-        Script sc = new Script("hostname", Duration.millis(10000L), s_logger);
+        Script sc = new Script("hostname", Duration.millis(10000L), LOGGER);
         String res = sc.execute(parser);
         if (res != null) {
             throw new CloudRuntimeException(String.format("Unable to run 'hostname' command: %s", res));
@@ -264,7 +265,7 @@ public class LinstorStoragePool implements KVMStoragePool {
         } else {
             hostName = host.getParent();
             if (hostName == null) {
-                s_logger.error("No hostname set in host.getParent()");
+                LOGGER.error("No hostname set in host.getParent()");
                 return false;
             }
         }
@@ -273,62 +274,32 @@ public class LinstorStoragePool implements KVMStoragePool {
     }
 
     private String executeDrbdSetupStatus(OutputInterpreter.AllLinesParser parser) {
-        Script sc = new Script("drbdsetup", Duration.millis(HeartBeatUpdateTimeout), s_logger);
+        Script sc = new Script("drbdsetup", Duration.millis(HeartBeatUpdateTimeout), LOGGER);
         sc.add("status");
         sc.add("--json");
         return sc.execute(parser);
     }
 
-    private boolean checkLinstorNodeOnline(String nodeName) {
-        return ((LinstorStorageAdaptor)_storageAdaptor).isNodeOnline(this, nodeName);
-    }
-
-    /**
-     * Checks output of drbdsetup status output if this node has any valid connection to the specified
-     * otherNodeName.
-     * If there is no connection, ask the Linstor controller if the node is seen online and return false if not.
-     * If there is a connection but not connected(valid) return false.
-     * @param output Output of the drbdsetup status --json command
-     * @param otherNodeName Name of the node to check against
-     * @return true if we could say that this node thinks the node in question is reachable, otherwise false.
-     */
     private boolean checkDrbdSetupStatusOutput(String output, String otherNodeName) {
         JsonParser jsonParser = new JsonParser();
         JsonArray jResources = (JsonArray) jsonParser.parse(output);
-        boolean connectionFound = false;
         for (JsonElement jElem : jResources) {
             JsonObject jRes = (JsonObject) jElem;
             JsonArray jConnections = jRes.getAsJsonArray("connections");
             for (JsonElement jConElem : jConnections) {
                 JsonObject jConn = (JsonObject) jConElem;
-                if (jConn.getAsJsonPrimitive("name").getAsString().equals(otherNodeName))
-                {
-                    connectionFound = true;
-                    if (jConn.getAsJsonPrimitive("connection-state").getAsString()
-                            .equalsIgnoreCase("Connected")) {
-                        return true;
-                    }
+                if (jConn.getAsJsonPrimitive("name").getAsString().equals(otherNodeName)
+                        && jConn.getAsJsonPrimitive("connection-state").getAsString().equalsIgnoreCase("Connected")) {
+                    return true;
                 }
             }
         }
-        boolean otherNodeOnline = false;
-        if (connectionFound) {
-            s_logger.warn(String.format(
-                    "checkingHeartBeat: connection found, but not in state 'Connected' to %s", otherNodeName));
-        } else {
-            s_logger.warn(String.format(
-                    "checkingHeartBeat: no resource connected to %s, checking LINSTOR", otherNodeName));
-            otherNodeOnline = checkLinstorNodeOnline(otherNodeName);
-        }
-        s_logger.info(String.format(
-                "checkingHeartBeat: other node %s is %s.",
-                otherNodeName,
-                otherNodeOnline ? "online on controller" : "down"));
-        return otherNodeOnline;
+        LOGGER.warn(String.format("checkDrbdSetupStatusOutput: no resource connected to %s.", otherNodeName));
+        return false;
     }
 
     private String executeDrbdEventsNow(OutputInterpreter.AllLinesParser parser) {
-        Script sc = new Script("drbdsetup", Duration.millis(HeartBeatUpdateTimeout), s_logger);
+        Script sc = new Script("drbdsetup", Duration.millis(HeartBeatUpdateTimeout), LOGGER);
         sc.add("events2");
         sc.add("--now");
         return sc.execute(parser);
@@ -337,13 +308,13 @@ public class LinstorStoragePool implements KVMStoragePool {
     private boolean checkDrbdEventsNowOutput(String output) {
         boolean healthy = output.lines().noneMatch(line -> line.matches(".*role:Primary .* promotion_score:0.*"));
         if (!healthy) {
-            s_logger.warn("checkDrbdEventsNowOutput: primary resource with promotion score==0; HA false");
+            LOGGER.warn("checkDrbdEventsNowOutput: primary resource with promotion score==0; HA false");
         }
         return healthy;
     }
 
     private boolean checkHostUpToDateAndConnected(String hostName) {
-        s_logger.trace(String.format("checkHostUpToDateAndConnected: %s/%s", localNodeName, hostName));
+        LOGGER.trace(String.format("checkHostUpToDateAndConnected: %s/%s", localNodeName, hostName));
         OutputInterpreter.AllLinesParser parser = new OutputInterpreter.AllLinesParser();
 
         if (localNodeName.equalsIgnoreCase(hostName)) {
@@ -361,7 +332,7 @@ public class LinstorStoragePool implements KVMStoragePool {
             try {
                 return checkDrbdSetupStatusOutput(parser.getLines(), hostName);
             } catch (JsonIOException | JsonSyntaxException e) {
-                s_logger.error("Error parsing drbdsetup status --json", e);
+                LOGGER.error("Error parsing drbdsetup status --json", e);
             }
         }
         return false;
@@ -369,7 +340,7 @@ public class LinstorStoragePool implements KVMStoragePool {
 
     @Override
     public Boolean vmActivityCheck(HAStoragePool pool, HostTO host, Duration activityScriptTimeout, String volumeUUIDListString, String vmActivityCheckPath, long duration) {
-        s_logger.trace(String.format("Linstor.vmActivityCheck: %s, %s", pool.getPoolIp(), host.getPrivateNetwork().getIp()));
+        LOGGER.trace(String.format("Linstor.vmActivityCheck: %s, %s", pool.getPoolIp(), host.getPrivateNetwork().getIp()));
         return checkingHeartBeat(pool, host);
     }
 }
