@@ -64,7 +64,8 @@ import org.apache.cloudstack.storage.to.VolumeObjectTO;
 import org.apache.cloudstack.storage.volume.VolumeObject;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 
 import com.cloud.agent.api.Answer;
 import com.cloud.agent.api.GetVolumeStatAnswer;
@@ -110,7 +111,7 @@ import com.cloud.vm.dao.VMInstanceDao;
 import com.google.common.base.Preconditions;
 
 public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
-    private static final Logger LOGGER = Logger.getLogger(ScaleIOPrimaryDataStoreDriver.class);
+    protected Logger logger = LogManager.getLogger(getClass());
 
     @Inject
     EndPointSelector selector;
@@ -201,16 +202,16 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
 
             if (DataObjectType.VOLUME.equals(dataObject.getType())) {
                 final VolumeVO volume = volumeDao.findById(dataObject.getId());
-                LOGGER.debug("Granting access for PowerFlex volume: " + volume.getPath());
+                logger.debug("Granting access for PowerFlex volume: " + volume.getPath());
                 return setVolumeLimitsFromDetails(volume, host, dataStore);
             } else if (DataObjectType.TEMPLATE.equals(dataObject.getType())) {
                 final VMTemplateStoragePoolVO templatePoolRef = vmTemplatePoolDao.findByPoolTemplate(dataStore.getId(), dataObject.getId(), null);
-                LOGGER.debug("Granting access for PowerFlex template volume: " + templatePoolRef.getInstallPath());
+                logger.debug("Granting access for PowerFlex template volume: " + templatePoolRef.getInstallPath());
                 final ScaleIOGatewayClient client = getScaleIOClient(dataStore.getId());
                 return client.mapVolumeToSdc(ScaleIOUtil.getVolumePath(templatePoolRef.getInstallPath()), sdcId);
             } else if (DataObjectType.SNAPSHOT.equals(dataObject.getType())) {
                 SnapshotInfo snapshot = (SnapshotInfo) dataObject;
-                LOGGER.debug("Granting access for PowerFlex volume snapshot: " + snapshot.getPath());
+                logger.debug("Granting access for PowerFlex volume snapshot: " + snapshot.getPath());
                 final ScaleIOGatewayClient client = getScaleIOClient(dataStore.getId());
                 return client.mapVolumeToSdc(ScaleIOUtil.getVolumePath(snapshot.getPath()), sdcId);
             }
@@ -229,28 +230,28 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
     @Override
     public void revokeAccess(DataObject dataObject, Host host, DataStore dataStore) {
         if (host == null) {
-            LOGGER.info("Declining to revoke access to PowerFlex volume when a host is not provided");
+            logger.info("Declining to revoke access to PowerFlex volume when a host is not provided");
             return;
         }
 
         try {
             final String sdcId = getConnectedSdc(dataStore.getId(), host.getId());
             if (StringUtils.isBlank(sdcId)) {
-                LOGGER.warn(String.format("Unable to revoke access for %s: %s, no Sdc connected with host ip: %s", dataObject.getType(), dataObject.getId(), host.getPrivateIpAddress()));
+                logger.warn(String.format("Unable to revoke access for %s: %s, no Sdc connected with host ip: %s", dataObject.getType(), dataObject.getId(), host.getPrivateIpAddress()));
                 return;
             }
             final ScaleIOGatewayClient client = getScaleIOClient(dataStore.getId());
             if (DataObjectType.VOLUME.equals(dataObject.getType())) {
                 final VolumeVO volume = volumeDao.findById(dataObject.getId());
-                LOGGER.debug("Revoking access for PowerFlex volume: " + volume.getPath());
+                logger.debug("Revoking access for PowerFlex volume: " + volume.getPath());
                 client.unmapVolumeFromSdc(ScaleIOUtil.getVolumePath(volume.getPath()), sdcId);
             } else if (DataObjectType.TEMPLATE.equals(dataObject.getType())) {
                 final VMTemplateStoragePoolVO templatePoolRef = vmTemplatePoolDao.findByPoolTemplate(dataStore.getId(), dataObject.getId(), null);
-                LOGGER.debug("Revoking access for PowerFlex template volume: " + templatePoolRef.getInstallPath());
+                logger.debug("Revoking access for PowerFlex template volume: " + templatePoolRef.getInstallPath());
                 client.unmapVolumeFromSdc(ScaleIOUtil.getVolumePath(templatePoolRef.getInstallPath()), sdcId);
             } else if (DataObjectType.SNAPSHOT.equals(dataObject.getType())) {
                 SnapshotInfo snapshot = (SnapshotInfo) dataObject;
-                LOGGER.debug("Revoking access for PowerFlex volume snapshot: " + snapshot.getPath());
+                logger.debug("Revoking access for PowerFlex volume snapshot: " + snapshot.getPath());
                 client.unmapVolumeFromSdc(ScaleIOUtil.getVolumePath(snapshot.getPath()), sdcId);
             }
             if (client.listVolumesMappedToSdc(sdcId).isEmpty()) {
@@ -258,22 +259,22 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
                 sdcManager.stopSDC(host, dataStore);
             }
         } catch (Exception e) {
-            LOGGER.warn("Failed to revoke access due to: " + e.getMessage(), e);
+            logger.warn("Failed to revoke access due to: " + e.getMessage(), e);
         }
     }
 
     public void revokeVolumeAccess(String volumePath, Host host, DataStore dataStore) {
         if (host == null) {
-            LOGGER.warn("Declining to revoke access to PowerFlex volume when a host is not provided");
+            logger.warn("Declining to revoke access to PowerFlex volume when a host is not provided");
             return;
         }
 
         try {
-            LOGGER.debug("Revoking access for PowerFlex volume: " + volumePath);
+            logger.debug("Revoking access for PowerFlex volume: " + volumePath);
 
             final String sdcId = getConnectedSdc(dataStore.getId(), host.getId());
             if (StringUtils.isBlank(sdcId)) {
-                LOGGER.warn(String.format("Unable to revoke access for volume: %s, no Sdc connected with host ip: %s", volumePath, host.getPrivateIpAddress()));
+                logger.warn(String.format("Unable to revoke access for volume: %s, no Sdc connected with host ip: %s", volumePath, host.getPrivateIpAddress()));
                 return;
             }
 
@@ -284,7 +285,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
                 sdcManager.stopSDC(host, dataStore);
             }
         } catch (Exception e) {
-            LOGGER.warn("Failed to revoke access due to: " + e.getMessage(), e);
+            logger.warn("Failed to revoke access due to: " + e.getMessage(), e);
         }
     }
 
@@ -305,7 +306,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
                 return poolHostVO.getLocalPath();
             }
         } catch (Exception e) {
-            LOGGER.warn("Couldn't check SDC connection for the host: " + hostId + " and storage pool: " + poolId + " due to " + e.getMessage(), e);
+            logger.warn("Couldn't check SDC connection for the host: " + hostId + " and storage pool: " + poolId + " due to " + e.getMessage(), e);
         }
 
         return null;
@@ -346,7 +347,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             }
         }
 
-        LOGGER.debug("Used/Allocated storage space (in bytes): " + String.valueOf(usedSpaceBytes));
+        logger.debug("Used/Allocated storage space (in bytes): " + String.valueOf(usedSpaceBytes));
 
         return usedSpaceBytes;
     }
@@ -403,7 +404,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
 
     @Override
     public void takeSnapshot(SnapshotInfo snapshotInfo, AsyncCompletionCallback<CreateCmdResult> callback) {
-        LOGGER.debug("Taking PowerFlex volume snapshot");
+        logger.debug("Taking PowerFlex volume snapshot");
 
         Preconditions.checkArgument(snapshotInfo != null, "snapshotInfo cannot be null");
 
@@ -441,7 +442,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             result.setResult(null);
         } catch (Exception e) {
             String errMsg = "Unable to take PowerFlex volume snapshot for volume: " + volumeInfo.getId() + " due to " + e.getMessage();
-            LOGGER.warn(errMsg);
+            logger.warn(errMsg);
             result = new CreateCmdResult(null, new CreateObjectAnswer(e.toString()));
             result.setResult(e.toString());
         }
@@ -451,7 +452,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
 
     @Override
     public void revertSnapshot(SnapshotInfo snapshot, SnapshotInfo snapshotOnPrimaryStore, AsyncCompletionCallback<CommandResult> callback) {
-        LOGGER.debug("Reverting to PowerFlex volume snapshot");
+        logger.debug("Reverting to PowerFlex volume snapshot");
 
         Preconditions.checkArgument(snapshot != null, "snapshotInfo cannot be null");
 
@@ -478,7 +479,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             CommandResult commandResult = new CommandResult();
             callback.complete(commandResult);
         } catch (Exception ex) {
-            LOGGER.debug("Unable to revert to PowerFlex snapshot: " + snapshot.getId(), ex);
+            logger.debug("Unable to revert to PowerFlex snapshot: " + snapshot.getId(), ex);
             throw new CloudRuntimeException(ex.getMessage());
         }
     }
@@ -488,7 +489,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
     }
 
     public CreateObjectAnswer createVolume(VolumeInfo volumeInfo, long storagePoolId, boolean migrationInvolved, Long usageSize) {
-        LOGGER.debug("Creating PowerFlex volume");
+        logger.debug("Creating PowerFlex volume");
 
         StoragePoolVO storagePool = storagePoolDao.findById(storagePoolId);
 
@@ -533,7 +534,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
 
             // if volume needs to be set up with encryption, do it now if it's not a root disk (which gets done during template copy)
             if (anyVolumeRequiresEncryption(volumeInfo) && (!volumeInfo.getVolumeType().equals(Volume.Type.ROOT) || migrationInvolved)) {
-                LOGGER.debug(String.format("Setting up encryption for volume %s", volumeInfo.getId()));
+                logger.debug(String.format("Setting up encryption for volume %s", volumeInfo.getId()));
                 VolumeObjectTO prepVolume = (VolumeObjectTO) createdObject.getTO();
                 prepVolume.setPath(volumePath);
                 prepVolume.setUuid(volumePath);
@@ -557,19 +558,19 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
                     }
                 }
             } else {
-                 LOGGER.debug(String.format("No encryption configured for data volume %s", volumeInfo));
+                 logger.debug(String.format("No encryption configured for data volume %s", volumeInfo));
             }
 
             return answer;
         } catch (Exception e) {
             String errMsg = "Unable to create PowerFlex Volume due to " + e.getMessage();
-            LOGGER.warn(errMsg);
+            logger.warn(errMsg);
             throw new CloudRuntimeException(errMsg, e);
         }
     }
 
     private String  createTemplateVolume(TemplateInfo templateInfo, long storagePoolId) {
-        LOGGER.debug("Creating PowerFlex template volume");
+        logger.debug("Creating PowerFlex template volume");
 
         StoragePoolVO storagePool = storagePoolDao.findById(storagePoolId);
         Preconditions.checkArgument(templateInfo != null, "templateInfo cannot be null");
@@ -607,7 +608,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             return templatePath;
         } catch (Exception e) {
             String errMsg = "Unable to create PowerFlex template volume due to " + e.getMessage();
-            LOGGER.warn(errMsg);
+            logger.warn(errMsg);
             throw new CloudRuntimeException(errMsg, e);
         }
     }
@@ -619,22 +620,22 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
         Answer answer = new Answer(null, false, "not started");
         try {
             if (dataObject.getType() == DataObjectType.VOLUME) {
-                LOGGER.debug("createAsync - creating volume");
+                logger.debug("createAsync - creating volume");
                 CreateObjectAnswer createAnswer = createVolume((VolumeInfo) dataObject, dataStore.getId());
                 scaleIOVolumePath = createAnswer.getData().getPath();
                 answer = createAnswer;
             } else if (dataObject.getType() == DataObjectType.TEMPLATE) {
-                LOGGER.debug("createAsync - creating template");
+                logger.debug("createAsync - creating template");
                 scaleIOVolumePath = createTemplateVolume((TemplateInfo)dataObject, dataStore.getId());
                 answer = new Answer(null, true, "created template");
             } else {
                 errMsg = "Invalid DataObjectType (" + dataObject.getType() + ") passed to createAsync";
-                LOGGER.error(errMsg);
+                logger.error(errMsg);
                 answer = new Answer(null, false, errMsg);
             }
         } catch (Exception ex) {
             errMsg = ex.getMessage();
-            LOGGER.error(errMsg);
+            logger.error(errMsg);
             if (callback == null) {
                 throw ex;
             }
@@ -662,17 +663,17 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
         try {
             boolean deleteResult = false;
             if (dataObject.getType() == DataObjectType.VOLUME) {
-                LOGGER.debug("deleteAsync - deleting volume");
+                logger.debug("deleteAsync - deleting volume");
                 scaleIOVolumePath = ((VolumeInfo) dataObject).getPath();
             } else if (dataObject.getType() == DataObjectType.SNAPSHOT) {
-                LOGGER.debug("deleteAsync - deleting snapshot");
+                logger.debug("deleteAsync - deleting snapshot");
                 scaleIOVolumePath = ((SnapshotInfo) dataObject).getPath();
             } else if (dataObject.getType() == DataObjectType.TEMPLATE) {
-                LOGGER.debug("deleteAsync - deleting template");
+                logger.debug("deleteAsync - deleting template");
                 scaleIOVolumePath = ((TemplateInfo) dataObject).getInstallPath();
             } else {
                 errMsg = "Invalid DataObjectType (" + dataObject.getType() + ") passed to deleteAsync";
-                LOGGER.error(errMsg);
+                logger.error(errMsg);
                 throw new CloudRuntimeException(errMsg);
             }
 
@@ -690,12 +691,12 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
                 storagePoolDao.update(storagePoolId, storagePool);
             } catch (Exception e) {
                 errMsg = "Unable to delete PowerFlex volume: " + scaleIOVolumePath + " due to " + e.getMessage();
-                LOGGER.warn(errMsg);
+                logger.warn(errMsg);
                 throw new CloudRuntimeException(errMsg, e);
             }
         } catch (Exception ex) {
             errMsg = ex.getMessage();
-            LOGGER.error(errMsg);
+            logger.error(errMsg);
             if (callback == null) {
                 throw ex;
             }
@@ -739,16 +740,16 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
                 } else {
                     errMsg = "Unsupported copy operation from src object: (" + srcData.getType() + ", " + srcData.getDataStore() + "), dest object: ("
                             + destData.getType() + ", " + destData.getDataStore() + ")";
-                    LOGGER.warn(errMsg);
+                    logger.warn(errMsg);
                     answer = new Answer(null, false, errMsg);
                 }
             } else {
                 errMsg = "Unsupported copy operation";
-                LOGGER.warn(errMsg);
+                logger.warn(errMsg);
                 answer = new Answer(null, false, errMsg);
             }
         } catch (Exception e) {
-            LOGGER.debug("Failed to copy due to " + e.getMessage(), e);
+            logger.debug("Failed to copy due to " + e.getMessage(), e);
             errMsg = e.toString();
             answer = new Answer(null, false, errMsg);
         }
@@ -772,26 +773,26 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
          * Data stores of file type happen automatically, but block device types have to handle it. Unfortunately for ScaleIO this means we add a whole 8GB to
          * the original size, but only if we are close to an 8GB boundary.
          */
-        LOGGER.debug(String.format("Copying template %s to volume %s", srcData.getId(), destData.getId()));
+        logger.debug(String.format("Copying template %s to volume %s", srcData.getId(), destData.getId()));
         VolumeInfo destInfo = (VolumeInfo) destData;
         boolean encryptionRequired = anyVolumeRequiresEncryption(destData);
         if (encryptionRequired) {
             if (needsExpansionForEncryptionHeader(srcData.getSize(), destData.getSize())) {
                 long newSize = destData.getSize() + (1<<30);
-                LOGGER.debug(String.format("Destination volume %s(%s) is configured for encryption. Resizing to fit headers, new size %s will be rounded up to nearest 8Gi", destInfo.getId(), destData.getSize(), newSize));
+                logger.debug(String.format("Destination volume %s(%s) is configured for encryption. Resizing to fit headers, new size %s will be rounded up to nearest 8Gi", destInfo.getId(), destData.getSize(), newSize));
                 ResizeVolumePayload p = new ResizeVolumePayload(newSize, destInfo.getMinIops(), destInfo.getMaxIops(),
                     destInfo.getHypervisorSnapshotReserve(), false, destInfo.getAttachedVmName(), null, true);
                 destInfo.addPayload(p);
                 resizeVolume(destInfo);
             } else {
-                LOGGER.debug(String.format("Template %s has size %s, ok for volume %s with size %s", srcData.getId(), srcData.getSize(), destData.getId(), destData.getSize()));
+                logger.debug(String.format("Template %s has size %s, ok for volume %s with size %s", srcData.getId(), srcData.getSize(), destData.getId(), destData.getSize()));
             }
         } else {
-            LOGGER.debug(String.format("Destination volume is not configured for encryption, skipping encryption prep. Volume: %s", destData.getId()));
+            logger.debug(String.format("Destination volume is not configured for encryption, skipping encryption prep. Volume: %s", destData.getId()));
         }
 
         // Copy PowerFlex/ScaleIO template to volume
-        LOGGER.debug(String.format("Initiating copy from PowerFlex template volume on host %s", destHost != null ? destHost.getId() : "<not specified>"));
+        logger.debug(String.format("Initiating copy from PowerFlex template volume on host %s", destHost != null ? destHost.getId() : "<not specified>"));
         int primaryStorageDownloadWait = StorageManager.PRIMARY_STORAGE_DOWNLOAD_WAIT.value();
         CopyCommand cmd = new CopyCommand(srcData.getTO(), destData.getTO(), primaryStorageDownloadWait, VirtualMachineManager.ExecuteInSequence.value());
 
@@ -799,7 +800,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
         EndPoint ep = destHost != null ? RemoteHostEndPoint.getHypervisorHostEndPoint(destHost) : selector.select(srcData, encryptionRequired);
         if (ep == null) {
             String errorMsg = String.format("No remote endpoint to send command, unable to find a valid endpoint. Requires encryption support: %s", encryptionRequired);
-            LOGGER.error(errorMsg);
+            logger.error(errorMsg);
             answer = new Answer(cmd, false, errorMsg);
         } else {
             VolumeVO volume = volumeDao.findById(destData.getId());
@@ -808,7 +809,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
                 setVolumeLimitsOnSDC(volume, host, destData.getDataStore(), 0L, 0L);
                 answer = ep.sendMessage(cmd);
             } catch (Exception e) {
-                LOGGER.error("Failed to copy template to volume due to: " + e.getMessage(), e);
+                logger.error("Failed to copy template to volume due to: " + e.getMessage(), e);
                 answer = new Answer(cmd, false, e.getMessage());
             }
         }
@@ -818,7 +819,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
 
     protected Answer copyOfflineVolume(DataObject srcData, DataObject destData, Host destHost) {
         // Copy PowerFlex/ScaleIO volume
-        LOGGER.debug(String.format("Initiating copy from PowerFlex template volume on host %s", destHost != null ? destHost.getId() : "<not specified>"));
+        logger.debug(String.format("Initiating copy from PowerFlex template volume on host %s", destHost != null ? destHost.getId() : "<not specified>"));
         String value = configDao.getValue(Config.CopyVolumeWait.key());
         int copyVolumeWait = NumbersUtil.parseInt(value, Integer.parseInt(Config.CopyVolumeWait.getDefaultValue()));
 
@@ -829,7 +830,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
         EndPoint ep = destHost != null ? RemoteHostEndPoint.getHypervisorHostEndPoint(destHost) : selector.select(srcData, encryptionRequired);
         if (ep == null) {
             String errorMsg = String.format("No remote endpoint to send command, unable to find a valid endpoint. Requires encryption support: %s", encryptionRequired);
-            LOGGER.error(errorMsg);
+            logger.error(errorMsg);
             answer = new Answer(cmd, false, errorMsg);
         } else {
             answer = ep.sendMessage(cmd);
@@ -860,7 +861,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             GetVolumeStatCommand statCmd = new GetVolumeStatCommand(srcVolumeInfo.getPath(), srcVolumeInfo.getStoragePoolType(), srcStore.getUuid());
             GetVolumeStatAnswer statAnswer = (GetVolumeStatAnswer) ep.sendMessage(statCmd);
             if (!statAnswer.getResult() ) {
-                LOGGER.warn(String.format("Unable to get volume %s stats", srcVolumeInfo.getId()));
+                logger.warn(String.format("Unable to get volume %s stats", srcVolumeInfo.getId()));
             } else if (statAnswer.getVirtualSize() > 0) {
                 srcVolumeUsableSize = statAnswer.getVirtualSize();
             }
@@ -881,15 +882,15 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
                 updateVolumeAfterCopyVolume(srcData, destData);
                 updateSnapshotsAfterCopyVolume(srcData, destData);
                 deleteSourceVolumeAfterSuccessfulBlockCopy(srcData, host);
-                LOGGER.debug(String.format("Successfully migrated migrate PowerFlex volume %d to storage pool %d", srcVolumeId,  destPoolId));
+                logger.debug(String.format("Successfully migrated migrate PowerFlex volume %d to storage pool %d", srcVolumeId,  destPoolId));
                 answer = new Answer(null, true, null);
             } else {
                 String errorMsg = "Failed to migrate PowerFlex volume: " + srcVolumeId + " to storage pool " + destPoolId;
-                LOGGER.debug(errorMsg);
+                logger.debug(errorMsg);
                 answer = new Answer(null, false, errorMsg);
             }
         } catch (Exception e) {
-            LOGGER.error("Failed to migrate PowerFlex volume: " + srcVolumeId + " due to: " + e.getMessage());
+            logger.error("Failed to migrate PowerFlex volume: " + srcVolumeId + " due to: " + e.getMessage());
             answer = new Answer(null, false, e.getMessage());
         }
 
@@ -982,11 +983,11 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             Boolean deleteResult =  client.deleteVolume(scaleIOVolumeId);
             if (!deleteResult) {
                 errMsg = "Failed to delete source PowerFlex volume with id: " + scaleIOVolumeId;
-                LOGGER.warn(errMsg);
+                logger.warn(errMsg);
             }
         } catch (Exception e) {
             errMsg = "Unable to delete source PowerFlex volume: " + srcVolumePath + " due to " + e.getMessage();
-            LOGGER.warn(errMsg);;
+            logger.warn(errMsg);;
         }
     }
 
@@ -1003,12 +1004,12 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             Boolean deleteResult =  client.deleteVolume(scaleIOVolumeId);
             if (!deleteResult) {
                 errMsg = "Failed to delete PowerFlex volume with id: " + scaleIOVolumeId;
-                LOGGER.warn(errMsg);
+                logger.warn(errMsg);
             }
 
         } catch (Exception e) {
             errMsg = "Unable to delete destination PowerFlex volume: " + destVolumePath + " due to " + e.getMessage();
-            LOGGER.warn(errMsg);
+            logger.warn(errMsg);
             throw new CloudRuntimeException(errMsg, e);
         }
 
@@ -1144,11 +1145,11 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
                 answer = new Answer(null, true, null);
             } else {
                 String errorMsg = "Failed to migrate PowerFlex volume: " + srcData.getId() + " to storage pool " + destPoolId;
-                LOGGER.debug(errorMsg);
+                logger.debug(errorMsg);
                 answer = new Answer(null, false, errorMsg);
             }
         } catch (Exception e) {
-            LOGGER.error("Failed to migrate PowerFlex volume: " + srcData.getId() + " due to: " + e.getMessage());
+            logger.error("Failed to migrate PowerFlex volume: " + srcData.getId() + " due to: " + e.getMessage());
             answer = new Answer(null, false, e.getMessage());
         }
 
@@ -1198,7 +1199,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
     }
 
     private void resizeVolume(VolumeInfo volumeInfo) {
-        LOGGER.debug("Resizing PowerFlex volume");
+        logger.debug("Resizing PowerFlex volume");
 
         Preconditions.checkArgument(volumeInfo != null, "volumeInfo cannot be null");
 
@@ -1219,7 +1220,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             long newSizeIn8gbBoundary = (long) (Math.ceil(newSizeInGB / 8.0) * 8.0);
 
             if (scaleIOVolume.getSizeInKb() == newSizeIn8gbBoundary << 20) {
-                LOGGER.debug("No resize necessary at API");
+                logger.debug("No resize necessary at API");
             } else {
                 scaleIOVolume = client.resizeVolume(scaleIOVolumeId, (int) newSizeIn8gbBoundary);
                 if (scaleIOVolume == null) {
@@ -1254,7 +1255,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             }
 
             if (volumeInfo.getFormat().equals(Storage.ImageFormat.QCOW2) || attachedRunning) {
-                LOGGER.debug("Volume needs to be resized at the hypervisor host");
+                logger.debug("Volume needs to be resized at the hypervisor host");
 
                 if (hostId == 0) {
                     hostId = selector.select(volumeInfo, true).getId();
@@ -1281,9 +1282,9 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
                     } else if (!answer.getResult()) {
                         // for non-qcow2, notifying the running VM is going to be best-effort since we can't roll back
                         // or avoid VM seeing a successful change at the PowerFlex volume after e.g. reboot
-                        LOGGER.warn("Resized raw volume, but failed to notify. VM will see change on reboot. Error:" + answer.getDetails());
+                        logger.warn("Resized raw volume, but failed to notify. VM will see change on reboot. Error:" + answer.getDetails());
                     } else {
-                        LOGGER.debug("Resized volume at host: " + answer.getDetails());
+                        logger.debug("Resized volume at host: " + answer.getDetails());
                     }
                 } finally {
                     if (!attachedRunning) {
@@ -1315,7 +1316,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             storagePoolDao.update(storagePoolId, storagePool);
         } catch (Exception e) {
             String errMsg = "Unable to resize PowerFlex volume: " + volumeInfo.getId() + " due to " + e.getMessage();
-            LOGGER.warn(errMsg);
+            logger.warn(errMsg);
             throw new CloudRuntimeException(errMsg, e);
         }
     }
@@ -1333,7 +1334,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             }
         } catch (Exception ex) {
             errMsg = ex.getMessage();
-            LOGGER.error(errMsg);
+            logger.error(errMsg);
             if (callback == null) {
                 throw ex;
             }
@@ -1346,6 +1347,16 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
         }
     }
 
+    @Override
+    public long getVolumeSizeRequiredOnPool(long volumeSize, Long templateSize, boolean isEncryptionRequired) {
+        long newSizeInGB = volumeSize / (1024 * 1024 * 1024);
+        if (templateSize != null && isEncryptionRequired && needsExpansionForEncryptionHeader(templateSize, volumeSize)) {
+            newSizeInGB = (volumeSize + (1<<30)) / (1024 * 1024 * 1024);
+        }
+        long newSizeIn8gbBoundary = (long) (Math.ceil(newSizeInGB / 8.0) * 8.0);
+        return newSizeIn8gbBoundary * (1024 * 1024 * 1024);
+    }
+
     @Override
     public void handleQualityOfServiceForVolumeMigration(VolumeInfo volumeInfo, QualityOfServiceState qualityOfServiceState) {
     }
@@ -1371,7 +1382,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             customStats.put(ScaleIOUtil.CONNECTED_SDC_COUNT_STAT, String.valueOf(connectedSdcsCount));
         } catch (Exception e) {
             String errMsg = "Unable to get custom storage stats for the pool: " + pool.getId() + " due to " + e.getMessage();
-            LOGGER.error(errMsg);
+            logger.error(errMsg);
         }
 
         return customStats;
@@ -1391,7 +1402,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             }
         } catch (Exception e) {
             String errMsg = "Unable to get storage stats for the pool: " + storagePool.getId() + " due to " + e.getMessage();
-            LOGGER.warn(errMsg);
+            logger.warn(errMsg);
             throw new CloudRuntimeException(errMsg, e);
         }
 
@@ -1418,7 +1429,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             }
         }  catch (Exception e) {
             String errMsg = "Unable to get stats for the volume: " + volumePath + " in the pool: " + storagePool.getId() + " due to " + e.getMessage();
-            LOGGER.warn(errMsg);
+            logger.warn(errMsg);
             throw new CloudRuntimeException(errMsg, e);
         }
 
@@ -1439,7 +1450,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             final ScaleIOGatewayClient client = getScaleIOClient(pool.getId());
             return client.isSdcConnected(poolHostVO.getLocalPath());
         } catch (Exception e) {
-            LOGGER.warn("Unable to check the host: " + host.getId() + " access to storage pool: " + pool.getId() + " due to " + e.getMessage(), e);
+            logger.warn("Unable to check the host: " + host.getId() + " access to storage pool: " + pool.getId() + " due to " + e.getMessage(), e);
             return false;
         }
     }
@@ -1459,7 +1470,7 @@ public class ScaleIOPrimaryDataStoreDriver implements PrimaryDataStoreDriver {
             return;
         }
 
-        LOGGER.warn("SDC not connected on the host: " + host.getId());
+        logger.warn("SDC not connected on the host: " + host.getId());
         String msg = "SDC not connected on the host: " + host.getId() + ", reconnect the SDC to MDM";
         alertMgr.sendAlert(AlertManager.AlertType.ALERT_TYPE_HOST, host.getDataCenterId(), host.getPodId(), "SDC disconnected on host: " + host.getUuid(), msg);
     }
