@@ -24,13 +24,16 @@ import javax.inject.Inject;
 
 import org.apache.cloudstack.engine.subsystem.api.storage.DataStore;
 import org.apache.cloudstack.engine.subsystem.api.storage.PrimaryDataStore;
+import org.apache.cloudstack.framework.config.ConfigKey;
+import org.apache.cloudstack.framework.config.Configurable;
 import org.apache.cloudstack.framework.config.dao.ConfigurationDao;
 import org.apache.cloudstack.storage.datastore.client.ScaleIOGatewayClient;
 import org.apache.cloudstack.storage.datastore.client.ScaleIOGatewayClientConnectionPool;
 import org.apache.cloudstack.storage.datastore.db.StoragePoolDetailsDao;
 import org.apache.commons.collections.MapUtils;
 import org.apache.commons.lang3.StringUtils;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
+import org.apache.logging.log4j.Logger;
 import org.springframework.stereotype.Component;
 
 import com.cloud.agent.AgentManager;
@@ -50,8 +53,17 @@ import com.cloud.utils.db.GlobalLock;
 import com.cloud.utils.exception.CloudRuntimeException;
 
 @Component
-public class ScaleIOSDCManagerImpl implements ScaleIOSDCManager {
-    private static final Logger LOGGER = Logger.getLogger(ScaleIOSDCManagerImpl.class);
+public class ScaleIOSDCManagerImpl implements ScaleIOSDCManager, Configurable {
+    private Logger logger = LogManager.getLogger(getClass());
+
+    static ConfigKey<Boolean> ConnectOnDemand = new ConfigKey<>("Storage",
+            Boolean.class,
+            "powerflex.connect.on.demand",
+            Boolean.FALSE.toString(),
+            "Connect PowerFlex client on Host when first Volume is mapped to SDC and disconnect when last Volume is unmapped from SDC," +
+                    " otherwise no action (that is connection remains in the same state whichever it is, connected or disconnected).",
+            Boolean.TRUE,
+            ConfigKey.Scope.Zone);
 
     @Inject
     AgentManager agentManager;
@@ -79,20 +91,25 @@ public class ScaleIOSDCManagerImpl implements ScaleIOSDCManager {
 
             int connectedSdcsCount = getScaleIOClient(storagePoolId).getConnectedSdcsCount();
             if (connectedSdcsCount < connectedClientsLimit) {
-                LOGGER.debug(String.format("Current connected SDCs count: %d - SDC connections are within the limit (%d) on PowerFlex Storage with pool id: %d", connectedSdcsCount, connectedClientsLimit, storagePoolId));
+                logger.debug(String.format("Current connected SDCs count: %d - SDC connections are within the limit (%d) on PowerFlex Storage with pool id: %d", connectedSdcsCount, connectedClientsLimit, storagePoolId));
                 return true;
             }
-            LOGGER.debug(String.format("Current connected SDCs count: %d - SDC connections limit (%d) reached on PowerFlex Storage with pool id: %d", connectedSdcsCount, connectedClientsLimit, storagePoolId));
+            logger.debug(String.format("Current connected SDCs count: %d - SDC connections limit (%d) reached on PowerFlex Storage with pool id: %d", connectedSdcsCount, connectedClientsLimit, storagePoolId));
             return false;
         } catch (Exception e) {
             String errMsg = "Unable to check SDC connections for the PowerFlex storage pool with id: " + storagePoolId + " due to " + e.getMessage();
-            LOGGER.warn(errMsg, e);
+            logger.warn(errMsg, e);
             return false;
         }
     }
 
     @Override
     public String prepareSDC(Host host, DataStore dataStore) {
+        if (Boolean.FALSE.equals(ConnectOnDemand.valueIn(host.getDataCenterId()))) {
+            logger.debug(String.format("On-demand connect/disconnect config %s disabled in the zone %d, no need to prepare SDC (check for connected SDC)", ConnectOnDemand.key(), host.getDataCenterId()));
+            return getConnectedSdc(host, dataStore);
+        }
+
         String systemId = storagePoolDetailsDao.findDetail(dataStore.getId(), ScaleIOGatewayClient.STORAGE_POOL_SYSTEM_ID).getValue();
         if (systemId == null) {
             throw new CloudRuntimeException("Unable to prepare SDC, failed to get the system id for PowerFlex storage pool: " + dataStore.getName());
@@ -109,33 +126,33 @@ public class ScaleIOSDCManagerImpl implements ScaleIOSDCManager {
 
             int storagePoolMaxWaitSeconds = NumbersUtil.parseInt(configDao.getValue(Config.StoragePoolMaxWaitSeconds.key()), 3600);
             if (!hostIdStorageSystemIdLock.lock(storagePoolMaxWaitSeconds)) {
-                LOGGER.debug("Unable to prepare SDC, couldn't lock on " + hostIdStorageSystemIdLockString);
+                logger.debug("Unable to prepare SDC, couldn't lock on " + hostIdStorageSystemIdLockString);
                 throw new CloudRuntimeException("Unable to prepare SDC, couldn't lock on " + hostIdStorageSystemIdLockString);
             }
 
             long poolId = dataStore.getId();
             long hostId = host.getId();
-            String sdcId = getConnectedSdc(poolId, hostId);
+            String sdcId = getConnectedSdc(host, dataStore);
             if (StringUtils.isNotBlank(sdcId)) {
-                LOGGER.debug(String.format("SDC %s already connected for the pool: %d on host: %d, no need to prepare/start it", sdcId, poolId, hostId));
+                logger.debug(String.format("SDC %s already connected for the pool: %d on host: %d, no need to prepare/start it", sdcId, poolId, hostId));
                 return sdcId;
             }
 
             String storageSystemIdLockString = String.format(POWERFLEX_SDC_SYSTEMID_LOCK_FORMAT, systemId);
             storageSystemIdLock = GlobalLock.getInternLock(storageSystemIdLockString);
             if (storageSystemIdLock == null) {
-                LOGGER.error("Unable to prepare SDC, couldn't get global lock on: " + storageSystemIdLockString);
+                logger.error("Unable to prepare SDC, couldn't get global lock on: " + storageSystemIdLockString);
                 throw new CloudRuntimeException("Unable to prepare SDC, couldn't get global lock on " + storageSystemIdLockString);
             }
 
             if (!storageSystemIdLock.lock(storagePoolMaxWaitSeconds)) {
-                LOGGER.error("Unable to prepare SDC, couldn't lock on " + storageSystemIdLockString);
+                logger.error("Unable to prepare SDC, couldn't lock on " + storageSystemIdLockString);
                 throw new CloudRuntimeException("Unable to prepare SDC, couldn't lock on " + storageSystemIdLockString);
             }
 
             if (!areSDCConnectionsWithinLimit(poolId)) {
                 String errorMsg = String.format("Unable to check SDC connections or the connections limit reached for Powerflex storage (System ID: %s)", systemId);
-                LOGGER.error(errorMsg);
+                logger.error(errorMsg);
                 throw new CloudRuntimeException(errorMsg);
             }
 
@@ -174,7 +191,7 @@ public class ScaleIOSDCManagerImpl implements ScaleIOSDCManager {
     }
 
     private String prepareSDCOnHost(Host host, DataStore dataStore, String systemId) {
-        LOGGER.debug(String.format("Preparing SDC on the host %s (%s)", host.getId(), host.getName()));
+        logger.debug(String.format("Preparing SDC on the host %s (%s)", host.getId(), host.getName()));
         Map<String,String> details = new HashMap<>();
         details.put(ScaleIOGatewayClient.STORAGE_POOL_SYSTEM_ID, systemId);
         PrepareStorageClientCommand cmd = new PrepareStorageClientCommand(((PrimaryDataStore) dataStore).getPoolType(), dataStore.getUuid(), details);
@@ -186,25 +203,25 @@ public class ScaleIOSDCManagerImpl implements ScaleIOSDCManager {
             prepareStorageClientAnswer = (PrepareStorageClientAnswer) agentManager.send(host.getId(), cmd);
         } catch (AgentUnavailableException | OperationTimedoutException e) {
             String err = String.format("Failed to prepare SDC on the host %s, due to: %s", host.getName(), e.getMessage());
-            LOGGER.error(err);
+            logger.error(err);
             throw new CloudRuntimeException(err);
         }
 
         if (prepareStorageClientAnswer == null) {
             String err = String.format("Unable to prepare SDC on the host %s", host.getName());
-            LOGGER.error(err);
+            logger.error(err);
             throw new CloudRuntimeException(err);
         }
 
         if (!prepareStorageClientAnswer.getResult()) {
             String err = String.format("Unable to prepare SDC on the host %s, due to: %s", host.getName(), prepareStorageClientAnswer.getDetails());
-            LOGGER.error(err);
+            logger.error(err);
             throw new CloudRuntimeException(err);
         }
 
         Map<String,String> poolDetails = prepareStorageClientAnswer.getDetailsMap();
         if (MapUtils.isEmpty(poolDetails)) {
-            LOGGER.warn(String.format("PowerFlex storage SDC details not found on the host: %s, try (re)install SDC and restart agent", host.getId()));
+            logger.warn(String.format("PowerFlex storage SDC details not found on the host: %s, try (re)install SDC and restart agent", host.getId()));
             return null;
         }
 
@@ -217,7 +234,7 @@ public class ScaleIOSDCManagerImpl implements ScaleIOSDCManager {
         }
 
         if (StringUtils.isBlank(sdcId)) {
-            LOGGER.warn(String.format("Couldn't retrieve PowerFlex storage SDC details from the host: %s, try (re)install SDC and restart agent", host.getId()));
+            logger.warn(String.format("Couldn't retrieve PowerFlex storage SDC details from the host: %s, try (re)install SDC and restart agent", host.getId()));
             return null;
         }
 
@@ -226,6 +243,11 @@ public class ScaleIOSDCManagerImpl implements ScaleIOSDCManager {
 
     @Override
     public boolean stopSDC(Host host, DataStore dataStore) {
+        if (Boolean.FALSE.equals(ConnectOnDemand.valueIn(host.getDataCenterId()))) {
+            logger.debug(String.format("On-demand connect/disconnect config %s disabled in the zone %d, no need to unprepare SDC", ConnectOnDemand.key(), host.getDataCenterId()));
+            return true;
+        }
+
         String systemId = storagePoolDetailsDao.findDetail(dataStore.getId(), ScaleIOGatewayClient.STORAGE_POOL_SYSTEM_ID).getValue();
         if (systemId == null) {
             throw new CloudRuntimeException("Unable to unprepare SDC, failed to get the system id for PowerFlex storage pool: " + dataStore.getName());
@@ -241,15 +263,15 @@ public class ScaleIOSDCManagerImpl implements ScaleIOSDCManager {
 
             int storagePoolMaxWaitSeconds = NumbersUtil.parseInt(configDao.getValue(Config.StoragePoolMaxWaitSeconds.key()), 3600);
             if (!lock.lock(storagePoolMaxWaitSeconds)) {
-                LOGGER.debug("Unable to unprepare SDC, couldn't lock on " + hostIdStorageSystemIdLockString);
+                logger.debug("Unable to unprepare SDC, couldn't lock on " + hostIdStorageSystemIdLockString);
                 throw new CloudRuntimeException("Unable to unprepare SDC, couldn't lock on " + hostIdStorageSystemIdLockString);
             }
 
             long poolId = dataStore.getId();
             long hostId = host.getId();
-            String sdcId = getConnectedSdc(poolId, hostId);
+            String sdcId = getConnectedSdc(host, dataStore);
             if (StringUtils.isBlank(sdcId)) {
-                LOGGER.debug("SDC not connected, no need to unprepare it");
+                logger.debug("SDC not connected, no need to unprepare it");
                 return true;
             }
 
@@ -263,7 +285,7 @@ public class ScaleIOSDCManagerImpl implements ScaleIOSDCManager {
     }
 
     private boolean unprepareSDCOnHost(Host host, DataStore dataStore) {
-        LOGGER.debug(String.format("Unpreparing SDC on the host %s (%s)", host.getId(), host.getName()));
+        logger.debug(String.format("Unpreparing SDC on the host %s (%s)", host.getId(), host.getName()));
         UnprepareStorageClientCommand cmd = new UnprepareStorageClientCommand(((PrimaryDataStore) dataStore).getPoolType(), dataStore.getUuid());
         int timeoutSeconds = 60;
         cmd.setWait(timeoutSeconds);
@@ -273,13 +295,13 @@ public class ScaleIOSDCManagerImpl implements ScaleIOSDCManager {
             unprepareStorageClientAnswer = agentManager.send(host.getId(), cmd);
         } catch (AgentUnavailableException | OperationTimedoutException e) {
             String err = String.format("Failed to unprepare SDC on the host %s due to: %s", host.getName(), e.getMessage());
-            LOGGER.error(err);
+            logger.error(err);
             return false;
         }
 
         if (!unprepareStorageClientAnswer.getResult()) {
             String err = String.format("Unable to unprepare SDC on the the host %s due to: %s", host.getName(), unprepareStorageClientAnswer.getDetails());
-            LOGGER.error(err);
+            logger.error(err);
             return false;
         }
         return true;
@@ -287,16 +309,19 @@ public class ScaleIOSDCManagerImpl implements ScaleIOSDCManager {
 
     private String getHostSdcId(String sdcGuid, long poolId) {
         try {
-            LOGGER.debug(String.format("Try to get host SDC Id for pool: %s, with SDC guid %s", poolId, sdcGuid));
+            logger.debug(String.format("Try to get host SDC Id for pool: %s, with SDC guid %s", poolId, sdcGuid));
             ScaleIOGatewayClient client = getScaleIOClient(poolId);
             return client.getSdcIdByGuid(sdcGuid);
         } catch (Exception e) {
-            LOGGER.error(String.format("Failed to get host SDC Id for pool: %s", poolId), e);
+            logger.error(String.format("Failed to get host SDC Id for pool: %s", poolId), e);
             throw new CloudRuntimeException(String.format("Failed to establish connection with PowerFlex Gateway to get host SDC Id for pool: %s", poolId));
         }
     }
 
-    private String getConnectedSdc(long poolId, long hostId) {
+    private String getConnectedSdc(Host host, DataStore dataStore) {
+        long poolId = dataStore.getId();
+        long hostId = host.getId();
+
         try {
             StoragePoolHostVO poolHostVO = storagePoolHostDao.findByPoolHost(poolId, hostId);
             if (poolHostVO == null) {
@@ -308,14 +333,14 @@ public class ScaleIOSDCManagerImpl implements ScaleIOSDCManager {
                 return poolHostVO.getLocalPath();
             }
         } catch (Exception e) {
-            LOGGER.warn("Unable to get connected SDC for the host: " + hostId + " and storage pool: " + poolId + " due to " + e.getMessage(), e);
+            logger.warn("Unable to get connected SDC for the host: " + hostId + " and storage pool: " + poolId + " due to " + e.getMessage(), e);
         }
 
         return null;
     }
 
     private boolean hostSdcConnected(String sdcId, long poolId, int waitTimeInSecs) {
-        LOGGER.debug(String.format("Waiting (for %d secs) for the SDC %s of the pool id: %d to connect", waitTimeInSecs, sdcId, poolId));
+        logger.debug(String.format("Waiting (for %d secs) for the SDC %s of the pool id: %d to connect", waitTimeInSecs, sdcId, poolId));
         int timeBetweenTries = 1000; // Try more frequently (every sec) and return early if connected
         while (waitTimeInSecs > 0) {
             if (isHostSdcConnected(sdcId, poolId)) {
@@ -335,7 +360,7 @@ public class ScaleIOSDCManagerImpl implements ScaleIOSDCManager {
             final ScaleIOGatewayClient client = getScaleIOClient(poolId);
             return client.isSdcConnected(sdcId);
         } catch (Exception e) {
-            LOGGER.error("Failed to check host SDC connection", e);
+            logger.error("Failed to check host SDC connection", e);
             throw new CloudRuntimeException("Failed to establish connection with PowerFlex Gateway to check host SDC connection");
         }
     }
@@ -343,4 +368,14 @@ public class ScaleIOSDCManagerImpl implements ScaleIOSDCManager {
     private ScaleIOGatewayClient getScaleIOClient(final Long storagePoolId) throws Exception {
         return ScaleIOGatewayClientConnectionPool.getInstance().getClient(storagePoolId, storagePoolDetailsDao);
     }
+
+    @Override
+    public String getConfigComponentName() {
+        return ScaleIOSDCManager.class.getSimpleName();
+    }
+
+    @Override
+    public ConfigKey<?>[] getConfigKeys() {
+        return new ConfigKey[]{ConnectOnDemand};
+    }
 }
