@@ -26,8 +26,6 @@ import java.util.Map;
 
 import javax.inject.Inject;
 
-import org.apache.log4j.Logger;
-
 import org.apache.cloudstack.context.CallContext;
 import org.apache.cloudstack.engine.subsystem.api.storage.ClusterScope;
 import org.apache.cloudstack.engine.subsystem.api.storage.DataStore;
@@ -73,8 +71,6 @@ import com.cloud.utils.db.GlobalLock;
 import com.cloud.utils.exception.CloudRuntimeException;
 
 public class SolidFireSharedPrimaryDataStoreLifeCycle extends BasePrimaryDataStoreLifeCycleImpl implements PrimaryDataStoreLifeCycle {
-    private static final Logger LOGGER = Logger.getLogger(SolidFireSharedPrimaryDataStoreLifeCycle.class);
-
     @Inject private AccountDao accountDao;
     @Inject private AccountDetailsDao accountDetailsDao;
     @Inject private AgentManager agentMgr;
@@ -183,7 +179,7 @@ public class SolidFireSharedPrimaryDataStoreLifeCycle extends BasePrimaryDataSto
                 lMinIops = Long.parseLong(minIops);
             }
         } catch (Exception ex) {
-            LOGGER.info("[ignored] error getting Min IOPS: " + ex.getLocalizedMessage());
+            logger.info("[ignored] error getting Min IOPS: " + ex.getLocalizedMessage());
         }
 
         try {
@@ -193,7 +189,7 @@ public class SolidFireSharedPrimaryDataStoreLifeCycle extends BasePrimaryDataSto
                 lMaxIops = Long.parseLong(maxIops);
             }
         } catch (Exception ex) {
-            LOGGER.info("[ignored] error getting Max IOPS: " + ex.getLocalizedMessage());
+            logger.info("[ignored] error getting Max IOPS: " + ex.getLocalizedMessage());
         }
 
         try {
@@ -203,7 +199,7 @@ public class SolidFireSharedPrimaryDataStoreLifeCycle extends BasePrimaryDataSto
                 lBurstIops = Long.parseLong(burstIops);
             }
         } catch (Exception ex) {
-            LOGGER.info("[ignored] error getting Burst IOPS: " + ex.getLocalizedMessage());
+            logger.info("[ignored] error getting Burst IOPS: " + ex.getLocalizedMessage());
         }
 
         if (lMinIops > lMaxIops) {
@@ -272,7 +268,7 @@ public class SolidFireSharedPrimaryDataStoreLifeCycle extends BasePrimaryDataSto
         if (!lock.lock(SolidFireUtil.LOCK_TIME_IN_SECONDS)) {
             String errMsg = "Couldn't lock the DB on the following string: " + cluster.getUuid();
 
-            LOGGER.debug(errMsg);
+            logger.debug(errMsg);
 
             throw new CloudRuntimeException(errMsg);
         }
@@ -418,12 +414,12 @@ public class SolidFireSharedPrimaryDataStoreLifeCycle extends BasePrimaryDataSto
 
                 poolHosts.add(host);
             } catch (Exception e) {
-                LOGGER.warn("Unable to establish a connection between " + host + " and " + primaryDataStoreInfo, e);
+                logger.warn("Unable to establish a connection between " + host + " and " + primaryDataStoreInfo, e);
             }
         }
 
         if (poolHosts.isEmpty()) {
-            LOGGER.warn("No host can access storage pool '" + primaryDataStoreInfo + "' on cluster '" + primaryDataStoreInfo.getClusterId() + "'.");
+            logger.warn("No host can access storage pool '" + primaryDataStoreInfo + "' on cluster '" + primaryDataStoreInfo.getClusterId() + "'.");
 
             primaryDataStoreDao.expunge(primaryDataStoreInfo.getId());
 
@@ -479,7 +475,7 @@ public class SolidFireSharedPrimaryDataStoreLifeCycle extends BasePrimaryDataSto
                 msg = "Cannot create storage pool through host '" + hostId + "' due to CreateStoragePoolCommand returns null";
             }
 
-            LOGGER.warn(msg);
+            logger.warn(msg);
 
             throw new CloudRuntimeException(msg);
         }
@@ -562,7 +558,7 @@ public class SolidFireSharedPrimaryDataStoreLifeCycle extends BasePrimaryDataSto
             final Answer answer = agentMgr.easySend(host.getHostId(), deleteCmd);
 
             if (answer != null && answer.getResult()) {
-                LOGGER.info("Successfully deleted storage pool using Host ID " + host.getHostId());
+                logger.info("Successfully deleted storage pool using Host ID " + host.getHostId());
 
                 HostVO hostVO = hostDao.findById(host.getHostId());
 
@@ -575,10 +571,10 @@ public class SolidFireSharedPrimaryDataStoreLifeCycle extends BasePrimaryDataSto
             }
             else {
                 if (answer != null) {
-                    LOGGER.error("Failed to delete storage pool using Host ID " + host.getHostId() + ": " + answer.getResult());
+                    logger.error("Failed to delete storage pool using Host ID " + host.getHostId() + ": " + answer.getResult());
                 }
                 else {
-                    LOGGER.error("Failed to delete storage pool using Host ID " + host.getHostId());
+                    logger.error("Failed to delete storage pool using Host ID " + host.getHostId());
                 }
             }
         }
@@ -591,7 +587,7 @@ public class SolidFireSharedPrimaryDataStoreLifeCycle extends BasePrimaryDataSto
             if (!lock.lock(SolidFireUtil.LOCK_TIME_IN_SECONDS)) {
                 String errMsg = "Couldn't lock the DB on the following string: " + cluster.getUuid();
 
-                LOGGER.debug(errMsg);
+                logger.debug(errMsg);
 
                 throw new CloudRuntimeException(errMsg);
             }
@@ -660,12 +656,12 @@ public class SolidFireSharedPrimaryDataStoreLifeCycle extends BasePrimaryDataSto
         if (answer == null) {
             String msg = "Unable to get an answer to the modify targets command";
 
-            LOGGER.warn(msg);
+            logger.warn(msg);
         }
         else if (!answer.getResult()) {
             String msg = "Unable to modify target on the following host: " + hostId;
 
-            LOGGER.warn(msg);
+            logger.warn(msg);
         }
     }
 
