@@ -39,7 +39,6 @@ import org.apache.cloudstack.utils.qemu.QemuImgFile;
 import org.apache.cloudstack.utils.qemu.QemuObject;
 import org.apache.cloudstack.utils.qemu.QemuObject.EncryptFormat;
 import org.apache.commons.io.FileUtils;
-import org.apache.log4j.Logger;
 
 import com.cloud.agent.api.storage.StorPoolBackupSnapshotCommand;
 import com.cloud.agent.api.to.DataStoreTO;
@@ -54,7 +53,6 @@ import com.cloud.resource.ResourceWrapper;
 @ResourceWrapper(handles = StorPoolBackupSnapshotCommand.class)
 public final class StorPoolBackupSnapshotCommandWrapper extends CommandWrapper<StorPoolBackupSnapshotCommand, CopyCmdAnswer, LibvirtComputingResource> {
 
-    private static final Logger s_logger = Logger.getLogger(StorPoolBackupSnapshotCommandWrapper.class);
 
     @Override
     public CopyCmdAnswer execute(final StorPoolBackupSnapshotCommand cmd, final LibvirtComputingResource libvirtComputingResource) {
@@ -96,7 +94,7 @@ public final class StorPoolBackupSnapshotCommandWrapper extends CommandWrapper<S
         } catch (final Exception e) {
             final String error = String.format("Failed to backup snapshot with id [%s] with a pool %s, due to %s", cmd.getSourceTO().getId(), cmd.getSourceTO().getDataStore().getUuid(), e.getMessage());
             SP_LOG(error);
-            s_logger.debug(error);
+            logger.debug(error);
             return new CopyCmdAnswer(cmd, e);
         } finally {
             if (srcPath != null) {
@@ -107,7 +105,7 @@ public final class StorPoolBackupSnapshotCommandWrapper extends CommandWrapper<S
                 try {
                     secondaryPool.delete();
                 } catch (final Exception e) {
-                    s_logger.debug("Failed to delete secondary storage", e);
+                    logger.debug("Failed to delete secondary storage", e);
                 }
             }
         }
