@@ -30,6 +30,7 @@ import com.google.gson.JsonParser;
 import com.google.gson.JsonPrimitive;
 
 import org.apache.cloudstack.storage.datastore.api.StorPoolSnapshotDef;
+import org.apache.cloudstack.storage.datastore.api.StorPoolVolumeDef;
 import org.apache.cloudstack.storage.datastore.db.PrimaryDataStoreDao;
 import org.apache.cloudstack.storage.datastore.db.StoragePoolDetailVO;
 import org.apache.cloudstack.storage.datastore.db.StoragePoolDetailsDao;
@@ -46,7 +47,8 @@ import org.apache.http.entity.ContentType;
 import org.apache.http.entity.StringEntity;
 import org.apache.http.impl.client.CloseableHttpClient;
 import org.apache.http.impl.client.HttpClientBuilder;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 
 import java.io.BufferedReader;
 import java.io.File;
@@ -69,7 +71,7 @@ import java.util.Map;
 import java.util.UUID;
 
 public class StorPoolUtil {
-    private static final Logger log = Logger.getLogger(StorPoolUtil.class);
+    protected static Logger LOGGER = LogManager.getLogger(StorPoolUtil.class);
 
     private static final File spLogFile = new File(
             Files.exists(Paths.get("/var/log/cloudstack/management/")) ?
@@ -79,23 +81,23 @@ public class StorPoolUtil {
 
     private static PrintWriter spLogFileInitialize() {
         try {
-            log.info("INITIALIZE SP-LOG_FILE");
+            LOGGER.info("INITIALIZE SP-LOGGER_FILE");
             if (spLogFile.exists()) {
                 final SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
                 final Timestamp timestamp = new Timestamp(System.currentTimeMillis());
                 final File spLogFileRename = new File(spLogFile + "-" + sdf.format(timestamp));
                 final boolean ret = spLogFile.renameTo(spLogFileRename);
                 if (!ret) {
-                    log.warn("Unable to rename" + spLogFile + " to " + spLogFileRename);
+                    LOGGER.warn("Unable to rename" + spLogFile + " to " + spLogFileRename);
                 } else {
-                    log.debug("Renamed " + spLogFile + " to " + spLogFileRename);
+                    LOGGER.debug("Renamed " + spLogFile + " to " + spLogFileRename);
                 }
             } else {
                 spLogFile.getParentFile().mkdirs();
             }
             return new PrintWriter(spLogFile);
         } catch (Exception e) {
-            log.info("INITIALIZE SP-LOG_FILE: " + e.getMessage());
+            LOGGER.info("INITIALIZE SP-LOGGER_FILE: " + e.getMessage());
             throw new RuntimeException(e);
         }
     }
@@ -134,6 +136,9 @@ public class StorPoolUtil {
 
     public static final String DELAY_DELETE = "delayDelete";
 
+    public static final String SP_TIER = "SP_QOSCLASS";
+
+    public static final String OBJECT_DOES_NOT_EXIST = "objectDoesNotExist";
 
     public static enum StorpoolRights {
         RO("ro"), RW("rw"), DETACH("detach");
@@ -187,19 +192,19 @@ public class StorPoolUtil {
                 extractUriParams(url);
                 return;
             } catch (URISyntaxException e) {
-                log.debug("[ignore] the uri is not valid");
+                LOGGER.debug("[ignore] the uri is not valid");
             }
             String[] urlSplit = url.split(";");
             if (urlSplit.length == 1 && !urlSplit[0].contains("=")) {
                 this.templateName = url;
 
-                Script sc = new Script("storpool_confget", 0, log);
+                Script sc = new Script("storpool_confget", 0, LOGGER);
                 OutputInterpreter.AllLinesParser parser = new OutputInterpreter.AllLinesParser();
 
                 final String err = sc.execute(parser);
                 if (err != null) {
                     final String errMsg = String.format("Could not execute storpool_confget. Error: %s", err);
-                    log.warn(errMsg);
+                    LOGGER.warn(errMsg);
                     throw new CloudRuntimeException(errMsg);
                 }
 
@@ -407,7 +412,7 @@ public class StorPoolUtil {
             Gson gson = new Gson();
             String js = gson.toJson(json);
             StringEntity input = new StringEntity(js, ContentType.APPLICATION_JSON);
-            log.info("Request:" + js);
+            LOGGER.info("Request:" + js);
             req.setEntity(input);
         }
 
@@ -455,7 +460,7 @@ public class StorPoolUtil {
     }
 
     private static boolean objectExists(SpApiError err) {
-        if (!err.getName().equals("objectDoesNotExist")) {
+        if (!err.getName().equals(OBJECT_DOES_NOT_EXIST)) {
             throw new CloudRuntimeException(err.getDescr());
         }
         return false;
@@ -498,7 +503,19 @@ public class StorPoolUtil {
         json.put("parent", parentName);
         json.put("size", size);
         json.put("template", conn.getTemplateName());
-        Map<String, String> tags = StorPoolHelper.addStorPoolTags(name, vmUuid, csTag, vcPolicy);
+        Map<String, String> tags = StorPoolHelper.addStorPoolTags(name, vmUuid, csTag, vcPolicy, null);
+        json.put("tags", tags);
+        return POST("MultiCluster/VolumeCreate", json, conn);
+    }
+
+    public static SpApiResponse volumeCreate(Long size, String parentName, String template, Map<String,String> tags, SpConnectionDesc conn) {
+        template = template != null ? template : conn.getTemplateName();
+
+        Map<String, Object> json = new LinkedHashMap<>();
+        json.put("name", "");
+        json.put("parent", parentName);
+        json.put("size", size);
+        json.put("template", template);
         json.put("tags", tags);
         return POST("MultiCluster/VolumeCreate", json, conn);
     }
@@ -522,7 +539,7 @@ public class StorPoolUtil {
             json.put("iops", iops);
         }
         json.put("template", conn.getTemplateName());
-        Map<String, String> tags = StorPoolHelper.addStorPoolTags(name, cvmTag, csTag, vcPolicyTag);
+        Map<String, String> tags = StorPoolHelper.addStorPoolTags(name, cvmTag, csTag, vcPolicyTag, null);
         json.put("tags", tags);
         return POST("MultiCluster/VolumeCreate", json, conn);
     }
@@ -550,7 +567,7 @@ public class StorPoolUtil {
 
     public static SpApiResponse volumeRemoveTags(String name, SpConnectionDesc conn) {
         Map<String, Object> json = new HashMap<>();
-        Map<String, String> tags = StorPoolHelper.addStorPoolTags(null, "", null, "");
+        Map<String, String> tags = StorPoolHelper.addStorPoolTags(null, "", null, "", null);
         json.put("tags", tags);
         return POST("MultiCluster/VolumeUpdate/" + name, json, conn);
     }
@@ -558,7 +575,7 @@ public class StorPoolUtil {
     public static SpApiResponse volumeUpdateIopsAndTags(final String name, final String uuid, Long iops,
             SpConnectionDesc conn, String vcPolicy) {
         Map<String, Object> json = new HashMap<>();
-        Map<String, String> tags = StorPoolHelper.addStorPoolTags(null, uuid, null, vcPolicy);
+        Map<String, String> tags = StorPoolHelper.addStorPoolTags(null, uuid, null, vcPolicy, null);
         json.put("iops", iops);
         json.put("tags", tags);
         return POST("MultiCluster/VolumeUpdate/" + name, json, conn);
@@ -566,14 +583,14 @@ public class StorPoolUtil {
 
     public static SpApiResponse volumeUpdateCvmTags(final String name, final String uuid, SpConnectionDesc conn) {
         Map<String, Object> json = new HashMap<>();
-        Map<String, String> tags = StorPoolHelper.addStorPoolTags(null, uuid, null, null);
+        Map<String, String> tags = StorPoolHelper.addStorPoolTags(null, uuid, null, null, null);
         json.put("tags", tags);
         return POST("MultiCluster/VolumeUpdate/" + name, json, conn);
     }
 
     public static SpApiResponse volumeUpdateVCTags(final String name, SpConnectionDesc conn, String vcPolicy) {
         Map<String, Object> json = new HashMap<>();
-        Map<String, String> tags = StorPoolHelper.addStorPoolTags(null, null, null, vcPolicy);
+        Map<String, String> tags = StorPoolHelper.addStorPoolTags(null, null, null, vcPolicy, null);
         json.put("tags", tags);
         return POST("MultiCluster/VolumeUpdate/" + name, json, conn);
     }
@@ -584,10 +601,14 @@ public class StorPoolUtil {
         return POST("MultiCluster/VolumeUpdate/" + name, json, conn);
     }
 
+    public static SpApiResponse volumeUpdate(StorPoolVolumeDef volume, SpConnectionDesc conn) {
+        return POST("MultiCluster/VolumeUpdate/" + volume.getName(), volume, conn);
+    }
+
     public static SpApiResponse volumeSnapshot(final String volumeName, final String snapshotName, String vmUuid,
             String csTag, String vcPolicy, SpConnectionDesc conn) {
         Map<String, Object> json = new HashMap<>();
-        Map<String, String> tags = StorPoolHelper.addStorPoolTags(snapshotName, vmUuid, csTag, vcPolicy);
+        Map<String, String> tags = StorPoolHelper.addStorPoolTags(snapshotName, vmUuid, csTag, vcPolicy, null);
         json.put("name", "");
         json.put("tags", tags);
 
@@ -601,7 +622,7 @@ public class StorPoolUtil {
     public static SpApiResponse volumesGroupSnapshot(final List<VolumeObjectTO> volumeTOs, final String vmUuid,
             final String snapshotName, String csTag, SpConnectionDesc conn) {
         Map<String, Object> json = new LinkedHashMap<>();
-        Map<String, String> tags = StorPoolHelper.addStorPoolTags(snapshotName, vmUuid, csTag, null);
+        Map<String, String> tags = StorPoolHelper.addStorPoolTags(snapshotName, vmUuid, csTag, null, null);
         List<Map<String, Object>> volumes = new ArrayList<>();
         for (VolumeObjectTO volumeTO : volumeTOs) {
             Map<String, Object> vol = new LinkedHashMap<>();
@@ -612,7 +633,7 @@ public class StorPoolUtil {
         }
         json.put("tags", tags);
         json.put("volumes", volumes);
-        log.info("json:" + json);
+        LOGGER.info("json:" + json);
         return POST("MultiCluster/VolumesGroupSnapshot", json, conn);
     }
 
