@@ -16,10 +16,19 @@
 // under the License.
 package org.apache.cloudstack.storage.snapshot;
 
-import java.util.ArrayList;
-import java.util.List;
-
-import javax.inject.Inject;
+import com.cloud.exception.InvalidParameterValueException;
+import com.cloud.hypervisor.kvm.storage.StorPoolStorageAdaptor;
+import com.cloud.storage.DataStoreRole;
+import com.cloud.storage.Snapshot;
+import com.cloud.storage.SnapshotVO;
+import com.cloud.storage.VolumeVO;
+import com.cloud.storage.dao.SnapshotDao;
+import com.cloud.storage.dao.SnapshotDetailsDao;
+import com.cloud.storage.dao.SnapshotDetailsVO;
+import com.cloud.storage.dao.SnapshotZoneDao;
+import com.cloud.storage.dao.VolumeDao;
+import com.cloud.utils.exception.CloudRuntimeException;
+import com.cloud.utils.fsm.NoTransitionException;
 
 import org.apache.cloudstack.engine.subsystem.api.storage.DataStore;
 import org.apache.cloudstack.engine.subsystem.api.storage.DataStoreManager;
@@ -40,27 +49,18 @@ import org.apache.cloudstack.storage.datastore.util.StorPoolUtil;
 import org.apache.cloudstack.storage.datastore.util.StorPoolUtil.SpApiResponse;
 import org.apache.cloudstack.storage.datastore.util.StorPoolUtil.SpConnectionDesc;
 import org.apache.commons.collections.CollectionUtils;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
+import org.apache.logging.log4j.Logger;
 import org.springframework.stereotype.Component;
 
-import com.cloud.exception.InvalidParameterValueException;
-import com.cloud.hypervisor.kvm.storage.StorPoolStorageAdaptor;
-import com.cloud.storage.DataStoreRole;
-import com.cloud.storage.Snapshot;
-import com.cloud.storage.SnapshotVO;
-import com.cloud.storage.VolumeVO;
-import com.cloud.storage.dao.SnapshotDao;
-import com.cloud.storage.dao.SnapshotDetailsDao;
-import com.cloud.storage.dao.SnapshotDetailsVO;
-import com.cloud.storage.dao.SnapshotZoneDao;
-import com.cloud.storage.dao.VolumeDao;
-import com.cloud.utils.exception.CloudRuntimeException;
-import com.cloud.utils.fsm.NoTransitionException;
+import javax.inject.Inject;
+import java.util.ArrayList;
+import java.util.List;
 
 
 @Component
 public class StorPoolSnapshotStrategy implements SnapshotStrategy {
-    private static final Logger log = Logger.getLogger(StorPoolSnapshotStrategy.class);
+    protected Logger logger = LogManager.getLogger(getClass());
 
     @Inject
     private SnapshotDao _snapshotDao;
@@ -90,11 +90,11 @@ public class StorPoolSnapshotStrategy implements SnapshotStrategy {
             snapshotObj.processEvent(Snapshot.Event.BackupToSecondary);
             snapshotObj.processEvent(Snapshot.Event.OperationSucceeded);
         } catch (NoTransitionException ex) {
-            log.debug("Failed to change state: " + ex.toString());
+            logger.debug("Failed to change state: " + ex.toString());
             try {
                 snapshotObj.processEvent(Snapshot.Event.OperationFailed);
             } catch (NoTransitionException ex2) {
-                log.debug("Failed to change state: " + ex2.toString());
+                logger.debug("Failed to change state: " + ex2.toString());
             }
         }
         return snapshotInfo;
@@ -116,10 +116,11 @@ public class StorPoolSnapshotStrategy implements SnapshotStrategy {
                 if (resp.getError() != null) {
                     final String err = String.format("Failed to clean-up Storpool snapshot %s. Error: %s", name, resp.getError());
                     StorPoolUtil.spLog(err);
-                    markSnapshotAsDestroyedIfAlreadyRemoved(snapshotId, resp);
+                    markSnapshotAsDestroyedIfAlreadyRemoved(snapshotId, resp.getError().getName().equals(StorPoolUtil.OBJECT_DOES_NOT_EXIST));
                     throw new CloudRuntimeException(err);
                 } else {
                     res = deleteSnapshotFromDbIfNeeded(snapshotVO, zoneId);
+                    markSnapshotAsDestroyedIfAlreadyRemoved(snapshotId,true);
                     StorPoolUtil.spLog("StorpoolSnapshotStrategy.deleteSnapshot: executed successfully=%s, snapshot uuid=%s, name=%s", res, snapshotVO.getUuid(), name);
                 }
             } catch (Exception e) {
@@ -128,22 +129,30 @@ public class StorPoolSnapshotStrategy implements SnapshotStrategy {
             }
         }
 
+        List<SnapshotDataStoreVO> snapshots = _snapshotStoreDao.listBySnapshotIdAndState(snapshotId, State.Ready);
+        if (res || CollectionUtils.isEmpty(snapshots)) {
+            updateSnapshotToDestroyed(snapshotVO);
+            return true;
+        }
         return res;
     }
 
-    private void markSnapshotAsDestroyedIfAlreadyRemoved(Long snapshotId, SpApiResponse resp) {
-        if (resp.getError().getName().equals("objectDoesNotExist")) {
-            SnapshotDataStoreVO snapshotOnPrimary = _snapshotStoreDao.findBySourceSnapshot(snapshotId, DataStoreRole.Primary);
-            if (snapshotOnPrimary != null) {
-                snapshotOnPrimary.setState(State.Destroyed);
-                _snapshotStoreDao.update(snapshotOnPrimary.getId(), snapshotOnPrimary);
+    private void markSnapshotAsDestroyedIfAlreadyRemoved(Long snapshotId, boolean isSnapshotDeleted) {
+        if (!isSnapshotDeleted) {
+            return;
+        }
+        List<SnapshotDataStoreVO> snapshotsOnStore = _snapshotStoreDao.listBySnapshotIdAndState(snapshotId, State.Ready);
+        for (SnapshotDataStoreVO snapshot : snapshotsOnStore) {
+            if (snapshot.getInstallPath() != null && snapshot.getInstallPath().contains(StorPoolUtil.SP_DEV_PATH)) {
+                snapshot.setState(State.Destroyed);
+                _snapshotStoreDao.update(snapshot.getId(), snapshot);
             }
         }
     }
 
     @Override
     public StrategyPriority canHandle(Snapshot snapshot, Long zoneId, SnapshotOperation op) {
-        log.debug(String.format("StorpoolSnapshotStrategy.canHandle: snapshot=%s, uuid=%s, op=%s", snapshot.getName(), snapshot.getUuid(), op));
+        logger.debug(String.format("StorpoolSnapshotStrategy.canHandle: snapshot=%s, uuid=%s, op=%s", snapshot.getName(), snapshot.getUuid(), op));
 
         if (op != SnapshotOperation.DELETE) {
             return StrategyPriority.CANT_HANDLE;
@@ -172,7 +181,7 @@ public class StorPoolSnapshotStrategy implements SnapshotStrategy {
     }
 
     private boolean deleteSnapshotChain(SnapshotInfo snapshot) {
-        log.debug("delete snapshot chain for snapshot: " + snapshot.getId());
+        logger.debug("delete snapshot chain for snapshot: " + snapshot.getId());
         final SnapshotInfo snapOnImage = snapshot;
         boolean result = false;
         boolean resultIsSet = false;
@@ -182,15 +191,15 @@ public class StorPoolSnapshotStrategy implements SnapshotStrategy {
                 SnapshotInfo child = snapshot.getChild();
 
                 if (child != null) {
-                    log.debug("the snapshot has child, can't delete it on the storage");
+                    logger.debug("the snapshot has child, can't delete it on the storage");
                     break;
                 }
-                log.debug("Snapshot: " + snapshot.getId() + " doesn't have children, so it's ok to delete it and its parents");
+                logger.debug("Snapshot: " + snapshot.getId() + " doesn't have children, so it's ok to delete it and its parents");
                 SnapshotInfo parent = snapshot.getParent();
                 boolean deleted = false;
                 if (parent != null) {
                     if (parent.getPath() != null && parent.getPath().equalsIgnoreCase(snapshot.getPath())) {
-                        log.debug("for empty delta snapshot, only mark it as destroyed in db");
+                        logger.debug("for empty delta snapshot, only mark it as destroyed in db");
                         snapshot.processEvent(Event.DestroyRequested);
                         snapshot.processEvent(Event.OperationSuccessed);
                         deleted = true;
@@ -207,7 +216,7 @@ public class StorPoolSnapshotStrategy implements SnapshotStrategy {
                             if (r) {
                                 List<SnapshotInfo> cacheSnaps = snapshotDataFactory.listSnapshotOnCache(snapshot.getId());
                                 for (SnapshotInfo cacheSnap : cacheSnaps) {
-                                    log.debug("Delete snapshot " + snapshot.getId() + " from image cache store: " + cacheSnap.getDataStore().getName());
+                                    logger.debug("Delete snapshot " + snapshot.getId() + " from image cache store: " + cacheSnap.getDataStore().getName());
                                     cacheSnap.delete();
                                 }
                             }
@@ -216,7 +225,7 @@ public class StorPoolSnapshotStrategy implements SnapshotStrategy {
                                 resultIsSet = true;
                             }
                         } catch (Exception e) {
-                            log.debug("Failed to delete snapshot on storage. ", e);
+                            logger.debug("Failed to delete snapshot on storage. ", e);
                         }
                     }
                 } else {
@@ -225,7 +234,7 @@ public class StorPoolSnapshotStrategy implements SnapshotStrategy {
                 snapshot = parent;
             }
         } catch (Exception e) {
-            log.debug("delete snapshot failed: ", e);
+            logger.debug("delete snapshot failed: ", e);
         }
         return result;
     }
@@ -247,7 +256,7 @@ public class StorPoolSnapshotStrategy implements SnapshotStrategy {
                 obj.processEvent(Snapshot.Event.DestroyRequested);
             }
         } catch (NoTransitionException e) {
-            log.debug("Failed to set the state to destroying: ", e);
+            logger.debug("Failed to set the state to destroying: ", e);
             return false;
         }
 
@@ -265,13 +274,13 @@ public class StorPoolSnapshotStrategy implements SnapshotStrategy {
                 }
             }
         } catch (Exception e) {
-            log.debug("Failed to delete snapshot: ", e);
+            logger.debug("Failed to delete snapshot: ", e);
             try {
                 if (areLastSnapshotRef) {
                     obj.processEvent(Snapshot.Event.OperationFailed);
                 }
             } catch (NoTransitionException e1) {
-                log.debug("Failed to change snapshot state: " + e.toString());
+                logger.debug("Failed to change snapshot state: " + e.toString());
             }
             return false;
         }
