@@ -36,7 +36,6 @@ import org.apache.cloudstack.storage.datastore.util.StorPoolUtil.SpConnectionDes
 import org.apache.cloudstack.storage.to.VolumeObjectTO;
 import org.apache.cloudstack.storage.vmsnapshot.DefaultVMSnapshotStrategy;
 import org.apache.cloudstack.storage.vmsnapshot.VMSnapshotHelper;
-import org.apache.log4j.Logger;
 import org.springframework.stereotype.Component;
 
 import com.cloud.agent.api.VMSnapshotTO;
@@ -66,7 +65,6 @@ import com.google.gson.JsonObject;
 
 @Component
 public class StorPoolVMSnapshotStrategy extends DefaultVMSnapshotStrategy {
-    private static final Logger log = Logger.getLogger(StorPoolVMSnapshotStrategy.class);
 
     @Inject
     private VMSnapshotHelper vmSnapshotHelper;
@@ -94,7 +92,7 @@ public class StorPoolVMSnapshotStrategy extends DefaultVMSnapshotStrategy {
 
     @Override
     public VMSnapshot takeVMSnapshot(VMSnapshot vmSnapshot) {
-        log.info("KVMVMSnapshotStrategy take snapshot");
+        logger.info("KVMVMSnapshotStrategy take snapshot");
         UserVm userVm = userVmDao.findById(vmSnapshot.getVmId());
         VMSnapshotVO vmSnapshotVO = (VMSnapshotVO) vmSnapshot;
 
@@ -163,7 +161,7 @@ public class StorPoolVMSnapshotStrategy extends DefaultVMSnapshotStrategy {
                 for (VolumeObjectTO volumeObjectTO : volumeTOs) {
                     publishUsageEvents(EventTypes.EVENT_VM_SNAPSHOT_CREATE, vmSnapshot, userVm, volumeObjectTO);
                     new_chain_size += volumeObjectTO.getSize();
-                    log.info("EventTypes.EVENT_VM_SNAPSHOT_CREATE publishUsageEvent" + volumeObjectTO);
+                    logger.info("EventTypes.EVENT_VM_SNAPSHOT_CREATE publishUsageEvent" + volumeObjectTO);
                 }
                 publishUsageEvents(EventTypes.EVENT_VM_SNAPSHOT_ON_PRIMARY, vmSnapshot, userVm, new_chain_size - prev_chain_size, virtual_size);
             } else {
@@ -171,15 +169,15 @@ public class StorPoolVMSnapshotStrategy extends DefaultVMSnapshotStrategy {
             }
             return vmSnapshot;
         } catch (Exception e) {
-            log.debug("Could not create VM snapshot:" + e.getMessage());
+            logger.debug("Could not create VM snapshot:" + e.getMessage());
             throw new CloudRuntimeException("Could not create VM snapshot:" + e.getMessage());
         } finally {
             if (!result) {
                 try {
                     vmSnapshotHelper.vmSnapshotStateTransitTo(vmSnapshot, VMSnapshot.Event.OperationFailed);
-                    log.info(String.format("VMSnapshot.Event.OperationFailed vmSnapshot=%s", vmSnapshot));
+                    logger.info(String.format("VMSnapshot.Event.OperationFailed vmSnapshot=%s", vmSnapshot));
                 } catch (NoTransitionException nte) {
-                    log.error("Cannot set vm state:" + nte.getMessage());
+                    logger.error("Cannot set vm state:" + nte.getMessage());
                 }
             }
         }
@@ -219,7 +217,7 @@ public class StorPoolVMSnapshotStrategy extends DefaultVMSnapshotStrategy {
         try {
             vmSnapshotHelper.vmSnapshotStateTransitTo(vmSnapshot, VMSnapshot.Event.ExpungeRequested);
         } catch (NoTransitionException e) {
-            log.debug("Failed to change vm snapshot state with event ExpungeRequested");
+            logger.debug("Failed to change vm snapshot state with event ExpungeRequested");
             throw new CloudRuntimeException(
                     "Failed to change vm snapshot state with event ExpungeRequested: " + e.getMessage());
         }
@@ -241,13 +239,13 @@ public class StorPoolVMSnapshotStrategy extends DefaultVMSnapshotStrategy {
             if (snapshotName == null) {
                 err = String.format("Could not find StorPool's snapshot vm snapshot uuid=%s and volume uui=%s",
                         vmSnapshot.getUuid(), volumeObjectTO.getUuid());
-                log.error("Could not delete snapshot for vm:" + err);
+                logger.error("Could not delete snapshot for vm:" + err);
             }
             StorPoolUtil.spLog("StorpoolVMSnapshotStrategy.deleteVMSnapshot snapshotName=%s", snapshotName);
             resp = StorPoolUtil.snapshotDelete(snapshotName, conn);
             if (resp.getError() != null) {
                 err = String.format("Could not delete storpool vm error=%s", resp.getError());
-                log.error("Could not delete snapshot for vm:" + err);
+                logger.error("Could not delete snapshot for vm:" + err);
             } else {
                 // do we need to clean database?
                 if (snapshotDetailsVO != null) {
@@ -278,7 +276,7 @@ public class StorPoolVMSnapshotStrategy extends DefaultVMSnapshotStrategy {
 
     @Override
     public boolean revertVMSnapshot(VMSnapshot vmSnapshot) {
-        log.debug("Revert vm snapshot");
+        logger.debug("Revert vm snapshot");
         VMSnapshotVO vmSnapshotVO = (VMSnapshotVO) vmSnapshot;
         UserVmVO userVm = userVmDao.findById(vmSnapshot.getVmId());
 
@@ -306,7 +304,7 @@ public class StorPoolVMSnapshotStrategy extends DefaultVMSnapshotStrategy {
                 if (snapshotName == null) {
                     err = String.format("Could not find StorPool's snapshot vm snapshot uuid=%s and volume uui=%s",
                             vmSnapshot.getUuid(), volumeObjectTO.getUuid());
-                    log.error("Could not delete snapshot for vm:" + err);
+                    logger.error("Could not delete snapshot for vm:" + err);
                 }
                 String volumeName = StorPoolStorageAdaptor.getVolumeNameFromPath(volumeObjectTO.getPath(), true);
                 VolumeDetailVO detail = volumeDetailsDao.findDetail(volumeObjectTO.getId(), StorPoolUtil.SP_PROVIDER_NAME);
@@ -347,14 +345,14 @@ public class StorPoolVMSnapshotStrategy extends DefaultVMSnapshotStrategy {
             result = vmSnapshotHelper.vmSnapshotStateTransitTo(vmSnapshot, VMSnapshot.Event.OperationSucceeded);
         } catch (CloudRuntimeException | NoTransitionException  e) {
             String errMsg = String.format("Error while finalize create vm snapshot [%s] due to %s", vmSnapshot.getName(), e.getMessage());
-            log.error(errMsg, e);
+            logger.error(errMsg, e);
             throw new CloudRuntimeException(errMsg);
         } finally {
             if (!result) {
                 try {
                     vmSnapshotHelper.vmSnapshotStateTransitTo(vmSnapshot, VMSnapshot.Event.OperationFailed);
                 } catch (NoTransitionException e1) {
-                    log.error("Cannot set vm snapshot state due to: " + e1.getMessage());
+                    logger.error("Cannot set vm snapshot state due to: " + e1.getMessage());
                 }
             }
         }
@@ -381,7 +379,7 @@ public class StorPoolVMSnapshotStrategy extends DefaultVMSnapshotStrategy {
                     vmSnapshot.getName(), 0L, 0L, vmSnapSize, virtualSize, VMSnapshot.class.getName(),
                     vmSnapshot.getUuid());
         } catch (Exception e) {
-            log.error("Failed to publis usage event " + type, e);
+            logger.error("Failed to publis usage event " + type, e);
         }
     }
 }
