@@ -52,7 +52,6 @@ import org.apache.cloudstack.framework.messagebus.MessageSubscriber;
 import org.apache.cloudstack.ldap.dao.LdapConfigurationDao;
 import org.apache.cloudstack.ldap.dao.LdapTrustMapDao;
 import org.apache.commons.lang.Validate;
-import org.apache.log4j.Logger;
 import org.springframework.stereotype.Component;
 
 import com.cloud.domain.DomainVO;
@@ -65,7 +64,6 @@ import com.cloud.utils.Pair;
 
 @Component
 public class LdapManagerImpl extends ComponentLifecycleBase implements LdapManager, LdapValidator {
-    private static final Logger LOGGER = Logger.getLogger(LdapManagerImpl.class.getName());
 
     @Inject
     private LdapConfigurationDao _ldapConfigurationDao;
@@ -106,7 +104,7 @@ public class LdapManagerImpl extends ComponentLifecycleBase implements LdapManag
     @Override
     public boolean configure(String name, Map<String, Object> params) throws ConfigurationException {
         super.configure(name, params);
-        LOGGER.debug("Configuring LDAP Manager");
+        logger.debug("Configuring LDAP Manager");
 
         addAccountRemovalListener();
         addDomainRemovalListener();
@@ -126,7 +124,7 @@ public class LdapManagerImpl extends ComponentLifecycleBase implements LdapManag
                         removeTrustmap(ldapTrustMapVO);
                     }
                 } catch (final Exception e) {
-                    LOGGER.error("Caught exception while removing account linked to LDAP", e);
+                    logger.error("Caught exception while removing account linked to LDAP", e);
                 }
             }
         });
@@ -143,7 +141,7 @@ public class LdapManagerImpl extends ComponentLifecycleBase implements LdapManag
                         removeTrustmap(ldapTrustMapVO);
                     }
                 } catch (final Exception e) {
-                    LOGGER.error("Caught exception while removing trust-map for domain linked to LDAP", e);
+                    logger.error("Caught exception while removing trust-map for domain linked to LDAP", e);
                 }
             }
         });
@@ -152,7 +150,7 @@ public class LdapManagerImpl extends ComponentLifecycleBase implements LdapManag
     private void removeTrustmap(LdapTrustMapVO ldapTrustMapVO) {
         String msg = String.format("Removing link between LDAP: %s - type: %s  and account: %s on domain: %s",
                 ldapTrustMapVO.getName(), ldapTrustMapVO.getType().name(), ldapTrustMapVO.getAccountId(), ldapTrustMapVO.getDomainId());
-        LOGGER.debug(msg);
+        logger.debug(msg);
         _ldapTrustMapDao.remove(ldapTrustMapVO.getId());
     }
 
@@ -181,10 +179,10 @@ public class LdapManagerImpl extends ComponentLifecycleBase implements LdapManag
                 context = _ldapContextFactory.createBindContext(providerUrl,domainId);
                 configuration = new LdapConfigurationVO(hostname, port, domainId);
                 _ldapConfigurationDao.persist(configuration);
-                LOGGER.info("Added new ldap server with url: " + providerUrl + (domainId == null ? "": " for domain " + domainId));
+                logger.info("Added new ldap server with url: " + providerUrl + (domainId == null ? "": " for domain " + domainId));
                 return createLdapConfigurationResponse(configuration);
             } catch (NamingException | IOException e) {
-                LOGGER.debug("NamingException while doing an LDAP bind", e);
+                logger.debug("NamingException while doing an LDAP bind", e);
                 throw new InvalidParameterValueException("Unable to bind to the given LDAP server");
             } finally {
                 closeContext(context);
@@ -207,13 +205,13 @@ public class LdapManagerImpl extends ComponentLifecycleBase implements LdapManag
             // TODO return the right account for this user
             final LdapContext context = _ldapContextFactory.createUserContext(principal, password, domainId);
             closeContext(context);
-            if(LOGGER.isTraceEnabled()) {
-                LOGGER.trace(String.format("User(%s) authenticated for domain(%s)", principal, domainId));
+            if(logger.isTraceEnabled()) {
+                logger.trace(String.format("User(%s) authenticated for domain(%s)", principal, domainId));
             }
             return true;
         } catch (NamingException | IOException e) {/* AuthenticationException is caught as NamingException */
-            LOGGER.debug("Exception while doing an LDAP bind for user "+" "+principal, e);
-            LOGGER.info("Failed to authenticate user: " + principal + ". incorrect password.");
+            logger.debug("Exception while doing an LDAP bind for user "+" "+principal, e);
+            logger.info("Failed to authenticate user: " + principal + ". incorrect password.");
             return false;
         }
     }
@@ -224,7 +222,7 @@ public class LdapManagerImpl extends ComponentLifecycleBase implements LdapManag
                 context.close();
             }
         } catch (final NamingException e) {
-            LOGGER.warn(e.getMessage(), e);
+            logger.warn(e.getMessage(), e);
         }
     }
 
@@ -268,7 +266,7 @@ public class LdapManagerImpl extends ComponentLifecycleBase implements LdapManag
             throw new InvalidParameterValueException("Cannot find configuration with hostname " + hostname);
         } else {
             _ldapConfigurationDao.remove(configuration.getId());
-            LOGGER.info("Removed ldap server with url: " + hostname + ':' + port + (domainId == null ? "" : " for domain id " + domainId));
+            logger.info("Removed ldap server with url: " + hostname + ':' + port + (domainId == null ? "" : " for domain id " + domainId));
             return createLdapConfigurationResponse(configuration);
         }
     }
@@ -300,7 +298,7 @@ public class LdapManagerImpl extends ComponentLifecycleBase implements LdapManag
             return _ldapUserManagerFactory.getInstance(_ldapConfiguration.getLdapProvider(null)).getUser(escapedUsername, context, domainId);
 
         } catch (NamingException | IOException e) {
-            LOGGER.debug("ldap Exception: ",e);
+            logger.debug("ldap Exception: ",e);
             throw new NoLdapUserMatchingQueryException("No Ldap User found for username: "+username);
         } finally {
             closeContext(context);
@@ -321,7 +319,7 @@ public class LdapManagerImpl extends ComponentLifecycleBase implements LdapManag
             LdapUserManager userManagerFactory = _ldapUserManagerFactory.getInstance(ldapProvider);
             return userManagerFactory.getUser(escapedUsername, type, name, context, domainId);
         } catch (NamingException | IOException e) {
-            LOGGER.debug("ldap Exception: ",e);
+            logger.debug("ldap Exception: ",e);
             throw new NoLdapUserMatchingQueryException("No Ldap User found for username: "+username + " in group: " + name + " of type: " + type);
         } finally {
             closeContext(context);
@@ -335,7 +333,7 @@ public class LdapManagerImpl extends ComponentLifecycleBase implements LdapManag
             context = _ldapContextFactory.createBindContext(domainId);
             return _ldapUserManagerFactory.getInstance(_ldapConfiguration.getLdapProvider(domainId)).getUsers(context, domainId);
         } catch (NamingException | IOException e) {
-            LOGGER.debug("ldap Exception: ",e);
+            logger.debug("ldap Exception: ",e);
             throw new NoLdapUserMatchingQueryException("*");
         } finally {
             closeContext(context);
@@ -349,7 +347,7 @@ public class LdapManagerImpl extends ComponentLifecycleBase implements LdapManag
             context = _ldapContextFactory.createBindContext(domainId);
             return _ldapUserManagerFactory.getInstance(_ldapConfiguration.getLdapProvider(domainId)).getUsersInGroup(groupName, context, domainId);
         } catch (NamingException | IOException e) {
-            LOGGER.debug("ldap NamingException: ",e);
+            logger.debug("ldap NamingException: ",e);
             throw new NoLdapUserMatchingQueryException("groupName=" + groupName);
         } finally {
             closeContext(context);
@@ -387,7 +385,7 @@ public class LdapManagerImpl extends ComponentLifecycleBase implements LdapManag
             final String escapedUsername = LdapUtils.escapeLDAPSearchFilter(username);
             return _ldapUserManagerFactory.getInstance(_ldapConfiguration.getLdapProvider(null)).getUsers("*" + escapedUsername + "*", context, null);
         } catch (NamingException | IOException e) {
-            LOGGER.debug("ldap Exception: ",e);
+            logger.debug("ldap Exception: ",e);
             throw new NoLdapUserMatchingQueryException(username);
         } finally {
             closeContext(context);
@@ -416,7 +414,7 @@ public class LdapManagerImpl extends ComponentLifecycleBase implements LdapManag
         DomainVO domain = domainDao.findById(vo.getDomainId());
         String domainUuid = "<unknown>";
         if (domain == null) {
-            LOGGER.error("no domain in database for id " + vo.getDomainId());
+            logger.error("no domain in database for id " + vo.getDomainId());
         } else {
             domainUuid = domain.getUuid();
         }
@@ -466,7 +464,7 @@ public class LdapManagerImpl extends ComponentLifecycleBase implements LdapManag
         DomainVO domain = domainDao.findById(vo.getDomainId());
         String domainUuid = "<unknown>";
         if (domain == null) {
-            LOGGER.error("no domain in database for id " + vo.getDomainId());
+            logger.error("no domain in database for id " + vo.getDomainId());
         } else {
             domainUuid = domain.getUuid();
         }
@@ -485,16 +483,16 @@ public class LdapManagerImpl extends ComponentLifecycleBase implements LdapManag
                 String msg = String.format("group %s is mapped to account %d in the current domain (%s)", cmd.getLdapDomain(), oldVo.getAccountId(), cmd.getDomainId());
                 if (null == oldAcount.getRemoved()) {
                     msg += ", delete the old map before mapping a new account to the same group.";
-                    LOGGER.error(msg);
+                    logger.error(msg);
                     throw new CloudRuntimeException(msg);
                 } else {
                     msg += ", the old map is deleted.";
-                    LOGGER.warn(msg);
+                    logger.warn(msg);
                     _ldapTrustMapDao.expunge(oldVo.getId());
                 }
             } else {
                 String msg = String.format("group %s is mapped to the current domain (%s) for autoimport and can not be used for autosync", cmd.getLdapDomain(), cmd.getDomainId());
-                LOGGER.error(msg);
+                logger.error(msg);
                 throw new CloudRuntimeException(msg);
             }
         }
