@@ -57,7 +57,6 @@ import org.apache.cloudstack.framework.security.keystore.KeystoreVO;
 import org.apache.cloudstack.utils.security.CertUtils;
 import org.apache.commons.codec.binary.Base64;
 import org.apache.commons.httpclient.HttpClient;
-import org.apache.log4j.Logger;
 import org.bouncycastle.operator.OperatorCreationException;
 import org.opensaml.DefaultBootstrap;
 import org.opensaml.common.xml.SAMLConstants;
@@ -92,7 +91,6 @@ import com.cloud.utils.component.AdapterBase;
 
 @Component
 public class SAML2AuthManagerImpl extends AdapterBase implements SAML2AuthManager, Configurable {
-    private static final Logger s_logger = Logger.getLogger(SAML2AuthManagerImpl.class);
 
     private SAMLProviderMetadata _spMetadata = new SAMLProviderMetadata();
     private Map<String, SAMLProviderMetadata> _idpMetadataMap = new HashMap<String, SAMLProviderMetadata>();
@@ -123,10 +121,10 @@ public class SAML2AuthManagerImpl extends AdapterBase implements SAML2AuthManage
     @Override
     public boolean start() {
         if (isSAMLPluginEnabled()) {
-            s_logger.info("SAML auth plugin loaded");
+            logger.info("SAML auth plugin loaded");
             return setup();
         } else {
-            s_logger.info("SAML auth plugin not enabled so not loading");
+            logger.info("SAML auth plugin not enabled so not loading");
             return super.start();
         }
     }
@@ -148,9 +146,9 @@ public class SAML2AuthManagerImpl extends AdapterBase implements SAML2AuthManage
                         SAMLUtils.encodePrivateKey(keyPair.getPrivate()),
                         SAMLUtils.encodePublicKey(keyPair.getPublic()), "samlsp-keypair");
                 keyStoreVO = _ksDao.findByName(SAMLPluginConstants.SAMLSP_KEYPAIR);
-                s_logger.info("No SAML keystore found, created and saved a new Service Provider keypair");
+                logger.info("No SAML keystore found, created and saved a new Service Provider keypair");
             } catch (final NoSuchProviderException | NoSuchAlgorithmException e) {
-                s_logger.error("Unable to create and save SAML keypair, due to: ", e);
+                logger.error("Unable to create and save SAML keypair, due to: ", e);
             }
         }
 
@@ -179,7 +177,7 @@ public class SAML2AuthManagerImpl extends AdapterBase implements SAML2AuthManage
                         _ksDao.save(SAMLPluginConstants.SAMLSP_X509CERT, Base64.encodeBase64String(bos.toByteArray()), "", "samlsp-x509cert");
                         bos.close();
                     } catch (final NoSuchAlgorithmException | NoSuchProviderException | CertificateException | SignatureException | InvalidKeyException | IOException | OperatorCreationException e) {
-                        s_logger.error("SAML plugin won't be able to use X509 signed authentication", e);
+                        logger.error("SAML plugin won't be able to use X509 signed authentication", e);
                     }
                 } else {
                     try {
@@ -188,7 +186,7 @@ public class SAML2AuthManagerImpl extends AdapterBase implements SAML2AuthManage
                         spX509Key = (X509Certificate) si.readObject();
                         bi.close();
                     } catch (IOException | ClassNotFoundException ignored) {
-                        s_logger.error("SAML Plugin won't be able to use X509 signed authentication. Failed to load X509 Certificate from Database.");
+                        logger.error("SAML Plugin won't be able to use X509 signed authentication. Failed to load X509 Certificate from Database.");
                     }
                 }
             }
@@ -215,7 +213,7 @@ public class SAML2AuthManagerImpl extends AdapterBase implements SAML2AuthManage
     private void addIdpToMap(EntityDescriptor descriptor, Map<String, SAMLProviderMetadata> idpMap) {
         SAMLProviderMetadata idpMetadata = new SAMLProviderMetadata();
         idpMetadata.setEntityId(descriptor.getEntityID());
-        s_logger.debug("Adding IdP to the list of discovered IdPs: " + descriptor.getEntityID());
+        logger.debug("Adding IdP to the list of discovered IdPs: " + descriptor.getEntityID());
         if (descriptor.getOrganization() != null) {
             if (descriptor.getOrganization().getDisplayNames() != null) {
                 for (OrganizationDisplayName orgName : descriptor.getOrganization().getDisplayNames()) {
@@ -289,21 +287,21 @@ public class SAML2AuthManagerImpl extends AdapterBase implements SAML2AuthManage
                         try {
                             idpMetadata.setSigningCertificate(KeyInfoHelper.getCertificates(kd.getKeyInfo()).get(0));
                         } catch (CertificateException ignored) {
-                            s_logger.info("[ignored] encountered invalid certificate signing.", ignored);
+                            logger.info("[ignored] encountered invalid certificate signing.", ignored);
                         }
                     }
                     if (kd.getUse() == UsageType.ENCRYPTION) {
                         try {
                             idpMetadata.setEncryptionCertificate(KeyInfoHelper.getCertificates(kd.getKeyInfo()).get(0));
                         } catch (CertificateException ignored) {
-                            s_logger.info("[ignored] encountered invalid certificate encryption.", ignored);
+                            logger.info("[ignored] encountered invalid certificate encryption.", ignored);
                         }
                     }
                     if (kd.getUse() == UsageType.UNSPECIFIED) {
                         try {
                             unspecifiedKey = KeyInfoHelper.getCertificates(kd.getKeyInfo()).get(0);
                         } catch (CertificateException ignored) {
-                            s_logger.info("[ignored] encountered invalid certificate.", ignored);
+                            logger.info("[ignored] encountered invalid certificate.", ignored);
                         }
                     }
                 }
@@ -315,7 +313,7 @@ public class SAML2AuthManagerImpl extends AdapterBase implements SAML2AuthManage
                 idpMetadata.setEncryptionCertificate(unspecifiedKey);
             }
             if (idpMap.containsKey(idpMetadata.getEntityId())) {
-                s_logger.warn("Duplicate IdP metadata found with entity Id: " + idpMetadata.getEntityId());
+                logger.warn("Duplicate IdP metadata found with entity Id: " + idpMetadata.getEntityId());
             }
             idpMap.put(idpMetadata.getEntityId(), idpMetadata);
         }
@@ -346,16 +344,16 @@ public class SAML2AuthManagerImpl extends AdapterBase implements SAML2AuthManage
             if (_idpMetaDataProvider == null) {
                 return;
             }
-            s_logger.debug("Starting SAML IDP Metadata Refresh Task");
+            logger.debug("Starting SAML IDP Metadata Refresh Task");
 
             Map <String, SAMLProviderMetadata> metadataMap = new HashMap<String, SAMLProviderMetadata>();
             try {
                 discoverAndAddIdp(_idpMetaDataProvider.getMetadata(), metadataMap);
                 _idpMetadataMap = metadataMap;
                 expireTokens();
-                s_logger.debug("Finished refreshing SAML Metadata and expiring old auth tokens");
+                logger.debug("Finished refreshing SAML Metadata and expiring old auth tokens");
             } catch (MetadataProviderException e) {
-                s_logger.warn("SAML Metadata Refresh task failed with exception: " + e.getMessage());
+                logger.warn("SAML Metadata Refresh task failed with exception: " + e.getMessage());
             }
 
         }
@@ -363,7 +361,7 @@ public class SAML2AuthManagerImpl extends AdapterBase implements SAML2AuthManage
 
     private boolean setup() {
         if (!initSP()) {
-            s_logger.error("SAML Plugin failed to initialize, please fix the configuration and restart management server");
+            logger.error("SAML Plugin failed to initialize, please fix the configuration and restart management server");
             return false;
         }
         _timer = new Timer();
@@ -379,11 +377,11 @@ public class SAML2AuthManagerImpl extends AdapterBase implements SAML2AuthManage
             } else {
                 File metadataFile = PropertiesUtil.findConfigFile(idpMetaDataUrl);
                 if (metadataFile == null) {
-                    s_logger.error("Provided Metadata is not a URL, Unable to locate metadata file from local path: " + idpMetaDataUrl);
+                    logger.error("Provided Metadata is not a URL, Unable to locate metadata file from local path: " + idpMetaDataUrl);
                     return false;
                 }
                 else{
-                    s_logger.debug("Provided Metadata is not a URL, trying to read metadata file from local path: " + metadataFile.getAbsolutePath());
+                    logger.debug("Provided Metadata is not a URL, trying to read metadata file from local path: " + metadataFile.getAbsolutePath());
                     _idpMetaDataProvider = new FilesystemMetadataProvider(_timer, metadataFile);
                 }
             }
@@ -393,14 +391,14 @@ public class SAML2AuthManagerImpl extends AdapterBase implements SAML2AuthManage
             _timer.scheduleAtFixedRate(new MetadataRefreshTask(), 0, _refreshInterval * 1000);
 
         } catch (MetadataProviderException e) {
-            s_logger.error("Unable to read SAML2 IDP MetaData URL, error:" + e.getMessage());
-            s_logger.error("SAML2 Authentication may be unavailable");
+            logger.error("Unable to read SAML2 IDP MetaData URL, error:" + e.getMessage());
+            logger.error("SAML2 Authentication may be unavailable");
             return false;
         } catch (ConfigurationException | FactoryConfigurationError e) {
-            s_logger.error("OpenSAML bootstrapping failed: error: " + e.getMessage());
+            logger.error("OpenSAML bootstrapping failed: error: " + e.getMessage());
             return false;
         } catch (NullPointerException e) {
-            s_logger.error("Unable to setup SAML Auth Plugin due to NullPointerException" +
+            logger.error("Unable to setup SAML Auth Plugin due to NullPointerException" +
                     " please check the SAML global settings: " + e.getMessage());
             return false;
         }
@@ -478,7 +476,7 @@ public class SAML2AuthManagerImpl extends AdapterBase implements SAML2AuthManage
         if (_samlTokenDao.findByUuid(authnId) == null) {
             _samlTokenDao.persist(token);
         } else {
-            s_logger.warn("Duplicate SAML token for entity=" + entity + " token id=" + authnId + " domain=" + domainPath);
+            logger.warn("Duplicate SAML token for entity=" + entity + " token id=" + authnId + " domain=" + domainPath);
         }
     }
 
@@ -543,6 +541,6 @@ public class SAML2AuthManagerImpl extends AdapterBase implements SAML2AuthManage
                 SAMLCloudStackRedirectionUrl, SAMLUserAttributeName,
                 SAMLIdentityProviderMetadataURL, SAMLDefaultIdentityProviderId,
                 SAMLSignatureAlgorithm, SAMLAppendDomainSuffix, SAMLTimeout, SAMLCheckSignature,
-                SAMLForceAuthn, SAMLUserSessionKeyPathAttribute, SAMLRequirePasswordLogin};
+                SAMLForceAuthn, SAMLUserSessionKeyPathAttribute};
     }
 }
