@@ -25,8 +25,9 @@ import java.util.Map;
 import javax.inject.Inject;
 import javax.naming.ConfigurationException;
 
+import com.cloud.utils.exception.CloudRuntimeException;
 import org.apache.cloudstack.framework.config.dao.ConfigurationDao;
-import org.apache.log4j.Logger;
+import org.apache.cloudstack.utils.reflectiontostringbuilderutils.ReflectionToStringBuilderUtils;
 import org.springframework.stereotype.Component;
 
 import com.cloud.agent.manager.allocator.HostAllocator;
@@ -69,7 +70,6 @@ import com.cloud.vm.dao.VMInstanceDao;
  */
 @Component
 public class FirstFitAllocator extends AdapterBase implements HostAllocator {
-    private static final Logger s_logger = Logger.getLogger(FirstFitAllocator.class);
     @Inject
     protected HostDao _hostDao = null;
     @Inject
@@ -123,19 +123,15 @@ public class FirstFitAllocator extends AdapterBase implements HostAllocator {
                 isVMDeployedWithUefi = true;
             }
         }
-        s_logger.info(" Guest VM is requested with Custom[UEFI] Boot Type "+ isVMDeployedWithUefi);
+        logger.info(" Guest VM is requested with Custom[UEFI] Boot Type "+ isVMDeployedWithUefi);
 
 
         if (type == Host.Type.Storage) {
             // FirstFitAllocator should be used for user VMs only since it won't care whether the host is capable of routing or not
-            return new ArrayList<Host>();
+            return new ArrayList<>();
         }
 
-        String paramAsStringToLog = String.format("zone [%s], pod [%s], cluster [%s]", dcId, podId, clusterId);
-
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug(String.format("Looking for hosts in %s.", paramAsStringToLog));
-        }
+        logger.debug("Looking for hosts in zone [{}], pod [{}], cluster [{}]", dcId, podId, clusterId);
 
         String hostTagOnOffering = offering.getHostTag();
         String hostTagOnTemplate = template.getTemplateTag();
@@ -144,12 +140,12 @@ public class FirstFitAllocator extends AdapterBase implements HostAllocator {
         boolean hasSvcOfferingTag = hostTagOnOffering != null ? true : false;
         boolean hasTemplateTag = hostTagOnTemplate != null ? true : false;
 
-        List<HostVO> clusterHosts = new ArrayList<HostVO>();
-        List<HostVO> hostsMatchingUefiTag = new ArrayList<HostVO>();
+        List<HostVO> clusterHosts = new ArrayList<>();
+        List<HostVO> hostsMatchingUefiTag = new ArrayList<>();
         if(isVMDeployedWithUefi){
             hostsMatchingUefiTag = _hostDao.listByHostCapability(type, clusterId, podId, dcId, Host.HOST_UEFI_ENABLE);
-            if (s_logger.isDebugEnabled()) {
-                s_logger.debug("Hosts with tag '" + hostTagUefi + "' are:" + hostsMatchingUefiTag);
+            if (logger.isDebugEnabled()) {
+                logger.debug("Hosts with tag '" + hostTagUefi + "' are:" + hostsMatchingUefiTag);
             }
         }
 
@@ -161,31 +157,31 @@ public class FirstFitAllocator extends AdapterBase implements HostAllocator {
             if (hostTagOnOffering == null && hostTagOnTemplate == null) {
                 clusterHosts = _resourceMgr.listAllUpAndEnabledNonHAHosts(type, clusterId, podId, dcId);
             } else {
-                List<HostVO> hostsMatchingOfferingTag = new ArrayList<HostVO>();
-                List<HostVO> hostsMatchingTemplateTag = new ArrayList<HostVO>();
+                List<HostVO> hostsMatchingOfferingTag = new ArrayList<>();
+                List<HostVO> hostsMatchingTemplateTag = new ArrayList<>();
                 if (hasSvcOfferingTag) {
-                    if (s_logger.isDebugEnabled()) {
-                        s_logger.debug("Looking for hosts having tag specified on SvcOffering:" + hostTagOnOffering);
+                    if (logger.isDebugEnabled()) {
+                        logger.debug("Looking for hosts having tag specified on SvcOffering:" + hostTagOnOffering);
                     }
                     hostsMatchingOfferingTag = _hostDao.listByHostTag(type, clusterId, podId, dcId, hostTagOnOffering);
-                    if (s_logger.isDebugEnabled()) {
-                        s_logger.debug("Hosts with tag '" + hostTagOnOffering + "' are:" + hostsMatchingOfferingTag);
+                    if (logger.isDebugEnabled()) {
+                        logger.debug("Hosts with tag '" + hostTagOnOffering + "' are:" + hostsMatchingOfferingTag);
                     }
                 }
                 if (hasTemplateTag) {
-                    if (s_logger.isDebugEnabled()) {
-                        s_logger.debug("Looking for hosts having tag specified on Template:" + hostTagOnTemplate);
+                    if (logger.isDebugEnabled()) {
+                        logger.debug("Looking for hosts having tag specified on Template:" + hostTagOnTemplate);
                     }
                     hostsMatchingTemplateTag = _hostDao.listByHostTag(type, clusterId, podId, dcId, hostTagOnTemplate);
-                    if (s_logger.isDebugEnabled()) {
-                        s_logger.debug("Hosts with tag '" + hostTagOnTemplate + "' are:" + hostsMatchingTemplateTag);
+                    if (logger.isDebugEnabled()) {
+                        logger.debug("Hosts with tag '" + hostTagOnTemplate + "' are:" + hostsMatchingTemplateTag);
                     }
                 }
 
                 if (hasSvcOfferingTag && hasTemplateTag) {
                     hostsMatchingOfferingTag.retainAll(hostsMatchingTemplateTag);
-                    if (s_logger.isDebugEnabled()) {
-                        s_logger.debug("Found " + hostsMatchingOfferingTag.size() + " Hosts satisfying both tags, host ids are:" + hostsMatchingOfferingTag);
+                    if (logger.isDebugEnabled()) {
+                        logger.debug("Found " + hostsMatchingOfferingTag.size() + " Hosts satisfying both tags, host ids are:" + hostsMatchingOfferingTag);
                     }
 
                     clusterHosts = hostsMatchingOfferingTag;
@@ -207,12 +203,16 @@ public class FirstFitAllocator extends AdapterBase implements HostAllocator {
 
 
         if (clusterHosts.isEmpty()) {
-            s_logger.info(String.format("No suitable host found for VM [%s] with tags [%s] in %s.", vmProfile, hostTagOnOffering, paramAsStringToLog));
-            return null;
+            logger.error("No suitable host found for vm [{}] with tags [{}].", vmProfile, hostTagOnOffering);
+            throw new CloudRuntimeException(String.format("No suitable host found for vm [%s].", vmProfile));
         }
         // add all hosts that we are not considering to the avoid list
         List<HostVO> allhostsInCluster = _hostDao.listAllUpAndEnabledNonHAHosts(type, clusterId, podId, dcId, null);
         allhostsInCluster.removeAll(clusterHosts);
+
+        logger.debug(() -> String.format("Adding hosts [%s] to the avoid set because these hosts do not support HA.",
+                ReflectionToStringBuilderUtils.reflectOnlySelectedFields(allhostsInCluster, "uuid", "name")));
+
         for (HostVO host : allhostsInCluster) {
             avoid.addHost(host.getId());
         }
@@ -229,8 +229,8 @@ public class FirstFitAllocator extends AdapterBase implements HostAllocator {
         ServiceOffering offering = vmProfile.getServiceOffering();
         VMTemplateVO template = (VMTemplateVO)vmProfile.getTemplate();
         Account account = vmProfile.getOwner();
-        List<Host> suitableHosts = new ArrayList<Host>();
-        List<Host> hostsCopy = new ArrayList<Host>(hosts);
+        List<Host> suitableHosts = new ArrayList<>();
+        List<Host> hostsCopy = new ArrayList<>(hosts);
 
         if (type == Host.Type.Storage) {
             // FirstFitAllocator should be used for user VMs only since it won't care whether the host is capable of
@@ -251,25 +251,25 @@ public class FirstFitAllocator extends AdapterBase implements HostAllocator {
                 hostsCopy.retainAll(_resourceMgr.listAllUpAndEnabledNonHAHosts(type, clusterId, podId, dcId));
             } else {
                 if (hasSvcOfferingTag) {
-                    if (s_logger.isDebugEnabled()) {
-                        s_logger.debug("Looking for hosts having tag specified on SvcOffering:" + hostTagOnOffering);
+                    if (logger.isDebugEnabled()) {
+                        logger.debug("Looking for hosts having tag specified on SvcOffering:" + hostTagOnOffering);
                     }
                     hostsCopy.retainAll(_hostDao.listByHostTag(type, clusterId, podId, dcId, hostTagOnOffering));
 
-                    if (s_logger.isDebugEnabled()) {
-                        s_logger.debug("Hosts with tag '" + hostTagOnOffering + "' are:" + hostsCopy);
+                    if (logger.isDebugEnabled()) {
+                        logger.debug("Hosts with tag '" + hostTagOnOffering + "' are:" + hostsCopy);
                     }
                 }
 
                 if (hasTemplateTag) {
-                    if (s_logger.isDebugEnabled()) {
-                        s_logger.debug("Looking for hosts having tag specified on Template:" + hostTagOnTemplate);
+                    if (logger.isDebugEnabled()) {
+                        logger.debug("Looking for hosts having tag specified on Template:" + hostTagOnTemplate);
                     }
 
                     hostsCopy.retainAll(_hostDao.listByHostTag(type, clusterId, podId, dcId, hostTagOnTemplate));
 
-                    if (s_logger.isDebugEnabled()) {
-                        s_logger.debug("Hosts with tag '" + hostTagOnTemplate + "' are:" + hostsCopy);
+                    if (logger.isDebugEnabled()) {
+                        logger.debug("Hosts with tag '" + hostTagOnTemplate + "' are:" + hostsCopy);
                     }
                 }
             }
@@ -295,24 +295,24 @@ public class FirstFitAllocator extends AdapterBase implements HostAllocator {
             hosts = reorderHostsByCapacity(plan, hosts);
         }
 
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("FirstFitAllocator has " + hosts.size() + " hosts to check for allocation: " + hosts);
+        if (logger.isDebugEnabled()) {
+            logger.debug("FirstFitAllocator has " + hosts.size() + " hosts to check for allocation: " + hosts);
         }
 
         // We will try to reorder the host lists such that we give priority to hosts that have
         // the minimums to support a VM's requirements
         hosts = prioritizeHosts(template, offering, hosts);
 
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Found " + hosts.size() + " hosts for allocation after prioritization: " + hosts);
+        if (logger.isDebugEnabled()) {
+            logger.debug("Found " + hosts.size() + " hosts for allocation after prioritization: " + hosts);
         }
 
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Looking for speed=" + (offering.getCpu() * offering.getSpeed()) + "Mhz, Ram=" + offering.getRamSize() + " MB");
+        if (logger.isDebugEnabled()) {
+            logger.debug("Looking for speed=" + (offering.getCpu() * offering.getSpeed()) + "Mhz, Ram=" + offering.getRamSize() + " MB");
         }
 
         long serviceOfferingId = offering.getId();
-        List<Host> suitableHosts = new ArrayList<Host>();
+        List<Host> suitableHosts = new ArrayList<>();
         ServiceOfferingDetailsVO offeringDetails = null;
 
         for (Host host : hosts) {
@@ -320,18 +320,16 @@ public class FirstFitAllocator extends AdapterBase implements HostAllocator {
                 break;
             }
             if (avoid.shouldAvoid(host)) {
-                if (s_logger.isDebugEnabled()) {
-                    s_logger.debug("Host name: " + host.getName() + ", hostId: " + host.getId() + " is in avoid set, skipping this and trying other available hosts");
+                if (logger.isDebugEnabled()) {
+                    logger.debug("Host name: " + host.getName() + ", hostId: " + host.getId() + " is in avoid set, skipping this and trying other available hosts");
                 }
                 continue;
             }
 
             //find number of guest VMs occupying capacity on this host.
             if (_capacityMgr.checkIfHostReachMaxGuestLimit(host)) {
-                if (s_logger.isDebugEnabled()) {
-                    s_logger.debug("Host name: " + host.getName() + ", hostId: " + host.getId() +
-                        " already has max Running VMs(count includes system VMs), skipping this and trying other available hosts");
-                }
+                logger.debug(() -> String.format("Adding host [%s] to the avoid set because this host already has the max number of running (user and/or system) VMs.",
+                        ReflectionToStringBuilderUtils.reflectOnlySelectedFields(host, "uuid", "name")));
                 avoid.addHost(host.getId());
                 continue;
             }
@@ -340,27 +338,28 @@ public class FirstFitAllocator extends AdapterBase implements HostAllocator {
             if ((offeringDetails   = _serviceOfferingDetailsDao.findDetail(serviceOfferingId, GPU.Keys.vgpuType.toString())) != null) {
                 ServiceOfferingDetailsVO groupName = _serviceOfferingDetailsDao.findDetail(serviceOfferingId, GPU.Keys.pciDevice.toString());
                 if(!_resourceMgr.isGPUDeviceAvailable(host.getId(), groupName.getValue(), offeringDetails.getValue())){
-                    s_logger.info("Host name: " + host.getName() + ", hostId: "+ host.getId() +" does not have required GPU devices available");
+                    logger.debug(String.format("Adding host [%s] to avoid set, because this host does not have required GPU devices available.",
+                            ReflectionToStringBuilderUtils.reflectOnlySelectedFields(host, "uuid", "name")));
                     avoid.addHost(host.getId());
                     continue;
                 }
             }
             Pair<Boolean, Boolean> cpuCapabilityAndCapacity = _capacityMgr.checkIfHostHasCpuCapabilityAndCapacity(host, offering, considerReservedCapacity);
             if (cpuCapabilityAndCapacity.first() && cpuCapabilityAndCapacity.second()) {
-                if (s_logger.isDebugEnabled()) {
-                    s_logger.debug("Found a suitable host, adding to list: " + host.getId());
+                if (logger.isDebugEnabled()) {
+                    logger.debug("Found a suitable host, adding to list: " + host.getId());
                 }
                 suitableHosts.add(host);
             } else {
-                if (s_logger.isDebugEnabled()) {
-                    s_logger.debug("Not using host " + host.getId() + "; host has cpu capability? " + cpuCapabilityAndCapacity.first() + ", host has capacity?" + cpuCapabilityAndCapacity.second());
+                if (logger.isDebugEnabled()) {
+                    logger.debug("Not using host " + host.getId() + "; host has cpu capability? " + cpuCapabilityAndCapacity.first() + ", host has capacity?" + cpuCapabilityAndCapacity.second());
                 }
                 avoid.addHost(host.getId());
             }
         }
 
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Host Allocator returning " + suitableHosts.size() + " suitable hosts");
+        if (logger.isDebugEnabled()) {
+            logger.debug("Host Allocator returning " + suitableHosts.size() + " suitable hosts");
         }
 
         return suitableHosts;
@@ -377,20 +376,20 @@ public class FirstFitAllocator extends AdapterBase implements HostAllocator {
             capacityType = CapacityVO.CAPACITY_TYPE_MEMORY;
         }
         List<Long> hostIdsByFreeCapacity = _capacityDao.orderHostsByFreeCapacity(zoneId, clusterId, capacityType);
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("List of hosts in descending order of free capacity in the cluster: "+ hostIdsByFreeCapacity);
+        if (logger.isDebugEnabled()) {
+            logger.debug("List of hosts in descending order of free capacity in the cluster: "+ hostIdsByFreeCapacity);
         }
 
         //now filter the given list of Hosts by this ordered list
-        Map<Long, Host> hostMap = new HashMap<Long, Host>();
+        Map<Long, Host> hostMap = new HashMap<>();
         for (Host host : hosts) {
             hostMap.put(host.getId(), host);
         }
-        List<Long> matchingHostIds = new ArrayList<Long>(hostMap.keySet());
+        List<Long> matchingHostIds = new ArrayList<>(hostMap.keySet());
 
         hostIdsByFreeCapacity.retainAll(matchingHostIds);
 
-        List<Host> reorderedHosts = new ArrayList<Host>();
+        List<Host> reorderedHosts = new ArrayList<>();
         for(Long id: hostIdsByFreeCapacity){
             reorderedHosts.add(hostMap.get(id));
         }
@@ -407,20 +406,20 @@ public class FirstFitAllocator extends AdapterBase implements HostAllocator {
         Long clusterId = plan.getClusterId();
 
         List<Long> hostIdsByVmCount = _vmInstanceDao.listHostIdsByVmCount(dcId, podId, clusterId, account.getAccountId());
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("List of hosts in ascending order of number of VMs: " + hostIdsByVmCount);
+        if (logger.isDebugEnabled()) {
+            logger.debug("List of hosts in ascending order of number of VMs: " + hostIdsByVmCount);
         }
 
         //now filter the given list of Hosts by this ordered list
-        Map<Long, Host> hostMap = new HashMap<Long, Host>();
+        Map<Long, Host> hostMap = new HashMap<>();
         for (Host host : hosts) {
             hostMap.put(host.getId(), host);
         }
-        List<Long> matchingHostIds = new ArrayList<Long>(hostMap.keySet());
+        List<Long> matchingHostIds = new ArrayList<>(hostMap.keySet());
 
         hostIdsByVmCount.retainAll(matchingHostIds);
 
-        List<Host> reorderedHosts = new ArrayList<Host>();
+        List<Host> reorderedHosts = new ArrayList<>();
         for (Long id : hostIdsByVmCount) {
             reorderedHosts.add(hostMap.get(id));
         }
@@ -443,11 +442,11 @@ public class FirstFitAllocator extends AdapterBase implements HostAllocator {
         // Determine the guest OS category of the template
         String templateGuestOSCategory = getTemplateGuestOSCategory(template);
 
-        List<Host> prioritizedHosts = new ArrayList<Host>();
-        List<Host> noHvmHosts = new ArrayList<Host>();
+        List<Host> prioritizedHosts = new ArrayList<>();
+        List<Host> noHvmHosts = new ArrayList<>();
 
         // If a template requires HVM and a host doesn't support HVM, remove it from consideration
-        List<Host> hostsToCheck = new ArrayList<Host>();
+        List<Host> hostsToCheck = new ArrayList<>();
         if (template.isRequiresHvm()) {
             for (Host host : hosts) {
                 if (hostSupportsHVM(host)) {
@@ -460,15 +459,15 @@ public class FirstFitAllocator extends AdapterBase implements HostAllocator {
             hostsToCheck.addAll(hosts);
         }
 
-        if (s_logger.isDebugEnabled()) {
+        if (logger.isDebugEnabled()) {
             if (noHvmHosts.size() > 0) {
-                s_logger.debug("Not considering hosts: " + noHvmHosts + "  to deploy template: " + template + " as they are not HVM enabled");
+                logger.debug("Not considering hosts: " + noHvmHosts + "  to deploy template: " + template + " as they are not HVM enabled");
             }
         }
         // If a host is tagged with the same guest OS category as the template, move it to a high priority list
         // If a host is tagged with a different guest OS category than the template, move it to a low priority list
-        List<Host> highPriorityHosts = new ArrayList<Host>();
-        List<Host> lowPriorityHosts = new ArrayList<Host>();
+        List<Host> highPriorityHosts = new ArrayList<>();
+        List<Host> lowPriorityHosts = new ArrayList<>();
         for (Host host : hostsToCheck) {
             String hostGuestOSCategory = getHostGuestOSCategory(host);
             if (hostGuestOSCategory == null) {
@@ -501,7 +500,7 @@ public class FirstFitAllocator extends AdapterBase implements HostAllocator {
         // if service offering is not GPU enabled then move all the GPU enabled hosts to the end of priority list.
         if (_serviceOfferingDetailsDao.findDetail(offering.getId(), GPU.Keys.vgpuType.toString()) == null) {
 
-            List<Host> gpuEnabledHosts = new ArrayList<Host>();
+            List<Host> gpuEnabledHosts = new ArrayList<>();
             // Check for GPU enabled hosts.
             for (Host host : prioritizedHosts) {
                 if (_resourceMgr.isHostGpuEnabled(host.getId())) {
