@@ -21,7 +21,6 @@ import java.util.Map;
 import javax.inject.Inject;
 import javax.naming.ConfigurationException;
 
-import org.apache.log4j.Logger;
 import org.springframework.stereotype.Component;
 
 import com.cloud.cluster.ClusterManager;
@@ -36,7 +35,6 @@ import com.cloud.utils.events.SubscriptionMgr;
 @Component
 public class ClusterAlertAdapter extends AdapterBase implements AlertAdapter {
 
-    private static final Logger s_logger = Logger.getLogger(ClusterAlertAdapter.class);
 
     @Inject
     private AlertManager _alertMgr;
@@ -44,8 +42,8 @@ public class ClusterAlertAdapter extends AdapterBase implements AlertAdapter {
     private ManagementServerHostDao _mshostDao;
 
     public void onClusterAlert(Object sender, EventArgs args) {
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Receive cluster alert, EventArgs: " + args.getClass().getName());
+        if (logger.isDebugEnabled()) {
+            logger.debug("Receive cluster alert, EventArgs: " + args.getClass().getName());
         }
 
         if (args instanceof ClusterNodeJoinEventArgs) {
@@ -53,21 +51,21 @@ public class ClusterAlertAdapter extends AdapterBase implements AlertAdapter {
         } else if (args instanceof ClusterNodeLeftEventArgs) {
             onClusterNodeLeft(sender, (ClusterNodeLeftEventArgs)args);
         } else {
-            s_logger.error("Unrecognized cluster alert event");
+            logger.error("Unrecognized cluster alert event");
         }
     }
 
     private void onClusterNodeJoined(Object sender, ClusterNodeJoinEventArgs args) {
-        if (s_logger.isDebugEnabled()) {
+        if (logger.isDebugEnabled()) {
             for (ManagementServerHostVO mshost : args.getJoinedNodes()) {
-                s_logger.debug("Handle cluster node join alert, joined node: " + mshost.getServiceIP() + ", msid: " + mshost.getMsid());
+                logger.debug("Handle cluster node join alert, joined node: " + mshost.getServiceIP() + ", msid: " + mshost.getMsid());
             }
         }
 
         for (ManagementServerHostVO mshost : args.getJoinedNodes()) {
             if (mshost.getId() == args.getSelf().longValue()) {
-                if (s_logger.isDebugEnabled()) {
-                    s_logger.debug("Management server node " + mshost.getServiceIP() + " is up, send alert");
+                if (logger.isDebugEnabled()) {
+                    logger.debug("Management server node " + mshost.getServiceIP() + " is up, send alert");
                 }
 
                 _alertMgr.sendAlert(AlertManager.AlertType.ALERT_TYPE_MANAGEMENT_NODE, 0, new Long(0), "Management server node " + mshost.getServiceIP() + " is up", "");
@@ -78,23 +76,23 @@ public class ClusterAlertAdapter extends AdapterBase implements AlertAdapter {
 
     private void onClusterNodeLeft(Object sender, ClusterNodeLeftEventArgs args) {
 
-        if (s_logger.isDebugEnabled()) {
+        if (logger.isDebugEnabled()) {
             for (ManagementServerHostVO mshost : args.getLeftNodes()) {
-                s_logger.debug("Handle cluster node left alert, leaving node: " + mshost.getServiceIP() + ", msid: " + mshost.getMsid());
+                logger.debug("Handle cluster node left alert, leaving node: " + mshost.getServiceIP() + ", msid: " + mshost.getMsid());
             }
         }
 
         for (ManagementServerHostVO mshost : args.getLeftNodes()) {
             if (mshost.getId() != args.getSelf().longValue()) {
                 if (_mshostDao.increaseAlertCount(mshost.getId()) > 0) {
-                    if (s_logger.isDebugEnabled()) {
-                        s_logger.debug("Detected management server node " + mshost.getServiceIP() + " is down, send alert");
+                    if (logger.isDebugEnabled()) {
+                        logger.debug("Detected management server node " + mshost.getServiceIP() + " is down, send alert");
                     }
                     _alertMgr.sendAlert(AlertManager.AlertType.ALERT_TYPE_MANAGEMENT_NODE, 0, new Long(0), "Management server node " + mshost.getServiceIP() + " is down",
                         "");
                 } else {
-                    if (s_logger.isDebugEnabled()) {
-                        s_logger.debug("Detected management server node " + mshost.getServiceIP() + " is down, but alert has already been set");
+                    if (logger.isDebugEnabled()) {
+                        logger.debug("Detected management server node " + mshost.getServiceIP() + " is down, but alert has already been set");
                     }
                 }
             }
@@ -104,8 +102,8 @@ public class ClusterAlertAdapter extends AdapterBase implements AlertAdapter {
     @Override
     public boolean configure(String name, Map<String, Object> params) throws ConfigurationException {
 
-        if (s_logger.isInfoEnabled()) {
-            s_logger.info("Start configuring cluster alert manager : " + name);
+        if (logger.isInfoEnabled()) {
+            logger.info("Start configuring cluster alert manager : " + name);
         }
 
         try {
