@@ -20,7 +20,6 @@ import java.util.List;
 
 
 import com.cloud.user.AccountManagerImpl;
-import org.apache.log4j.Logger;
 import org.springframework.stereotype.Component;
 
 import org.apache.cloudstack.api.response.UserResponse;
@@ -34,7 +33,6 @@ import com.cloud.utils.db.SearchCriteria;
 
 @Component
 public class UserAccountJoinDaoImpl extends GenericDaoBase<UserAccountJoinVO, Long> implements UserAccountJoinDao {
-    public static final Logger s_logger = Logger.getLogger(UserAccountJoinDaoImpl.class);
 
     private SearchBuilder<UserAccountJoinVO> vrIdSearch;
 
