@@ -85,6 +85,5 @@ public interface HighAvailabilityDao extends GenericDao<HaWorkVO, Long> {
     List<HaWorkVO> listPendingHaWorkForVm(long vmId);
 
     List<HaWorkVO> listPendingMigrationsForVm(long vmId);
-
-    List<HaWorkVO> listPendingHAWorkForHost(long hostId);
+    int expungeByVmList(List<Long> vmIds, Long batchSize);
 }
