@@ -21,7 +21,8 @@ import java.util.List;
 
 import javax.inject.Inject;
 
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 
 import org.apache.cloudstack.context.CallContext;
 import org.apache.cloudstack.engine.cloud.entity.api.db.VMNetworkMapVO;
@@ -107,7 +108,7 @@ import com.cloud.vm.dao.NicSecondaryIpDao;
 import com.cloud.vm.dao.UserVmDao;
 
 public class NetworkMigrationManagerImpl implements NetworkMigrationManager {
-    public static final Logger s_logger = Logger.getLogger(NetworkMigrationManagerImpl.class.getName());
+    protected Logger logger = LogManager.getLogger(getClass());
 
     @Inject
     private DataCenterDao _dcDao = null;
@@ -181,8 +182,8 @@ public class NetworkMigrationManagerImpl implements NetworkMigrationManager {
     private ResourceTagDao _resourceTagDao = null;
 
     @Override public long makeCopyOfNetwork(Network network, NetworkOffering networkOffering, Long vpcId) {
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Making a copy of network with uuid " + network.getUuid() + " and id " + network.getId() + " for migration.");
+        if (logger.isDebugEnabled()) {
+            logger.debug("Making a copy of network with uuid " + network.getUuid() + " and id " + network.getId() + " for migration.");
         }
         long originalNetworkId = network.getId();
         NetworkDomainVO domainNetworkMapByNetworkId = _networkDomainDao.getDomainNetworkMapByNetworkId(originalNetworkId);
@@ -238,8 +239,8 @@ public class NetworkMigrationManagerImpl implements NetworkMigrationManager {
         assignUserNicsToNewNetwork(originalNetworkId, networkCopyId);
         assignRouterNicsToNewNetwork(network.getId(), networkCopyId);
 
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Successfully created a copy of network  " + originalNetwork.getName() + "(" + originalNetwork.getUuid() + ") id is " + originalNetwork.getId() + " for migration. The network copy has uuid " + network.getUuid() + " and id " + network.getId());
+        if (logger.isDebugEnabled()) {
+            logger.debug("Successfully created a copy of network  " + originalNetwork.getName() + "(" + originalNetwork.getUuid() + ") id is " + originalNetwork.getId() + " for migration. The network copy has uuid " + network.getUuid() + " and id " + network.getId());
         }
         return networkCopyId;
     }
@@ -285,8 +286,8 @@ public class NetworkMigrationManagerImpl implements NetworkMigrationManager {
     @Override
     public Long makeCopyOfVpc(long vpcId, long vpcOfferingId) {
         VpcVO vpc = _vpcDao.findById(vpcId);
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Making a copy of vpc with uuid " + vpc.getUuid() + " and id " + vpc.getId() + " for migration.");
+        if (logger.isDebugEnabled()) {
+            logger.debug("Making a copy of vpc with uuid " + vpc.getUuid() + " and id " + vpc.getId() + " for migration.");
         }
         if (vpc == null) {
             InvalidParameterValueException ex = new InvalidParameterValueException("Specified vpc id doesn't exist in the system");
@@ -300,7 +301,7 @@ public class NetworkMigrationManagerImpl implements NetworkMigrationManager {
 
             copyOfVpc = _vpcService.createVpc(vpc.getZoneId(), vpcOfferingId, vpc.getAccountId(), vpc.getName(),
                     vpc.getDisplayText(), vpc.getCidr(), vpc.getNetworkDomain(), vpc.getIp4Dns1(), vpc.getIp4Dns2(),
-                    vpc.getIp6Dns1(), vpc.getIp6Dns2(), vpc.isDisplay(), vpc.getPublicMtu());
+                    vpc.getIp6Dns1(), vpc.getIp6Dns2(), vpc.isDisplay(), vpc.getPublicMtu(), null, null, null);
 
             copyOfVpcId = copyOfVpc.getId();
             //on resume of migration the uuid will be swapped already. So the copy will have the value of the original vpcid.
@@ -313,8 +314,8 @@ public class NetworkMigrationManagerImpl implements NetworkMigrationManager {
             copyVpcDetails(vpcId, copyOfVpcId);
             reassignGatewayToNewVpc(vpcId, copyOfVpcId);
             copyVpcResourceTagsToNewVpc(vpcId, copyOfVpcId);
-            if (s_logger.isDebugEnabled()) {
-                s_logger.debug("Successfully created a copy of network  " + vpc.getName() + "(" + vpc.getUuid() + ") id is " + vpc.getId() + " for migration. The network copy has uuid " + copyVpcVO.getUuid() + " and id " + copyOfVpc.getId());
+            if (logger.isDebugEnabled()) {
+                logger.debug("Successfully created a copy of network  " + vpc.getName() + "(" + vpc.getUuid() + ") id is " + vpc.getId() + " for migration. The network copy has uuid " + copyVpcVO.getUuid() + " and id " + copyOfVpc.getId());
             }
         } catch (ResourceAllocationException e) {
             throw new CloudRuntimeException(e.getMessage());
@@ -329,7 +330,7 @@ public class NetworkMigrationManagerImpl implements NetworkMigrationManager {
             try {
                 _vpcService.startVpc(vpc.getId(), true);
             } catch (ResourceUnavailableException | InsufficientCapacityException e) {
-                s_logger.error("Vpc can not be started. Aborting migration process");
+                logger.error("Vpc can not be started. Aborting migration process");
                 throw new CloudRuntimeException("Vpc can not be started.", e);
             }
         }
@@ -395,8 +396,8 @@ public class NetworkMigrationManagerImpl implements NetworkMigrationManager {
     private void copyFirewallRulesToNewNetwork(Network srcNetwork, long dstNetworkId) {
         List<FirewallRuleVO> firewallRules = _firewallDao.listByNetworkPurposeTrafficType(srcNetwork.getId(), FirewallRule.Purpose.Firewall, FirewallRule.TrafficType.Egress);
         firewallRules.addAll(_firewallDao.listByNetworkPurposeTrafficType(srcNetwork.getId(), FirewallRule.Purpose.Firewall, FirewallRule.TrafficType.Ingress));
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Copying firewall rules from network with id " + srcNetwork.getId() + " to network with id " + dstNetworkId);
+        if (logger.isDebugEnabled()) {
+            logger.debug("Copying firewall rules from network with id " + srcNetwork.getId() + " to network with id " + dstNetworkId);
         }
 
         //Loop over all the firewall rules in the original network and copy all values to a new firewall rule
@@ -450,7 +451,7 @@ public class NetworkMigrationManagerImpl implements NetworkMigrationManager {
 
     @Override
     public Network upgradeNetworkToNewNetworkOffering(long networkId, long newPhysicalNetworkId, long networkOfferingId, Long vpcId) {
-        s_logger.debug("upgrading network to network with new offering.");
+        logger.debug("upgrading network to network with new offering.");
         NetworkVO network = _networksDao.findById(networkId);
         NetworkOffering newOffering = _networkOfferingDao.findByIdIncludingRemoved(networkOfferingId);
         long gurusImplementing = 0;
@@ -459,7 +460,7 @@ public class NetworkMigrationManagerImpl implements NetworkMigrationManager {
         DataCenterDeployment plan = new DataCenterDeployment(network.getDataCenterId(), null, null, null, null, newPhysicalNetworkId);
         for (final NetworkGuru guru : _networkMgr.getNetworkGurus()) {
 
-            final Network designedNetwork = guru.design(newOffering, plan, network, networkAccount);
+            final Network designedNetwork = guru.design(newOffering, plan, network, network.getName(), vpcId, networkAccount);
             if (designedNetwork == null) {
                 continue;
             }
@@ -492,7 +493,7 @@ public class NetworkMigrationManagerImpl implements NetworkMigrationManager {
 
         NicVO userNic = _nicDao.findByNetworkIdAndType(networkCopyId, VirtualMachine.Type.User);
         if (userNic != null) {
-            s_logger.error("Something went wrong while migrating nics from the old network to the new network. Failed to delete copy of network. There are still user nics present in the network.");
+            logger.error("Something went wrong while migrating nics from the old network to the new network. Failed to delete copy of network. There are still user nics present in the network.");
             throw new CloudRuntimeException("Failed to delete copy of network. There are still user nics present in the network.");
         }
 
@@ -530,7 +531,7 @@ public class NetworkMigrationManagerImpl implements NetworkMigrationManager {
     }
 
     private Boolean migrateNicsInDB(NicVO originalNic, Network networkInNewPhysicalNet, DataCenter dc, ReservationContext context) {
-        s_logger.debug("migrating nics in database.");
+        logger.debug("migrating nics in database.");
         UserVmVO vmVO = _vmDao.findById(originalNic.getInstanceId());
         VirtualMachineProfile vmProfile = new VirtualMachineProfileImpl(vmVO, null, null, null, null);
         NicProfile nicProfile = new NicProfile(originalNic, networkInNewPhysicalNet, null, null, null, _networkModel.isSecurityGroupSupportedInNetwork(networkInNewPhysicalNet), null);
@@ -569,8 +570,8 @@ public class NetworkMigrationManagerImpl implements NetworkMigrationManager {
         markAsNonDefault(originalNic);
         _networkMgr.removeNic(vmProfile, originalNic);
 
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Nic is migrated successfully for vm " + vmVO + " to " + networkInNewPhysicalNet);
+        if (logger.isDebugEnabled()) {
+            logger.debug("Nic is migrated successfully for vm " + vmVO + " to " + networkInNewPhysicalNet);
         }
         return true;
     }
