@@ -16,6 +16,7 @@
 // under the License.
 package com.cloud.network.element;
 
+import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.List;
@@ -24,6 +25,7 @@ import java.util.Set;
 
 import javax.inject.Inject;
 
+import org.apache.cloudstack.engine.orchestration.service.NetworkOrchestrationService;
 import org.apache.cloudstack.engine.subsystem.api.storage.DataStore;
 import org.apache.cloudstack.engine.subsystem.api.storage.DataStoreManager;
 import org.apache.cloudstack.engine.subsystem.api.storage.EndPoint;
@@ -34,7 +36,6 @@ import org.apache.cloudstack.storage.datastore.db.ImageStoreDao;
 import org.apache.cloudstack.storage.to.TemplateObjectTO;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.collections.MapUtils;
-import org.apache.log4j.Logger;
 
 import com.cloud.agent.AgentManager;
 import com.cloud.agent.api.HandleConfigDriveIsoAnswer;
@@ -91,9 +92,9 @@ import com.cloud.vm.VmDetailConstants;
 import com.cloud.vm.dao.UserVmDao;
 import com.cloud.vm.dao.UserVmDetailsDao;
 
-public class ConfigDriveNetworkElement extends AdapterBase implements NetworkElement, UserDataServiceProvider,
+public class ConfigDriveNetworkElement extends AdapterBase implements NetworkElement,
+        UserDataServiceProvider, DhcpServiceProvider, DnsServiceProvider,
         StateListener<VirtualMachine.State, VirtualMachine.Event, VirtualMachine>, NetworkMigrationResponder {
-    private static final Logger LOG = Logger.getLogger(ConfigDriveNetworkElement.class);
 
     private static final Map<Service, Map<Capability, String>> capabilities = setCapabilities();
 
@@ -112,6 +113,8 @@ public class ConfigDriveNetworkElement extends AdapterBase implements NetworkEle
     @Inject
     NetworkModel _networkModel;
     @Inject
+    NetworkOrchestrationService _networkOrchestrationService;
+    @Inject
     GuestOSCategoryDao _guestOSCategoryDao;
     @Inject
     GuestOSDao _guestOSDao;
@@ -171,7 +174,7 @@ public class ConfigDriveNetworkElement extends AdapterBase implements NetworkEle
         try {
             return deleteConfigDriveIso(vm.getVirtualMachine());
         } catch (ResourceUnavailableException e) {
-            LOG.error("Failed to delete config drive due to: ", e);
+            logger.error("Failed to delete config drive due to: ", e);
             return false;
         }
     }
@@ -199,6 +202,8 @@ public class ConfigDriveNetworkElement extends AdapterBase implements NetworkEle
     private static Map<Service, Map<Capability, String>> setCapabilities() {
         Map<Service, Map<Capability, String>> capabilities = new HashMap<>();
         capabilities.put(Service.UserData, null);
+        capabilities.put(Service.Dhcp, new HashMap<>());
+        capabilities.put(Service.Dns, new HashMap<>());
         return capabilities;
     }
 
@@ -226,8 +231,7 @@ public class ConfigDriveNetworkElement extends AdapterBase implements NetworkEle
     public boolean addPasswordAndUserdata(Network network, NicProfile nic, VirtualMachineProfile profile, DeployDestination dest, ReservationContext context)
             throws ConcurrentOperationException, InsufficientCapacityException, ResourceUnavailableException {
         return (canHandle(network.getTrafficType())
-                && configureConfigDriveData(profile, nic, dest))
-                && createConfigDriveIso(profile, dest, null);
+                && configureConfigDriveData(profile, nic, dest));
     }
 
     @Override
@@ -268,7 +272,7 @@ public class ConfigDriveNetworkElement extends AdapterBase implements NetworkEle
             try {
                 recreateConfigDriveIso(nic, network, vm, dest);
             } catch (ResourceUnavailableException e) {
-                LOG.error("Failed to add config disk drive due to: ", e);
+                logger.error("Failed to add config disk drive due to: ", e);
                 return false;
             }
         }
@@ -320,16 +324,12 @@ public class ConfigDriveNetworkElement extends AdapterBase implements NetworkEle
             try {
                 final Network network = _networkMgr.getNetwork(nic.getNetworkId());
                 final UserDataServiceProvider userDataUpdateProvider = _networkModel.getUserDataUpdateProvider(network);
-                if (userDataUpdateProvider == null) {
-                    LOG.warn("Failed to get user data provider");
-                    return false;
-                }
                 final Provider provider = userDataUpdateProvider.getProvider();
-                if (Provider.ConfigDrive.equals(provider)) {
+                if (provider.equals(Provider.ConfigDrive)) {
                     try {
                         return deleteConfigDriveIso(vm);
                     } catch (ResourceUnavailableException e) {
-                        LOG.error("Failed to delete config drive due to: ", e);
+                        logger.error("Failed to delete config drive due to: ", e);
                         return false;
                     }
                 }
@@ -340,26 +340,24 @@ public class ConfigDriveNetworkElement extends AdapterBase implements NetworkEle
 
     @Override
     public boolean prepareMigration(NicProfile nic, Network network, VirtualMachineProfile vm, DeployDestination dest, ReservationContext context) {
-        final UserDataServiceProvider userDataUpdateProvider = _networkModel.getUserDataUpdateProvider(network);
-        if (userDataUpdateProvider == null) {
-            LOG.warn("Failed to prepare for migration, can't get user data provider");
-            return false;
-        }
-        if (Provider.ConfigDrive.equals(userDataUpdateProvider.getProvider())) {
-            LOG.trace(String.format("[prepareMigration] for vm: %s", vm.getInstanceName()));
+        if (_networkModel.getUserDataUpdateProvider(network).getProvider().equals(Provider.ConfigDrive)) {
+            logger.trace(String.format("[prepareMigration] for vm: %s", vm.getInstanceName()));
             try {
                 if (isConfigDriveIsoOnHostCache(vm.getId())) {
                     vm.setConfigDriveLocation(Location.HOST);
-                    if (configureConfigDriveData(vm, nic, dest)) {
-                        // Create the config drive on dest host cache
-                        createConfigDriveIsoOnHostCache(vm, dest.getHost().getId());
-                    }
+                    configureConfigDriveData(vm, nic, dest);
+
+                    // Create the config drive on dest host cache
+                    createConfigDriveIsoOnHostCache(nic, vm, dest.getHost().getId());
                 } else {
                     vm.setConfigDriveLocation(getConfigDriveLocation(vm.getId()));
-                    addPasswordAndUserdata(network, nic, vm, dest, context);
+                    boolean result = addPasswordAndUserdata(network, nic, vm, dest, context);
+                    if (result) {
+                        createConfigDriveIso(nic, vm, dest, null);
+                    }
                 }
             } catch (InsufficientCapacityException | ResourceUnavailableException e) {
-                LOG.error("Failed to add config disk drive due to: ", e);
+                logger.error("Failed to add config disk drive due to: ", e);
                 return false;
             }
         }
@@ -375,29 +373,25 @@ public class ConfigDriveNetworkElement extends AdapterBase implements NetworkEle
                 deleteConfigDriveIsoOnHostCache(vm.getVirtualMachine(), vm.getHostId());
             }
         } catch (ConcurrentOperationException | ResourceUnavailableException e) {
-            LOG.error("rollbackMigration failed.", e);
+            logger.error("rollbackMigration failed.", e);
         }
     }
 
     @Override
     public void commitMigration(NicProfile nic, Network network, VirtualMachineProfile vm, ReservationContext src, ReservationContext dst) {
         try {
-            if (isLastConfigDriveIsoOnHostCache(vm.getId())) {
+            if (isConfigDriveIsoOnHostCache(vm.getId())) {
                 vm.setConfigDriveLocation(Location.HOST);
                 // Delete the config drive on src host cache
                 deleteConfigDriveIsoOnHostCache(vm.getVirtualMachine(), vm.getHostId());
             }
         } catch (ConcurrentOperationException | ResourceUnavailableException e) {
-            LOG.error("commitMigration failed.", e);
+            logger.error("commitMigration failed.", e);
         }
     }
 
     private void recreateConfigDriveIso(NicProfile nic, Network network, VirtualMachineProfile vm, DeployDestination dest) throws ResourceUnavailableException {
-        final UserDataServiceProvider userDataUpdateProvider = _networkModel.getUserDataUpdateProvider(network);
-        if (userDataUpdateProvider == null) {
-            return;
-        }
-        if (nic.isDefaultNic() && Provider.ConfigDrive.equals(userDataUpdateProvider.getProvider())) {
+        if (nic.isDefaultNic() && _networkModel.getUserDataUpdateProvider(network).getProvider().equals(Provider.ConfigDrive)) {
             DiskTO diskToUse = null;
             for (DiskTO disk : vm.getDisks()) {
                 if (disk.getType() == Volume.Type.ISO && disk.getPath() != null && disk.getPath().contains("configdrive")) {
@@ -413,7 +407,7 @@ public class ConfigDriveNetworkElement extends AdapterBase implements NetworkEle
                         vm.getUuid(), nic.getMacAddress(), userVm.getDetail("SSH.PublicKey"), (String) vm.getParameter(VirtualMachineProfile.Param.VmPassword), isWindows, VirtualMachineManager.getHypervisorHostname(dest.getHost() != null ? dest.getHost().getName() : ""));
                 vm.setVmData(vmData);
                 vm.setConfigDriveLabel(VirtualMachineManager.VmConfigDriveLabel.value());
-                createConfigDriveIso(vm, dest, diskToUse);
+                createConfigDriveIso(nic, vm, dest, diskToUse);
             }
         }
     }
@@ -543,30 +537,21 @@ public class ConfigDriveNetworkElement extends AdapterBase implements NetworkEle
         return false;
     }
 
-    private boolean isLastConfigDriveIsoOnHostCache(long vmId) {
-        final UserVmDetailVO vmDetailLastConfigDriveLocation = _userVmDetailsDao.findDetail(vmId, VmDetailConstants.LAST_CONFIG_DRIVE_LOCATION);
-        if (vmDetailLastConfigDriveLocation == null) {
-            return isConfigDriveIsoOnHostCache(vmId);
-        }
-        if (Location.HOST.toString().equalsIgnoreCase(vmDetailLastConfigDriveLocation.getValue())) {
-            return true;
-        }
-        return false;
-    }
-
-    private boolean createConfigDriveIsoOnHostCache(VirtualMachineProfile profile, Long hostId) throws ResourceUnavailableException {
+    private boolean createConfigDriveIsoOnHostCache(NicProfile nic, VirtualMachineProfile profile, Long hostId) throws ResourceUnavailableException {
         if (hostId == null) {
             throw new ResourceUnavailableException("Config drive iso creation failed, dest host not available",
                     ConfigDriveNetworkElement.class, 0L);
         }
 
-        LOG.debug("Creating config drive ISO for vm: " + profile.getInstanceName() + " on host: " + hostId);
+        logger.debug("Creating config drive ISO for vm: " + profile.getInstanceName() + " on host: " + hostId);
 
         Map<String, String> customUserdataParamMap = getVMCustomUserdataParamMap(profile.getId());
 
         final String isoFileName = ConfigDrive.configIsoFileName(profile.getInstanceName());
         final String isoPath = ConfigDrive.createConfigDrivePath(profile.getInstanceName());
-        final String isoData = ConfigDriveBuilder.buildConfigDrive(profile.getVmData(), isoFileName, profile.getConfigDriveLabel(), customUserdataParamMap);
+        List<NicProfile> nicProfiles = _networkOrchestrationService.getNicProfiles(nic.getVirtualMachineId(), profile.getHypervisorType());
+        final Map<Long, List<Service>> supportedServices = getSupportedServicesByElementForNetwork(nicProfiles);
+        final String isoData = ConfigDriveBuilder.buildConfigDrive(nicProfiles, profile.getVmData(), isoFileName, profile.getConfigDriveLabel(), customUserdataParamMap, supportedServices);
         final HandleConfigDriveIsoCommand configDriveIsoCommand = new HandleConfigDriveIsoCommand(isoPath, isoData, null, false, true, true);
 
         final HandleConfigDriveIsoAnswer answer = (HandleConfigDriveIsoAnswer) agentManager.easySend(hostId, configDriveIsoCommand);
@@ -580,7 +565,7 @@ public class ConfigDriveNetworkElement extends AdapterBase implements NetworkEle
         }
 
         profile.setConfigDriveLocation(answer.getConfigDriveLocation());
-        updateConfigDriveLocationInVMDetails(profile.getId(), answer.getConfigDriveLocation());
+        _userVmDetailsDao.addDetail(profile.getId(), VmDetailConstants.CONFIG_DRIVE_LOCATION, answer.getConfigDriveLocation().toString(), false);
         addConfigDriveDisk(profile, null);
         return true;
     }
@@ -591,16 +576,16 @@ public class ConfigDriveNetworkElement extends AdapterBase implements NetworkEle
                     ConfigDriveNetworkElement.class, 0L);
         }
 
-        LOG.debug("Deleting config drive ISO for vm: " + vm.getInstanceName() + " on host: " + hostId);
+        logger.debug("Deleting config drive ISO for vm: " + vm.getInstanceName() + " on host: " + hostId);
         final String isoPath = ConfigDrive.createConfigDrivePath(vm.getInstanceName());
         final HandleConfigDriveIsoCommand configDriveIsoCommand = new HandleConfigDriveIsoCommand(isoPath, null, null, false, true, false);
         HostVO hostVO = _hostDao.findById(hostId);
         if (hostVO == null) {
-            LOG.warn(String.format("Host %s appears to be unavailable, skipping deletion of config-drive ISO on host cache", hostId));
+            logger.warn(String.format("Host %s appears to be unavailable, skipping deletion of config-drive ISO on host cache", hostId));
             return false;
         }
         if (!Arrays.asList(Status.Up, Status.Connecting).contains(hostVO.getStatus())) {
-            LOG.warn(String.format("Host status %s is not Up or Connecting, skipping deletion of config-drive ISO on host cache", hostId));
+            logger.warn(String.format("Host status %s is not Up or Connecting, skipping deletion of config-drive ISO on host cache", hostId));
             return false;
         }
 
@@ -610,13 +595,33 @@ public class ConfigDriveNetworkElement extends AdapterBase implements NetworkEle
         }
 
         if (!answer.getResult()) {
-            LOG.error("Failed to remove config drive for instance: " + vm.getInstanceName());
+            logger.error("Failed to remove config drive for instance: " + vm.getInstanceName());
             return false;
         }
         return true;
     }
 
-    private boolean createConfigDriveIso(VirtualMachineProfile profile, DeployDestination dest, DiskTO disk) throws ResourceUnavailableException {
+    private Map<Long, List<Network.Service>> getSupportedServicesByElementForNetwork(List<NicProfile> nics) {
+
+        Map<Long, List<Network.Service>> supportedServices = new HashMap<>();
+        for (NicProfile nic: nics) {
+            ArrayList<Network.Service> serviceList = new ArrayList<>();
+            if (_networkModel.isProviderSupportServiceInNetwork(nic.getNetworkId(), Service.Dns, getProvider())) {
+                serviceList.add(Service.Dns);
+            }
+            if (_networkModel.isProviderSupportServiceInNetwork(nic.getNetworkId(), Service.UserData, getProvider())) {
+                serviceList.add(Service.UserData);
+            }
+            if (_networkModel.isProviderSupportServiceInNetwork(nic.getNetworkId(), Service.Dhcp, getProvider())) {
+                serviceList.add(Service.Dhcp);
+            }
+            supportedServices.put(nic.getId(), serviceList);
+        }
+
+        return supportedServices;
+    }
+
+    public boolean createConfigDriveIso(NicProfile nic, VirtualMachineProfile profile, DeployDestination dest, DiskTO disk) throws ResourceUnavailableException {
         DataStore dataStore = getDatastoreForConfigDriveIso(disk, profile, dest);
 
         final Long agentId = findAgentId(profile, dest, dataStore);
@@ -625,13 +630,16 @@ public class ConfigDriveNetworkElement extends AdapterBase implements NetworkEle
                     ConfigDriveNetworkElement.class, 0L);
         }
 
-        LOG.debug("Creating config drive ISO for vm: " + profile.getInstanceName());
+        logger.debug("Creating config drive ISO for vm: " + profile.getInstanceName());
 
         Map<String, String> customUserdataParamMap = getVMCustomUserdataParamMap(profile.getId());
 
         final String isoFileName = ConfigDrive.configIsoFileName(profile.getInstanceName());
         final String isoPath = ConfigDrive.createConfigDrivePath(profile.getInstanceName());
-        final String isoData = ConfigDriveBuilder.buildConfigDrive(profile.getVmData(), isoFileName, profile.getConfigDriveLabel(), customUserdataParamMap);
+        List<NicProfile> nicProfiles = _networkOrchestrationService.getNicProfiles(nic.getVirtualMachineId(), profile.getHypervisorType());
+        final Map<Long, List<Service>> supportedServices = getSupportedServicesByElementForNetwork(nicProfiles);
+        final String isoData = ConfigDriveBuilder.buildConfigDrive(
+                nicProfiles, profile.getVmData(), isoFileName, profile.getConfigDriveLabel(), customUserdataParamMap, supportedServices);
         boolean useHostCacheOnUnsupportedPool = VirtualMachineManager.VmConfigDriveUseHostCacheOnUnsupportedPool.valueIn(dest.getDataCenter().getId());
         boolean preferHostCache = VirtualMachineManager.VmConfigDriveForceHostCacheUse.valueIn(dest.getDataCenter().getId());
         final HandleConfigDriveIsoCommand configDriveIsoCommand = new HandleConfigDriveIsoCommand(isoPath, isoData, dataStore.getTO(), useHostCacheOnUnsupportedPool, preferHostCache, true);
@@ -642,23 +650,11 @@ public class ConfigDriveNetworkElement extends AdapterBase implements NetworkEle
                     answer.getDetails()), ConfigDriveNetworkElement.class, 0L);
         }
         profile.setConfigDriveLocation(answer.getConfigDriveLocation());
-        updateConfigDriveLocationInVMDetails(profile.getId(), answer.getConfigDriveLocation());
+        _userVmDetailsDao.addDetail(profile.getId(), VmDetailConstants.CONFIG_DRIVE_LOCATION, answer.getConfigDriveLocation().toString(), false);
         addConfigDriveDisk(profile, dataStore);
         return true;
     }
 
-    private void updateConfigDriveLocationInVMDetails(long vmId, NetworkElement.Location configDriveLocation) {
-        final UserVmDetailVO vmDetailConfigDriveLocation = _userVmDetailsDao.findDetail(vmId, VmDetailConstants.CONFIG_DRIVE_LOCATION);
-        if (vmDetailConfigDriveLocation != null) {
-            if (!configDriveLocation.toString().equalsIgnoreCase(vmDetailConfigDriveLocation.getValue())) {
-                _userVmDetailsDao.addDetail(vmId, VmDetailConstants.LAST_CONFIG_DRIVE_LOCATION, vmDetailConfigDriveLocation.getValue(), false);
-            } else {
-                _userVmDetailsDao.removeDetail(vmId, VmDetailConstants.LAST_CONFIG_DRIVE_LOCATION);
-            }
-        }
-        _userVmDetailsDao.addDetail(vmId, VmDetailConstants.CONFIG_DRIVE_LOCATION, configDriveLocation.toString(), false);
-    }
-
     private Map<String, String> getVMCustomUserdataParamMap(long vmId) {
         UserVmVO userVm = _userVmDao.findById(vmId);
         String userDataDetails = userVm.getUserDataDetails();
@@ -702,7 +698,7 @@ public class ConfigDriveNetworkElement extends AdapterBase implements NetworkEle
         Long hostId  = (vm.getHostId() != null) ? vm.getHostId() : vm.getLastHostId();
         Location location = getConfigDriveLocation(vm.getId());
         if (hostId == null) {
-            LOG.info(String.format("The VM was never booted; no config-drive ISO created for VM %s", vm.getName()));
+            logger.info(String.format("The VM was never booted; no config-drive ISO created for VM %s", vm.getName()));
             return true;
         }
         if (location == Location.HOST) {
@@ -730,14 +726,14 @@ public class ConfigDriveNetworkElement extends AdapterBase implements NetworkEle
                     ConfigDriveNetworkElement.class, 0L);
         }
 
-        LOG.debug("Deleting config drive ISO for vm: " + vm.getInstanceName());
+        logger.debug("Deleting config drive ISO for vm: " + vm.getInstanceName());
 
         final String isoPath = ConfigDrive.createConfigDrivePath(vm.getInstanceName());
         final HandleConfigDriveIsoCommand configDriveIsoCommand = new HandleConfigDriveIsoCommand(isoPath, null, dataStore.getTO(), false, false, false);
 
         final HandleConfigDriveIsoAnswer answer = (HandleConfigDriveIsoAnswer) agentManager.easySend(agentId, configDriveIsoCommand);
         if (!answer.getResult()) {
-            LOG.error("Failed to remove config drive for instance: " + vm.getInstanceName());
+            logger.error("Failed to remove config drive for instance: " + vm.getInstanceName());
             return false;
         }
         return true;
@@ -767,13 +763,13 @@ public class ConfigDriveNetworkElement extends AdapterBase implements NetworkEle
 
             profile.addDisk(new DiskTO(dataTO, CONFIGDRIVEDISKSEQ.longValue(), isoPath, Volume.Type.ISO));
         } else {
-            LOG.warn("Config drive iso already is in VM profile.");
+            logger.warn("Config drive iso already is in VM profile.");
         }
     }
 
     private boolean configureConfigDriveData(final VirtualMachineProfile profile, final NicProfile nic, final DeployDestination dest) {
         final UserVmVO vm = _userVmDao.findById(profile.getId());
-        if (vm == null || vm.getType() != VirtualMachine.Type.User) {
+        if (vm.getType() != VirtualMachine.Type.User) {
             return false;
         }
         final Nic defaultNic = _networkModel.getDefaultNic(vm.getId());
@@ -796,4 +792,52 @@ public class ConfigDriveNetworkElement extends AdapterBase implements NetworkEle
         return true;
     }
 
+    @Override
+    public boolean addDhcpEntry(Network network, NicProfile nic, VirtualMachineProfile vm, DeployDestination dest,
+            ReservationContext context) throws ConcurrentOperationException, InsufficientCapacityException, ResourceUnavailableException {
+        // Update nic profile with required information.
+        // Add network checks
+        return true;
+    }
+
+    @Override
+    public boolean configDhcpSupportForSubnet(Network network, NicProfile nic, VirtualMachineProfile vm,
+            DeployDestination dest,
+            ReservationContext context) throws ConcurrentOperationException, InsufficientCapacityException, ResourceUnavailableException {
+        return false;
+    }
+
+    @Override
+    public boolean removeDhcpSupportForSubnet(Network network) throws ResourceUnavailableException {
+        return true;
+    }
+
+    @Override
+    public boolean setExtraDhcpOptions(Network network, long nicId, Map<Integer, String> dhcpOptions) {
+        return false;
+    }
+
+    @Override
+    public boolean removeDhcpEntry(Network network, NicProfile nic,
+            VirtualMachineProfile vmProfile) throws ResourceUnavailableException {
+        return true;
+    }
+
+    @Override
+    public boolean addDnsEntry(Network network, NicProfile nic, VirtualMachineProfile vm, DeployDestination dest,
+            ReservationContext context) throws ConcurrentOperationException, InsufficientCapacityException, ResourceUnavailableException {
+        return true;
+    }
+
+    @Override
+    public boolean configDnsSupportForSubnet(Network network, NicProfile nic, VirtualMachineProfile vm,
+            DeployDestination dest,
+            ReservationContext context) throws ConcurrentOperationException, InsufficientCapacityException, ResourceUnavailableException {
+        return true;
+    }
+
+    @Override
+    public boolean removeDnsSupportForSubnet(Network network) throws ResourceUnavailableException {
+        return true;
+    }
 }
