@@ -76,13 +76,11 @@ import org.apache.cloudstack.network.router.deployment.RouterDeploymentDefinitio
 import org.apache.cloudstack.network.router.deployment.RouterDeploymentDefinitionBuilder;
 import org.apache.cloudstack.network.topology.NetworkTopology;
 import org.apache.commons.collections.CollectionUtils;
-import org.apache.log4j.Logger;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.beans.factory.annotation.Qualifier;
 
 public class VpcVirtualRouterElement extends VirtualRouterElement implements VpcProvider, Site2SiteVpnServiceProvider, NetworkACLServiceProvider {
 
-    private static final Logger s_logger = Logger.getLogger(VpcVirtualRouterElement.class);
 
     private static final Map<Service, Map<Capability, String>> capabilities = setCapabilities();
 
@@ -134,12 +132,12 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
 
         if (service == null) {
             if (!_networkMdl.isProviderForNetwork(getProvider(), network.getId())) {
-                s_logger.trace("Element " + getProvider().getName() + " is not a provider for the network " + network);
+                logger.trace("Element " + getProvider().getName() + " is not a provider for the network " + network);
                 return false;
             }
         } else {
             if (!_networkMdl.isProviderSupportServiceInNetwork(network.getId(), service, getProvider())) {
-                s_logger.trace("Element " + getProvider().getName() + " doesn't support service " + service.getName() + " in the network " + network);
+                logger.trace("Element " + getProvider().getName() + " doesn't support service " + service.getName() + " in the network " + network);
                 return false;
             }
         }
@@ -151,7 +149,7 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
     public boolean implementVpc(final Vpc vpc, final DeployDestination dest, final ReservationContext context) throws ConcurrentOperationException, ResourceUnavailableException,
     InsufficientCapacityException {
 
-        final Map<VirtualMachineProfile.Param, Object> params = new HashMap<VirtualMachineProfile.Param, Object>(1);
+        final Map<VirtualMachineProfile.Param, Object> params = new HashMap<>(1);
         params.put(VirtualMachineProfile.Param.ReProgramGuestNetworks, true);
 
         if (vpc.isRollingRestart()) {
@@ -186,17 +184,17 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
 
         final Long vpcId = network.getVpcId();
         if (vpcId == null) {
-            s_logger.trace("Network " + network + " is not associated with any VPC");
+            logger.trace("Network " + network + " is not associated with any VPC");
             return false;
         }
 
         final Vpc vpc = _vpcMgr.getActiveVpc(vpcId);
         if (vpc == null) {
-            s_logger.warn("Unable to find Enabled VPC by id " + vpcId);
+            logger.warn("Unable to find Enabled VPC by id " + vpcId);
             return false;
         }
 
-        final Map<VirtualMachineProfile.Param, Object> params = new HashMap<VirtualMachineProfile.Param, Object>(1);
+        final Map<VirtualMachineProfile.Param, Object> params = new HashMap<>(1);
         params.put(VirtualMachineProfile.Param.ReProgramGuestNetworks, true);
 
         if (network.isRollingRestart()) {
@@ -226,15 +224,15 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
     protected boolean configureGuestNetworkForRouter(final Network network,
             final DomainRouterVO router) throws ConcurrentOperationException, InsufficientCapacityException, ResourceUnavailableException {
         if (!_networkMdl.isVmPartOfNetwork(router.getId(), network.getId())) {
-            final Map<VirtualMachineProfile.Param, Object> paramsForRouter = new HashMap<VirtualMachineProfile.Param, Object>(1);
+            final Map<VirtualMachineProfile.Param, Object> paramsForRouter = new HashMap<>(1);
             if (network.getState() == State.Setup) {
                 paramsForRouter.put(VirtualMachineProfile.Param.ReProgramGuestNetworks, true);
             }
             if (!_vpcRouterMgr.addVpcRouterToGuestNetwork(router, network, paramsForRouter)) {
-                s_logger.error("Failed to add VPC router " + router + " to guest network " + network);
+                logger.error("Failed to add VPC router {} to guest network {}", router, network);
                 return false;
             } else {
-                s_logger.debug("Successfully added VPC router " + router + " to guest network " + network);
+                logger.debug("Successfully added VPC router {} to guest network {}", router, network);
                 return true;
             }
         }
@@ -243,7 +241,8 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
 
     protected void configureGuestNetwork(final Network network, final List<DomainRouterVO> routers)
             throws ConcurrentOperationException, InsufficientCapacityException, ResourceUnavailableException {
-        s_logger.info("Adding VPC routers to Guest Network: " + routers.size() + " to be added!");
+
+        logger.info("Adding VPC routers to Guest Network: {} to be added!", routers.size());
 
         List<DomainRouterVO> backupRouters = new ArrayList<>();
         List<DomainRouterVO> remainingRouters = new ArrayList<>();
@@ -260,9 +259,9 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
         for (final DomainRouterVO router : backupRouters) {
             if (network.getState() != State.Setup) {
                 if (!_vpcRouterMgr.stopKeepAlivedOnRouter(router, network)) {
-                    s_logger.error("Failed to stop keepalived on VPC router " + router + " to guest network " + network);
+                    logger.error("Failed to stop keepalived on VPC router {} to guest network {}", router, network);
                 } else {
-                    s_logger.debug("Successfully stopped keepalived on VPC router " + router + " to guest network " + network);
+                    logger.debug("Successfully stopped keepalived on VPC router {} to guest network {}", router, network);
                 }
             }
         }
@@ -271,7 +270,7 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
         }
         for (final DomainRouterVO router : backupRouters) {
             if (!configureGuestNetworkForRouter(network, router) && !_vpcRouterMgr.startKeepAlivedOnRouter(router, network)) {
-                s_logger.error("Failed to start keepalived on VPC router " + router + " to guest network " + network);
+                logger.error("Failed to start keepalived on VPC router {} to guest network {}", router, network);
             }
         }
     }
@@ -282,18 +281,18 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
 
         final Long vpcId = network.getVpcId();
         if (vpcId == null) {
-            s_logger.trace("Network " + network + " is not associated with any VPC");
+            logger.trace("Network " + network + " is not associated with any VPC");
             return false;
         }
 
         final Vpc vpc = _vpcMgr.getActiveVpc(vpcId);
         if (vpc == null) {
-            s_logger.warn("Unable to find Enabled VPC by id " + vpcId);
+            logger.warn("Unable to find Enabled VPC by id " + vpcId);
             return false;
         }
 
         if (vm.getType() == VirtualMachine.Type.User) {
-            final Map<VirtualMachineProfile.Param, Object> params = new HashMap<VirtualMachineProfile.Param, Object>(1);
+            final Map<VirtualMachineProfile.Param, Object> params = new HashMap<>(1);
             params.put(VirtualMachineProfile.Param.ReProgramGuestNetworks, true);
 
             final RouterDeploymentDefinition routerDeploymentDefinition = routerDeploymentDefinitionBuilder.create()
@@ -325,7 +324,7 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
     public boolean destroy(final Network config, final ReservationContext context) throws ConcurrentOperationException, ResourceUnavailableException {
         final Long vpcId = config.getVpcId();
         if (vpcId == null) {
-            s_logger.debug("Network " + config + " doesn't belong to any vpc, so skipping unplug nic part");
+            logger.debug("Network " + config + " doesn't belong to any vpc, so skipping unplug nic part");
             return true;
         }
 
@@ -334,15 +333,15 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
         for (final VirtualRouter router : routers) {
             // 1) Check if router is already a part of the network
             if (!_networkMdl.isVmPartOfNetwork(router.getId(), config.getId())) {
-                s_logger.debug("Router " + router + " is not a part the network " + config);
+                logger.debug("Router " + router + " is not a part the network " + config);
                 continue;
             }
             // 2) Call unplugNics in the network service
             success = success && _vpcRouterMgr.removeVpcRouterFromGuestNetwork(router, config);
             if (!success) {
-                s_logger.warn("Failed to unplug nic in network " + config + " for virtual router " + router);
+                logger.warn("Failed to unplug nic in network " + config + " for virtual router " + router);
             } else {
-                s_logger.debug("Successfully unplugged nic in network " + config + " for virtual router " + router);
+                logger.debug("Successfully unplugged nic in network " + config + " for virtual router " + router);
             }
         }
 
@@ -366,13 +365,13 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
         //For the 2nd time it returns the VPC routers.
         final Long vpcId = network.getVpcId();
         if (vpcId == null) {
-            s_logger.error("Network " + network + " is not associated with any VPC");
+            logger.error("Network " + network + " is not associated with any VPC");
             return routers;
         }
 
         final Vpc vpc = _vpcMgr.getActiveVpc(vpcId);
         if (vpc == null) {
-            s_logger.warn("Unable to find Enabled VPC by id " + vpcId);
+            logger.warn("Unable to find Enabled VPC by id " + vpcId);
             return routers;
         }
 
@@ -386,27 +385,27 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
         try {
             routers = routerDeploymentDefinition.deployVirtualRouter();
         } catch (final ConcurrentOperationException e) {
-            s_logger.error("Error occurred when loading routers from routerDeploymentDefinition.deployVirtualRouter()!", e);
+            logger.error("Error occurred when loading routers from routerDeploymentDefinition.deployVirtualRouter()!", e);
         } catch (final InsufficientCapacityException e) {
-            s_logger.error("Error occurred when loading routers from routerDeploymentDefinition.deployVirtualRouter()!", e);
+            logger.error("Error occurred when loading routers from routerDeploymentDefinition.deployVirtualRouter()!", e);
         } catch (final ResourceUnavailableException e) {
-            s_logger.error("Error occurred when loading routers from routerDeploymentDefinition.deployVirtualRouter()!", e);
+            logger.error("Error occurred when loading routers from routerDeploymentDefinition.deployVirtualRouter()!", e);
         }
 
         return routers;
     }
 
     private static Map<Service, Map<Capability, String>> setCapabilities() {
-        final Map<Service, Map<Capability, String>> capabilities = new HashMap<Service, Map<Capability, String>>();
+        final Map<Service, Map<Capability, String>> capabilities = new HashMap<>();
         capabilities.putAll(VirtualRouterElement.capabilities);
 
-        final Map<Capability, String> sourceNatCapabilities = new HashMap<Capability, String>();
+        final Map<Capability, String> sourceNatCapabilities = new HashMap<>();
         sourceNatCapabilities.putAll(capabilities.get(Service.SourceNat));
         // TODO This kind of logic is already placed in the DB
         sourceNatCapabilities.put(Capability.RedundantRouter, "true");
         capabilities.put(Service.SourceNat, sourceNatCapabilities);
 
-        final Map<Capability, String> vpnCapabilities = new HashMap<Capability, String>();
+        final Map<Capability, String> vpnCapabilities = new HashMap<>();
         vpnCapabilities.putAll(capabilities.get(Service.Vpn));
         vpnCapabilities.put(Capability.VpnTypes, "s2svpn");
         capabilities.put(Service.Vpn, vpnCapabilities);
@@ -430,17 +429,17 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
     @Override
     public boolean createPrivateGateway(final PrivateGateway gateway) throws ConcurrentOperationException, ResourceUnavailableException {
         if (gateway.getType() != VpcGateway.Type.Private) {
-            s_logger.warn("Type of vpc gateway is not " + VpcGateway.Type.Private);
+            logger.warn("Type of vpc gateway is not " + VpcGateway.Type.Private);
             return true;
         }
 
         final List<DomainRouterVO> routers = _vpcRouterMgr.getVpcRouters(gateway.getVpcId());
         if (routers == null || routers.isEmpty()) {
-            s_logger.debug(getName() + " element doesn't need to create Private gateway on the backend; VPC virtual " + "router doesn't exist in the vpc id=" + gateway.getVpcId());
+            logger.debug(getName() + " element doesn't need to create Private gateway on the backend; VPC virtual " + "router doesn't exist in the vpc id=" + gateway.getVpcId());
             return true;
         }
 
-        s_logger.info("Adding VPC routers to Guest Network: " + routers.size() + " to be added!");
+        logger.info("Adding VPC routers to Guest Network: " + routers.size() + " to be added!");
 
         final DataCenterVO dcVO = _dcDao.findById(gateway.getZoneId());
         final NetworkTopology networkTopology = networkTopologyContext.retrieveNetworkTopology(dcVO);
@@ -455,7 +454,7 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
                     final List<NetworkACLItemVO> rules = _networkACLItemDao.listByACL(gateway.getNetworkACLId());
                     result = result && networkTopology.applyNetworkACLs(network, rules, domainRouterVO, isPrivateGateway);
                 } catch (final Exception ex) {
-                    s_logger.debug("Failed to apply network acl id  " + gateway.getNetworkACLId() + "  on gateway ");
+                    logger.debug("Failed to apply network acl id  " + gateway.getNetworkACLId() + "  on gateway ");
                     return false;
                 }
             }
@@ -467,17 +466,17 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
     @Override
     public boolean deletePrivateGateway(final PrivateGateway gateway) throws ConcurrentOperationException, ResourceUnavailableException {
         if (gateway.getType() != VpcGateway.Type.Private) {
-            s_logger.warn("Type of vpc gateway is not " + VpcGateway.Type.Private);
+            logger.warn("Type of vpc gateway is not " + VpcGateway.Type.Private);
             return false;
         }
 
         final List<DomainRouterVO> routers = _vpcRouterMgr.getVpcRouters(gateway.getVpcId());
         if (routers == null || routers.isEmpty()) {
-            s_logger.debug(getName() + " element doesn't need to delete Private gateway on the backend; VPC virtual " + "router doesn't exist in the vpc id=" + gateway.getVpcId());
+            logger.debug(getName() + " element doesn't need to delete Private gateway on the backend; VPC virtual " + "router doesn't exist in the vpc id=" + gateway.getVpcId());
             return true;
         }
 
-        s_logger.info("Adding VPC routers to Guest Network: " + routers.size() + " to be added!");
+        logger.info("Adding VPC routers to Guest Network: " + routers.size() + " to be added!");
 
         int result = 0;
         for (final DomainRouterVO domainRouterVO : routers) {
@@ -502,7 +501,7 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
         if (canHandle) {
             final List<DomainRouterVO> routers = _routerDao.listByNetworkAndRole(network.getId(), Role.VIRTUAL_ROUTER);
             if (routers == null || routers.isEmpty()) {
-                s_logger.debug(getName() + " element doesn't need to associate ip addresses on the backend; VPC virtual " + "router doesn't exist in the network "
+                logger.debug(getName() + " element doesn't need to associate ip addresses on the backend; VPC virtual " + "router doesn't exist in the network "
                         + network.getId());
                 return false;
             }
@@ -523,7 +522,7 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
         if (canHandle(network, Service.NetworkACL)) {
             final List<DomainRouterVO> routers = _routerDao.listByNetworkAndRole(network.getId(), Role.VIRTUAL_ROUTER);
             if (routers == null || routers.isEmpty()) {
-                s_logger.debug("Virtual router elemnt doesn't need to apply firewall rules on the backend; virtual " + "router doesn't exist in the network " + network.getId());
+                logger.debug("Virtual router elemnt doesn't need to apply firewall rules on the backend; virtual " + "router doesn't exist in the network " + network.getId());
                 return true;
             }
 
@@ -534,13 +533,18 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
                 try {
                     result = result && networkTopology.applyNetworkACLs(network, rules, domainRouterVO, false);
                 } catch (final Exception ex) {
-                    s_logger.debug("Failed to apply network acl in network " + network.getId());
+                    logger.debug("Failed to apply network acl in network " + network.getId());
                 }
             }
         }
         return result;
     }
 
+    @Override
+    public boolean reorderAclRules(Vpc vpc, List<? extends Network> networks, List<? extends NetworkACLItem> networkACLItems) {
+        return true;
+    }
+
     @Override
     protected Type getVirtualRouterProvider() {
         return Type.VPCVirtualRouter;
@@ -550,7 +554,7 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
     public boolean applyStaticRoutes(final Vpc vpc, final List<StaticRouteProfile> routes) throws ResourceUnavailableException {
         final List<DomainRouterVO> routers = _routerDao.listByVpcId(vpc.getId());
         if (routers == null || routers.isEmpty()) {
-            s_logger.debug("Virtual router elemnt doesn't need to static routes on the backend; virtual " + "router doesn't exist in the vpc " + vpc);
+            logger.debug("Virtual router elemnt doesn't need to static routes on the backend; virtual " + "router doesn't exist in the vpc " + vpc);
             return true;
         }
 
@@ -560,7 +564,7 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
         if (!networkTopology.applyStaticRoutes(routes, routers)) {
             throw new CloudRuntimeException("Failed to apply static routes in vpc " + vpc);
         } else {
-            s_logger.debug("Applied static routes on vpc " + vpc);
+            logger.debug("Applied static routes on vpc " + vpc);
             return true;
         }
     }
@@ -572,7 +576,7 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
 
         final List<DomainRouterVO> routers = _vpcRouterMgr.getVpcRouters(gateway.getVpcId());
         if (routers == null || routers.isEmpty()) {
-            s_logger.debug("Virtual router element doesn't need to apply network acl rules on the backend; virtual " + "router doesn't exist in the network " + network.getId());
+            logger.debug("Virtual router element doesn't need to apply network acl rules on the backend; virtual " + "router doesn't exist in the network " + network.getId());
             return true;
         }
 
@@ -587,7 +591,7 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
             if (nicProfile != null) {
                 result = result && networkTopology.applyNetworkACLs(network, rules, domainRouterVO, isPrivateGateway);
             } else {
-                s_logger.warn("Nic Profile for router '" + domainRouterVO + "' has already been removed. Router is redundant = " + domainRouterVO.getIsRedundantRouter());
+                logger.warn("Nic Profile for router '" + domainRouterVO + "' has already been removed. Router is redundant = " + domainRouterVO.getIsRedundantRouter());
             }
         }
         return result;
@@ -600,7 +604,7 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
 
         final Map<Capability, String> vpnCapabilities = capabilities.get(Service.Vpn);
         if (!vpnCapabilities.get(Capability.VpnTypes).contains("s2svpn")) {
-            s_logger.error("try to start site 2 site vpn on unsupported network element?");
+            logger.error("try to start site 2 site vpn on unsupported network element?");
             return false;
         }
 
@@ -631,7 +635,7 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
 
         final Map<Capability, String> vpnCapabilities = capabilities.get(Service.Vpn);
         if (!vpnCapabilities.get(Capability.VpnTypes).contains("s2svpn")) {
-            s_logger.error("try to stop site 2 site vpn on unsupported network element?");
+            logger.error("try to stop site 2 site vpn on unsupported network element?");
             return false;
         }
 
@@ -665,7 +669,7 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
 
         final List<DomainRouterVO> routers = _vpcRouterMgr.getVpcRouters(vpcId);
         if (routers == null) {
-            s_logger.debug("Cannot apply vpn users on the backend; virtual router doesn't exist in the network " + vpcId);
+            logger.debug("Cannot apply vpn users on the backend; virtual router doesn't exist in the network " + vpcId);
             return null;
         }
 
@@ -674,7 +678,7 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
         final NetworkTopology networkTopology = networkTopologyContext.retrieveNetworkTopology(dcVO);
 
         String[] result = null;
-        final List<String> combinedResults = new ArrayList<String>();
+        final List<String> combinedResults = new ArrayList<>();
         for (final DomainRouterVO domainRouterVO : routers) {
             result = networkTopology.applyVpnUsers(vpn, users, domainRouterVO);
             combinedResults.addAll(Arrays.asList(result));
@@ -694,7 +698,7 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
 
         final List<DomainRouterVO> routers = _vpcRouterMgr.getVpcRouters(vpn.getVpcId());
         if (routers == null) {
-            s_logger.debug("Cannot apply vpn users on the backend; virtual router doesn't exist in the network " + vpn.getVpcId());
+            logger.debug("Cannot apply vpn users on the backend; virtual router doesn't exist in the network " + vpn.getVpcId());
             return false;
         }
 
@@ -713,7 +717,7 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
 
         final List<DomainRouterVO> routers = _vpcRouterMgr.getVpcRouters(vpn.getVpcId());
         if (routers == null) {
-            s_logger.debug("Cannot apply vpn users on the backend; virtual router doesn't exist in the network " + vpn.getVpcId());
+            logger.debug("Cannot apply vpn users on the backend; virtual router doesn't exist in the network " + vpn.getVpcId());
             return false;
         }
 
@@ -723,4 +727,9 @@ public class VpcVirtualRouterElement extends VirtualRouterElement implements Vpc
         }
         return result;
     }
+
+    @Override
+    public boolean updateVpcSourceNatIp(Vpc vpc, IpAddress address) {
+        return true;
+    }
 }
