@@ -28,6 +28,8 @@ import java.util.Map;
 import javax.annotation.PostConstruct;
 import javax.inject.Inject;
 
+import com.cloud.network.vpc.dao.VpcDao;
+import com.cloud.utils.validation.ChecksumUtil;
 import org.apache.cloudstack.api.ApiConstants;
 import org.apache.cloudstack.context.CallContext;
 import org.apache.cloudstack.engine.orchestration.service.NetworkOrchestrationService;
@@ -36,7 +38,8 @@ import org.apache.cloudstack.framework.config.dao.ConfigurationDao;
 import org.apache.cloudstack.network.router.deployment.RouterDeploymentDefinition;
 import org.apache.cloudstack.utils.CloudStackVersion;
 import org.apache.commons.collections.CollectionUtils;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 
 import com.cloud.agent.AgentManager;
 import com.cloud.agent.api.Answer;
@@ -101,7 +104,6 @@ import com.cloud.user.dao.UserDao;
 import com.cloud.utils.Pair;
 import com.cloud.utils.exception.CloudRuntimeException;
 import com.cloud.utils.net.NetUtils;
-import com.cloud.utils.validation.ChecksumUtil;
 import com.cloud.vm.DomainRouterVO;
 import com.cloud.vm.Nic;
 import com.cloud.vm.NicProfile;
@@ -115,7 +117,7 @@ import com.cloud.vm.dao.NicDao;
 
 public class NetworkHelperImpl implements NetworkHelper {
 
-    private static final Logger s_logger = Logger.getLogger(NetworkHelperImpl.class);
+    protected Logger logger = LogManager.getLogger(NetworkHelperImpl.class);
 
     protected static Account s_systemAccount;
     protected static String s_vmInstanceName;
@@ -172,6 +174,8 @@ public class NetworkHelperImpl implements NetworkHelper {
     Ipv6Service ipv6Service;
     @Inject
     CapacityManager capacityMgr;
+    @Inject
+    VpcDao vpcDao;
 
     protected final Map<HypervisorType, ConfigKey<String>> hypervisorsMap = new HashMap<>();
 
@@ -188,7 +192,7 @@ public class NetworkHelperImpl implements NetworkHelper {
     @Override
     public boolean sendCommandsToRouter(final VirtualRouter router, final Commands cmds) throws AgentUnavailableException, ResourceUnavailableException {
         if (!checkRouterVersion(router)) {
-            s_logger.debug("Router requires upgrade. Unable to send command to router:" + router.getId() + ", router template version : " + router.getTemplateVersion()
+            logger.debug("Router requires upgrade. Unable to send command to router:" + router.getId() + ", router template version : " + router.getTemplateVersion()
                     + ", minimal required version : " + NetworkOrchestrationService.MinVRVersion.valueIn(router.getDataCenterId()));
             throw new ResourceUnavailableException("Unable to send command. Router requires upgrade", VirtualRouter.class, router.getId());
         }
@@ -196,7 +200,7 @@ public class NetworkHelperImpl implements NetworkHelper {
         try {
             answers = _agentMgr.send(router.getHostId(), cmds);
         } catch (final OperationTimedoutException e) {
-            s_logger.warn("Timed Out", e);
+            logger.warn("Timed Out", e);
             throw new AgentUnavailableException("Unable to send commands to virtual router ", router.getHostId(), e);
         }
 
@@ -237,8 +241,8 @@ public class NetworkHelperImpl implements NetworkHelper {
         final DomainRouterVO connectedRouter = (DomainRouterVO) connectedRouters.get(0);
         DomainRouterVO disconnectedRouter = (DomainRouterVO) disconnectedRouters.get(0);
 
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("About to stop the router " + disconnectedRouter.getInstanceName() + " due to: " + reason);
+        if (logger.isDebugEnabled()) {
+            logger.debug("About to stop the router " + disconnectedRouter.getInstanceName() + " due to: " + reason);
         }
         final String title = "Virtual router " + disconnectedRouter.getInstanceName() + " would be stopped after connecting back, due to " + reason;
         final String context = "Virtual router (name: " + disconnectedRouter.getInstanceName() + ", id: " + disconnectedRouter.getId()
@@ -258,8 +262,8 @@ public class NetworkHelperImpl implements NetworkHelper {
     @Override
     public VirtualRouter destroyRouter(final long routerId, final Account caller, final Long callerUserId) throws ResourceUnavailableException, ConcurrentOperationException {
 
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Attempting to destroy router " + routerId);
+        if (logger.isDebugEnabled()) {
+            logger.debug("Attempting to destroy router " + routerId);
         }
 
         final DomainRouterVO router = _routerDao.findById(routerId);
@@ -315,14 +319,14 @@ public class NetworkHelperImpl implements NetworkHelper {
 
     protected DomainRouterVO start(DomainRouterVO router, final User user, final Account caller, final Map<Param, Object> params, final DeploymentPlan planToDeploy)
             throws StorageUnavailableException, InsufficientCapacityException, ConcurrentOperationException, ResourceUnavailableException {
-        s_logger.debug("Starting router " + router);
+        logger.debug("Starting router " + router);
         try {
             _itMgr.advanceStart(router.getUuid(), params, planToDeploy, null);
         } catch (final OperationTimedoutException e) {
             throw new ResourceUnavailableException("Starting router " + router + " failed! " + e.toString(), DataCenter.class, router.getDataCenterId());
         }
         if (router.isStopPending()) {
-            s_logger.info("Clear the stop pending flag of router " + router.getHostName() + " after start router successfully!");
+            logger.info("Clear the stop pending flag of router " + router.getHostName() + " after start router successfully!");
             router.setStopPending(false);
             router = _routerDao.persist(router);
         }
@@ -339,8 +343,8 @@ public class NetworkHelperImpl implements NetworkHelper {
     protected DomainRouterVO waitRouter(final DomainRouterVO router) {
         DomainRouterVO vm = _routerDao.findById(router.getId());
 
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Router " + router.getInstanceName() + " is not fully up yet, we will wait");
+        if (logger.isDebugEnabled()) {
+            logger.debug("Router " + router.getInstanceName() + " is not fully up yet, we will wait");
         }
         while (vm.getState() == State.Starting) {
             try {
@@ -353,14 +357,14 @@ public class NetworkHelperImpl implements NetworkHelper {
         }
 
         if (vm.getState() == State.Running) {
-            if (s_logger.isDebugEnabled()) {
-                s_logger.debug("Router " + router.getInstanceName() + " is now fully up");
+            if (logger.isDebugEnabled()) {
+                logger.debug("Router " + router.getInstanceName() + " is now fully up");
             }
 
             return router;
         }
 
-        s_logger.warn("Router " + router.getInstanceName() + " failed to start. current state: " + vm.getState());
+        logger.warn("Router " + router.getInstanceName() + " failed to start. current state: " + vm.getState());
         return null;
     }
 
@@ -400,7 +404,7 @@ public class NetworkHelperImpl implements NetworkHelper {
         }
 
         if (router.getState() == State.Running) {
-            s_logger.debug("Redundant router " + router.getInstanceName() + " is already running!");
+            logger.debug("Redundant router " + router.getInstanceName() + " is already running!");
             return router;
         }
 
@@ -445,9 +449,7 @@ public class NetworkHelperImpl implements NetworkHelper {
         final int retryIndex = 5;
         final ExcludeList[] avoids = new ExcludeList[5];
         avoids[0] = new ExcludeList();
-        if (routerToBeAvoid.getPodIdToDeployIn() != null) {
-            avoids[0].addPod(routerToBeAvoid.getPodIdToDeployIn());
-        }
+        avoids[0].addPod(routerToBeAvoid.getPodIdToDeployIn());
         avoids[1] = new ExcludeList();
         avoids[1].addCluster(_hostDao.findById(routerToBeAvoid.getHostId()).getClusterId());
         avoids[2] = new ExcludeList();
@@ -461,8 +463,8 @@ public class NetworkHelperImpl implements NetworkHelper {
         avoids[4] = new ExcludeList();
 
         for (int i = 0; i < retryIndex; i++) {
-            if (s_logger.isTraceEnabled()) {
-                s_logger.trace("Try to deploy redundant virtual router:" + router.getHostName() + ", for " + i + " time");
+            if (logger.isTraceEnabled()) {
+                logger.trace("Try to deploy redundant virtual router:" + router.getHostName() + ", for " + i + " time");
             }
             plan.setAvoids(avoids[i]);
             try {
@@ -516,8 +518,8 @@ public class NetworkHelperImpl implements NetworkHelper {
                 checkIfZoneHasCapacity(routerDeploymentDefinition.getDest().getDataCenter(), hType, routerOffering);
 
                 final long id = _routerDao.getNextInSequence(Long.class, "id");
-                if (s_logger.isDebugEnabled()) {
-                    s_logger.debug(String.format("Allocating the VR with id=%s in datacenter %s with the hypervisor type %s", id, routerDeploymentDefinition.getDest()
+                if (logger.isDebugEnabled()) {
+                    logger.debug(String.format("Allocating the VR with id=%s in datacenter %s with the hypervisor type %s", id, routerDeploymentDefinition.getDest()
                             .getDataCenter(), hType));
                 }
 
@@ -525,7 +527,7 @@ public class NetworkHelperImpl implements NetworkHelper {
                 final VMTemplateVO template = _templateDao.findRoutingTemplate(hType, templateName);
 
                 if (template == null) {
-                    s_logger.debug(hType + " won't support system vm, skip it");
+                    logger.debug(hType + " won't support system vm, skip it");
                     continue;
                 }
 
@@ -556,7 +558,7 @@ public class NetworkHelperImpl implements NetworkHelper {
                 router = _routerDao.findById(router.getId());
             } catch (final InsufficientCapacityException ex) {
                 if (iter.hasNext()) {
-                    s_logger.debug("Failed to allocate the VR with hypervisor type " + hType + ", retrying one more time");
+                    logger.debug("Failed to allocate the VR with hypervisor type " + hType + ", retrying one more time");
                     continue;
                 } else {
                     throw ex;
@@ -569,7 +571,7 @@ public class NetworkHelperImpl implements NetworkHelper {
                     break;
                 } catch (final InsufficientCapacityException ex) {
                     if (iter.hasNext()) {
-                        s_logger.debug("Failed to start the VR  " + router + " with hypervisor type " + hType + ", " + "destroying it and recreating one more time");
+                        logger.debug("Failed to start the VR  " + router + " with hypervisor type " + hType + ", " + "destroying it and recreating one more time");
                         // destroy the router
                         destroyRouter(router.getId(), _accountMgr.getAccount(Account.ACCOUNT_ID_SYSTEM), User.UID_SYSTEM);
                         continue;
@@ -590,18 +592,18 @@ public class NetworkHelperImpl implements NetworkHelper {
         List <HostVO> hosts = _hostDao.listByDataCenterIdAndHypervisorType(zone.getId(), hypervisorType);
         if (CollectionUtils.isEmpty(hosts)) {
             String msg = String.format("Zone %s has no %s host available which is enabled and in Up state", zone.getName(), hypervisorType);
-            s_logger.debug(msg);
+            logger.debug(msg);
             throw new InsufficientServerCapacityException(msg, DataCenter.class, zone.getId());
         }
         for (HostVO host : hosts) {
             Pair<Boolean, Boolean> cpuCapabilityAndCapacity = capacityMgr.checkIfHostHasCpuCapabilityAndCapacity(host, routerOffering, false);
             if (cpuCapabilityAndCapacity.first() && cpuCapabilityAndCapacity.second()) {
-                s_logger.debug("Host " + host + " has enough capacity for the router");
+                logger.debug("Host " + host + " has enough capacity for the router");
                 return;
             }
         }
         String msg = String.format("Zone %s has no %s host which has enough capacity", zone.getName(), hypervisorType);
-        s_logger.debug(msg);
+        logger.debug(msg);
         throw new InsufficientServerCapacityException(msg, DataCenter.class, zone.getId());
     }
 
@@ -662,7 +664,7 @@ public class NetworkHelperImpl implements NetworkHelper {
 
             for (final HostVO h : hosts) {
                 if (h.getState() == Status.Up) {
-                    s_logger.debug("Pick up host that has hypervisor type " + h.getHypervisorType() + " in cluster " + cv.getId() + " to start domain router for OVM");
+                    logger.debug("Pick up host that has hypervisor type " + h.getHypervisorType() + " in cluster " + cv.getId() + " to start domain router for OVM");
                     return h.getHypervisorType();
                 }
             }
@@ -678,7 +680,7 @@ public class NetworkHelperImpl implements NetworkHelper {
     protected LinkedHashMap<Network, List<? extends NicProfile>> configureControlNic(final RouterDeploymentDefinition routerDeploymentDefinition) {
         final LinkedHashMap<Network, List<? extends NicProfile>> controlConfig = new LinkedHashMap<Network, List<? extends NicProfile>>(3);
 
-        s_logger.debug("Adding nic for Virtual Router in Control network ");
+        logger.debug("Adding nic for Virtual Router in Control network ");
         final List<? extends NetworkOffering> offerings = _networkModel.getSystemAccountNetworkOfferings(NetworkOffering.SystemControlNetwork);
         final NetworkOffering controlOffering = offerings.get(0);
         final Network controlNic = _networkMgr.setupNetwork(s_systemAccount, controlOffering, routerDeploymentDefinition.getPlan(), null, null, false).get(0);
@@ -692,7 +694,7 @@ public class NetworkHelperImpl implements NetworkHelper {
         final LinkedHashMap<Network, List<? extends NicProfile>> publicConfig = new LinkedHashMap<Network, List<? extends NicProfile>>(3);
 
         if (routerDeploymentDefinition.isPublicNetwork()) {
-            s_logger.debug("Adding nic for Virtual Router in Public network ");
+            logger.debug("Adding nic for Virtual Router in Public network ");
             // if source nat service is supported by the network, get the source
             // nat ip address
             final NicProfile defaultNic = new NicProfile();
@@ -710,8 +712,8 @@ public class NetworkHelperImpl implements NetworkHelper {
                 defaultNic.setIsolationUri(BroadcastDomainType.Vxlan.toUri(sourceNatIp.getVlanTag()));
             } else {
                 defaultNic.setBroadcastType(BroadcastDomainType.Vlan);
-                defaultNic.setBroadcastUri(BroadcastDomainType.Vlan.toUri(sourceNatIp.getVlanTag()));
-                defaultNic.setIsolationUri(IsolationType.Vlan.toUri(sourceNatIp.getVlanTag()));
+                defaultNic.setBroadcastUri(sourceNatIp.getVlanTag() != null ? BroadcastDomainType.Vlan.toUri(sourceNatIp.getVlanTag()) : null);
+                defaultNic.setIsolationUri(sourceNatIp.getVlanTag() != null ?  IsolationType.Vlan.toUri(sourceNatIp.getVlanTag()) : null);
             }
 
             //If guest nic has already been added we will have 2 devices in the list.
@@ -726,7 +728,7 @@ public class NetworkHelperImpl implements NetworkHelper {
             // interface if possible
             final NicVO peerNic = _nicDao.findByIp4AddressAndNetworkId(publicIp, publicNetworks.get(0).getId());
             if (peerNic != null) {
-                s_logger.info("Use same MAC as previous RvR, the MAC is " + peerNic.getMacAddress());
+                logger.info("Use same MAC as previous RvR, the MAC is " + peerNic.getMacAddress());
                 defaultNic.setMacAddress(peerNic.getMacAddress());
             }
             if (routerDeploymentDefinition.getGuestNetwork() != null) {
@@ -768,13 +770,13 @@ public class NetworkHelperImpl implements NetworkHelper {
         final Network guestNetwork = routerDeploymentDefinition.getGuestNetwork();
 
         if (guestNetwork != null) {
-            s_logger.debug("Adding nic for Virtual Router in Guest network " + guestNetwork);
+            logger.debug("Adding nic for Virtual Router in Guest network " + guestNetwork);
             String defaultNetworkStartIp = null, defaultNetworkStartIpv6 = null;
             final Nic placeholder = _networkModel.getPlaceholderNicForRouter(guestNetwork, routerDeploymentDefinition.getPodId());
             if (!routerDeploymentDefinition.isPublicNetwork()) {
                 if (guestNetwork.getCidr() != null) {
                     if (placeholder != null && placeholder.getIPv4Address() != null) {
-                        s_logger.debug("Requesting ipv4 address " + placeholder.getIPv4Address() + " stored in placeholder nic for the network "
+                        logger.debug("Requesting ipv4 address " + placeholder.getIPv4Address() + " stored in placeholder nic for the network "
                                 + guestNetwork);
                         defaultNetworkStartIp = placeholder.getIPv4Address();
                     } else {
@@ -787,8 +789,8 @@ public class NetworkHelperImpl implements NetworkHelper {
                             if (startIp != null
                                     && _ipAddressDao.findByIpAndSourceNetworkId(guestNetwork.getId(), startIp).getAllocatedTime() == null) {
                                 defaultNetworkStartIp = startIp;
-                            } else if (s_logger.isDebugEnabled()) {
-                                s_logger.debug("First ipv4 " + startIp + " in network id=" + guestNetwork.getId()
+                            } else if (logger.isDebugEnabled()) {
+                                logger.debug("First ipv4 " + startIp + " in network id=" + guestNetwork.getId()
                                         + " is already allocated, can't use it for domain router; will get random ip address from the range");
                             }
                         }
@@ -797,7 +799,7 @@ public class NetworkHelperImpl implements NetworkHelper {
 
                 if (guestNetwork.getIp6Cidr() != null) {
                     if (placeholder != null && placeholder.getIPv6Address() != null) {
-                        s_logger.debug("Requesting ipv6 address " + placeholder.getIPv6Address() + " stored in placeholder nic for the network "
+                        logger.debug("Requesting ipv6 address " + placeholder.getIPv6Address() + " stored in placeholder nic for the network "
                                 + guestNetwork);
                         defaultNetworkStartIpv6 = placeholder.getIPv6Address();
                     } else {
@@ -809,8 +811,8 @@ public class NetworkHelperImpl implements NetworkHelper {
                             final String startIpv6 = _networkModel.getStartIpv6Address(guestNetwork.getId());
                             if (startIpv6 != null && _ipv6Dao.findByNetworkIdAndIp(guestNetwork.getId(), startIpv6) == null) {
                                 defaultNetworkStartIpv6 = startIpv6;
-                            } else if (s_logger.isDebugEnabled()) {
-                                s_logger.debug("First ipv6 " + startIpv6 + " in network id=" + guestNetwork.getId()
+                            } else if (logger.isDebugEnabled()) {
+                                logger.debug("First ipv6 " + startIpv6 + " in network id=" + guestNetwork.getId()
                                         + " is already allocated, can't use it for domain router; will get random ipv6 address from the range");
                             }
                         }
@@ -865,15 +867,15 @@ public class NetworkHelperImpl implements NetworkHelper {
         final String timeEndChar = "dhms";
         int haproxy_stats_port = Integer.parseInt(_configDao.getValue(Config.NetworkLBHaproxyStatsPort.key()));
         if (rule.getSourcePortStart() == haproxy_stats_port) {
-            if (s_logger.isDebugEnabled()) {
-                s_logger.debug("Can't create LB on port "+ haproxy_stats_port +", haproxy is listening for  LB stats on this port");
+            if (logger.isDebugEnabled()) {
+                logger.debug("Can't create LB on port "+ haproxy_stats_port +", haproxy is listening for  LB stats on this port");
             }
             return false;
         }
         String lbProtocol = rule.getLbProtocol();
         if (lbProtocol != null && lbProtocol.toLowerCase().equals(NetUtils.UDP_PROTO)) {
-            if (s_logger.isDebugEnabled()) {
-                s_logger.debug("Can't create LB rule as haproxy does not support udp");
+            if (logger.isDebugEnabled()) {
+                logger.debug("Can't create LB rule as haproxy does not support udp");
             }
             return false;
         }
