@@ -23,14 +23,16 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 
 import javax.inject.Inject;
 import javax.naming.ConfigurationException;
 
+import com.cloud.network.dao.NetworkDao;
+import com.cloud.network.vpc.dao.VpcDao;
 import org.apache.cloudstack.agent.routing.ManageServiceCommand;
 import com.cloud.agent.api.routing.NetworkElementCommand;
 import org.apache.commons.collections.CollectionUtils;
-import org.apache.log4j.Logger;
 import org.springframework.stereotype.Component;
 
 import com.cloud.agent.api.Answer;
@@ -113,7 +115,6 @@ import com.cloud.vm.dao.VMInstanceDao;
 
 @Component
 public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplianceManagerImpl implements VpcVirtualNetworkApplianceManager {
-    private static final Logger s_logger = Logger.getLogger(VpcVirtualNetworkApplianceManagerImpl.class);
 
     @Inject
     private NetworkACLManager _networkACLMgr;
@@ -136,6 +137,10 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
     @Inject
     protected HypervisorGuruManager _hvGuruMgr;
     @Inject
+    protected NetworkDao networkDao;
+    @Inject
+    protected VpcDao vpcDao;
+    @Inject
     private LoadBalancerDao loadBalancerDao;
 
     @Override
@@ -148,7 +153,7 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
     public boolean addVpcRouterToGuestNetwork(final VirtualRouter router, final Network network, final Map<VirtualMachineProfile.Param, Object> params)
             throws ConcurrentOperationException, ResourceUnavailableException, InsufficientCapacityException {
         if (network.getTrafficType() != TrafficType.Guest) {
-            s_logger.warn("Network " + network + " is not of type " + TrafficType.Guest);
+            logger.warn("Network " + network + " is not of type " + TrafficType.Guest);
             return false;
         }
 
@@ -169,7 +174,7 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
             if (guestNic != null) {
                 result = setupVpcGuestNetwork(network, router, true, guestNic);
             } else {
-                s_logger.warn("Failed to add router " + router + " to guest network " + network);
+                logger.warn("Failed to add router " + router + " to guest network " + network);
                 result = false;
             }
             // 3) apply networking rules
@@ -178,18 +183,18 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
                 sendNetworkRulesToRouter(router.getId(), network.getId(), reprogramNetwork);
             }
         } catch (final Exception ex) {
-            s_logger.warn("Failed to add router " + router + " to network " + network + " due to ", ex);
+            logger.warn("Failed to add router " + router + " to network " + network + " due to ", ex);
             result = false;
         } finally {
             if (!result) {
-                s_logger.debug("Removing the router " + router + " from network " + network + " as a part of cleanup");
+                logger.debug("Removing the router " + router + " from network " + network + " as a part of cleanup");
                 if (removeVpcRouterFromGuestNetwork(router, network)) {
-                    s_logger.debug("Removed the router " + router + " from network " + network + " as a part of cleanup");
+                    logger.debug("Removed the router " + router + " from network " + network + " as a part of cleanup");
                 } else {
-                    s_logger.warn("Failed to remove the router " + router + " from network " + network + " as a part of cleanup");
+                    logger.warn("Failed to remove the router " + router + " from network " + network + " as a part of cleanup");
                 }
             } else {
-                s_logger.debug("Successfully added router " + router + " to guest network " + network);
+                logger.debug("Successfully added router " + router + " to guest network " + network);
             }
         }
 
@@ -200,7 +205,7 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
     public boolean removeVpcRouterFromGuestNetwork(final VirtualRouter router, final Network network) throws ConcurrentOperationException,
     ResourceUnavailableException {
         if (network.getTrafficType() != TrafficType.Guest) {
-            s_logger.warn("Network " + network + " is not of type " + TrafficType.Guest);
+            logger.warn("Network " + network + " is not of type " + TrafficType.Guest);
             return false;
         }
 
@@ -208,13 +213,13 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
         try {
             // Check if router is a part of the Guest network
             if (!_networkModel.isVmPartOfNetwork(router.getId(), network.getId())) {
-                s_logger.debug("Router " + router + " is not a part of the Guest network " + network);
+                logger.debug("Router " + router + " is not a part of the Guest network " + network);
                 return result;
             }
 
             result = setupVpcGuestNetwork(network, router, false, _networkModel.getNicProfile(router, network.getId(), null));
             if (!result) {
-                s_logger.warn("Failed to destroy guest network config " + network + " on router " + router);
+                logger.warn("Failed to destroy guest network config " + network + " on router " + router);
                 return false;
             }
 
@@ -243,7 +248,7 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
     private boolean manageKeepalivedServiceOnRouter(VirtualRouter router,
             Network network, String action) throws ConcurrentOperationException, ResourceUnavailableException {
         if (network.getTrafficType() != TrafficType.Guest) {
-            s_logger.warn("Network " + network + " is not of type " + TrafficType.Guest);
+            logger.warn("Network {} is not of type {}", network, TrafficType.Guest);
             return false;
         }
         boolean result = true;
@@ -258,18 +263,19 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
 
                 final Answer setupAnswer = cmds.getAnswer("manageKeepalived");
                 if (!(setupAnswer != null && setupAnswer.getResult())) {
-                    s_logger.warn("Unable to " + action + " keepalived on router " + router);
+                    logger.warn("Unable to {} keepalived on router {}", action, router);
                     result = false;
                 }
             } else if (router.getState() == State.Stopped || router.getState() == State.Stopping) {
-                s_logger.debug("Router " + router.getInstanceName() + " is in " + router.getState() + ", so not sending command to the backend");
+                logger.debug("Router {} is in {}, so not sending command to the backend", router.getInstanceName(), router.getState());
             } else {
                 String message = "Unable to " + action + " keepalived on virtual router [" + router + "] is not in the right state " + router.getState();
-                s_logger.warn(message);
+                logger.warn(message);
                 throw new ResourceUnavailableException(message, DataCenter.class, router.getDataCenterId());
             }
         } catch (final Exception ex) {
-            s_logger.warn("Failed to " + action + "  keepalived on router " + router + " to network " + network + " due to ", ex);
+            logger.warn("Failed to {}  keepalived on router {} to network {} due to {}", action, router, network, ex.getLocalizedMessage());
+            logger.debug("Failed to {}  keepalived on router {} to network {}", action, router, network, ex);
             result = false;
         }
         return result;
@@ -289,15 +295,15 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
             final Answer setupAnswer = cmds.getAnswer("setupguestnetwork");
             final String setup = add ? "set" : "destroy";
             if (!(setupAnswer != null && setupAnswer.getResult())) {
-                s_logger.warn("Unable to " + setup + " guest network on router " + router);
+                logger.warn("Unable to " + setup + " guest network on router " + router);
                 result = false;
             }
             return result;
         } else if (router.getState() == State.Stopped || router.getState() == State.Stopping) {
-            s_logger.debug("Router " + router.getInstanceName() + " is in " + router.getState() + ", so not sending setup guest network command to the backend");
+            logger.debug("Router " + router.getInstanceName() + " is in " + router.getState() + ", so not sending setup guest network command to the backend");
             return true;
         } else {
-            s_logger.warn("Unable to setup guest network on virtual router " + router + " is not in the right state " + router.getState());
+            logger.warn("Unable to setup guest network on virtual router " + router + " is not in the right state " + router.getState());
             throw new ResourceUnavailableException("Unable to setup guest network on the backend," + " virtual router " + router + " is not in the right state", DataCenter.class,
                     router.getDataCenterId());
         }
@@ -327,7 +333,7 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
                             defaultIp6Dns1 = nic.getIPv6Dns1();
                             defaultIp6Dns2 = nic.getIPv6Dns2();
                         }
-                        s_logger.debug("Removing nic " + nic + " of type " + nic.getTrafficType() + " from the nics passed on vm start. " + "The nic will be plugged later");
+                        logger.debug("Removing nic " + nic + " of type " + nic.getTrafficType() + " from the nics passed on vm start. " + "The nic will be plugged later");
                         it.remove();
                     }
                 }
@@ -347,6 +353,9 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
                 if (defaultIp6Dns2 != null) {
                     buf.append(" ip6dns2=").append(defaultIp6Dns2);
                 }
+                if (routedIpv4Manager.isRoutedVpc(vpc)) {
+                    buf.append(" is_routed=true");
+                }
             }
         }
 
@@ -362,9 +371,7 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
             List<IPAddressVO> vpcIps = _ipAddressDao.listByAssociatedVpc(router.getVpcId(), true);
             if (CollectionUtils.isNotEmpty(vpcIps)) {
                 buf.append(String.format(" source_nat_ip=%s", vpcIps.get(0).getAddress().toString()));
-                if (s_logger.isDebugEnabled()) {
-                    s_logger.debug("The final Boot Args for " + profile + ": " + buf);
-                }
+                logger.debug("The final Boot Args for " + profile + ": " + buf);
             }
         }
     }
@@ -392,7 +399,7 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
             // 1) FORM SSH CHECK COMMAND
             final NicProfile controlNic = getControlNic(profile);
             if (controlNic == null) {
-                s_logger.error("Control network doesn't exist for the router " + domainRouterVO);
+                logger.error("Control network doesn't exist for the router " + domainRouterVO);
                 return false;
             }
 
@@ -417,7 +424,12 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
                 } else if (network.getTrafficType() == TrafficType.Public) {
                     final Pair<Nic, Network> publicNic = new Pair<Nic, Network>(routerNic, network);
                     publicNics.add(publicNic);
-                    final String vlanTag = BroadcastDomainType.getValue(routerNic.getBroadcastUri());
+                    String vlanTag = null;
+                    if (Objects.nonNull(routerNic.getBroadcastUri())) {
+                        vlanTag = BroadcastDomainType.getValue(routerNic.getBroadcastUri());
+                    } else {
+                        vlanTag = "nsx-"+routerNic.getIPv4Address();
+                    }
                     vlanMacAddress.put(vlanTag, routerNic.getMacAddress());
                 }
             }
@@ -447,10 +459,14 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
                             _routerDao.update(routerVO.getId(), routerVO);
                         }
                     }
-                    final PlugNicCommand plugNicCmd = new PlugNicCommand(_nwHelper.getNicTO(domainRouterVO, publicNic.getNetworkId(), publicNic.getBroadcastUri().toString()),
+                    String broadcastURI = publicNic.getBroadcastUri() != null ? publicNic.getBroadcastUri().toString() : null;
+                    final PlugNicCommand plugNicCmd = new PlugNicCommand(_nwHelper.getNicTO(domainRouterVO, publicNic.getNetworkId(), broadcastURI),
                             domainRouterVO.getInstanceName(), domainRouterVO.getType(), details);
                     cmds.addCommand(plugNicCmd);
                     final VpcVO vpc = _vpcDao.findById(domainRouterVO.getVpcId());
+                    if (routedIpv4Manager.isRoutedVpc(vpc)) {
+                        continue;
+                    }
                     final NetworkUsageCommand netUsageCmd = new NetworkUsageCommand(domainRouterVO.getPrivateIpAddress(), domainRouterVO.getInstanceName(), true, publicNic.getIPv4Address(), vpc.getCidr());
                     usageCmds.add(netUsageCmd);
                     UserStatisticsVO stats = _userStatsDao.findBy(domainRouterVO.getAccountId(), domainRouterVO.getDataCenterId(), publicNtwk.getId(), publicNic.getIPv4Address(), domainRouterVO.getId(),
@@ -490,7 +506,7 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
                     if (privateGwAclId != null) {
                         // set network acl on private gateway
                         final List<NetworkACLItemVO> networkACLs = _networkACLItemDao.listByACL(privateGwAclId);
-                        s_logger.debug("Found " + networkACLs.size() + " network ACLs to apply as a part of VPC VR " + domainRouterVO + " start for private gateway ip = "
+                        logger.debug("Found " + networkACLs.size() + " network ACLs to apply as a part of VPC VR " + domainRouterVO + " start for private gateway ip = "
                                 + ipVO.getIpAddress());
 
                         _commandSetupHelper.createNetworkACLsCommands(networkACLs, domainRouterVO, cmds, ipVO.getNetworkId(), true);
@@ -511,7 +527,7 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
                     cmds.addCommand(setupCmd);
                 }
             } catch (final Exception ex) {
-                s_logger.warn("Failed to add router " + domainRouterVO + " to network due to exception ", ex);
+                logger.warn("Failed to add router " + domainRouterVO + " to network due to exception ", ex);
                 return false;
             }
 
@@ -528,7 +544,7 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
                 staticRouteProfiles.add(new StaticRouteProfile(route, gateway));
             }
 
-            s_logger.debug("Found " + staticRouteProfiles.size() + " static routes to apply as a part of vpc route " + domainRouterVO + " start");
+            logger.debug("Found " + staticRouteProfiles.size() + " static routes to apply as a part of vpc route " + domainRouterVO + " start");
             if (!staticRouteProfiles.isEmpty()) {
                 _commandSetupHelper.createStaticRouteCommands(staticRouteProfiles, domainRouterVO, cmds);
             }
@@ -590,7 +606,7 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
         final List<LoadBalancerVO> lbs = loadBalancerDao.listByVpcIdAndScheme(domainRouterVO.getVpcId(), Scheme.Public);
         final List<LoadBalancingRule> lbRules = new ArrayList<>();
         createLoadBalancingRulesList(lbRules, lbs);
-        s_logger.debug("Found " + lbRules.size() + " load balancing rule(s) to apply as a part of VPC VR " + domainRouterVO + " start.");
+        logger.debug("Found " + lbRules.size() + " load balancing rule(s) to apply as a part of VPC VR " + domainRouterVO + " start.");
         if (!lbRules.isEmpty()) {
             for (final Pair<Nic, Network> nicNtwk : guestNics) {
                 final Nic guestNic = nicNtwk.first();
@@ -622,7 +638,7 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
                 if (_networkModel.isProviderSupportServiceInNetwork(guestNetworkId, Service.NetworkACL, Provider.VPCVirtualRouter)) {
                     final List<NetworkACLItemVO> networkACLs = _networkACLMgr.listNetworkACLItems(guestNetworkId);
                     if (networkACLs != null && !networkACLs.isEmpty()) {
-                        s_logger.debug("Found " + networkACLs.size() + " network ACLs to apply as a part of VPC VR " + domainRouterVO + " start for guest network id=" + guestNetworkId);
+                        logger.debug("Found " + networkACLs.size() + " network ACLs to apply as a part of VPC VR " + domainRouterVO + " start for guest network id=" + guestNetworkId);
                         _commandSetupHelper.createNetworkACLsCommands(networkACLs, domainRouterVO, cmds, guestNetworkId, false);
                     }
                 }
@@ -685,20 +701,20 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
 
             try {
                 if (_nwHelper.sendCommandsToRouter(router, cmds)) {
-                    s_logger.debug("Successfully applied ip association for ip " + ip + " in vpc network " + network);
+                    logger.debug("Successfully applied ip association for ip " + ip + " in vpc network " + network);
                     return true;
                 } else {
-                    s_logger.warn("Failed to associate ip address " + ip + " in vpc network " + network);
+                    logger.warn("Failed to associate ip address " + ip + " in vpc network " + network);
                     return false;
                 }
             } catch (final Exception ex) {
-                s_logger.warn("Failed to send  " + (add ? "add " : "delete ") + " private network " + network + " commands to rotuer ");
+                logger.warn("Failed to send  " + (add ? "add " : "delete ") + " private network " + network + " commands to rotuer ");
                 return false;
             }
         } else if (router.getState() == State.Stopped || router.getState() == State.Stopping) {
-            s_logger.debug("Router " + router.getInstanceName() + " is in " + router.getState() + ", so not sending setup private network command to the backend");
+            logger.debug("Router " + router.getInstanceName() + " is in " + router.getState() + ", so not sending setup private network command to the backend");
         } else {
-            s_logger.warn("Unable to setup private gateway, virtual router " + router + " is not in the right state " + router.getState());
+            logger.warn("Unable to setup private gateway, virtual router " + router + " is not in the right state " + router.getState());
 
             throw new ResourceUnavailableException("Unable to setup Private gateway on the backend," + " virtual router " + router + " is not in the right state",
                     DataCenter.class, router.getDataCenterId());
@@ -711,29 +727,29 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
         boolean result = true;
 
         if (!_networkModel.isVmPartOfNetwork(router.getId(), gateway.getNetworkId())) {
-            s_logger.debug("Router doesn't have nic for gateway " + gateway + " so no need to removed it");
+            logger.debug("Router doesn't have nic for gateway " + gateway + " so no need to removed it");
             return result;
         }
 
         final Network privateNetwork = _networkModel.getNetwork(gateway.getNetworkId());
         final NicProfile nicProfile = _networkModel.getNicProfile(router, privateNetwork.getId(), null);
 
-        s_logger.debug("Releasing private ip for gateway " + gateway + " from " + router);
+        logger.debug("Releasing private ip for gateway " + gateway + " from " + router);
         result = setupVpcPrivateNetwork(router, false, nicProfile);
         if (!result) {
-            s_logger.warn("Failed to release private ip for gateway " + gateway + " on router " + router);
+            logger.warn("Failed to release private ip for gateway " + gateway + " on router " + router);
             return false;
         }
 
         // revoke network acl on the private gateway.
         if (!_networkACLMgr.revokeACLItemsForPrivateGw(gateway)) {
-            s_logger.debug("Failed to delete network acl items on " + gateway + " from router " + router);
+            logger.debug("Failed to delete network acl items on " + gateway + " from router " + router);
             return false;
         }
 
-        s_logger.debug("Removing router " + router + " from private network " + privateNetwork + " as a part of delete private gateway");
+        logger.debug("Removing router " + router + " from private network " + privateNetwork + " as a part of delete private gateway");
         result = result && _itMgr.removeVmFromNetwork(router, privateNetwork, null);
-        s_logger.debug("Private gateawy " + gateway + " is removed from router " + router);
+        logger.debug("Private gateawy " + gateway + " is removed from router " + router);
         return result;
     }
 
@@ -750,7 +766,7 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
             final ArrayList<? extends PublicIpAddress> publicIps = getPublicIpsToApply(provider, guestNetworkId, IpAddress.State.Releasing);
 
             if (publicIps != null && !publicIps.isEmpty()) {
-                s_logger.debug("Found " + publicIps.size() + " ip(s) to apply as a part of domR " + domainRouterVO + " start.");
+                logger.debug("Found " + publicIps.size() + " ip(s) to apply as a part of domR " + domainRouterVO + " start.");
                 // Re-apply public ip addresses - should come before PF/LB/VPN
                 _commandSetupHelper.createVpcAssociatePublicIPCommands(domainRouterVO, publicIps, cmds, vlanMacAddress);
             }
@@ -760,7 +776,7 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
     @Override
     public boolean startSite2SiteVpn(final Site2SiteVpnConnection conn, final VirtualRouter router) throws ResourceUnavailableException {
         if (router.getState() != State.Running) {
-            s_logger.warn("Unable to apply site-to-site VPN configuration, virtual router is not in the right state " + router.getState());
+            logger.warn("Unable to apply site-to-site VPN configuration, virtual router is not in the right state " + router.getState());
             throw new ResourceUnavailableException("Unable to apply site 2 site VPN configuration," + " virtual router is not in the right state", DataCenter.class,
                     router.getDataCenterId());
         }
@@ -782,7 +798,7 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
     @Override
     public boolean stopSite2SiteVpn(final Site2SiteVpnConnection conn, final VirtualRouter router) throws ResourceUnavailableException {
         if (router.getState() != State.Running) {
-            s_logger.warn("Unable to apply site-to-site VPN configuration, virtual router is not in the right state " + router.getState());
+            logger.warn("Unable to apply site-to-site VPN configuration, virtual router is not in the right state " + router.getState());
             throw new ResourceUnavailableException("Unable to apply site 2 site VPN configuration," + " virtual router is not in the right state", DataCenter.class,
                     router.getDataCenterId());
         }
@@ -816,7 +832,7 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
                 final Nic nic = _nicDao.findByIp4AddressAndNetworkIdAndInstanceId(publicNtwkId, router.getId(), ip.getAddress().addr());
                 if (nic != null) {
                     nicsToUnplug.put(ip.getVlanTag(), ip);
-                    s_logger.debug("Need to unplug the nic for ip=" + ip + "; vlan=" + ip.getVlanTag() + " in public network id =" + publicNtwkId);
+                    logger.debug("Need to unplug the nic for ip=" + ip + "; vlan=" + ip.getVlanTag() + " in public network id =" + publicNtwkId);
                 }
             }
         }
@@ -839,14 +855,14 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
 
                 if (nic == null && nicsToPlug.get(ip.getVlanTag()) == null) {
                     nicsToPlug.put(ip.getVlanTag(), ip);
-                    s_logger.debug("Need to plug the nic for ip=" + ip + "; vlan=" + ip.getVlanTag() + " in public network id =" + publicNtwkId);
+                    logger.debug("Need to plug the nic for ip=" + ip + "; vlan=" + ip.getVlanTag() + " in public network id =" + publicNtwkId);
                 } else {
                     final PublicIpAddress nicToUnplug = nicsToUnplug.get(ip.getVlanTag());
                     if (nicToUnplug != null) {
                         final NicVO nicVO = _nicDao.findByIp4AddressAndNetworkIdAndInstanceId(publicNtwkId, router.getId(), nicToUnplug.getAddress().addr());
                         nicVO.setIPv4Address(ip.getAddress().addr());
                         _nicDao.update(nicVO.getId(), nicVO);
-                        s_logger.debug("Updated the nic " + nicVO + " with the new ip address " + ip.getAddress().addr());
+                        logger.debug("Updated the nic " + nicVO + " with the new ip address " + ip.getAddress().addr());
                         nicsToUnplug.remove(ip.getVlanTag());
                     }
                 }
@@ -887,7 +903,7 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
     @Override
     public boolean startRemoteAccessVpn(final RemoteAccessVpn vpn, final VirtualRouter router) throws ResourceUnavailableException {
         if (router.getState() != State.Running) {
-            s_logger.warn("Unable to apply remote access VPN configuration, virtual router is not in the right state " + router.getState());
+            logger.warn("Unable to apply remote access VPN configuration, virtual router is not in the right state " + router.getState());
             throw new ResourceUnavailableException("Unable to apply remote access VPN configuration," + " virtual router is not in the right state", DataCenter.class,
                     router.getDataCenterId());
         }
@@ -898,13 +914,13 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
         try {
             _agentMgr.send(router.getHostId(), cmds);
         } catch (final OperationTimedoutException e) {
-            s_logger.debug("Failed to start remote access VPN: ", e);
+            logger.debug("Failed to start remote access VPN: ", e);
             throw new AgentUnavailableException("Unable to send commands to virtual router ", router.getHostId(), e);
         }
         Answer answer = cmds.getAnswer("users");
         if (answer == null || !answer.getResult()) {
             String errorMessage = (answer == null) ? "null answer object" : answer.getDetails();
-            s_logger.error("Unable to start vpn: unable add users to vpn in zone " + router.getDataCenterId() + " for account " + vpn.getAccountId() + " on domR: "
+            logger.error("Unable to start vpn: unable add users to vpn in zone " + router.getDataCenterId() + " for account " + vpn.getAccountId() + " on domR: "
                     + router.getInstanceName() + " due to " + errorMessage);
             throw new ResourceUnavailableException("Unable to start vpn: Unable to add users to vpn in zone " + router.getDataCenterId() + " for account " + vpn.getAccountId()
             + " on domR: " + router.getInstanceName() + " due to " + errorMessage, DataCenter.class, router.getDataCenterId());
@@ -912,7 +928,7 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
         answer = cmds.getAnswer("startVpn");
         if (answer == null || !answer.getResult()) {
             String errorMessage = (answer == null) ? "null answer object" : answer.getDetails();
-            s_logger.error("Unable to start vpn in zone " + router.getDataCenterId() + " for account " + vpn.getAccountId() + " on domR: " + router.getInstanceName() + " due to "
+            logger.error("Unable to start vpn in zone " + router.getDataCenterId() + " for account " + vpn.getAccountId() + " on domR: " + router.getInstanceName() + " due to "
                     + errorMessage);
             throw new ResourceUnavailableException("Unable to start vpn in zone " + router.getDataCenterId() + " for account " + vpn.getAccountId() + " on domR: "
                     + router.getInstanceName() + " due to " + errorMessage, DataCenter.class, router.getDataCenterId());
@@ -930,9 +946,9 @@ public class VpcVirtualNetworkApplianceManagerImpl extends VirtualNetworkApplian
             _commandSetupHelper.createApplyVpnCommands(false, vpn, router, cmds);
             result = result && _nwHelper.sendCommandsToRouter(router, cmds);
         } else if (router.getState() == State.Stopped) {
-            s_logger.debug("Router " + router + " is in Stopped state, not sending deleteRemoteAccessVpn command to it");
+            logger.debug("Router " + router + " is in Stopped state, not sending deleteRemoteAccessVpn command to it");
         } else {
-            s_logger.warn("Failed to stop remote access VPN: domR " + router + " is not in right state " + router.getState());
+            logger.warn("Failed to stop remote access VPN: domR " + router + " is not in right state " + router.getState());
             throw new ResourceUnavailableException("Failed to stop remote access VPN: domR is not in right state " + router.getState(), DataCenter.class,
                     router.getDataCenterId());
         }
