@@ -33,10 +33,8 @@ import com.cloud.vm.VirtualMachineProfile;
 import com.cloud.vm.VirtualMachineProfileImpl;
 import org.apache.cloudstack.acl.SecurityChecker;
 import org.apache.cloudstack.api.command.user.firewall.ListPortForwardingRulesCmd;
-import org.apache.cloudstack.api.command.user.firewall.UpdatePortForwardingRuleCmd;
 import org.apache.cloudstack.context.CallContext;
 import org.apache.cloudstack.engine.orchestration.service.NetworkOrchestrationService;
-import org.apache.log4j.Logger;
 
 import com.cloud.configuration.ConfigurationManager;
 import com.cloud.domain.dao.DomainDao;
@@ -104,10 +102,8 @@ import com.cloud.vm.dao.NicSecondaryIpDao;
 import com.cloud.vm.dao.NicSecondaryIpVO;
 import com.cloud.vm.dao.UserVmDao;
 import com.cloud.vm.dao.VMInstanceDao;
-import org.apache.commons.collections.CollectionUtils;
 
 public class RulesManagerImpl extends ManagerBase implements RulesManager, RulesService {
-    private static final Logger s_logger = Logger.getLogger(RulesManagerImpl.class);
 
     @Inject
     IpAddressManager _ipAddrMgr;
@@ -116,7 +112,7 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
     @Inject
     PortForwardingRulesDao _portForwardingDao;
     @Inject
-    FirewallRulesCidrsDao firewallCidrsDao;
+    FirewallRulesCidrsDao _firewallCidrsDao;
     @Inject
     FirewallRulesDao _firewallDao;
     @Inject
@@ -229,7 +225,7 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
                 if (assignToVpcNtwk) {
                     _networkModel.checkIpForService(ipAddress, Service.PortForwarding, networkId);
 
-                    s_logger.debug("The ip is not associated with the VPC network id=" + networkId + ", so assigning");
+                    logger.debug("The ip is not associated with the VPC network id=" + networkId + ", so assigning");
                     try {
                         ipAddress = _ipAddrMgr.associateIPToGuestNetwork(ipAddrId, networkId, false);
                         performedIpAssoc = true;
@@ -251,7 +247,6 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
 
                 final Long accountId = ipAddress.getAllocatedToAccountId();
                 final Long domainId = ipAddress.getAllocatedInDomainId();
-                List<String> sourceCidrList = rule.getSourceCidrList();
 
                 // start port can't be bigger than end port
                 if (rule.getDestinationPortStart() > rule.getDestinationPortEnd()) {
@@ -315,8 +310,9 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
                 final IPAddressVO ipAddressFinal = ipAddress;
                 return Transaction.execute((TransactionCallbackWithException<PortForwardingRuleVO, NetworkRuleConflictException>) status -> {
                     PortForwardingRuleVO newRule =
-                        new PortForwardingRuleVO(rule.getXid(), rule.getSourceIpAddressId(), rule.getSourcePortStart(), rule.getSourcePortEnd(), dstIpFinal,
-                                    rule.getDestinationPortStart(), rule.getDestinationPortEnd(), rule.getProtocol().toLowerCase(), networkId, accountId, domainId, vmId, sourceCidrList);
+                            new PortForwardingRuleVO(rule.getXid(), rule.getSourceIpAddressId(), rule.getSourcePortStart(), rule.getSourcePortEnd(), dstIpFinal,
+                                    rule.getDestinationPortStart(), rule.getDestinationPortEnd(), rule.getProtocol().toLowerCase(), networkId, accountId, domainId, vmId);
+
                     if (forDisplay != null) {
                         newRule.setDisplay(forDisplay);
                     }
@@ -494,16 +490,16 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
                     if (assignToVpcNtwk) {
                         _networkModel.checkIpForService(ipAddress, Service.StaticNat, networkId);
 
-                        s_logger.debug("The ip is not associated with the VPC network id=" + networkId + ", so assigning");
+                        logger.debug("The ip is not associated with the VPC network id=" + networkId + ", so assigning");
                         try {
                             ipAddress = _ipAddrMgr.associateIPToGuestNetwork(ipId, networkId, false);
                             performedIpAssoc = true;
                         } catch (Exception ex) {
-                            s_logger.warn("Failed to associate ip id=" + ipId + " to VPC network id=" + networkId + " as " + "a part of enable static nat");
+                            logger.warn("Failed to associate ip id=" + ipId + " to VPC network id=" + networkId + " as " + "a part of enable static nat");
                             return false;
                         }
                     }  else if (ipAddress.isPortable()) {
-                        s_logger.info("Portable IP " + ipAddress.getUuid() + " is not associated with the network yet " + " so associate IP with the network " +
+                        logger.info("Portable IP " + ipAddress.getUuid() + " is not associated with the network yet " + " so associate IP with the network " +
                             networkId);
                         try {
                             // check if StaticNat service is enabled in the network
@@ -517,7 +513,7 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
                             // associate portable IP with guest network
                             ipAddress = _ipAddrMgr.associatePortableIPToGuestNetwork(ipId, networkId, false);
                         } catch (Exception e) {
-                            s_logger.warn("Failed to associate portable id=" + ipId + " to network id=" + networkId + " as " + "a part of enable static nat");
+                            logger.warn("Failed to associate portable id=" + ipId + " to network id=" + networkId + " as " + "a part of enable static nat");
                             return false;
                         }
                     }
@@ -533,7 +529,7 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
                                 _ipAddrMgr.transferPortableIP(ipId, ipAddress.getAssociatedWithNetworkId(), networkId);
                                 ipAddress = _ipAddressDao.findById(ipId);
                             } catch (Exception e) {
-                                s_logger.warn("Failed to associate portable id=" + ipId + " to network id=" + networkId + " as " + "a part of enable static nat");
+                                logger.warn("Failed to associate portable id=" + ipId + " to network id=" + networkId + " as " + "a part of enable static nat");
                                 return false;
                             }
                         } else {
@@ -594,20 +590,20 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
             ipAddress.setVmIp(dstIp);
             if (_ipAddressDao.update(ipAddress.getId(), ipAddress)) {
                 // enable static nat on the backend
-                s_logger.trace("Enabling static nat for ip address " + ipAddress + " and vm id=" + vmId + " on the backend");
+                logger.trace("Enabling static nat for ip address " + ipAddress + " and vm id=" + vmId + " on the backend");
                 if (applyStaticNatForIp(ipId, false, caller, false)) {
                     applyUserDataIfNeeded(vmId, network, guestNic);
                     performedIpAssoc = false; // ignor unassignIPFromVpcNetwork in finally block
                     return true;
                 } else {
-                    s_logger.warn("Failed to enable static nat rule for ip address " + ipId + " on the backend");
+                    logger.warn("Failed to enable static nat rule for ip address " + ipId + " on the backend");
                     ipAddress.setOneToOneNat(isOneToOneNat);
                     ipAddress.setAssociatedWithVmId(associatedWithVmId);
                     ipAddress.setVmIp(null);
                     _ipAddressDao.update(ipAddress.getId(), ipAddress);
                 }
             } else {
-                s_logger.warn("Failed to update ip address " + ipAddress + " in the DB as a part of enableStaticNat");
+                logger.warn("Failed to update ip address " + ipAddress + " in the DB as a part of enableStaticNat");
 
             }
         } finally {
@@ -625,11 +621,11 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
         try {
             element = _networkModel.getUserDataUpdateProvider(network);
         } catch (UnsupportedServiceException ex) {
-            s_logger.info(String.format("%s is not supported by network %s, skipping.", Service.UserData.getName(), network));
+            logger.info(String.format("%s is not supported by network %s, skipping.", Service.UserData.getName(), network));
             return;
         }
         if (element == null) {
-            s_logger.error("Can't find network element for " + Service.UserData.getName() + " provider needed for UserData update");
+            logger.error("Can't find network element for " + Service.UserData.getName() + " provider needed for UserData update");
         } else {
             UserVmVO vm = _vmDao.findById(vmId);
             try {
@@ -639,10 +635,10 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
                             _networkModel.getNetworkTag(template.getHypervisorType(), network));
                 VirtualMachineProfile vmProfile = new VirtualMachineProfileImpl(vm);
                 if (!element.saveUserData(network, nicProfile, vmProfile)) {
-                    s_logger.error("Failed to update userdata for vm " + vm + " and nic " + guestNic);
+                    logger.error("Failed to update userdata for vm " + vm + " and nic " + guestNic);
                 }
             } catch (Exception e) {
-                s_logger.error("Failed to update userdata for vm " + vm + " and nic " + guestNic + " due to " + e.getMessage(), e);
+                logger.error("Failed to update userdata for vm " + vm + " and nic " + guestNic + " due to " + e.getMessage(), e);
             }
         }
     }
@@ -694,7 +690,7 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
                         oldIP.getUuid());
             }
         // unassign old static nat rule
-        s_logger.debug("Disassociating static nat for ip " + oldIP);
+        logger.debug("Disassociating static nat for ip " + oldIP);
         if (!disableStaticNat(oldIP.getId(), caller, callerUserId, true)) {
                 throw new CloudRuntimeException("Failed to disable old static nat rule for vm "+ vm.getInstanceName() +
                         " with id "+vm.getUuid() +"  and public ip " + oldIP);
@@ -784,7 +780,7 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
         Set<Long> ipsToReprogram = new HashSet<Long>();
 
         if (rules == null || rules.isEmpty()) {
-            s_logger.debug("No port forwarding rules are found for vm id=" + vmId);
+            logger.debug("No port forwarding rules are found for vm id=" + vmId);
             return true;
         }
 
@@ -796,9 +792,9 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
 
         // apply rules for all ip addresses
         for (Long ipId : ipsToReprogram) {
-            s_logger.debug("Applying port forwarding rules for ip address id=" + ipId + " as a part of vm expunge");
+            logger.debug("Applying port forwarding rules for ip address id=" + ipId + " as a part of vm expunge");
             if (!applyPortForwardingRules(ipId,  _ipAddrMgr.RulesContinueOnError.value(), _accountMgr.getSystemAccount())) {
-                s_logger.warn("Failed to apply port forwarding rules for ip id=" + ipId);
+                logger.warn("Failed to apply port forwarding rules for ip id=" + ipId);
                 success = false;
             }
         }
@@ -892,7 +888,7 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
         List<PortForwardingRuleVO> rules = _portForwardingDao.listForApplication(ipId);
 
         if (rules.size() == 0) {
-            s_logger.debug("There are no port forwarding rules to apply for ip id=" + ipId);
+            logger.debug("There are no port forwarding rules to apply for ip id=" + ipId);
             return true;
         }
 
@@ -900,16 +896,12 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
             _accountMgr.checkAccess(caller, null, true, rules.toArray(new PortForwardingRuleVO[rules.size()]));
         }
 
-        for (PortForwardingRuleVO rule : rules) {
-            rule.setSourceCidrList(firewallCidrsDao.getSourceCidrs(rule.getId()));
-        }
-
         try {
             if (!_firewallMgr.applyRules(rules, continueOnError, true)) {
                 return false;
             }
         } catch (ResourceUnavailableException ex) {
-            s_logger.warn("Failed to apply port forwarding rules for ip due to ", ex);
+            logger.warn("Failed to apply port forwarding rules for ip due to ", ex);
             return false;
         }
 
@@ -921,7 +913,7 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
         List<StaticNatRule> staticNatRules = new ArrayList<StaticNatRule>();
 
         if (rules.size() == 0) {
-            s_logger.debug("There are no static nat rules to apply for ip id=" + sourceIpId);
+            logger.debug("There are no static nat rules to apply for ip id=" + sourceIpId);
             return true;
         }
 
@@ -938,7 +930,7 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
                 return false;
             }
         } catch (ResourceUnavailableException ex) {
-            s_logger.warn("Failed to apply static nat rules for ip due to ", ex);
+            logger.warn("Failed to apply static nat rules for ip due to ", ex);
             return false;
         }
 
@@ -949,7 +941,7 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
     public boolean applyPortForwardingRulesForNetwork(long networkId, boolean continueOnError, Account caller) {
         List<PortForwardingRuleVO> rules = listByNetworkId(networkId);
         if (rules.size() == 0) {
-            s_logger.debug("There are no port forwarding rules to apply for network id=" + networkId);
+            logger.debug("There are no port forwarding rules to apply for network id=" + networkId);
             return true;
         }
 
@@ -957,16 +949,12 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
             _accountMgr.checkAccess(caller, null, true, rules.toArray(new PortForwardingRuleVO[rules.size()]));
         }
 
-        for (PortForwardingRuleVO rule: rules) {
-            rule.setSourceCidrList(firewallCidrsDao.getSourceCidrs(rule.getId()));
-        }
-
         try {
             if (!_firewallMgr.applyRules(rules, continueOnError, true)) {
                 return false;
             }
         } catch (ResourceUnavailableException ex) {
-            s_logger.warn("Failed to apply port forwarding rules for network due to ", ex);
+            logger.warn("Failed to apply port forwarding rules for network due to ", ex);
             return false;
         }
 
@@ -979,7 +967,7 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
         List<StaticNatRule> staticNatRules = new ArrayList<StaticNatRule>();
 
         if (rules.size() == 0) {
-            s_logger.debug("There are no static nat rules to apply for network id=" + networkId);
+            logger.debug("There are no static nat rules to apply for network id=" + networkId);
             return true;
         }
 
@@ -996,7 +984,7 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
                 return false;
             }
         } catch (ResourceUnavailableException ex) {
-            s_logger.warn("Failed to apply static nat rules for network due to ", ex);
+            logger.warn("Failed to apply static nat rules for network due to ", ex);
             return false;
         }
 
@@ -1007,7 +995,7 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
     public boolean applyStaticNatsForNetwork(long networkId, boolean continueOnError, Account caller) {
         List<IPAddressVO> ips = _ipAddressDao.listStaticNatPublicIps(networkId);
         if (ips.isEmpty()) {
-            s_logger.debug("There are no static nat to apply for network id=" + networkId);
+            logger.debug("There are no static nat to apply for network id=" + networkId);
             return true;
         }
 
@@ -1028,7 +1016,7 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
                 return false;
             }
         } catch (ResourceUnavailableException ex) {
-            s_logger.warn("Failed to create static nat for network due to ", ex);
+            logger.warn("Failed to create static nat for network due to ", ex);
             return false;
         }
 
@@ -1112,8 +1100,8 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
         List<FirewallRule> rules = new ArrayList<FirewallRule>();
 
         List<PortForwardingRuleVO> pfRules = _portForwardingDao.listByIpAndNotRevoked(ipId);
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Releasing " + pfRules.size() + " port forwarding rules for ip id=" + ipId);
+        if (logger.isDebugEnabled()) {
+            logger.debug("Releasing " + pfRules.size() + " port forwarding rules for ip id=" + ipId);
         }
 
         for (PortForwardingRuleVO rule : pfRules) {
@@ -1122,8 +1110,8 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
         }
 
         List<FirewallRuleVO> staticNatRules = _firewallDao.listByIpAndPurposeAndNotRevoked(ipId, Purpose.StaticNat);
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Releasing " + staticNatRules.size() + " static nat rules for ip id=" + ipId);
+        if (logger.isDebugEnabled()) {
+            logger.debug("Releasing " + staticNatRules.size() + " static nat rules for ip id=" + ipId);
         }
 
         for (FirewallRuleVO rule : staticNatRules) {
@@ -1160,8 +1148,8 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
         rules.addAll(_portForwardingDao.listByIpAndNotRevoked(ipId));
         rules.addAll(_firewallDao.listByIpAndPurposeAndNotRevoked(ipId, Purpose.StaticNat));
 
-        if (s_logger.isDebugEnabled() && success) {
-            s_logger.debug("Successfully released rules for ip id=" + ipId + " and # of rules now = " + rules.size());
+        if (logger.isDebugEnabled() && success) {
+            logger.debug("Successfully released rules for ip id=" + ipId + " and # of rules now = " + rules.size());
         }
 
         return (rules.size() == 0 && success);
@@ -1172,13 +1160,13 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
         List<FirewallRule> rules = new ArrayList<FirewallRule>();
 
         List<PortForwardingRuleVO> pfRules = _portForwardingDao.listByNetwork(networkId);
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Releasing " + pfRules.size() + " port forwarding rules for network id=" + networkId);
+        if (logger.isDebugEnabled()) {
+            logger.debug("Releasing " + pfRules.size() + " port forwarding rules for network id=" + networkId);
         }
 
         List<FirewallRuleVO> staticNatRules = _firewallDao.listByNetworkAndPurpose(networkId, Purpose.StaticNat);
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Releasing " + staticNatRules.size() + " static nat rules for network id=" + networkId);
+        if (logger.isDebugEnabled()) {
+            logger.debug("Releasing " + staticNatRules.size() + " static nat rules for network id=" + networkId);
         }
 
         // Mark all pf rules (Active and non-Active) to be revoked, but don't revoke it yet - pass apply=false
@@ -1204,8 +1192,8 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
         rules.addAll(_portForwardingDao.listByNetworkAndNotRevoked(networkId));
         rules.addAll(_firewallDao.listByNetworkAndPurposeAndNotRevoked(networkId, Purpose.StaticNat));
 
-        if (s_logger.isDebugEnabled()) {
-            s_logger.debug("Successfully released rules for network id=" + networkId + " and # of rules now = " + rules.size());
+        if (logger.isDebugEnabled()) {
+            logger.debug("Successfully released rules for network id=" + networkId + " and # of rules now = " + rules.size());
         }
 
         return success && rules.size() == 0;
@@ -1320,18 +1308,18 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
 
         // Revoke all firewall rules for the ip
         try {
-            s_logger.debug("Revoking all " + Purpose.Firewall + "rules as a part of disabling static nat for public IP id=" + ipId);
+            logger.debug("Revoking all " + Purpose.Firewall + "rules as a part of disabling static nat for public IP id=" + ipId);
             if (!_firewallMgr.revokeFirewallRulesForIp(ipId, callerUserId, caller)) {
-                s_logger.warn("Unable to revoke all the firewall rules for ip id=" + ipId + " as a part of disable statis nat");
+                logger.warn("Unable to revoke all the firewall rules for ip id=" + ipId + " as a part of disable statis nat");
                 success = false;
             }
         } catch (ResourceUnavailableException e) {
-            s_logger.warn("Unable to revoke all firewall rules for ip id=" + ipId + " as a part of ip release", e);
+            logger.warn("Unable to revoke all firewall rules for ip id=" + ipId + " as a part of ip release", e);
             success = false;
         }
 
         if (!revokeAllPFAndStaticNatRulesForIp(ipId, callerUserId, caller)) {
-            s_logger.warn("Unable to revoke all static nat rules for ip " + ipAddress);
+            logger.warn("Unable to revoke all static nat rules for ip " + ipAddress);
             success = false;
         }
 
@@ -1348,13 +1336,13 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
             _vpcMgr.unassignIPFromVpcNetwork(ipAddress.getId(), networkId);
 
             if (isIpSystem && releaseIpIfElastic && !_ipAddrMgr.handleSystemIpRelease(ipAddress)) {
-                s_logger.warn("Failed to release system ip address " + ipAddress);
+                logger.warn("Failed to release system ip address " + ipAddress);
                 success = false;
             }
 
             return true;
         } else {
-            s_logger.warn("Failed to disable one to one nat for the ip address id" + ipId);
+            logger.warn("Failed to disable one to one nat for the ip address id" + ipId);
             ipAddress = _ipAddressDao.findById(ipId);
             ipAddress.setRuleState(null);
             _ipAddressDao.update(ipAddress.getId(), ipAddress);
@@ -1394,7 +1382,7 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
                     return false;
                 }
             } catch (ResourceUnavailableException ex) {
-                s_logger.warn("Failed to create static nat rule due to ", ex);
+                logger.warn("Failed to create static nat rule due to ", ex);
                 return false;
             }
         }
@@ -1413,18 +1401,18 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
 
         if (staticNats != null && !staticNats.isEmpty()) {
             if (forRevoke) {
-                s_logger.debug("Found " + staticNats.size() + " static nats to disable for network id " + networkId);
+                logger.debug("Found " + staticNats.size() + " static nats to disable for network id " + networkId);
             }
             try {
                 if (!_ipAddrMgr.applyStaticNats(staticNats, continueOnError, forRevoke)) {
                     return false;
                 }
             } catch (ResourceUnavailableException ex) {
-                s_logger.warn("Failed to create static nat rule due to ", ex);
+                logger.warn("Failed to create static nat rule due to ", ex);
                 return false;
             }
         } else {
-            s_logger.debug("Found 0 static nat rules to apply for network id " + networkId);
+            logger.debug("Found 0 static nat rules to apply for network id " + networkId);
         }
 
         return true;
@@ -1433,7 +1421,7 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
     protected List<StaticNat> createStaticNatForIp(IpAddress sourceIp, Account caller, boolean forRevoke) {
         List<StaticNat> staticNats = new ArrayList<StaticNat>();
         if (!sourceIp.isOneToOneNat()) {
-            s_logger.debug("Source ip id=" + sourceIp + " is not one to one nat");
+            logger.debug("Source ip id=" + sourceIp + " is not one to one nat");
             return staticNats;
         }
 
@@ -1497,36 +1485,36 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
                 }
                 // check if there is already static nat enabled
                 if (_ipAddressDao.findByAssociatedVmId(vm.getId()) != null && !getNewIp) {
-                    s_logger.debug("Vm " + vm + " already has ip associated with it in guest network " + guestNetwork);
+                    logger.debug("Vm " + vm + " already has ip associated with it in guest network " + guestNetwork);
                     continue;
                 }
 
-                s_logger.debug("Allocating system ip and enabling static nat for it for the vm " + vm + " in guest network " + guestNetwork);
+                logger.debug("Allocating system ip and enabling static nat for it for the vm " + vm + " in guest network " + guestNetwork);
                 IpAddress ip = _ipAddrMgr.assignSystemIp(guestNetwork.getId(), _accountMgr.getAccount(vm.getAccountId()), false, true);
                 if (ip == null) {
                     throw new CloudRuntimeException("Failed to allocate system ip for vm " + vm + " in guest network " + guestNetwork);
                 }
 
-                s_logger.debug("Allocated system ip " + ip + ", now enabling static nat on it for vm " + vm);
+                logger.debug("Allocated system ip " + ip + ", now enabling static nat on it for vm " + vm);
 
                 try {
                     success = enableStaticNat(ip.getId(), vm.getId(), guestNetwork.getId(), isSystemVM, null);
                 } catch (NetworkRuleConflictException ex) {
-                    s_logger.warn("Failed to enable static nat as a part of enabling elasticIp and staticNat for vm " + vm + " in guest network " + guestNetwork +
+                    logger.warn("Failed to enable static nat as a part of enabling elasticIp and staticNat for vm " + vm + " in guest network " + guestNetwork +
                         " due to exception ", ex);
                     success = false;
                 } catch (ResourceUnavailableException ex) {
-                    s_logger.warn("Failed to enable static nat as a part of enabling elasticIp and staticNat for vm " + vm + " in guest network " + guestNetwork +
+                    logger.warn("Failed to enable static nat as a part of enabling elasticIp and staticNat for vm " + vm + " in guest network " + guestNetwork +
                         " due to exception ", ex);
                     success = false;
                 }
 
                 if (!success) {
-                    s_logger.warn("Failed to enable static nat on system ip " + ip + " for the vm " + vm + ", releasing the ip...");
+                    logger.warn("Failed to enable static nat on system ip " + ip + " for the vm " + vm + ", releasing the ip...");
                     _ipAddrMgr.handleSystemIpRelease(ip);
                     throw new CloudRuntimeException("Failed to enable static nat on system ip for the vm " + vm);
                 } else {
-                    s_logger.warn("Successfully enabled static nat on system ip " + ip + " for the vm " + vm);
+                    logger.warn("Successfully enabled static nat on system ip " + ip + " for the vm " + vm);
                 }
             }
         }
@@ -1538,19 +1526,19 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
 
     @Override
     public List<FirewallRuleVO> listAssociatedRulesForGuestNic(Nic nic) {
-        s_logger.debug("Checking if PF/StaticNat/LoadBalancer rules are configured for nic " + nic.getId());
+        logger.debug("Checking if PF/StaticNat/LoadBalancer rules are configured for nic " + nic.getId());
         List<FirewallRuleVO> result = new ArrayList<FirewallRuleVO>();
         // add PF rules
         result.addAll(_portForwardingDao.listByNetworkAndDestIpAddr(nic.getIPv4Address(), nic.getNetworkId()));
         if(result.size() > 0) {
-            s_logger.debug("Found " + result.size() + " portforwarding rule configured for the nic in the network " + nic.getNetworkId());
+            logger.debug("Found " + result.size() + " portforwarding rule configured for the nic in the network " + nic.getNetworkId());
         }
         // add static NAT rules
         List<FirewallRuleVO> staticNatRules = _firewallDao.listStaticNatByVmId(nic.getInstanceId());
         for (FirewallRuleVO rule : staticNatRules) {
             if (rule.getNetworkId() == nic.getNetworkId()) {
                 result.add(rule);
-                s_logger.debug("Found rule " + rule.getId() + " " + rule.getPurpose() + " configured");
+                logger.debug("Found rule " + rule.getId() + " " + rule.getPurpose() + " configured");
             }
         }
         List<? extends IpAddress> staticNatIps = _ipAddressDao.listStaticNatPublicIps(nic.getNetworkId());
@@ -1563,7 +1551,7 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
                         new FirewallRuleVO(null, ip.getId(), 0, 65535, NetUtils.ALL_PROTO.toString(), nic.getNetworkId(), vm.getAccountId(), vm.getDomainId(),
                                 Purpose.StaticNat, null, null, null, null, null);
                 result.add(staticNatRule);
-                s_logger.debug("Found rule " + staticNatRule.getId() + " " + staticNatRule.getPurpose() + " configured");
+                logger.debug("Found rule " + staticNatRule.getId() + " " + staticNatRule.getPurpose() + " configured");
             }
         }
         // add LB rules
@@ -1572,7 +1560,7 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
             FirewallRuleVO lbRule = _firewallDao.findById(lb.getLoadBalancerId());
             if (lbRule.getNetworkId() == nic.getNetworkId()) {
                 result.add(lbRule);
-                s_logger.debug("Found rule " + lbRule.getId() + " " + lbRule.getPurpose() + " configured");
+                logger.debug("Found rule " + lbRule.getId() + " " + lbRule.getPurpose() + " configured");
             }
         }
         return result;
@@ -1580,22 +1568,12 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
 
     @Override
     @ActionEvent(eventType = EventTypes.EVENT_NET_RULE_MODIFY, eventDescription = "updating forwarding rule", async = true)
-    public PortForwardingRule updatePortForwardingRule(UpdatePortForwardingRuleCmd cmd) {
-        long id = cmd.getId();
-        Integer privatePort = cmd.getPrivatePort();
-        Integer privateEndPort = cmd.getPrivateEndPort();
-        Long virtualMachineId = cmd.getVirtualMachineId();
-        Ip vmGuestIp = cmd.getVmGuestIp();
-        String customId = cmd.getCustomId();
-        Boolean forDisplay = cmd.getDisplay();
-        List<String> sourceCidrList = cmd.getSourceCidrList();
-
+    public PortForwardingRule updatePortForwardingRule(long id, Integer privatePort, Integer privateEndPort, Long virtualMachineId, Ip vmGuestIp, String customId, Boolean forDisplay) {
+        Account caller = CallContext.current().getCallingAccount();
         PortForwardingRuleVO rule = _portForwardingDao.findById(id);
         if (rule == null) {
             throw new InvalidParameterValueException("Unable to find " + id);
         }
-
-        Account caller = CallContext.current().getCallingAccount();
         _accountMgr.checkAccess(caller, null, true, rule);
 
         if (customId != null) {
@@ -1656,8 +1634,6 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
             }
         }
 
-        validatePortForwardingSourceCidrList(sourceCidrList);
-
         // revoke old rules at first
         List<PortForwardingRuleVO> rules = new ArrayList<PortForwardingRuleVO>();
         rule.setState(State.Revoke);
@@ -1685,11 +1661,6 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
             rule.setVirtualMachineId(virtualMachineId);
             rule.setDestinationIpAddress(dstIp);
         }
-
-        if (sourceCidrList != null) {
-            rule.setSourceCidrList(sourceCidrList);
-        }
-
         _portForwardingDao.update(id, rule);
 
         //apply new rules
@@ -1699,17 +1670,4 @@ public class RulesManagerImpl extends ManagerBase implements RulesManager, Rules
 
         return _portForwardingDao.findById(id);
     }
-
-    @Override
-    public void validatePortForwardingSourceCidrList(List<String> sourceCidrList) {
-        if (CollectionUtils.isEmpty(sourceCidrList)) {
-            return;
-        }
-
-        for (String cidr : sourceCidrList) {
-            if (!NetUtils.isValidCidrList(cidr) && !NetUtils.isValidIp6Cidr(cidr)) {
-                throw new InvalidParameterValueException(String.format("The given source CIDR [%s] is invalid.", cidr));
-            }
-        }
-    }
 }
