@@ -18,6 +18,7 @@ package com.cloud.projects;
 
 import java.io.UnsupportedEncodingException;
 import java.security.SecureRandom;
+import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
@@ -35,6 +36,7 @@ import javax.inject.Inject;
 import javax.mail.MessagingException;
 import javax.naming.ConfigurationException;
 
+import org.apache.cloudstack.acl.ControlledEntity;
 import org.apache.cloudstack.acl.ProjectRole;
 import org.apache.cloudstack.acl.SecurityChecker.AccessType;
 import org.apache.cloudstack.acl.dao.ProjectRoleDao;
@@ -48,8 +50,9 @@ import org.apache.cloudstack.managed.context.ManagedContextRunnable;
 import org.apache.cloudstack.utils.mailing.MailAddress;
 import org.apache.cloudstack.utils.mailing.SMTPMailProperties;
 import org.apache.cloudstack.utils.mailing.SMTPMailSender;
+import org.apache.cloudstack.webhook.WebhookHelper;
 import org.apache.commons.lang3.BooleanUtils;
-import org.apache.log4j.Logger;
+import org.springframework.beans.factory.NoSuchBeanDefinitionException;
 import org.springframework.stereotype.Component;
 
 import com.cloud.api.ApiDBUtils;
@@ -90,6 +93,7 @@ import com.cloud.user.ResourceLimitService;
 import com.cloud.user.User;
 import com.cloud.user.dao.AccountDao;
 import com.cloud.user.dao.UserDao;
+import com.cloud.utils.component.ComponentContext;
 import com.cloud.utils.component.ManagerBase;
 import com.cloud.utils.concurrency.NamedThreadFactory;
 import com.cloud.utils.db.DB;
@@ -106,7 +110,6 @@ import com.cloud.vm.snapshot.dao.VMSnapshotDao;
 
 @Component
 public class ProjectManagerImpl extends ManagerBase implements ProjectManager, Configurable {
-    public static final Logger s_logger = Logger.getLogger(ProjectManagerImpl.class);
 
     private static final SecureRandom secureRandom = new SecureRandom();
 
@@ -165,6 +168,17 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
     private String senderAddress;
     protected SMTPMailSender mailSender;
 
+    protected List<? extends ControlledEntity> listWebhooksForProject(Project project) {
+        List<? extends ControlledEntity> webhooks = new ArrayList<>();
+        try {
+            WebhookHelper webhookService = ComponentContext.getDelegateComponentOfType(WebhookHelper.class);
+            webhooks = webhookService.listWebhooksByAccount(project.getProjectAccountId());
+        } catch (NoSuchBeanDefinitionException ignored) {
+            logger.debug("No WebhookHelper bean found");
+        }
+        return webhooks;
+    }
+
     @Override
     public boolean configure(final String name, final Map<String, Object> params) throws ConfigurationException {
 
@@ -341,8 +355,9 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
             List<VolumeVO> volumes = _volumeDao.findDetachedByAccount(project.getProjectAccountId());
             List<NetworkVO> networks = _networkDao.listByOwner(project.getProjectAccountId());
             List<? extends Vpc> vpcs = _vpcMgr.getVpcsForAccount(project.getProjectAccountId());
+            List<? extends ControlledEntity> webhooks = listWebhooksForProject(project);
 
-            Optional<String> message = Stream.of(userTemplates, vmSnapshots, vms, volumes, networks, vpcs)
+            Optional<String> message = Stream.of(userTemplates, vmSnapshots, vms, volumes, networks, vpcs, webhooks)
                     .filter(entity -> !entity.isEmpty())
                     .map(entity -> entity.size() + " " +  entity.get(0).getEntityType().getSimpleName() + " to clean up")
                     .findFirst();
@@ -364,7 +379,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
         boolean updateResult = Transaction.execute(new TransactionCallback<Boolean>() {
             @Override
             public Boolean doInTransaction(TransactionStatus status) {
-        s_logger.debug("Marking project id=" + project.getId() + " with state " + State.Disabled + " as a part of project delete...");
+        logger.debug("Marking project id=" + project.getId() + " with state " + State.Disabled + " as a part of project delete...");
         project.setState(State.Disabled);
         boolean updateResult = _projectDao.update(project.getId(), project);
         //owner can be already removed at this point, so adding the conditional check
@@ -380,7 +395,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
         if (updateResult) {
             //pass system caller when clenaup projects account
             if (!cleanupProject(project, _accountDao.findById(Account.ACCOUNT_ID_SYSTEM), User.UID_SYSTEM)) {
-                s_logger.warn("Failed to cleanup project's id=" + project.getId() + " resources, not removing the project yet");
+                logger.warn("Failed to cleanup project's id=" + project.getId() + " resources, not removing the project yet");
                 return false;
             } else {
                 //check if any Tungsten-Fabric provider exists and delete the project from Tungsten-Fabric providers
@@ -388,7 +403,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
                 return _projectDao.remove(project.getId());
             }
         } else {
-            s_logger.warn("Failed to mark the project id=" + project.getId() + " with state " + State.Disabled);
+            logger.warn("Failed to mark the project id=" + project.getId() + " with state " + State.Disabled);
             return false;
         }
     }
@@ -398,7 +413,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
         boolean result = true;
         //Delete project's account
         AccountVO account = _accountDao.findById(project.getProjectAccountId());
-        s_logger.debug("Deleting projects " + project + " internal account id=" + account.getId() + " as a part of project cleanup...");
+        logger.debug("Deleting projects " + project + " internal account id=" + account.getId() + " as a part of project cleanup...");
 
         result = result && _accountMgr.deleteAccount(account, callerUserId, caller);
 
@@ -408,22 +423,22 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
                 @Override
                 public Boolean doInTransaction(TransactionStatus status) {
                     boolean result = true;
-            s_logger.debug("Unassigning all accounts from project " + project + " as a part of project cleanup...");
+            logger.debug("Unassigning all accounts from project " + project + " as a part of project cleanup...");
             List<? extends ProjectAccount> projectAccounts = _projectAccountDao.listByProjectId(project.getId());
             for (ProjectAccount projectAccount : projectAccounts) {
                 result = result && unassignAccountFromProject(projectAccount.getProjectId(), projectAccount.getAccountId());
             }
 
-            s_logger.debug("Removing all invitations for the project " + project + " as a part of project cleanup...");
+            logger.debug("Removing all invitations for the project " + project + " as a part of project cleanup...");
             _projectInvitationDao.cleanupInvitations(project.getId());
                     return result;
                 }
             });
             if (result) {
-                s_logger.debug("Accounts are unassign successfully from project " + project + " as a part of project cleanup...");
+                logger.debug("Accounts are unassign successfully from project " + project + " as a part of project cleanup...");
             }
         } else {
-            s_logger.warn("Failed to cleanup project's internal account");
+            logger.warn("Failed to cleanup project's internal account");
         }
 
         return result;
@@ -433,14 +448,14 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
     public boolean unassignAccountFromProject(long projectId, long accountId) {
         ProjectAccountVO projectAccount = _projectAccountDao.findByProjectIdAccountId(projectId, accountId);
         if (projectAccount == null) {
-            s_logger.debug("Account id=" + accountId + " is not assigned to project id=" + projectId + " so no need to unassign");
+            logger.debug("Account id=" + accountId + " is not assigned to project id=" + projectId + " so no need to unassign");
             return true;
         }
 
         if (_projectAccountDao.remove(projectAccount.getId())) {
             return true;
         } else {
-            s_logger.warn("Failed to unassign account id=" + accountId + " from the project id=" + projectId);
+            logger.warn("Failed to unassign account id=" + accountId + " from the project id=" + projectId);
             return false;
         }
     }
@@ -479,7 +494,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
 
         //remove all invitations for account
         if (success) {
-            s_logger.debug("Removed account " + accountId + " from project " + projectId + " , cleaning up old invitations for account/project...");
+            logger.debug("Removed account " + accountId + " from project " + projectId + " , cleaning up old invitations for account/project...");
             ProjectInvitation invite = _projectInvitationDao.findByAccountIdProjectId(accountId, projectId);
             if (invite != null) {
                 success = success && _projectInvitationDao.remove(invite.getId());
@@ -557,7 +572,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
 
         ProjectAccount projectAccountUser = _projectAccountDao.findByProjectIdUserId(projectId, user.getAccountId(), user.getId());
         if (projectAccountUser != null) {
-            s_logger.info("User with id: " + user.getId() + " is already added to the project with id: " + projectId);
+            logger.info("User with id: " + user.getId() + " is already added to the project with id: " + projectId);
             return true;
         }
 
@@ -583,7 +598,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
                     Optional.ofNullable(role).map(ProjectRole::getId).orElse(null)) != null) {
                 return true;
             }
-            s_logger.warn("Failed to add user to project with id: " + projectId);
+            logger.warn("Failed to add user to project with id: " + projectId);
             return false;
         }
     }
@@ -676,7 +691,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
                     }
                     Account currentOwnerAccount = getProjectOwner(projectId);
                     if (currentOwnerAccount == null) {
-                        s_logger.error("Unable to find the current owner for the project id=" + projectId);
+                        logger.error("Unable to find the current owner for the project id=" + projectId);
                         throw new InvalidParameterValueException("Unable to find the current owner for the project id=" + projectId);
                     }
                     if (currentOwnerAccount.getId() != futureOwnerAccount.getId()) {
@@ -701,7 +716,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
                         _resourceLimitMgr.incrementResourceCount(futureOwnerAccount.getId(), ResourceType.project);
 
                     } else {
-                        s_logger.trace("Future owner " + newOwnerName + "is already the owner of the project id=" + projectId);
+                        logger.trace("Future owner " + newOwnerName + "is already the owner of the project id=" + projectId);
                     }
                 }
             }
@@ -820,7 +835,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
             //Check if the account already added to the project
             ProjectAccount projectAccount =  _projectAccountDao.findByProjectIdAccountId(projectId, account.getId());
             if (projectAccount != null) {
-                s_logger.debug("Account " + accountName + " already added to the project id=" + projectId);
+                logger.debug("Account " + accountName + " already added to the project id=" + projectId);
                 return true;
             }
         }
@@ -847,7 +862,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
                     Optional.ofNullable(projectRole).map(ProjectRole::getId).orElse(null)) != null) {
                 return true;
             } else {
-                s_logger.warn("Failed to add account " + accountName + " to project id=" + projectId);
+                logger.warn("Failed to add account " + accountName + " to project id=" + projectId);
                 return false;
             }
         }
@@ -859,7 +874,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
                     Optional.ofNullable(projectRole).map(ProjectRole::getId).orElse(null)) != null) {
                 return true;
             } else {
-                s_logger.warn("Failed to generate invitation for account " + account.getAccountName() + " to project id=" + project);
+                logger.warn("Failed to generate invitation for account " + account.getAccountName() + " to project id=" + project);
                 return false;
             }
         }
@@ -871,7 +886,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
                     Optional.ofNullable(projectRole).map(ProjectRole::getId).orElse(null)) != null) {
                 return true;
             } else {
-                s_logger.warn("Failed to generate invitation for email " + email + " to project id=" + project);
+                logger.warn("Failed to generate invitation for email " + email + " to project id=" + project);
                 return false;
             }
         }
@@ -885,7 +900,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
                     Optional.ofNullable(projectRole).map(ProjectRole::getId).orElse(null)) != null) {
                 return true;
             } else {
-                s_logger.warn("Failed to generate invitation for account " + user.getUsername()  + " to project id=" + project);
+                logger.warn("Failed to generate invitation for account " + user.getUsername()  + " to project id=" + project);
                 return false;
             }
         } else {
@@ -895,7 +910,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
                     Optional.ofNullable(projectRole).map(ProjectRole::getId).orElse(null)) != null) {
                 return true;
             } else {
-                s_logger.warn("Failed to generate invitation for email " + email + " to project id=" + project);
+                logger.warn("Failed to generate invitation for email " + email + " to project id=" + project);
                 return false;
             }
         }
@@ -1013,9 +1028,9 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
         if (invite != null) {
             boolean success = _projectInvitationDao.remove(invite.getId());
             if (success){
-                s_logger.info("Successfully deleted invite pending for the user : "+user.getUsername());
+                logger.info("Successfully deleted invite pending for the user : "+user.getUsername());
             } else {
-                s_logger.info("Failed to delete project invite for user: "+ user.getUsername());
+                logger.info("Failed to delete project invite for user: "+ user.getUsername());
             }
         }
     }
@@ -1030,7 +1045,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
                 success = _projectAccountDao.remove(projectAccount.getId());
 
                 if (success) {
-                    s_logger.debug("Removed user " + user.getId() + " from project. Removing any invite sent to the user");
+                    logger.debug("Removed user " + user.getId() + " from project. Removing any invite sent to the user");
                     ProjectInvitation invite = _projectInvitationDao.findByUserIdProjectId(user.getId(), user.getAccountId(),  projectId);
                     if (invite != null) {
                         success = success && _projectInvitationDao.remove(invite.getId());
@@ -1084,11 +1099,11 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
                 }
                 //remove the expired/declined invitation
                 if (accountId != null) {
-                    s_logger.debug("Removing invitation in state " + invite.getState() + " for account id=" + accountId + " to project " + project);
+                    logger.debug("Removing invitation in state " + invite.getState() + " for account id=" + accountId + " to project " + project);
                 } else if (userId != null) {
-                    s_logger.debug("Removing invitation in state " + invite.getState() + " for user id=" + userId + " to project " + project);
+                    logger.debug("Removing invitation in state " + invite.getState() + " for user id=" + userId + " to project " + project);
                 } else if (email != null) {
-                    s_logger.debug("Removing invitation in state " + invite.getState() + " for email " + email + " to project " + project);
+                    logger.debug("Removing invitation in state " + invite.getState() + " for email " + email + " to project " + project);
                 }
 
                 _projectInvitationDao.expunge(invite.getId());
@@ -1121,7 +1136,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
         try {
             sendInvite(token, email, project.getId());
         } catch (Exception ex) {
-            s_logger.warn("Failed to send project id=" + project + " invitation to the email " + email + "; removing the invitation record from the db", ex);
+            logger.warn("Failed to send project id=" + project + " invitation to the email " + email + "; removing the invitation record from the db", ex);
             _projectInvitationDao.remove(projectInvitation.getId());
             return null;
         }
@@ -1151,7 +1166,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
     }
 
     private boolean expireInvitation(ProjectInvitationVO invite) {
-        s_logger.debug("Expiring invitation id=" + invite.getId());
+        logger.debug("Expiring invitation id=" + invite.getId());
         invite.setState(ProjectInvitation.State.Expired);
         return _projectInvitationDao.update(invite.getId(), invite);
     }
@@ -1226,7 +1241,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
                         ProjectInvitation.State newState = accept ? ProjectInvitation.State.Completed : ProjectInvitation.State.Declined;
 
                         //update invitation
-                        s_logger.debug("Marking invitation " + inviteFinal + " with state " + newState);
+                        logger.debug("Marking invitation " + inviteFinal + " with state " + newState);
                         inviteFinal.setState(newState);
                         result = _projectInvitationDao.update(inviteFinal.getId(), inviteFinal);
 
@@ -1235,20 +1250,20 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
                             if (inviteFinal.getForUserId() == -1) {
                                 ProjectAccount projectAccount = _projectAccountDao.findByProjectIdAccountId(projectId, accountIdFinal);
                                 if (projectAccount != null) {
-                                    s_logger.debug("Account " + accountNameFinal + " already added to the project id=" + projectId);
+                                    logger.debug("Account " + accountNameFinal + " already added to the project id=" + projectId);
                                 } else {
                                     assignAccountToProject(project, accountIdFinal, inviteFinal.getAccountRole(), null, inviteFinal.getProjectRoleId());
                                 }
                             } else {
                                 ProjectAccount projectAccount = _projectAccountDao.findByProjectIdUserId(projectId, finalUser.getAccountId(), finalUser.getId());
                                 if (projectAccount != null) {
-                                    s_logger.debug("User " + finalUser.getId() + "has already been added to the project id=" + projectId);
+                                    logger.debug("User " + finalUser.getId() + "has already been added to the project id=" + projectId);
                                 } else {
                                     assignUserToProject(project, inviteFinal.getForUserId(), finalUser.getAccountId(), inviteFinal.getAccountRole(), inviteFinal.getProjectRoleId());
                                 }
                             }
                         } else {
-                            s_logger.warn("Failed to update project invitation " + inviteFinal + " with state " + newState);
+                            logger.warn("Failed to update project invitation " + inviteFinal + " with state " + newState);
                         }
                         return result;
                     }
@@ -1297,7 +1312,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
         Project.State currentState = project.getState();
 
         if (currentState == State.Active) {
-            s_logger.debug("The project id=" + projectId + " is already active, no need to activate it again");
+            logger.debug("The project id=" + projectId + " is already active, no need to activate it again");
             return project;
         }
 
@@ -1335,7 +1350,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
         _accountMgr.checkAccess(caller, AccessType.ModifyProject, true, _accountMgr.getAccount(project.getProjectAccountId()));
 
         if (suspendProject(project)) {
-            s_logger.debug("Successfully suspended project id=" + projectId);
+            logger.debug("Successfully suspended project id=" + projectId);
             return _projectDao.findById(projectId);
         } else {
             CloudRuntimeException ex = new CloudRuntimeException("Failed to suspend project with specified id");
@@ -1347,14 +1362,14 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
 
     private boolean suspendProject(ProjectVO project) throws ConcurrentOperationException, ResourceUnavailableException {
 
-        s_logger.debug("Marking project " + project + " with state " + State.Suspended + " as a part of project suspend...");
+        logger.debug("Marking project " + project + " with state " + State.Suspended + " as a part of project suspend...");
         project.setState(State.Suspended);
         boolean updateResult = _projectDao.update(project.getId(), project);
 
         if (updateResult) {
             long projectAccountId = project.getProjectAccountId();
             if (!_accountMgr.disableAccount(projectAccountId)) {
-                s_logger.warn("Failed to suspend all project's " + project + " resources; the resources will be suspended later by background thread");
+                logger.warn("Failed to suspend all project's " + project + " resources; the resources will be suspended later by background thread");
             }
         } else {
             throw new CloudRuntimeException("Failed to mark the project " + project + " with state " + State.Suspended);
@@ -1391,10 +1406,10 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
         _accountMgr.checkAccess(caller, AccessType.ModifyProject, true, _accountMgr.getAccount(project.getProjectAccountId()));
 
         if (_projectInvitationDao.remove(id)) {
-            s_logger.debug("Project Invitation id=" + id + " is removed");
+            logger.debug("Project Invitation id=" + id + " is removed");
             return true;
         } else {
-            s_logger.debug("Failed to remove project invitation id=" + id);
+            logger.debug("Failed to remove project invitation id=" + id);
             return false;
         }
     }
@@ -1406,15 +1421,15 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
                 TimeZone.getDefault();
                 List<ProjectInvitationVO> invitationsToExpire = _projectInvitationDao.listInvitationsToExpire(_invitationTimeOut);
                 if (!invitationsToExpire.isEmpty()) {
-                    s_logger.debug("Found " + invitationsToExpire.size() + " projects to expire");
+                    logger.debug("Found " + invitationsToExpire.size() + " projects to expire");
                     for (ProjectInvitationVO invitationToExpire : invitationsToExpire) {
                         invitationToExpire.setState(ProjectInvitation.State.Expired);
                         _projectInvitationDao.update(invitationToExpire.getId(), invitationToExpire);
-                        s_logger.trace("Expired project invitation id=" + invitationToExpire.getId());
+                        logger.trace("Expired project invitation id=" + invitationToExpire.getId());
                     }
                 }
             } catch (Exception ex) {
-                s_logger.warn("Exception while running expired invitations cleanup", ex);
+                logger.warn("Exception while running expired invitations cleanup", ex);
             }
         }
     }
@@ -1436,7 +1451,7 @@ public class ProjectManagerImpl extends ManagerBase implements ProjectManager, C
 
     @Override
     public ConfigKey<?>[] getConfigKeys() {
-        return new ConfigKey<?>[] {ProjectSmtpEnabledSecurityProtocols, ProjectSmtpUseStartTLS};
+        return new ConfigKey<?>[] {ProjectSmtpEnabledSecurityProtocols, ProjectSmtpUseStartTLS, ProjectSmtpUseAuth};
     }
 
     protected void updateProjectNameAndDisplayText(final ProjectVO project, String name, String displayText) {
