@@ -37,8 +37,6 @@ import org.apache.cloudstack.api.command.admin.resource.StartRollingMaintenanceC
 import org.apache.cloudstack.context.CallContext;
 import org.apache.cloudstack.framework.config.ConfigKey;
 import org.apache.commons.collections.CollectionUtils;
-import org.apache.commons.lang3.ObjectUtils;
-import org.apache.log4j.Logger;
 
 import com.cloud.agent.AgentManager;
 import com.cloud.agent.api.Answer;
@@ -66,16 +64,12 @@ import com.cloud.org.Grouping;
 import com.cloud.service.ServiceOfferingVO;
 import com.cloud.service.dao.ServiceOfferingDao;
 import com.cloud.utils.Pair;
-import com.cloud.utils.StringUtils;
 import com.cloud.utils.Ternary;
 import com.cloud.utils.component.ManagerBase;
 import com.cloud.utils.exception.CloudRuntimeException;
-import com.cloud.vm.UserVmDetailVO;
 import com.cloud.vm.VMInstanceVO;
 import com.cloud.vm.VirtualMachine.State;
 import com.cloud.vm.VirtualMachineProfileImpl;
-import com.cloud.vm.VmDetailConstants;
-import com.cloud.vm.dao.UserVmDetailsDao;
 import com.cloud.vm.dao.VMInstanceDao;
 
 public class RollingMaintenanceManagerImpl extends ManagerBase implements RollingMaintenanceManager {
@@ -91,8 +85,6 @@ public class RollingMaintenanceManagerImpl extends ManagerBase implements Rollin
     @Inject
     private VMInstanceDao vmInstanceDao;
     @Inject
-    protected UserVmDetailsDao userVmDetailsDao;
-    @Inject
     private ServiceOfferingDao serviceOfferingDao;
     @Inject
     private ClusterDetailsDao clusterDetailsDao;
@@ -107,7 +99,6 @@ public class RollingMaintenanceManagerImpl extends ManagerBase implements Rollin
         _affinityProcessors = affinityProcessors;
     }
 
-    public static final Logger s_logger = Logger.getLogger(RollingMaintenanceManagerImpl.class.getName());
 
     private Pair<ResourceType, List<Long>> getResourceTypeAndIdPair(List<Long> podIds, List<Long> clusterIds, List<Long> zoneIds, List<Long> hostIds) {
         Pair<ResourceType, List<Long>> pair = CollectionUtils.isNotEmpty(podIds) ? new Pair<>(ResourceType.Pod, podIds) :
@@ -201,11 +192,11 @@ public class RollingMaintenanceManagerImpl extends ManagerBase implements Rollin
                 }
                 disableClusterIfEnabled(cluster, disabledClusters);
 
-                s_logger.debug("State checks on the hosts in the cluster");
+                logger.debug("State checks on the hosts in the cluster");
                 performStateChecks(cluster, hosts, forced, hostsSkipped);
-                s_logger.debug("Checking hosts capacity before attempting rolling maintenance");
+                logger.debug("Checking hosts capacity before attempting rolling maintenance");
                 performCapacityChecks(cluster, hosts, forced);
-                s_logger.debug("Attempting pre-flight stages on each host before starting rolling maintenance");
+                logger.debug("Attempting pre-flight stages on each host before starting rolling maintenance");
                 performPreFlightChecks(hosts, timeout, payload, forced, hostsToAvoidMaintenance);
 
                 for (Host host: hosts) {
@@ -224,7 +215,7 @@ public class RollingMaintenanceManagerImpl extends ManagerBase implements Rollin
             }
         } catch (AgentUnavailableException | InterruptedException | CloudRuntimeException e) {
             String err = "Error starting rolling maintenance: " + e.getMessage();
-            s_logger.error(err, e);
+            logger.error(err, e);
             success = false;
             details = err;
             return new Ternary<>(success, details, new Pair<>(hostsUpdated, hostsSkipped));
@@ -318,7 +309,7 @@ public class RollingMaintenanceManagerImpl extends ManagerBase implements Rollin
             return new Ternary<>(false, true, "Maintenance stage must be avoided");
         }
 
-        s_logger.debug("Updating capacity before re-checking capacity");
+        logger.debug("Updating capacity before re-checking capacity");
         alertManager.recalculateCapacity();
         result = reCheckCapacityBeforeMaintenanceOnHost(cluster, host, forced, hostsSkipped);
         if (result.first() || result.second()) {
@@ -373,7 +364,7 @@ public class RollingMaintenanceManagerImpl extends ManagerBase implements Rollin
     private void cancelHostMaintenance(Host host) {
         if (!resourceManager.cancelMaintenance(host.getId())) {
             String message = "Could not cancel maintenance on host " + host.getUuid();
-            s_logger.error(message);
+            logger.error(message);
             throw new CloudRuntimeException(message);
         }
     }
@@ -406,7 +397,7 @@ public class RollingMaintenanceManagerImpl extends ManagerBase implements Rollin
      * @throws AgentUnavailableException
      */
     private void putHostIntoMaintenance(Host host) throws InterruptedException, AgentUnavailableException {
-        s_logger.debug(String.format("Trying to set %s into maintenance", host));
+        logger.debug(String.format("Trying to set %s into maintenance", host));
         PrepareForMaintenanceCmd cmd = new PrepareForMaintenanceCmd();
         cmd.setId(host.getId());
         resourceManager.maintain(cmd);
@@ -436,7 +427,7 @@ public class RollingMaintenanceManagerImpl extends ManagerBase implements Rollin
         if (!capacityCheckBeforeMaintenance.first()) {
             String errorMsg = String.format("Capacity check failed for %s: %s", host, capacityCheckBeforeMaintenance.second());
             if (forced) {
-                s_logger.info(String.format("Skipping %s as: %s", host, errorMsg));
+                logger.info(String.format("Skipping %s as: %s", host, errorMsg));
                 hostsSkipped.add(new HostSkipped(host, errorMsg));
                 return new Ternary<>(true, true, capacityCheckBeforeMaintenance.second());
             }
@@ -452,7 +443,7 @@ public class RollingMaintenanceManagerImpl extends ManagerBase implements Rollin
         if (hostsToAvoidMaintenance.containsKey(host.getId())) {
             HostSkipped hostSkipped = new HostSkipped(host, hostsToAvoidMaintenance.get(host.getId()));
             hostsSkipped.add(hostSkipped);
-            s_logger.debug(String.format("%s is in avoid maintenance list [hosts skipped: %d], skipping its maintenance.", host, hostsSkipped.size()));
+            logger.debug(String.format("%s is in avoid maintenance list [hosts skipped: %d], skipping its maintenance.", host, hostsSkipped.size()));
             return true;
         }
         return false;
@@ -503,7 +494,7 @@ public class RollingMaintenanceManagerImpl extends ManagerBase implements Rollin
             return answer.isMaintenaceScriptDefined();
         } catch (AgentUnavailableException | OperationTimedoutException e) {
             String msg = String.format("Could not check for maintenance script on %s due to: %s", host, e.getMessage());
-            s_logger.error(msg, e);
+            logger.error(msg, e);
             return false;
         }
     }
@@ -549,7 +540,7 @@ public class RollingMaintenanceManagerImpl extends ManagerBase implements Rollin
             } catch (AgentUnavailableException | OperationTimedoutException e) {
                 // Agent may be restarted on the scripts - continue polling until it is up
                 String msg = String.format("Cannot send command to %s, waiting %sms - %s", host, pingInterval, e.getMessage());
-                s_logger.warn(msg, e);
+                logger.warn(msg, e);
                 cmd.setStarted(true);
                 Thread.sleep(pingInterval);
                 timeSpent += pingInterval;
@@ -589,7 +580,7 @@ public class RollingMaintenanceManagerImpl extends ManagerBase implements Rollin
     }
 
     private void logHostAddedToAvoidMaintenanceSet(Host host) {
-        s_logger.debug(String.format("%s added to the avoid maintenance set.", host));
+        logger.debug(String.format("%s added to the avoid maintenance set.", host));
     }
 
     /**
@@ -628,19 +619,10 @@ public class RollingMaintenanceManagerImpl extends ManagerBase implements Rollin
         int successfullyCheckedVmMigrations = 0;
         for (VMInstanceVO runningVM : vmsRunning) {
             boolean canMigrateVm = false;
-            Ternary<Integer, Integer, Integer> cpuSpeedAndRamSize = getComputeResourcesCpuSpeedAndRamSize(runningVM);
-            Integer cpu = cpuSpeedAndRamSize.first();
-            Integer speed = cpuSpeedAndRamSize.second();
-            Integer ramSize = cpuSpeedAndRamSize.third();
-            if (ObjectUtils.anyNull(cpu, speed, ramSize)) {
-                s_logger.warn(String.format("Cannot fetch compute resources for the VM %s, skipping it from the capacity check", runningVM));
-                continue;
-            }
-
             ServiceOfferingVO serviceOffering = serviceOfferingDao.findById(runningVM.getServiceOfferingId());
             for (Host hostInCluster : hostsInCluster) {
                 if (!checkHostTags(hostTags, hostTagsDao.getHostTags(hostInCluster.getId()), serviceOffering.getHostTag())) {
-                    s_logger.warn(String.format("Host tags mismatch between %s and %s, skipping it from the capacity check", host, hostInCluster));
+                    logger.debug(String.format("Host tags mismatch between %s and %s Skipping it from the capacity check", host, hostInCluster));
                     continue;
                 }
                 DeployDestination deployDestination = new DeployDestination(null, null, null, host);
@@ -650,13 +632,13 @@ public class RollingMaintenanceManagerImpl extends ManagerBase implements Rollin
                     affinityChecks = affinityChecks && affinityProcessor.check(vmProfile, deployDestination);
                 }
                 if (!affinityChecks) {
-                    s_logger.warn(String.format("Affinity check failed between %s and %s, skipping it from the capacity check", host, hostInCluster));
+                    logger.debug(String.format("Affinity check failed between %s and %s Skipping it from the capacity check", host, hostInCluster));
                     continue;
                 }
                 boolean maxGuestLimit = capacityManager.checkIfHostReachMaxGuestLimit(host);
-                boolean hostHasCPUCapacity = capacityManager.checkIfHostHasCpuCapability(hostInCluster.getId(), cpu, speed);
-                int cpuRequested = cpu * speed;
-                long ramRequested = ramSize * 1024L * 1024L;
+                boolean hostHasCPUCapacity = capacityManager.checkIfHostHasCpuCapability(hostInCluster.getId(), serviceOffering.getCpu(), serviceOffering.getSpeed());
+                int cpuRequested = serviceOffering.getCpu() * serviceOffering.getSpeed();
+                long ramRequested = serviceOffering.getRamSize() * 1024L * 1024L;
                 ClusterDetailsVO clusterDetailsCpuOvercommit = clusterDetailsDao.findDetail(cluster.getId(), "cpuOvercommitRatio");
                 ClusterDetailsVO clusterDetailsRamOvercommmt = clusterDetailsDao.findDetail(cluster.getId(), "memoryOvercommitRatio");
                 Float cpuOvercommitRatio = Float.parseFloat(clusterDetailsCpuOvercommit.getValue());
@@ -670,7 +652,7 @@ public class RollingMaintenanceManagerImpl extends ManagerBase implements Rollin
             }
             if (!canMigrateVm) {
                 String msg = String.format("%s cannot be migrated away from %s to any other host in the cluster", runningVM, host);
-                s_logger.error(msg);
+                logger.error(msg);
                 return new Pair<>(false, msg);
             }
             successfullyCheckedVmMigrations++;
@@ -682,42 +664,11 @@ public class RollingMaintenanceManagerImpl extends ManagerBase implements Rollin
         return new Pair<>(true, "OK");
     }
 
-    protected Ternary<Integer, Integer, Integer> getComputeResourcesCpuSpeedAndRamSize(VMInstanceVO runningVM) {
-        ServiceOfferingVO serviceOffering = serviceOfferingDao.findById(runningVM.getServiceOfferingId());
-        Integer cpu = serviceOffering.getCpu();
-        Integer speed = serviceOffering.getSpeed();
-        Integer ramSize = serviceOffering.getRamSize();
-        if (!serviceOffering.isDynamic()) {
-            return new Ternary<>(cpu, speed, ramSize);
-        }
-
-        List<UserVmDetailVO> vmDetails = userVmDetailsDao.listDetails(runningVM.getId());
-        if (CollectionUtils.isEmpty(vmDetails)) {
-            return new Ternary<>(cpu, speed, ramSize);
-        }
-
-        for (UserVmDetailVO vmDetail : vmDetails) {
-            if (StringUtils.isBlank(vmDetail.getName()) || StringUtils.isBlank(vmDetail.getValue())) {
-                continue;
-            }
-
-            if (cpu == null && VmDetailConstants.CPU_NUMBER.equals(vmDetail.getName())) {
-                cpu = Integer.valueOf(vmDetail.getValue());
-            } else if (speed == null && VmDetailConstants.CPU_SPEED.equals(vmDetail.getName())) {
-                speed = Integer.valueOf(vmDetail.getValue());
-            } else if (ramSize == null && VmDetailConstants.MEMORY.equals(vmDetail.getName())) {
-                ramSize = Integer.valueOf(vmDetail.getValue());
-            }
-        }
-
-        return new Ternary<>(cpu, speed, ramSize);
-    }
-
     /**
      * Check hosts tags
      */
     private boolean checkHostTags(List<HostTagVO> hostTags, List<HostTagVO> hostInClusterTags, String offeringTag) {
-        if ((CollectionUtils.isEmpty(hostTags) && CollectionUtils.isEmpty(hostInClusterTags)) || StringUtils.isBlank(offeringTag)) {
+        if (CollectionUtils.isEmpty(hostTags) && CollectionUtils.isEmpty(hostInClusterTags)) {
             return true;
         } else if ((CollectionUtils.isNotEmpty(hostTags) && CollectionUtils.isEmpty(hostInClusterTags)) ||
                 (CollectionUtils.isEmpty(hostTags) && CollectionUtils.isNotEmpty(hostInClusterTags))) {
@@ -773,10 +724,10 @@ public class RollingMaintenanceManagerImpl extends ManagerBase implements Rollin
         if (host.getResourceState() != ResourceState.Maintenance) {
             String errorMsg = "Timeout: waited " + timeout + "ms for host " + host.getUuid() + "(" + host.getName() + ")" +
                     " to be in Maintenance state, but after timeout it is in " + host.getResourceState().toString() + " state";
-            s_logger.error(errorMsg);
+            logger.error(errorMsg);
             throw new CloudRuntimeException(errorMsg);
         }
-        s_logger.debug("Host " + host.getUuid() + "(" + host.getName() + ") is in maintenance");
+        logger.debug("Host " + host.getUuid() + "(" + host.getName() + ") is in maintenance");
     }
 
     @Override
