@@ -25,13 +25,11 @@ import javax.persistence.EntityExistsException;
 
 import org.apache.cloudstack.api.ApiCommandResourceType;
 import org.apache.cloudstack.context.CallContext;
-import org.apache.log4j.Logger;
 
 import com.cloud.domain.PartOf;
 import com.cloud.event.ActionEvent;
 import com.cloud.event.EventTypes;
 import com.cloud.exception.InvalidParameterValueException;
-import com.cloud.metadata.ResourceMetaDataManagerImpl;
 import com.cloud.network.security.SecurityGroupRuleVO;
 import com.cloud.network.security.SecurityGroupVO;
 import com.cloud.network.vpc.NetworkACLItemVO;
@@ -64,7 +62,6 @@ import com.cloud.utils.db.TransactionStatus;
 import com.cloud.utils.exception.CloudRuntimeException;
 
 public class ResourceIconManagerImpl extends ManagerBase implements ResourceIconManager {
-    public static final Logger s_logger = Logger.getLogger(ResourceMetaDataManagerImpl.class);
 
     @Inject
     AccountService accountService;
@@ -211,7 +208,7 @@ public class ResourceIconManagerImpl extends ManagerBase implements ResourceIcon
         Account caller = CallContext.current().getCallingAccount();
         List<? extends ResourceIcon> resourceIcons = searchResourceIcons(resourceIds, resourceType);
         if (resourceIcons.isEmpty()) {
-            s_logger.debug("No resource Icon(s) uploaded for the specified resources");
+            logger.debug("No resource Icon(s) uploaded for the specified resources");
             return false;
         }
         Transaction.execute(new TransactionCallbackNoReturn() {
@@ -226,7 +223,7 @@ public class ResourceIconManagerImpl extends ManagerBase implements ResourceIcon
                     Long accountId = accountDomainPair.first();
                     resourceManagerUtil.checkResourceAccessible(accountId, domainId, String.format("Account ' %s ' doesn't have permissions to upload icon for resource ' %s ", caller, id));
                     resourceIconDao.remove(resourceIcon.getId());
-                    s_logger.debug("Removed icon for resources (" +
+                    logger.debug("Removed icon for resources (" +
                             String.join(", ", resourceIds) + ")");
                 }
             }
