@@ -31,7 +31,8 @@ import org.apache.cloudstack.engine.subsystem.api.storage.DataStoreProviderManag
 import org.apache.cloudstack.storage.datastore.db.PrimaryDataStoreDao;
 import org.apache.cloudstack.storage.datastore.db.StoragePoolDetailsDao;
 import org.apache.cloudstack.storage.datastore.db.StoragePoolVO;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 import org.springframework.stereotype.Component;
 
 import com.cloud.agent.AgentManager;
@@ -68,7 +69,7 @@ import com.cloud.vm.dao.VMInstanceDao;
 
 @Component
 public class StoragePoolAutomationImpl implements StoragePoolAutomation {
-    private static final Logger s_logger = Logger.getLogger(StoragePoolAutomationImpl.class);
+    protected Logger logger = LogManager.getLogger(getClass());
     @Inject
     protected VirtualMachineManager vmMgr;
     @Inject
@@ -163,15 +164,15 @@ public class StoragePoolAutomationImpl implements StoragePoolAutomation {
                 ModifyStoragePoolCommand cmd = new ModifyStoragePoolCommand(false, storagePool);
                 final Answer answer = agentMgr.easySend(host.getId(), cmd);
                 if (answer == null || !answer.getResult()) {
-                    if (s_logger.isDebugEnabled()) {
-                        s_logger.debug("ModifyStoragePool false failed due to " + ((answer == null) ? "answer null" : answer.getDetails()));
+                    if (logger.isDebugEnabled()) {
+                        logger.debug("ModifyStoragePool false failed due to " + ((answer == null) ? "answer null" : answer.getDetails()));
                     }
                 } else {
-                    if (s_logger.isDebugEnabled()) {
-                        s_logger.debug("ModifyStoragePool false succeeded");
+                    if (logger.isDebugEnabled()) {
+                        logger.debug("ModifyStoragePool false succeeded");
                     }
                     if (pool.getPoolType() == Storage.StoragePoolType.DatastoreCluster) {
-                        s_logger.debug(String.format("Started synchronising datastore cluster storage pool %s with vCenter", pool.getUuid()));
+                        logger.debug(String.format("Started synchronising datastore cluster storage pool %s with vCenter", pool.getUuid()));
                         storageManager.syncDatastoreClusterStoragePool(pool.getId(), ((ModifyStoragePoolAnswer) answer).getDatastoreClusterChildren(), host.getId());
                     }
                 }
@@ -203,8 +204,8 @@ public class StoragePoolAutomationImpl implements StoragePoolAutomation {
                         StoragePoolWorkVO work = new StoragePoolWorkVO(vmInstance.getId(), pool.getId(), false, false, server.getId());
                         _storagePoolWorkDao.persist(work);
                     } catch (Exception e) {
-                        if (s_logger.isDebugEnabled()) {
-                            s_logger.debug("Work record already exists, re-using by re-setting values");
+                        if (logger.isDebugEnabled()) {
+                            logger.debug("Work record already exists, re-using by re-setting values");
                         }
                         StoragePoolWorkVO work = _storagePoolWorkDao.findByPoolIdAndVmId(pool.getId(), vmInstance.getId());
                         work.setStartedAfterMaintenance(false);
@@ -289,7 +290,7 @@ public class StoragePoolAutomationImpl implements StoragePoolAutomation {
                 }
             }
         } catch (Exception e) {
-            s_logger.error("Exception in enabling primary storage maintenance:", e);
+            logger.error("Exception in enabling primary storage maintenance:", e);
             pool.setStatus(StoragePoolStatus.ErrorInMaintenance);
             primaryDataStoreDao.update(pool.getId(), pool);
             throw new CloudRuntimeException(e.getMessage());
@@ -330,11 +331,11 @@ public class StoragePoolAutomationImpl implements StoragePoolAutomation {
             ModifyStoragePoolCommand msPoolCmd = new ModifyStoragePoolCommand(true, pool, nfsMountOpts.first());
             final Answer answer = agentMgr.easySend(host.getId(), msPoolCmd);
             if (answer == null || !answer.getResult()) {
-                if (s_logger.isDebugEnabled()) {
-                    s_logger.debug("ModifyStoragePool add failed due to " + ((answer == null) ? "answer null" : answer.getDetails()));
+                if (logger.isDebugEnabled()) {
+                    logger.debug("ModifyStoragePool add failed due to " + ((answer == null) ? "answer null" : answer.getDetails()));
                 }
                 if (answer != null && nfsMountOpts.second()) {
-                    s_logger.error(String.format("Unable to attach storage pool to the host %s due to %s",  host,  answer.getDetails()));
+                    logger.error(String.format("Unable to attach storage pool to the host %s due to %s",  host,  answer.getDetails()));
                     StringBuilder exceptionSB = new StringBuilder("Unable to attach storage pool to the host ").append(host.getName());
                     String reason = storageManager.getStoragePoolMountFailureReason(answer.getDetails());
                     if (reason!= null) {
@@ -343,11 +344,11 @@ public class StoragePoolAutomationImpl implements StoragePoolAutomation {
                     throw new CloudRuntimeException(exceptionSB.toString());
                 }
             } else {
-                if (s_logger.isDebugEnabled()) {
-                    s_logger.debug("ModifyStoragePool add succeeded");
+                if (logger.isDebugEnabled()) {
+                    logger.debug("ModifyStoragePool add succeeded");
                 }
                 if (pool.getPoolType() == Storage.StoragePoolType.DatastoreCluster) {
-                    s_logger.debug(String.format("Started synchronising datastore cluster storage pool %s with vCenter", pool.getUuid()));
+                    logger.debug(String.format("Started synchronising datastore cluster storage pool %s with vCenter", pool.getUuid()));
                     storageManager.syncDatastoreClusterStoragePool(pool.getId(), ((ModifyStoragePoolAnswer) answer).getDatastoreClusterChildren(), host.getId());
                 }
             }
@@ -415,7 +416,7 @@ public class StoragePoolAutomationImpl implements StoragePoolAutomation {
                     }
                 }
             } catch (Exception e) {
-                s_logger.debug("Failed start vm", e);
+                logger.debug("Failed start vm", e);
                 throw new CloudRuntimeException(e.toString());
             }
         }
