@@ -51,11 +51,11 @@ import org.apache.cloudstack.context.CallContext;
 import org.apache.cloudstack.engine.orchestration.service.NetworkOrchestrationService;
 import org.apache.cloudstack.framework.messagebus.MessageBus;
 import org.apache.cloudstack.framework.messagebus.PublishScope;
+import org.apache.cloudstack.network.RoutedIpv4Manager;
 import org.apache.cloudstack.region.RegionManager;
 import org.apache.cloudstack.resourcedetail.dao.DiskOfferingDetailsDao;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang.BooleanUtils;
-import org.apache.log4j.Logger;
 import org.springframework.stereotype.Component;
 
 import com.cloud.api.query.dao.DiskOfferingJoinDao;
@@ -105,7 +105,6 @@ import org.apache.commons.lang3.StringUtils;
 
 @Component
 public class DomainManagerImpl extends ManagerBase implements DomainManager, DomainService {
-    public static final Logger s_logger = Logger.getLogger(DomainManagerImpl.class);
 
     @Inject
     private DomainDao _domainDao;
@@ -163,6 +162,8 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
     private ResourceLimitService resourceLimitService;
     @Inject
     private AffinityGroupDomainMapDao affinityGroupDomainMapDao;
+    @Inject
+    private RoutedIpv4Manager routedIpv4Manager;
 
     @Inject
     MessageBus _messageBus;
@@ -265,7 +266,7 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
     protected DomainVO createDomainVo(String name, Long parentId, Long ownerId, String networkDomain, String domainUuid) {
         if (StringUtils.isBlank(domainUuid)) {
             domainUuid = UUID.randomUUID().toString();
-            s_logger.info(String.format("Domain UUID [%s] generated for domain name [%s].", domainUuid, name));
+            logger.info(String.format("Domain UUID [%s] generated for domain name [%s].", domainUuid, name));
         }
 
         DomainVO domainVO = new DomainVO(name, ownerId, parentId, networkDomain, domainUuid);
@@ -361,7 +362,7 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
 
         try {
             // mark domain as inactive
-            s_logger.debug("Marking domain id=" + domain.getId() + " as " + Domain.State.Inactive + " before actually deleting it");
+            logger.debug("Marking domain id=" + domain.getId() + " as " + Domain.State.Inactive + " before actually deleting it");
             domain.setState(Domain.State.Inactive);
             _domainDao.update(domain.getId(), domain);
 
@@ -375,12 +376,12 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
     private GlobalLock getGlobalLock() {
         GlobalLock lock = getGlobalLock("DomainCleanup");
         if (lock == null) {
-            s_logger.debug("Couldn't get the global lock");
+            logger.debug("Couldn't get the global lock");
             return null;
         }
 
         if (!lock.lock(30)) {
-            s_logger.debug("Couldn't lock the db");
+            logger.debug("Couldn't lock the db");
             return null;
         }
         return lock;
@@ -395,12 +396,18 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
                 removeDomainWithNoAccountsForCleanupNetworksOrDedicatedResources(domain);
             }
 
+            // remove dedicated IPv4 subnets
+            routedIpv4Manager.removeIpv4SubnetsForZoneByDomainId(domain.getId());
+
+            // remove dedicated BGP peers
+            routedIpv4Manager.removeBgpPeersByDomainId(domain.getId());
+
             if (!_configMgr.releaseDomainSpecificVirtualRanges(domain.getId())) {
                 CloudRuntimeException e = new CloudRuntimeException("Can't delete the domain yet because failed to release domain specific virtual ip ranges");
                 e.addProxyObject(domain.getUuid(), "domainId");
                 throw e;
             } else {
-                s_logger.debug("Domain specific Virtual IP ranges " + " are successfully released as a part of domain id=" + domain.getId() + " cleanup.");
+                logger.debug("Domain specific Virtual IP ranges " + " are successfully released as a part of domain id=" + domain.getId() + " cleanup.");
             }
 
             cleanupDomainDetails(domain.getId());
@@ -409,7 +416,7 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
             CallContext.current().putContextParameter(Domain.class, domain.getUuid());
             return true;
         } catch (Exception ex) {
-            s_logger.error("Exception deleting domain with id " + domain.getId(), ex);
+            logger.error("Exception deleting domain with id " + domain.getId(), ex);
             if (ex instanceof CloudRuntimeException) {
                 rollbackDomainState(domain);
                 throw (CloudRuntimeException)ex;
@@ -424,7 +431,7 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
      * @param domain domain
      */
     protected void rollbackDomainState(DomainVO domain) {
-        s_logger.debug("Changing domain id=" + domain.getId() + " state back to " + Domain.State.Active +
+        logger.debug("Changing domain id=" + domain.getId() + " state back to " + Domain.State.Active +
                 " because it can't be removed due to resources referencing to it");
         domain.setState(Domain.State.Active);
         _domainDao.update(domain.getId(), domain);
@@ -465,7 +472,7 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
         List<AccountVO> accountsForCleanup = _accountDao.findCleanupsForRemovedAccounts(domain.getId());
         List<DedicatedResourceVO> dedicatedResources = _dedicatedDao.listByDomainId(domain.getId());
         if (CollectionUtils.isNotEmpty(dedicatedResources)) {
-            s_logger.error("There are dedicated resources for the domain " + domain.getId());
+            logger.error("There are dedicated resources for the domain " + domain.getId());
             hasDedicatedResources = true;
         }
         if (accountsForCleanup.isEmpty() && networkIds.isEmpty() && !hasDedicatedResources) {
@@ -597,7 +604,7 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
     }
 
     protected boolean cleanupDomain(Long domainId, Long ownerId) throws ConcurrentOperationException, ResourceUnavailableException {
-        s_logger.debug("Cleaning up domain id=" + domainId);
+        logger.debug("Cleaning up domain id=" + domainId);
         boolean success = true;
         DomainVO domainHandle = _domainDao.findById(domainId);
         {
@@ -622,7 +629,7 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
             for (DomainVO domain : domains) {
                 success = (success && cleanupDomain(domain.getId(), domain.getAccountId()));
                 if (!success) {
-                    s_logger.warn("Failed to cleanup domain id=" + domain.getId());
+                    logger.warn("Failed to cleanup domain id=" + domain.getId());
                 }
             }
         }
@@ -633,18 +640,18 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
         List<AccountVO> accounts = _accountDao.search(sc, null);
         for (AccountVO account : accounts) {
             if (account.getType() != Account.Type.PROJECT) {
-                s_logger.debug("Deleting account " + account + " as a part of domain id=" + domainId + " cleanup");
+                logger.debug("Deleting account " + account + " as a part of domain id=" + domainId + " cleanup");
                 boolean deleteAccount = _accountMgr.deleteAccount(account, CallContext.current().getCallingUserId(), getCaller());
                 if (!deleteAccount) {
-                    s_logger.warn("Failed to cleanup account id=" + account.getId() + " as a part of domain cleanup");
+                    logger.warn("Failed to cleanup account id=" + account.getId() + " as a part of domain cleanup");
                 }
                 success = (success && deleteAccount);
             } else {
                 ProjectVO project = _projectDao.findByProjectAccountId(account.getId());
-                s_logger.debug("Deleting project " + project + " as a part of domain id=" + domainId + " cleanup");
+                logger.debug("Deleting project " + project + " as a part of domain id=" + domainId + " cleanup");
                 boolean deleteProject = _projectMgr.deleteProject(getCaller(), CallContext.current().getCallingUserId(), project);
                 if (!deleteProject) {
-                    s_logger.warn("Failed to cleanup project " + project + " as a part of domain cleanup");
+                    logger.warn("Failed to cleanup project " + project + " as a part of domain cleanup");
                 }
                 success = (success && deleteProject);
             }
@@ -652,23 +659,23 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
 
         //delete the domain shared networks
         boolean networksDeleted = true;
-        s_logger.debug("Deleting networks for domain id=" + domainId);
+        logger.debug("Deleting networks for domain id=" + domainId);
         List<Long> networkIds = _networkDomainDao.listNetworkIdsByDomain(domainId);
         CallContext ctx = CallContext.current();
         ReservationContext context = new ReservationContextImpl(null, null, _accountMgr.getActiveUser(ctx.getCallingUserId()), ctx.getCallingAccount());
         for (Long networkId : networkIds) {
-            s_logger.debug("Deleting network id=" + networkId + " as a part of domain id=" + domainId + " cleanup");
+            logger.debug("Deleting network id=" + networkId + " as a part of domain id=" + domainId + " cleanup");
             if (!_networkMgr.destroyNetwork(networkId, context, false)) {
-                s_logger.warn("Unable to destroy network id=" + networkId + " as a part of domain id=" + domainId + " cleanup.");
+                logger.warn("Unable to destroy network id=" + networkId + " as a part of domain id=" + domainId + " cleanup.");
                 networksDeleted = false;
             } else {
-                s_logger.debug("Network " + networkId + " successfully deleted as a part of domain id=" + domainId + " cleanup.");
+                logger.debug("Network " + networkId + " successfully deleted as a part of domain id=" + domainId + " cleanup.");
             }
         }
 
         //don't proceed if networks failed to cleanup. The cleanup will be performed for inactive domain once again
         if (!networksDeleted) {
-            s_logger.debug("Failed to delete the shared networks as a part of domain id=" + domainId + " clenaup");
+            logger.debug("Failed to delete the shared networks as a part of domain id=" + domainId + " clenaup");
             return false;
         }
 
@@ -679,10 +686,10 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
             //release dedication if any, before deleting the domain
             List<DedicatedResourceVO> dedicatedResources = _dedicatedDao.listByDomainId(domainId);
             if (dedicatedResources != null && !dedicatedResources.isEmpty()) {
-                s_logger.debug("Releasing dedicated resources for domain" + domainId);
+                logger.debug("Releasing dedicated resources for domain" + domainId);
                 for (DedicatedResourceVO dr : dedicatedResources) {
                     if (!_dedicatedDao.remove(dr.getId())) {
-                        s_logger.warn("Fail to release dedicated resources for domain " + domainId);
+                        logger.warn("Fail to release dedicated resources for domain " + domainId);
                         return false;
                     }
                 }
@@ -696,7 +703,7 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
             _resourceCountDao.removeEntriesByOwner(domainId, ResourceOwnerType.Domain);
             _resourceLimitDao.removeEntriesByOwner(domainId, ResourceOwnerType.Domain);
         } else {
-            s_logger.debug("Can't delete the domain yet because it has " + accountsForCleanup.size() + "accounts that need a cleanup");
+            logger.debug("Can't delete the domain yet because it has " + accountsForCleanup.size() + "accounts that need a cleanup");
             return false;
         }
 
@@ -938,10 +945,10 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
         }
 
         DomainVO domainToBeMoved = returnDomainIfExistsAndIsActive(idOfDomainToBeMoved);
-        s_logger.debug(String.format("Found the domain [%s] as the domain to be moved.", domainToBeMoved));
+        logger.debug(String.format("Found the domain [%s] as the domain to be moved.", domainToBeMoved));
 
         DomainVO newParentDomain = returnDomainIfExistsAndIsActive(idOfNewParentDomain);
-        s_logger.debug(String.format("Found the domain [%s] as the new parent domain of the domain to be moved [%s].", newParentDomain, domainToBeMoved));
+        logger.debug(String.format("Found the domain [%s] as the new parent domain of the domain to be moved [%s].", newParentDomain, domainToBeMoved));
 
         Account caller = getCaller();
         _accountMgr.checkAccess(caller, domainToBeMoved);
@@ -970,7 +977,7 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
         Transaction.execute(new TransactionCallbackNoReturn() {
             @Override
             public void doInTransactionWithoutResult(TransactionStatus status) {
-                s_logger.debug(String.format("Setting the new parent of the domain to be moved [%s] as [%s].", domainToBeMoved, newParentDomain));
+                logger.debug(String.format("Setting the new parent of the domain to be moved [%s] as [%s].", domainToBeMoved, newParentDomain));
                 domainToBeMoved.setParent(idOfNewParentDomain);
 
                 updateDomainAndChildrenPathAndLevel(domainToBeMoved, newParentDomain, currentPathOfDomainToBeMoved, newPathOfDomainToBeMoved);
@@ -984,25 +991,43 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
         return domainToBeMoved;
     }
 
-    protected void validateNewParentDomainResourceLimits(DomainVO domainToBeMoved, DomainVO newParentDomain) throws ResourceAllocationException {
+    protected void validateNewParentDomainResourceLimit(DomainVO domainToBeMoved, DomainVO newParentDomain,
+            Resource.ResourceType resourceType, String tag) throws ResourceAllocationException {
         long domainToBeMovedId = domainToBeMoved.getId();
         long newParentDomainId = newParentDomain.getId();
+        long currentDomainResourceCount = _resourceCountDao.getResourceCount(domainToBeMovedId, ResourceOwnerType.Domain, resourceType, tag);
+        long newParentDomainResourceCount = _resourceCountDao.getResourceCount(newParentDomainId, ResourceOwnerType.Domain, resourceType, tag);
+        long newParentDomainResourceLimit = resourceLimitService.findCorrectResourceLimitForDomain(newParentDomain, resourceType, tag);
+
+        if (newParentDomainResourceLimit == Resource.RESOURCE_UNLIMITED) {
+            return;
+        }
+
+        if (currentDomainResourceCount + newParentDomainResourceCount > newParentDomainResourceLimit) {
+            String message = String.format("Cannot move domain [%s] to parent domain [%s] as maximum domain resource limit of type [%s] would be exceeded. The current resource "
+                            + "count for domain [%s] is [%s], the resource count for the new parent domain [%s] is [%s], and the limit is [%s].", domainToBeMoved.getUuid(),
+                    newParentDomain.getUuid(), resourceType, domainToBeMoved.getUuid(), currentDomainResourceCount, newParentDomain.getUuid(), newParentDomainResourceCount,
+                    newParentDomainResourceLimit);
+            logger.error(message);
+            throw new ResourceAllocationException(message, resourceType);
+        }
+    }
+
+
+    protected void validateNewParentDomainResourceLimits(DomainVO domainToBeMoved, DomainVO newParentDomain) throws ResourceAllocationException {
+        List<String> hostTags = resourceLimitService.getResourceLimitHostTags();
+        List<String> storageTags = resourceLimitService.getResourceLimitStorageTags();
         for (Resource.ResourceType resourceType : Resource.ResourceType.values()) {
-            long currentDomainResourceCount = _resourceCountDao.getResourceCount(domainToBeMovedId, ResourceOwnerType.Domain, resourceType);
-            long newParentDomainResourceCount = _resourceCountDao.getResourceCount(newParentDomainId, ResourceOwnerType.Domain, resourceType);
-            long newParentDomainResourceLimit = resourceLimitService.findCorrectResourceLimitForDomain(newParentDomain, resourceType);
-
-            if (newParentDomainResourceLimit == Resource.RESOURCE_UNLIMITED) {
-                return;
+            validateNewParentDomainResourceLimit(domainToBeMoved, newParentDomain, resourceType, null);
+            if (ResourceLimitService.HostTagsSupportingTypes.contains(resourceType)) {
+                for (String tag : hostTags) {
+                    validateNewParentDomainResourceLimit(domainToBeMoved, newParentDomain, resourceType, tag);
+                }
             }
-
-            if (currentDomainResourceCount + newParentDomainResourceCount > newParentDomainResourceLimit) {
-                String message = String.format("Cannot move domain [%s] to parent domain [%s] as maximum domain resource limit of type [%s] would be exceeded. The current resource "
-                        + "count for domain [%s] is [%s], the resource count for the new parent domain [%s] is [%s], and the limit is [%s].", domainToBeMoved.getUuid(),
-                        newParentDomain.getUuid(), resourceType, domainToBeMoved.getUuid(), currentDomainResourceCount, newParentDomain.getUuid(), newParentDomainResourceCount,
-                        newParentDomainResourceLimit);
-                s_logger.error(message);
-                throw new ResourceAllocationException(message, resourceType);
+            if (ResourceLimitService.StorageTagsSupportingTypes.contains(resourceType)) {
+                for (String tag : storageTags) {
+                    validateNewParentDomainResourceLimit(domainToBeMoved, newParentDomain, resourceType, tag);
+                }
             }
         }
     }
@@ -1043,7 +1068,7 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
         }
 
         if (!domainsOfResourcesInaccessibleToNewParentDomain.isEmpty()) {
-            s_logger.error(String.format("The new parent domain [%s] does not have access to domains [%s] used by [%s] in the domain to be moved [%s].",
+            logger.error(String.format("The new parent domain [%s] does not have access to domains [%s] used by [%s] in the domain to be moved [%s].",
                     newParentDomain, domainsOfResourcesInaccessibleToNewParentDomain.keySet(), domainsOfResourcesInaccessibleToNewParentDomain.values(), domainToBeMoved));
             throw new InvalidParameterValueException(String.format("New parent domain [%s] does not have access to [%s] used by domain [%s], therefore, domain [%s] cannot be moved.",
                     newParentDomain, resourceToLog, domainToBeMoved, domainToBeMoved));
@@ -1051,7 +1076,7 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
     }
 
     protected DomainVO returnDomainIfExistsAndIsActive(Long idOfDomain) {
-        s_logger.debug(String.format("Checking if domain with ID [%s] exists and is active.", idOfDomain));
+        logger.debug(String.format("Checking if domain with ID [%s] exists and is active.", idOfDomain));
         DomainVO domain = _domainDao.findById(idOfDomain);
 
         if (domain == null) {
@@ -1083,12 +1108,12 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
         int finalLevel = newLevel + currentLevel - oldRootLevel;
         domain.setLevel(finalLevel);
 
-        s_logger.debug(String.format("Updating the path to [%s] and the level to [%s] of the domain [%s].", finalPath, finalLevel, domain));
+        logger.debug(String.format("Updating the path to [%s] and the level to [%s] of the domain [%s].", finalPath, finalLevel, domain));
         _domainDao.update(domain.getId(), domain);
     }
 
     protected void updateResourceCounts(Long idOfOldParentDomain, Long idOfNewParentDomain) {
-        s_logger.debug(String.format("Updating the resource counts of the old parent domain [%s] and of the new parent domain [%s].", idOfOldParentDomain, idOfNewParentDomain));
+        logger.debug(String.format("Updating the resource counts of the old parent domain [%s] and of the new parent domain [%s].", idOfOldParentDomain, idOfNewParentDomain));
         resourceLimitService.recalculateResourceCount(null, idOfOldParentDomain, null);
         resourceLimitService.recalculateResourceCount(null, idOfNewParentDomain, null);
     }
@@ -1099,7 +1124,7 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
         oldParentDomain.setChildCount(finalOldParentChildCount);
         oldParentDomain.setNextChildSeq(finalOldParentChildCount + 1);
 
-        s_logger.debug(String.format("Updating the child count of the old parent domain [%s] to [%s].", oldParentDomain, finalOldParentChildCount));
+        logger.debug(String.format("Updating the child count of the old parent domain [%s] to [%s].", oldParentDomain, finalOldParentChildCount));
         _domainDao.update(oldParentDomain.getId(), oldParentDomain);
 
         int finalNewParentChildCount = newParentDomain.getChildCount() + 1;
@@ -1107,7 +1132,7 @@ public class DomainManagerImpl extends ManagerBase implements DomainManager, Dom
         newParentDomain.setChildCount(finalNewParentChildCount);
         newParentDomain.setNextChildSeq(finalNewParentChildCount + 1);
 
-        s_logger.debug(String.format("Updating the child count of the new parent domain [%s] to [%s].", newParentDomain, finalNewParentChildCount));
+        logger.debug(String.format("Updating the child count of the new parent domain [%s] to [%s].", newParentDomain, finalNewParentChildCount));
         _domainDao.update(newParentDomain.getId(), newParentDomain);
     }
 }
