@@ -36,7 +36,6 @@ import org.apache.cloudstack.api.command.admin.acl.project.UpdateProjectRoleCmd;
 import org.apache.cloudstack.api.command.admin.acl.project.UpdateProjectRolePermissionCmd;
 import org.apache.cloudstack.context.CallContext;
 import org.apache.commons.lang3.StringUtils;
-import org.apache.log4j.Logger;
 
 import com.cloud.event.ActionEvent;
 import com.cloud.event.EventTypes;
@@ -71,7 +70,6 @@ public class ProjectRoleManagerImpl extends ManagerBase implements ProjectRoleSe
     @Inject
     AccountService accountService;
 
-    private static final Logger LOGGER = Logger.getLogger(ProjectRoleManagerImpl.class);
 
     private Project validateProjectId(Long projectId) {
         Project project = projectDao.findById(projectId);
@@ -147,22 +145,22 @@ public class ProjectRoleManagerImpl extends ManagerBase implements ProjectRoleSe
     @Override
     public ProjectRole findProjectRole(Long roleId, Long projectId) {
         if (projectId == null || projectId < 1L || projectDao.findById(projectId) == null) {
-            LOGGER.warn("Invalid project ID provided");
+            logger.warn("Invalid project ID provided");
             return null;
         }
 
         if (roleId != null && roleId < 1L) {
-            LOGGER.warn(String.format("Project Role ID is invalid [%s]", roleId));
+            logger.warn(String.format("Project Role ID is invalid [%s]", roleId));
             return null;
         }
 
         ProjectRoleVO role = projRoleDao.findById(roleId);
         if (role == null) {
-            LOGGER.warn(String.format("Project Role not found [id=%s]", roleId));
+            logger.warn(String.format("Project Role not found [id=%s]", roleId));
             return null;
         }
         if (!(role.getProjectId().equals(projectId))) {
-            LOGGER.warn(String.format("Project role : %s doesn't belong to the project" + role.getName()));
+            logger.warn(String.format("Project role : %s doesn't belong to the project" + role.getName()));
             return null;
         }
         return role;
@@ -171,7 +169,7 @@ public class ProjectRoleManagerImpl extends ManagerBase implements ProjectRoleSe
     @Override
     public List<ProjectRole> findProjectRoles(Long projectId, String keyword) {
         if (projectId == null || projectId < 1L || projectDao.findById(projectId) == null) {
-            LOGGER.warn("Invalid project ID provided");
+            logger.warn("Invalid project ID provided");
             return null;
         }
         return ListUtils.toListOfInterface(projRoleDao.findAllRoles(projectId, keyword));
