@@ -56,7 +56,6 @@ import org.apache.cloudstack.poll.BackgroundPollManager;
 import org.apache.cloudstack.poll.BackgroundPollTask;
 import org.apache.cloudstack.utils.identity.ManagementServerNode;
 import org.apache.cloudstack.utils.security.CertUtils;
-import org.apache.log4j.Logger;
 import org.joda.time.DateTime;
 import org.joda.time.DateTimeZone;
 
@@ -76,7 +75,6 @@ import com.cloud.utils.exception.CloudRuntimeException;
 import org.apache.commons.lang3.StringUtils;
 
 public class CAManagerImpl extends ManagerBase implements CAManager {
-    public static final Logger LOG = Logger.getLogger(CAManagerImpl.class);
 
     @Inject
     private CrlDao crlDao;
@@ -197,7 +195,7 @@ public class CAManagerImpl extends ManagerBase implements CAManager {
             final Certificate certificate = issueCertificate(csr, Arrays.asList(host.getName(), host.getPrivateIpAddress()), Arrays.asList(host.getPrivateIpAddress(), host.getPublicIpAddress(), host.getStorageIpAddress()), CAManager.CertValidityPeriod.value(), caProvider);
             return deployCertificate(host, certificate, reconnect, null);
         } catch (final AgentUnavailableException | OperationTimedoutException e) {
-            LOG.error("Host/agent is not available or operation timed out, failed to setup keystore and generate CSR for host/agent id=" + host.getId() + ", due to: ", e);
+            logger.error("Host/agent is not available or operation timed out, failed to setup keystore and generate CSR for host/agent id=" + host.getId() + ", due to: ", e);
             throw new CloudRuntimeException("Failed to generate keystore and get CSR from the host/agent id=" + host.getId());
         }
     }
@@ -236,11 +234,11 @@ public class CAManagerImpl extends ManagerBase implements CAManager {
         if (answer.getResult()) {
             getActiveCertificatesMap().put(host.getPrivateIpAddress(), certificate.getClientCertificate());
             if (sshAccessDetails == null && reconnect != null && reconnect) {
-                LOG.info(String.format("Successfully setup certificate on host, reconnecting with agent with id=%d, name=%s, address=%s", host.getId(), host.getName(), host.getPublicIpAddress()));
+                logger.info(String.format("Successfully setup certificate on host, reconnecting with agent with id=%d, name=%s, address=%s", host.getId(), host.getName(), host.getPublicIpAddress()));
                 try {
                     agentManager.reconnect(host.getId());
                 } catch (AgentUnavailableException | CloudRuntimeException e) {
-                    LOG.debug("Error when reconnecting to host: " + host.getUuid(), e);
+                    logger.debug("Error when reconnecting to host: " + host.getUuid(), e);
                 }
             }
             return true;
@@ -309,8 +307,8 @@ public class CAManagerImpl extends ManagerBase implements CAManager {
         @Override
         protected void runInContext() {
             try {
-                if (LOG.isTraceEnabled()) {
-                    LOG.trace("CA background task is running...");
+                if (logger.isTraceEnabled()) {
+                    logger.trace("CA background task is running...");
                 }
                 final DateTime now = DateTime.now(DateTimeZone.UTC);
                 final Map<String, X509Certificate> certsMap = caManager.getActiveCertificatesMap();
@@ -338,18 +336,18 @@ public class CAManagerImpl extends ManagerBase implements CAManager {
                     try {
                         certificate.checkValidity(now.plusDays(CertExpiryAlertPeriod.valueIn(host.getClusterId())).toDate());
                     } catch (final CertificateExpiredException | CertificateNotYetValidException e) {
-                        LOG.warn("Certificate is going to expire for " + hostDescription, e);
+                        logger.warn("Certificate is going to expire for " + hostDescription, e);
                         if (AutomaticCertRenewal.valueIn(host.getClusterId())) {
                             try {
-                                LOG.debug("Attempting certificate auto-renewal for " + hostDescription, e);
+                                logger.debug("Attempting certificate auto-renewal for " + hostDescription, e);
                                 boolean result = caManager.provisionCertificate(host, false, null);
                                 if (result) {
-                                    LOG.debug("Succeeded in auto-renewing certificate for " + hostDescription, e);
+                                    logger.debug("Succeeded in auto-renewing certificate for " + hostDescription, e);
                                 } else {
-                                    LOG.debug("Failed in auto-renewing certificate for " + hostDescription, e);
+                                    logger.debug("Failed in auto-renewing certificate for " + hostDescription, e);
                                 }
                             } catch (final Throwable ex) {
-                                LOG.warn("Failed to auto-renew certificate for " + hostDescription + ", with error=", ex);
+                                logger.warn("Failed to auto-renew certificate for " + hostDescription + ", with error=", ex);
                                 caManager.sendAlert(host, "Certificate auto-renewal failed for " + hostDescription,
                                         String.format("Certificate is going to expire for %s. Auto-renewal failed to renew the certificate, please renew it manually. It is not valid after %s.",
                                                 hostDescription, certificate.getNotAfter()));
@@ -368,7 +366,7 @@ public class CAManagerImpl extends ManagerBase implements CAManager {
                     }
                 }
             } catch (final Throwable t) {
-                LOG.error("Error trying to run CA background task", t);
+                logger.error("Error trying to run CA background task", t);
             }
         }
 
@@ -399,7 +397,7 @@ public class CAManagerImpl extends ManagerBase implements CAManager {
             configuredCaProvider = caProviderMap.get(CAProviderPlugin.value());
         }
         if (configuredCaProvider == null) {
-            LOG.error("Failed to find valid configured CA provider, please check!");
+            logger.error("Failed to find valid configured CA provider, please check!");
             return false;
         }
         return true;
