@@ -73,7 +73,6 @@ import org.apache.cloudstack.storage.to.TemplateObjectTO;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.collections.MapUtils;
 import org.apache.commons.lang3.StringUtils;
-import org.apache.log4j.Logger;
 import org.joda.time.DateTime;
 import org.joda.time.DateTimeZone;
 
@@ -103,14 +102,12 @@ import com.cloud.storage.dao.VMTemplatePoolDao;
 import com.cloud.utils.component.ManagerBase;
 import com.cloud.utils.concurrency.NamedThreadFactory;
 import com.cloud.utils.exception.CloudRuntimeException;
-import com.cloud.utils.net.NetUtils;
 import com.cloud.utils.security.CertificateHelper;
 
 import sun.security.x509.X509CertImpl;
 
 public class DirectDownloadManagerImpl extends ManagerBase implements DirectDownloadManager {
 
-    private static final Logger s_logger = Logger.getLogger(DirectDownloadManagerImpl.class);
     protected static final String httpHeaderDetailKey = "HTTP_HEADER";
     protected static final String BEGIN_CERT = "-----BEGIN CERTIFICATE-----";
     protected static final String END_CERT = "-----END CERTIFICATE-----";
@@ -289,8 +286,8 @@ public class DirectDownloadManagerImpl extends ManagerBase implements DirectDown
 
         VMTemplateStoragePoolVO sPoolRef = vmTemplatePoolDao.findByPoolTemplate(poolId, templateId, null);
         if (sPoolRef == null) {
-            if (s_logger.isDebugEnabled()) {
-                s_logger.debug("Not found (templateId:" + templateId + " poolId: " + poolId + ") in template_spool_ref, persisting it");
+            if (logger.isDebugEnabled()) {
+                logger.debug("Not found (templateId:" + templateId + " poolId: " + poolId + ") in template_spool_ref, persisting it");
             }
             DirectDownloadAnswer ans = (DirectDownloadAnswer) answer;
             sPoolRef = new VMTemplateStoragePoolVO(poolId, templateId, null);
@@ -349,7 +346,7 @@ public class DirectDownloadManagerImpl extends ManagerBase implements DirectDown
                     }
                 }
 
-                s_logger.debug("Sending Direct download command to host " + hostToSendDownloadCmd);
+                logger.debug("Sending Direct download command to host " + hostToSendDownloadCmd);
                 answer = agentManager.easySend(hostToSendDownloadCmd, cmd);
                 if (answer != null) {
                     DirectDownloadAnswer ans = (DirectDownloadAnswer)answer;
@@ -388,7 +385,7 @@ public class DirectDownloadManagerImpl extends ManagerBase implements DirectDown
             event = EventTypes.EVENT_ISO_DIRECT_DOWNLOAD_FAILURE;
         }
         String description = "Direct Download for template Id: " + template.getId() + " on pool Id: " + poolId + " failed";
-        s_logger.error(description);
+        logger.error(description);
         ActionEventUtils.onCompletedActionEvent(CallContext.current().getCallingUserId(), template.getAccountId(), EventVO.LEVEL_INFO, event, description, template.getId(), ApiCommandResourceType.Template.toString(), 0);
     }
 
@@ -460,11 +457,11 @@ public class DirectDownloadManagerImpl extends ManagerBase implements DirectDown
                 x509Cert.checkValidity();
             } catch (CertificateExpiredException | CertificateNotYetValidException e) {
                 String msg = "Certificate is invalid. Please provide a valid certificate. Error: " + e.getMessage();
-                s_logger.error(msg);
+                logger.error(msg);
                 throw new CloudRuntimeException(msg);
             }
             if (x509Cert.getSubjectDN() != null) {
-                s_logger.debug("Valid certificate for domain name: " + x509Cert.getSubjectDN().getName());
+                logger.debug("Valid certificate for domain name: " + x509Cert.getSubjectDN().getName());
             }
         }
     }
@@ -472,18 +469,10 @@ public class DirectDownloadManagerImpl extends ManagerBase implements DirectDown
     @Override
     public Pair<DirectDownloadCertificate, List<HostCertificateStatus>> uploadCertificateToHosts(
             String certificateCer, String alias, String hypervisor, Long zoneId, Long hostId) {
-        if (StringUtils.isBlank(alias)) {
-            throw new CloudRuntimeException("Certificate name not provided, please provide a valid name");
-        }
-
-        if (alias.equalsIgnoreCase("cloud") || alias.startsWith("cloudca")) {
+        if (alias != null && (alias.equalsIgnoreCase("cloud") || alias.startsWith("cloudca"))) {
             throw new CloudRuntimeException("Please provide a different alias name for the certificate");
         }
 
-        if (!NetUtils.verifyDomainNameLabel(alias, false)) {
-            throw new CloudRuntimeException("The provided certificate name is invalid, please provide a valid name");
-        }
-
         List<HostVO> hosts;
         DirectDownloadCertificateVO certificateVO;
         HypervisorType hypervisorType = HypervisorType.getType(hypervisor);
@@ -509,12 +498,12 @@ public class DirectDownloadManagerImpl extends ManagerBase implements DirectDown
             hosts = Collections.singletonList(host);
             certificateVO = directDownloadCertificateDao.findByAlias(alias, hypervisorType, zoneId);
             if (certificateVO == null) {
-                s_logger.info("Certificate must be uploaded on zone " + zoneId);
+                logger.info("Certificate must be uploaded on zone " + zoneId);
                 return new Pair<>(certificateVO, new ArrayList<>());
             }
         }
 
-        s_logger.info("Attempting to upload certificate: " + alias + " to " + hosts.size() + " hosts on zone " + zoneId);
+        logger.info("Attempting to upload certificate: " + alias + " to " + hosts.size() + " hosts on zone " + zoneId);
         int success = 0;
         int failed = 0;
         List<HostCertificateStatus> results = new ArrayList<>();
@@ -527,7 +516,7 @@ public class DirectDownloadManagerImpl extends ManagerBase implements DirectDown
                 Pair<Boolean, String> result = provisionCertificate(certificateVO.getId(), host.getId());
                 if (!result.first()) {
                     String msg = "Could not upload certificate " + alias + " on host: " + host.getName() + " (" + host.getUuid() + "): " + result.second();
-                    s_logger.error(msg);
+                    logger.error(msg);
                     failed++;
                     hostStatus = new HostCertificateStatus(CertificateStatus.FAILED, host, result.second());
                 } else {
@@ -537,7 +526,7 @@ public class DirectDownloadManagerImpl extends ManagerBase implements DirectDown
                 results.add(hostStatus);
             }
         }
-        s_logger.info("Certificate was successfully uploaded to " + success + " hosts, " + failed + " failed");
+        logger.info("Certificate was successfully uploaded to " + success + " hosts, " + failed + " failed");
         return new Pair<>(certificateVO, results);
     }
 
@@ -546,7 +535,7 @@ public class DirectDownloadManagerImpl extends ManagerBase implements DirectDown
         String alias = certificate.getAlias();
         long certificateId = certificate.getId();
 
-        s_logger.debug("Uploading certificate: " + alias + " to host " + hostId);
+        logger.debug("Uploading certificate: " + alias + " to host " + hostId);
         SetupDirectDownloadCertificateCommand cmd = new SetupDirectDownloadCertificateCommand(certificateStr, alias);
         Answer answer = agentManager.easySend(hostId, cmd);
         Pair<Boolean, String> result;
@@ -555,13 +544,13 @@ public class DirectDownloadManagerImpl extends ManagerBase implements DirectDown
             if (answer != null) {
                 msg += " due to: " + answer.getDetails();
             }
-            s_logger.error(msg);
+            logger.error(msg);
             result = new Pair<>(false, msg);
         } else {
             result = new Pair<>(true, "OK");
         }
 
-        s_logger.info("Certificate " + alias + " successfully uploaded to host: " + hostId);
+        logger.info("Certificate " + alias + " successfully uploaded to host: " + hostId);
         DirectDownloadCertificateHostMapVO map = directDownloadCertificateHostMapDao.findByCertificateAndHost(certificateId, hostId);
         if (map != null) {
             map.setRevoked(false);
@@ -595,33 +584,33 @@ public class DirectDownloadManagerImpl extends ManagerBase implements DirectDown
     public boolean syncCertificatesToHost(long hostId, long zoneId) {
         List<DirectDownloadCertificateVO> zoneCertificates = directDownloadCertificateDao.listByZone(zoneId);
         if (CollectionUtils.isEmpty(zoneCertificates)) {
-            if (s_logger.isTraceEnabled()) {
-                s_logger.trace("No certificates to sync on host: " + hostId);
+            if (logger.isTraceEnabled()) {
+                logger.trace("No certificates to sync on host: " + hostId);
             }
             return true;
         }
 
         boolean syncCertificatesResult = true;
         int certificatesSyncCount = 0;
-        s_logger.debug("Syncing certificates on host: " + hostId);
+        logger.debug("Syncing certificates on host: " + hostId);
         for (DirectDownloadCertificateVO certificateVO : zoneCertificates) {
             DirectDownloadCertificateHostMapVO mapping = directDownloadCertificateHostMapDao.findByCertificateAndHost(certificateVO.getId(), hostId);
             if (mapping == null) {
-                s_logger.debug("Syncing certificate " + certificateVO.getId() + " (" + certificateVO.getAlias() + ") on host: " + hostId + ", uploading it");
+                logger.debug("Syncing certificate " + certificateVO.getId() + " (" + certificateVO.getAlias() + ") on host: " + hostId + ", uploading it");
                 Pair<Boolean, String> result = provisionCertificate(certificateVO.getId(), hostId);
                 if (!result.first()) {
                     String msg = "Could not sync certificate " + certificateVO.getId() + " (" + certificateVO.getAlias() + ") on host: " + hostId + ", upload failed: " + result.second();
-                    s_logger.error(msg);
+                    logger.error(msg);
                     syncCertificatesResult = false;
                 } else {
                     certificatesSyncCount++;
                 }
             } else {
-                s_logger.debug("Certificate " + certificateVO.getId() + " (" + certificateVO.getAlias() + ") already synced on host: " + hostId);
+                logger.debug("Certificate " + certificateVO.getId() + " (" + certificateVO.getAlias() + ") already synced on host: " + hostId);
             }
         }
 
-        s_logger.debug("Synced " + certificatesSyncCount + " out of " + zoneCertificates.size() + " certificates on host: " + hostId);
+        logger.debug("Synced " + certificatesSyncCount + " out of " + zoneCertificates.size() + " certificates on host: " + hostId);
         return syncCertificatesResult;
     }
 
@@ -633,10 +622,10 @@ public class DirectDownloadManagerImpl extends ManagerBase implements DirectDown
             DirectDownloadCertificateHostMapVO hostMap = directDownloadCertificateHostMapDao.findByCertificateAndHost(certificate.getId(), hostId);
             if (hostMap == null) {
                 String msg = "Certificate " + certificate.getAlias() + " cannot be revoked from host " + hostId + " as it is not available on the host";
-                s_logger.error(msg);
+                logger.error(msg);
                 throw new CloudRuntimeException(msg);
             } else if (hostMap.isRevoked()) {
-                s_logger.debug("Certificate " + certificate.getAlias() + " was already revoked from host " + hostId + " skipping it");
+                logger.debug("Certificate " + certificate.getAlias() + " was already revoked from host " + hostId + " skipping it");
                 return new LinkedList<>();
             }
             maps = Collections.singletonList(hostMap);
@@ -678,7 +667,7 @@ public class DirectDownloadManagerImpl extends ManagerBase implements DirectDown
         int success = 0;
         int failed = 0;
         int skipped = 0;
-        s_logger.info("Attempting to revoke certificate alias: " + certificateAlias + " from " + maps.size() + " hosts");
+        logger.info("Attempting to revoke certificate alias: " + certificateAlias + " from " + maps.size() + " hosts");
         for (DirectDownloadCertificateHostMapVO map : maps) {
             Long mappingHostId = map.getHostId();
             HostVO host = hostDao.findById(mappingHostId);
@@ -686,7 +675,7 @@ public class DirectDownloadManagerImpl extends ManagerBase implements DirectDown
             if (host == null || host.getDataCenterId() != zoneId || host.getHypervisorType() != HypervisorType.KVM) {
                 if (host != null) {
                     String reason = host.getDataCenterId() != zoneId ? "Host is not in the zone " + zoneId : "Host hypervisor is not KVM";
-                    s_logger.debug("Skipping host " + host.getName() + ": " + reason);
+                    logger.debug("Skipping host " + host.getName() + ": " + reason);
                     hostStatus = new HostCertificateStatus(CertificateStatus.SKIPPED, host, reason);
                     hostsList.add(hostStatus);
                 }
@@ -696,11 +685,11 @@ public class DirectDownloadManagerImpl extends ManagerBase implements DirectDown
             Pair<Boolean, String> result = revokeCertificateAliasFromHost(certificateAlias, mappingHostId);
             if (!result.first()) {
                 String msg = "Could not revoke certificate from host: " + mappingHostId + ": " + result.second();
-                s_logger.error(msg);
+                logger.error(msg);
                 hostStatus = new HostCertificateStatus(CertificateStatus.FAILED, host, result.second());
                 failed++;
             } else {
-                s_logger.info("Certificate " + certificateAlias + " revoked from host " + mappingHostId);
+                logger.info("Certificate " + certificateAlias + " revoked from host " + mappingHostId);
                 map.setRevoked(true);
                 hostStatus = new HostCertificateStatus(CertificateStatus.REVOKED, host, null);
                 success++;
@@ -708,7 +697,7 @@ public class DirectDownloadManagerImpl extends ManagerBase implements DirectDown
             }
             hostsList.add(hostStatus);
         }
-        s_logger.info(String.format("Certificate alias %s revoked from: %d hosts, %d failed, %d skipped",
+        logger.info(String.format("Certificate alias %s revoked from: %d hosts, %d failed, %d skipped",
                 certificateAlias, success, failed, skipped));
         return hostsList;
     }
@@ -743,7 +732,7 @@ public class DirectDownloadManagerImpl extends ManagerBase implements DirectDown
             Answer answer = agentManager.send(hostId, cmd);
             return new Pair<>(answer != null && answer.getResult(), answer != null ? answer.getDetails() : "");
         } catch (AgentUnavailableException | OperationTimedoutException e) {
-            s_logger.error("Error revoking certificate " + alias + " from host " + hostId, e);
+            logger.error("Error revoking certificate " + alias + " from host " + hostId, e);
             return new Pair<>(false, e.getMessage());
         }
     }
@@ -810,8 +799,8 @@ public class DirectDownloadManagerImpl extends ManagerBase implements DirectDown
         @Override
         protected void runInContext() {
             try {
-                if (s_logger.isTraceEnabled()) {
-                    s_logger.trace("Direct Download Manager background task is running...");
+                if (logger.isTraceEnabled()) {
+                    logger.trace("Direct Download Manager background task is running...");
                 }
                 final DateTime now = DateTime.now(DateTimeZone.UTC);
                 List<DataCenterVO> enabledZones = dataCenterDao.listEnabledZones();
@@ -824,15 +813,15 @@ public class DirectDownloadManagerImpl extends ManagerBase implements DirectDown
                                 for (HostVO hostVO : hostsToUpload) {
                                     DirectDownloadCertificateHostMapVO mapping = directDownloadCertificateHostMapDao.findByCertificateAndHost(certificateVO.getId(), hostVO.getId());
                                     if (mapping == null) {
-                                        s_logger.debug("Certificate " + certificateVO.getId() +
+                                        logger.debug("Certificate " + certificateVO.getId() +
                                                 " (" + certificateVO.getAlias() + ") was not uploaded to host: " + hostVO.getId() +
                                                 " uploading it");
                                         Pair<Boolean, String> result = directDownloadManager.provisionCertificate(certificateVO.getId(), hostVO.getId());
-                                        s_logger.debug("Certificate " + certificateVO.getAlias() + " " +
+                                        logger.debug("Certificate " + certificateVO.getAlias() + " " +
                                                 (result.first() ? "uploaded" : "could not be uploaded") +
                                                 " to host " + hostVO.getId());
                                         if (!result.first()) {
-                                            s_logger.error("Certificate " + certificateVO.getAlias() + " failed: " + result.second());
+                                            logger.error("Certificate " + certificateVO.getAlias() + " failed: " + result.second());
                                         }
                                     }
                                 }
@@ -841,7 +830,7 @@ public class DirectDownloadManagerImpl extends ManagerBase implements DirectDown
                     }
                 }
             } catch (final Throwable t) {
-                s_logger.error("Error trying to run Direct Download background task", t);
+                logger.error("Error trying to run Direct Download background task", t);
             }
         }
     }
