@@ -35,7 +35,8 @@ import org.apache.cloudstack.context.CallContext;
 import org.apache.cloudstack.framework.config.dao.ConfigurationDao;
 import org.apache.cloudstack.region.Region;
 import org.apache.cloudstack.region.dao.RegionDao;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 
 import com.cloud.agent.AgentManager;
 import com.cloud.agent.api.routing.GlobalLoadBalancerConfigCommand;
@@ -69,7 +70,7 @@ import com.cloud.utils.net.NetUtils;
 
 public class GlobalLoadBalancingRulesServiceImpl implements GlobalLoadBalancingRulesService {
 
-    private static final Logger s_logger = Logger.getLogger(GlobalLoadBalancingRulesServiceImpl.class);
+    protected Logger logger = LogManager.getLogger(getClass());
 
     @Inject
     AccountManager _accountMgr;
@@ -159,7 +160,7 @@ public class GlobalLoadBalancingRulesServiceImpl implements GlobalLoadBalancingR
             }
         });
 
-        s_logger.debug("successfully created new global load balancer rule for the account " + gslbOwner.getId());
+        logger.debug("successfully created new global load balancer rule for the account " + gslbOwner.getId());
 
         return newGslbRule;
     }
@@ -279,11 +280,11 @@ public class GlobalLoadBalancingRulesServiceImpl implements GlobalLoadBalancingR
 
         boolean success = false;
         try {
-            s_logger.debug("Configuring gslb rule configuration on the gslb service providers in the participating zones");
+            logger.debug("Configuring gslb rule configuration on the gslb service providers in the participating zones");
 
             // apply the gslb rule on to the back end gslb service providers on zones participating in gslb
             if (!applyGlobalLoadBalancerRuleConfig(gslbRuleId, false)) {
-                s_logger.warn("Failed to add load balancer rules " + newLbRuleIds + " to global load balancer rule id " + gslbRuleId);
+                logger.warn("Failed to add load balancer rules " + newLbRuleIds + " to global load balancer rule id " + gslbRuleId);
                 CloudRuntimeException ex = new CloudRuntimeException("Failed to add load balancer rules to GSLB rule ");
                 throw ex;
             }
@@ -382,11 +383,11 @@ public class GlobalLoadBalancingRulesServiceImpl implements GlobalLoadBalancingR
 
         boolean success = false;
         try {
-            s_logger.debug("Attempting to configure global load balancer rule configuration on the gslb service providers ");
+            logger.debug("Attempting to configure global load balancer rule configuration on the gslb service providers ");
 
             // apply the gslb rule on to the back end gslb service providers
             if (!applyGlobalLoadBalancerRuleConfig(gslbRuleId, false)) {
-                s_logger.warn("Failed to remove load balancer rules " + lbRuleIdsToremove + " from global load balancer rule id " + gslbRuleId);
+                logger.warn("Failed to remove load balancer rules " + lbRuleIdsToremove + " from global load balancer rule id " + gslbRuleId);
                 CloudRuntimeException ex = new CloudRuntimeException("Failed to remove load balancer rule ids from GSLB rule ");
                 throw ex;
             }
@@ -426,7 +427,7 @@ public class GlobalLoadBalancingRulesServiceImpl implements GlobalLoadBalancingR
         try {
             revokeGslbRule(gslbRuleId, caller);
         } catch (Exception e) {
-            s_logger.warn("Failed to delete GSLB rule due to" + e.getMessage());
+            logger.warn("Failed to delete GSLB rule due to" + e.getMessage());
             return false;
         }
 
@@ -445,8 +446,8 @@ public class GlobalLoadBalancingRulesServiceImpl implements GlobalLoadBalancingR
         _accountMgr.checkAccess(caller, SecurityChecker.AccessType.OperateEntry, true, gslbRule);
 
         if (gslbRule.getState() == com.cloud.region.ha.GlobalLoadBalancerRule.State.Staged) {
-            if (s_logger.isDebugEnabled()) {
-                s_logger.debug("Rule Id: " + gslbRuleId + " is still in Staged state so just removing it.");
+            if (logger.isDebugEnabled()) {
+                logger.debug("Rule Id: " + gslbRuleId + " is still in Staged state so just removing it.");
             }
             _gslbRuleDao.remove(gslbRuleId);
             UsageEventUtils.publishUsageEvent(EventTypes.EVENT_GLOBAL_LOAD_BALANCER_DELETE, gslbRule.getAccountId(), 0, gslbRule.getId(), gslbRule.getName(),
@@ -541,7 +542,7 @@ public class GlobalLoadBalancingRulesServiceImpl implements GlobalLoadBalancingR
         _gslbRuleDao.update(gslbRule.getId(), gslbRule);
 
         try {
-            s_logger.debug("Updating global load balancer with id " + gslbRule.getUuid());
+            logger.debug("Updating global load balancer with id " + gslbRule.getUuid());
 
             // apply the gslb rule on to the back end gslb service providers on zones participating in gslb
             applyGlobalLoadBalancerRuleConfig(gslbRuleId, false);
@@ -687,7 +688,7 @@ public class GlobalLoadBalancingRulesServiceImpl implements GlobalLoadBalancingR
                 lookupGslbServiceProvider().applyGlobalLoadBalancerRule(zoneId.first(), zoneId.second(), gslbConfigCmd);
             } catch (ResourceUnavailableException | NullPointerException e) {
                 String msg = "Failed to configure GSLB rule in the zone " + zoneId.first() + " due to " + e.getMessage();
-                s_logger.warn(msg);
+                logger.warn(msg);
                 throw new CloudRuntimeException(msg);
             }
         }
@@ -703,7 +704,7 @@ public class GlobalLoadBalancingRulesServiceImpl implements GlobalLoadBalancingR
                 revokeGslbRule(gslbRule.getId(), caller);
             }
         }
-        s_logger.debug("Successfully cleaned up GSLB rules for account id=" + accountId);
+        logger.debug("Successfully cleaned up GSLB rules for account id=" + accountId);
         return true;
     }
 
