@@ -74,7 +74,8 @@ import org.apache.cloudstack.storage.datastore.db.StoragePoolVO;
 import org.apache.cloudstack.utils.bytescale.ByteScaleUtils;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
+import org.apache.logging.log4j.Logger;
 
 import javax.inject.Inject;
 import java.util.ArrayList;
@@ -84,7 +85,7 @@ import java.util.List;
 import java.util.Map;
 
 public class VolumeImportUnmanageManagerImpl implements VolumeImportUnmanageService {
-    protected Logger logger = Logger.getLogger(VolumeImportUnmanageManagerImpl.class);
+    protected Logger logger = LogManager.getLogger(VolumeImportUnmanageManagerImpl.class);
 
     @Inject
     private AccountManager accountMgr;
@@ -205,7 +206,7 @@ public class VolumeImportUnmanageManagerImpl implements VolumeImportUnmanageServ
         if (diskOffering.isCustomized()) {
             volumeApiService.validateCustomDiskOfferingSizeRange(volume.getVirtualSize() / ByteScaleUtils.GiB);
         }
-        if (!volumeApiService.doesStoragePoolSupportDiskOfferingTags(pool, diskOffering.getTags())) {
+        if (!volumeApiService.doesTargetStorageSupportDiskOffering(pool, diskOffering.getTags())) {
             logFailureAndThrowException(String.format("Disk offering: %s storage tags are not compatible with selected storage pool: %s", diskOffering.getUuid(), pool.getUuid()));
         }
 
