@@ -16,53 +16,89 @@
 // under the License.
 package com.cloud.configuration;
 
-import static org.junit.Assert.assertThrows;
-import static org.mockito.Mockito.mock;
-import static org.mockito.Mockito.when;
-
-import com.cloud.exception.InvalidParameterValueException;
-import com.cloud.storage.StorageManager;
-import com.cloud.user.AccountManagerImpl;
-import com.cloud.utils.exception.CloudRuntimeException;
-import com.cloud.utils.net.NetUtils;
-import org.apache.cloudstack.context.CallContext;
-import org.apache.cloudstack.framework.config.ConfigDepot;
-import org.apache.cloudstack.framework.config.ConfigKey;
+import com.cloud.capacity.dao.CapacityDao;
+import com.cloud.dc.DataCenterVO;
+import com.cloud.dc.VlanVO;
 import com.cloud.dc.dao.DataCenterDao;
+import com.cloud.dc.dao.DataCenterIpAddressDao;
+import com.cloud.dc.dao.DedicatedResourceDao;
+import com.cloud.dc.dao.HostPodDao;
+import com.cloud.dc.dao.VlanDao;
 import com.cloud.domain.Domain;
 import com.cloud.domain.dao.DomainDao;
+import com.cloud.exception.InvalidParameterValueException;
+import com.cloud.host.dao.HostDao;
+import com.cloud.network.Network;
+import com.cloud.network.NetworkModel;
+import com.cloud.network.NetworkService;
+import com.cloud.network.Networks;
+import com.cloud.network.dao.IPAddressDao;
+import com.cloud.network.dao.NsxProviderDao;
+import com.cloud.network.dao.PhysicalNetworkDao;
+import com.cloud.network.element.NsxProviderVO;
 import com.cloud.offering.DiskOffering;
+import com.cloud.offering.NetworkOffering;
+import com.cloud.offerings.NetworkOfferingVO;
+import com.cloud.offerings.dao.NetworkOfferingDao;
 import com.cloud.storage.DiskOfferingVO;
+import com.cloud.storage.StorageManager;
+import com.cloud.storage.dao.VMTemplateZoneDao;
+import com.cloud.storage.dao.VolumeDao;
 import com.cloud.user.Account;
 import com.cloud.user.User;
 import com.cloud.utils.db.EntityManager;
 import com.cloud.utils.db.SearchCriteria;
+import com.cloud.utils.net.NetUtils;
+import com.cloud.vm.dao.VMInstanceDao;
+import org.apache.cloudstack.annotation.dao.AnnotationDao;
+import org.apache.cloudstack.api.command.admin.network.CreateNetworkOfferingCmd;
 import org.apache.cloudstack.api.command.admin.offering.UpdateDiskOfferingCmd;
+import org.apache.cloudstack.api.command.admin.zone.DeleteZoneCmd;
+import org.apache.cloudstack.engine.subsystem.api.storage.ZoneScope;
+import org.apache.cloudstack.framework.config.ConfigDepot;
+import org.apache.cloudstack.framework.config.ConfigKey;
 import org.apache.cloudstack.framework.config.dao.ConfigurationDao;
 import org.apache.cloudstack.framework.config.impl.ConfigurationVO;
+import org.apache.cloudstack.storage.datastore.db.ImageStoreDao;
 import org.apache.cloudstack.resourcedetail.DiskOfferingDetailVO;
-import org.apache.cloudstack.resourcedetail.dao.DiskOfferingDetailsDao;
 import org.apache.cloudstack.vm.UnmanagedVMsManager;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.mockito.InjectMocks;
 import org.mockito.Mock;
 import org.mockito.MockedStatic;
 import org.mockito.Mockito;
-import org.mockito.junit.MockitoJUnitRunner;
-import org.mockito.InjectMocks;
 import org.mockito.Spy;
+import org.mockito.junit.MockitoJUnitRunner;
+import org.springframework.test.util.ReflectionTestUtils;
 
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.List;
 
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyLong;
+import static org.mockito.Mockito.anyBoolean;
+import static org.mockito.Mockito.anyMap;
+import static org.mockito.Mockito.anyString;
+import static org.mockito.Mockito.doNothing;
+import static org.mockito.Mockito.lenient;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.nullable;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
+
 @RunWith(MockitoJUnitRunner.class)
 public class ConfigurationManagerImplTest {
+
+    @InjectMocks
+    @Spy
+    ConfigurationManagerImpl configurationManagerImplSpy;
     @Mock
     ConfigDepot configDepot;
-    @InjectMocks
-    ConfigurationManagerImpl configurationManagerImplSpy = Mockito.spy(new ConfigurationManagerImpl());
     @Mock
     SearchCriteria<DiskOfferingDetailVO> searchCriteriaDiskOfferingDetailMock;
     @Mock
@@ -74,19 +110,58 @@ public class ConfigurationManagerImplTest {
     @Mock
     Domain domainMock;
     @Mock
-    ConfigurationDao configDaoMock;
-    @Mock
-    DataCenterDao zoneDaoMock;
-    @Mock
     DomainDao domainDaoMock;
     @Mock
     EntityManager entityManagerMock;
     @Mock
-    DiskOfferingDetailsDao diskOfferingDetailsDao;
+    ConfigurationVO configurationVOMock;
+    @Mock
+    ConfigKey configKeyMock;
     @Spy
     DiskOfferingVO diskOfferingVOSpy;
     @Mock
     UpdateDiskOfferingCmd updateDiskOfferingCmdMock;
+    @Mock
+    NsxProviderDao nsxProviderDao;
+    @Mock
+    DataCenterDao zoneDao;
+    @Mock
+    HostDao hostDao;
+    @Mock
+    HostPodDao podDao;
+    @Mock
+    DataCenterIpAddressDao ipAddressDao;
+    @Mock
+    IPAddressDao publicIpAddressDao;
+    @Mock
+    VMInstanceDao vmInstanceDao;
+    @Mock
+    VolumeDao volumeDao;
+    @Mock
+    PhysicalNetworkDao physicalNetworkDao;
+    @Mock
+    ImageStoreDao imageStoreDao;
+    @Mock
+    VlanDao vlanDao;
+    @Mock
+    VMTemplateZoneDao vmTemplateZoneDao;
+    @Mock
+    CapacityDao capacityDao;
+    @Mock
+    DedicatedResourceDao dedicatedResourceDao;
+    @Mock
+    AnnotationDao annotationDao;
+    @Mock
+    ConfigurationDao configDao;
+    @Mock
+    NetworkOfferingDao networkOfferingDao;
+    @Mock
+    NetworkService networkService;
+    @Mock
+    NetworkModel networkModel;
+
+    DeleteZoneCmd deleteZoneCmd;
+    CreateNetworkOfferingCmd createNetworkOfferingCmd;
 
     Long validId = 1L;
     Long invalidId = 100L;
@@ -100,8 +175,18 @@ public class ConfigurationManagerImplTest {
 
     @Before
     public void setUp() throws Exception {
-        configurationManagerImplSpy._configDepot = configDepot;
-        configurationManagerImplSpy.populateConfigKeysAllowedOnlyForDefaultAdmin();
+        Mockito.when(configurationVOMock.getScope()).thenReturn(ConfigKey.Scope.Global.name());
+        Mockito.when(configDao.findByName(Mockito.anyString())).thenReturn(configurationVOMock);
+        Mockito.when(configDepot.get(Mockito.anyString())).thenReturn(configKeyMock);
+
+        configurationManagerImplSpy.populateConfigValuesForValidationSet();
+        configurationManagerImplSpy.weightBasedParametersForValidation();
+        configurationManagerImplSpy.overProvisioningFactorsForValidation();
+        ReflectionTestUtils.setField(configurationManagerImplSpy, "templateZoneDao", vmTemplateZoneDao);
+        ReflectionTestUtils.setField(configurationManagerImplSpy, "annotationDao", annotationDao);
+
+        deleteZoneCmd = Mockito.mock(DeleteZoneCmd.class);
+        createNetworkOfferingCmd = Mockito.mock(CreateNetworkOfferingCmd.class);
     }
 
     @Test
@@ -110,7 +195,6 @@ public class ConfigurationManagerImplTest {
         Assert.assertNull(testVariable);
     }
 
-
     @Test
     public void validateIfIntValueIsInRangeTestInvalidValueReturnString() {
         String testVariable = configurationManagerImplSpy.validateIfIntValueIsInRange("String name", "9", "1-5");
@@ -313,8 +397,53 @@ public class ConfigurationManagerImplTest {
     }
 
     @Test
+    public void testDeleteZoneInvokesDeleteNsxProviderWhenNSXIsEnabled() {
+        NsxProviderVO nsxProviderVO = Mockito.mock(NsxProviderVO.class);
+        DataCenterVO dataCenterVO = Mockito.mock(DataCenterVO.class);
+
+        when(nsxProviderDao.findByZoneId(anyLong())).thenReturn(nsxProviderVO);
+        when(zoneDao.findById(anyLong())).thenReturn(dataCenterVO);
+        lenient().when(hostDao.findByDataCenterId(anyLong())).thenReturn(Collections.emptyList());
+        when(podDao.listByDataCenterId(anyLong())).thenReturn(Collections.emptyList());
+        when(ipAddressDao.countIPs(anyLong(), anyBoolean())).thenReturn(0);
+        when(publicIpAddressDao.countIPs(anyLong(), anyBoolean())).thenReturn(0);
+        when(vmInstanceDao.listByZoneId(anyLong())).thenReturn(Collections.emptyList());
+        when(volumeDao.findByDc(anyLong())).thenReturn(Collections.emptyList());
+        when(physicalNetworkDao.listByZone(anyLong())).thenReturn(Collections.emptyList());
+        when(imageStoreDao.findByZone(any(ZoneScope.class), nullable(Boolean.class))).thenReturn(Collections.emptyList());
+        when(vlanDao.listByZone(anyLong())).thenReturn(List.of(Mockito.mock(VlanVO.class)));
+        when(nsxProviderVO.getId()).thenReturn(1L);
+        when(zoneDao.remove(anyLong())).thenReturn(true);
+        when(capacityDao.removeBy(nullable(Short.class), anyLong(), nullable(Long.class), nullable(Long.class), nullable(Long.class))).thenReturn(true);
+        when(dedicatedResourceDao.findByZoneId(anyLong())).thenReturn(null);
+        lenient().when(annotationDao.removeByEntityType(anyString(), anyString())).thenReturn(true);
+
+        configurationManagerImplSpy.deleteZone(deleteZoneCmd);
+
+        verify(nsxProviderDao, times(1)).remove(anyLong());
+    }
+
+    @Test
+    public void testCreateNetworkOfferingForNsx() {
+        NetworkOfferingVO offeringVO = Mockito.mock(NetworkOfferingVO.class);
+
+        when(createNetworkOfferingCmd.isForNsx()).thenReturn(true);
+        when(createNetworkOfferingCmd.getNetworkMode()).thenReturn(NetworkOffering.NetworkMode.NATTED.name());
+        when(createNetworkOfferingCmd.getTraffictype()).thenReturn(Networks.TrafficType.Guest.name());
+        when(createNetworkOfferingCmd.getGuestIpType()).thenReturn(Network.GuestType.Isolated.name());
+        when(createNetworkOfferingCmd.getAvailability()).thenReturn(NetworkOffering.Availability.Optional.name());
+        when(configDao.getValue(anyString())).thenReturn("1000");
+        when(networkOfferingDao.persist(any(NetworkOfferingVO.class), anyMap())).thenReturn(offeringVO);
+        doNothing().when(networkService).validateIfServiceOfferingIsActiveAndSystemVmTypeIsDomainRouter(anyLong());
+        doNothing().when(networkModel).canProviderSupportServices(anyMap());
+
+        NetworkOffering offering = configurationManagerImplSpy.createNetworkOffering(createNetworkOfferingCmd);
+
+        Assert.assertNotNull(offering);
+    }
+
     public void testValidateInvalidConfiguration() {
-        Mockito.doReturn(null).when(configDaoMock).findByName(Mockito.anyString());
+        Mockito.doReturn(null).when(configDao).findByName(Mockito.anyString());
         String msg = configurationManagerImplSpy.validateConfigurationValue("test.config.name", "testvalue", ConfigKey.Scope.Global.toString());
         Assert.assertEquals("Invalid configuration variable.", msg);
     }
@@ -323,19 +452,22 @@ public class ConfigurationManagerImplTest {
     public void testValidateInvalidScopeForConfiguration() {
         ConfigurationVO cfg = mock(ConfigurationVO.class);
         when(cfg.getScope()).thenReturn(ConfigKey.Scope.Account.toString());
-        Mockito.doReturn(cfg).when(configDaoMock).findByName(Mockito.anyString());
+        Mockito.doReturn(cfg).when(configDao).findByName(Mockito.anyString());
         String msg = configurationManagerImplSpy.validateConfigurationValue("test.config.name", "testvalue", ConfigKey.Scope.Domain.toString());
         Assert.assertEquals("Invalid scope id provided for the parameter test.config.name", msg);
     }
 
-    @Test(expected = InvalidParameterValueException.class)
+    @Test
     public void testValidateConfig_ThreadsOnKVMHostToTransferVMwareVMFiles_Failure() {
         ConfigurationVO cfg = mock(ConfigurationVO.class);
         when(cfg.getScope()).thenReturn(ConfigKey.Scope.Global.toString());
         ConfigKey<Integer> configKey = UnmanagedVMsManager.ThreadsOnKVMHostToImportVMwareVMFiles;
-        Mockito.doReturn(cfg).when(configDaoMock).findByName(Mockito.anyString());
+        Mockito.doReturn(cfg).when(configDao).findByName(Mockito.anyString());
         Mockito.doReturn(configKey).when(configurationManagerImplSpy._configDepot).get(configKey.key());
-        configurationManagerImplSpy.validateConfigurationValue(configKey.key(), "11", configKey.scope().toString());
+
+        String result = configurationManagerImplSpy.validateConfigurationValue(configKey.key(), "11", configKey.scope().toString());
+
+        Assert.assertNotNull(result);
     }
 
     @Test
@@ -343,21 +475,24 @@ public class ConfigurationManagerImplTest {
         ConfigurationVO cfg = mock(ConfigurationVO.class);
         when(cfg.getScope()).thenReturn(ConfigKey.Scope.Global.toString());
         ConfigKey<Integer> configKey = UnmanagedVMsManager.ThreadsOnKVMHostToImportVMwareVMFiles;
-        Mockito.doReturn(cfg).when(configDaoMock).findByName(Mockito.anyString());
+        Mockito.doReturn(cfg).when(configDao).findByName(Mockito.anyString());
         Mockito.doReturn(configKey).when(configurationManagerImplSpy._configDepot).get(configKey.key());
         String msg = configurationManagerImplSpy.validateConfigurationValue(configKey.key(), "10", configKey.scope().toString());
         Assert.assertNull(msg);
     }
 
-    @Test(expected = InvalidParameterValueException.class)
+    @Test
     public void testValidateConfig_ConvertVmwareInstanceToKvmTimeout_Failure() {
         ConfigurationVO cfg = mock(ConfigurationVO.class);
         when(cfg.getScope()).thenReturn(ConfigKey.Scope.Global.toString());
         ConfigKey<Integer> configKey = UnmanagedVMsManager.ConvertVmwareInstanceToKvmTimeout;
-        Mockito.doReturn(cfg).when(configDaoMock).findByName(Mockito.anyString());
+        Mockito.doReturn(cfg).when(configDao).findByName(Mockito.anyString());
         Mockito.doReturn(configKey).when(configurationManagerImplSpy._configDepot).get(configKey.key());
         configurationManagerImplSpy.populateConfigValuesForValidationSet();
-        configurationManagerImplSpy.validateConfigurationValue(configKey.key(), "0", configKey.scope().toString());
+
+        String result = configurationManagerImplSpy.validateConfigurationValue(configKey.key(), "0", configKey.scope().toString());
+
+        Assert.assertNotNull(result);
     }
 
     @Test
@@ -365,7 +500,7 @@ public class ConfigurationManagerImplTest {
         ConfigurationVO cfg = mock(ConfigurationVO.class);
         when(cfg.getScope()).thenReturn(ConfigKey.Scope.Global.toString());
         ConfigKey<Integer> configKey = UnmanagedVMsManager.ConvertVmwareInstanceToKvmTimeout;
-        Mockito.doReturn(cfg).when(configDaoMock).findByName(Mockito.anyString());
+        Mockito.doReturn(cfg).when(configDao).findByName(Mockito.anyString());
         Mockito.doReturn(configKey).when(configurationManagerImplSpy._configDepot).get(configKey.key());
         configurationManagerImplSpy.populateConfigValuesForValidationSet();
         String msg = configurationManagerImplSpy.validateConfigurationValue(configKey.key(), "9", configKey.scope().toString());
@@ -380,7 +515,7 @@ public class ConfigurationManagerImplTest {
 
     @Test
     public void validateZoneTestInvalidIdThrowException() {
-        Mockito.doReturn(null).when(zoneDaoMock).findById(invalidId);
+        Mockito.doReturn(null).when(zoneDao).findById(invalidId);
         Assert.assertThrows(InvalidParameterValueException.class, () -> configurationManagerImplSpy.validateZone(List.of(invalidId)));
     }
 
@@ -481,44 +616,239 @@ public class ConfigurationManagerImplTest {
     }
 
     @Test
-    public void testValidateConfigurationAllowedOnlyForDefaultAdmin_withAdminUser_shouldNotThrowException() {
-        CallContext callContext = mock(CallContext.class);
-        when(callContext.getCallingUserId()).thenReturn(User.UID_ADMIN);
-        try (MockedStatic<CallContext> ignored = Mockito.mockStatic(CallContext.class)) {
-            when(CallContext.current()).thenReturn(callContext);
-            configurationManagerImplSpy.validateConfigurationAllowedOnlyForDefaultAdmin(AccountManagerImpl.listOfRoleTypesAllowedForOperationsOfSameRoleType.key(), "Admin");
-        }
+    public void validateConfigurationValueTestValidatesValueType() {
+        Mockito.when(configKeyMock.type()).thenReturn(Integer.class);
+        configurationManagerImplSpy.validateConfigurationValue("validate.type", "100", ConfigKey.Scope.Global.name());
+        Mockito.verify(configurationManagerImplSpy).validateValueType("100", Integer.class);
     }
 
     @Test
-    public void testValidateConfigurationAllowedOnlyForDefaultAdmin_withNonAdminUser_shouldThrowException() {
-        CallContext callContext = mock(CallContext.class);
-        when(callContext.getCallingUserId()).thenReturn(123L);
-        try (MockedStatic<CallContext> ignored = Mockito.mockStatic(CallContext.class)) {
-            when(CallContext.current()).thenReturn(callContext);
-            assertThrows(CloudRuntimeException.class, () ->
-                    configurationManagerImplSpy.validateConfigurationAllowedOnlyForDefaultAdmin(AccountManagerImpl.allowOperationsOnUsersInSameAccount.key(), "Admin")
-            );
-        }
+    public void validateConfigurationValueTestValidatesValueRange() {
+        Mockito.when(configKeyMock.type()).thenReturn(Integer.class);
+        configurationManagerImplSpy.validateConfigurationValue("validate.range", "100", ConfigKey.Scope.Global.name());
+        Mockito.verify(configurationManagerImplSpy).validateValueRange("validate.range", "100", Integer.class, null);
     }
 
     @Test
-    public void testValidateConfigurationAllowedOnlyForDefaultAdmin_withNonRestrictedKey_shouldNotThrowException() {
-        CallContext callContext = mock(CallContext.class);
-        try (MockedStatic<CallContext> ignored = Mockito.mockStatic(CallContext.class)) {
-            when(CallContext.current()).thenReturn(callContext);
-            configurationManagerImplSpy.validateConfigurationAllowedOnlyForDefaultAdmin("some.other.config.key", "Admin");
-        }
+    public void validateValueTypeTestReturnsTrueWhenValueIsNullAndTypeIsString() {
+        Assert.assertTrue(configurationManagerImplSpy.validateValueType(null, String.class));
     }
 
-    @Test(expected = CloudRuntimeException.class)
-    public void testValidateConfigurationAllowedOnlyForDefaultAdmin_withValidConfigNameAndInvalidValue_shouldThrowException() {
-        CallContext callContext = mock(CallContext.class);
-        try (MockedStatic<CallContext> mockedCallContext = Mockito.mockStatic(CallContext.class)) {
-            mockedCallContext.when(CallContext::current).thenReturn(callContext);
-            when(callContext.getCallingUserId()).thenReturn(User.UID_ADMIN);
-            String invalidValue = "Admin, SuperUser";
-            configurationManagerImplSpy.validateConfigurationAllowedOnlyForDefaultAdmin(AccountManagerImpl.listOfRoleTypesAllowedForOperationsOfSameRoleType.key(), invalidValue);
-        }
+    @Test
+    public void validateValueTypeTestReturnsTrueWhenValueIsNumericAndTypeIsString() {
+        Assert.assertTrue(configurationManagerImplSpy.validateValueType("1", String.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsTrueWhenValueIsStringAndTypeIsString() {
+        Assert.assertTrue(configurationManagerImplSpy.validateValueType("test", String.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsFalseWhenValueIsNullAndTypeIsBoolean() {
+        Assert.assertFalse(configurationManagerImplSpy.validateValueType(null, Boolean.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsFalseWhenValueIsNumericAndTypeIsBoolean() {
+        Assert.assertFalse(configurationManagerImplSpy.validateValueType("1", Boolean.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsFalseWhenValueIsStringAndTypeIsBoolean() {
+        Assert.assertFalse(configurationManagerImplSpy.validateValueType("test", Boolean.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsTrueWhenValueIsTrueAndTypeIsBoolean() {
+        Assert.assertTrue(configurationManagerImplSpy.validateValueType("true", Boolean.class));
+
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsTrueWhenValueIsFalseAndTypeIsBoolean() {
+        Assert.assertTrue(configurationManagerImplSpy.validateValueType("false", Boolean.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsFalseWhenValueIsNullAndTypeIsInteger() {
+        Assert.assertFalse(configurationManagerImplSpy.validateValueType(null, Integer.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsTrueWhenValueIsIntegerAndTypeIsInteger() {
+        Assert.assertTrue(configurationManagerImplSpy.validateValueType("-2147483647", Integer.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsFalseWhenValueExceedsIntegerLimitAndTypeIsInteger() {
+        Assert.assertFalse(configurationManagerImplSpy.validateValueType("2147483648", Integer.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsFalseWhenValueIsDecimalAndTypeIsInteger() {
+        Assert.assertFalse(configurationManagerImplSpy.validateValueType("1.1", Integer.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsFalseWhenValueIsStringAndTypeIsInteger() {
+        Assert.assertFalse(configurationManagerImplSpy.validateValueType("test", Integer.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsFalseWhenValueIsNullAndTypeIsShort() {
+        Assert.assertFalse(configurationManagerImplSpy.validateValueType(null, Short.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsTrueWhenValueIsIntegerAndTypeIsShort() {
+        Assert.assertTrue(configurationManagerImplSpy.validateValueType("-32768", Short.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsFalseWhenValueExceedsShortLimitAndTypeIsShort() {
+        Assert.assertFalse(configurationManagerImplSpy.validateValueType("32768", Short.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsFalseWhenValueIsDecimalAndTypeIsShort() {
+        Assert.assertFalse(configurationManagerImplSpy.validateValueType("1.1", Short.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsFalseWhenValueIsStringAndTypeIsShort() {
+        Assert.assertFalse(configurationManagerImplSpy.validateValueType("test", Short.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsFalseWhenValueIsNullAndTypeIsLong() {
+        Assert.assertFalse(configurationManagerImplSpy.validateValueType(null, Long.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsTrueWhenValueIsIntegerAndTypeIsLong() {
+        Assert.assertTrue(configurationManagerImplSpy.validateValueType("-9223372036854775807", Long.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsFalseWhenValueExceedsLongLimitAndTypeIsLong() {
+        Assert.assertFalse(configurationManagerImplSpy.validateValueType("9223372036854775808", Long.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsFalseWhenValueIsDecimalAndTypeIsLong() {
+        Assert.assertFalse(configurationManagerImplSpy.validateValueType("1.1", Long.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsFalseWhenValueIsStringAndTypeIsLong() {
+        Assert.assertFalse(configurationManagerImplSpy.validateValueType("test", Long.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsFalseWhenValueIsNullAndTypeIsFloat() {
+        Assert.assertFalse(configurationManagerImplSpy.validateValueType(null, Float.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsFalseWhenValueIsInfiniteAndTypeIsFloat() {
+        Assert.assertFalse(configurationManagerImplSpy.validateValueType("9999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999", Float.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsTrueWhenValueIsNumericAndTypeIsFloat() {
+        Assert.assertTrue(configurationManagerImplSpy.validateValueType("1.1", Float.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsFalseWhenValueIsStringAndTypeIsFloat() {
+        Assert.assertFalse(configurationManagerImplSpy.validateValueType("test", Float.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsFalseWhenValueIsNullAndTypeIsDouble() {
+        Assert.assertFalse(configurationManagerImplSpy.validateValueType(null, Double.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsFalseWhenValueIsInfiniteAndTypeIsDouble() {
+        Assert.assertFalse(configurationManagerImplSpy.validateValueType("9999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999999", Double.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsTrueWhenValueIsNumericAndTypeIsDouble() {
+        Assert.assertTrue(configurationManagerImplSpy.validateValueType("1.1", Double.class));
+    }
+
+    @Test
+    public void validateValueTypeTestReturnsFalseWhenValueIsStringAndTypeIsDouble() {
+        Assert.assertFalse(configurationManagerImplSpy.validateValueType("test", Double.class));
+    }
+
+    @Test
+    public void validateValueRangeTestReturnsNullWhenConfigKeyHasNoRange() {
+        Assert.assertNull(configurationManagerImplSpy.validateValueRange("configkey.without.range", "0", Integer.class, null));
+    }
+
+    @Test
+    public void validateValueRangeTestReturnsNullWhenConfigKeyHasRangeAndValueIsValid() {
+        Assert.assertNull(configurationManagerImplSpy.validateValueRange(NetworkModel.MACIdentifier.key(), "100", Integer.class, null));
+    }
+
+    @Test
+    public void validateValueRangeTestReturnsNotNullWhenConfigKeyHasRangeAndValueIsInvalid() {
+        Assert.assertNotNull(configurationManagerImplSpy.validateValueRange(NetworkModel.MACIdentifier.key(), "-1", Integer.class, null));
+    }
+
+    @Test
+    public void validateValueRangeTestValidatesValueWhenConfigHasRange() {
+        Config config = Config.SecStorageEncryptCopy;
+        String name = config.name();
+        String value = "value";
+        String expectedResult = "expectedResult";
+
+        Mockito.doReturn(expectedResult).when(configurationManagerImplSpy).validateIfStringValueIsInRange(name, value, config.getRange().split(","));
+
+        String result = configurationManagerImplSpy.validateValueRange(name, value, config.getType(), config);
+
+        Assert.assertEquals(expectedResult, result);
+    }
+
+    @Test
+    public void validateValueRangeTestValidatesIntValueWhenConfigHasNumericRange() {
+        Config config = Config.RouterExtraPublicNics;
+        String name = config.name();
+        String value = "1";
+        String expectedResult = "expectedResult";
+
+        Mockito.doReturn(expectedResult).when(configurationManagerImplSpy).validateIfIntValueIsInRange(name, value, config.getRange());
+
+        String result = configurationManagerImplSpy.validateValueRange(name, value, config.getType(), config);
+
+        Assert.assertEquals(expectedResult, result);
+    }
+
+    @Test
+    public void shouldValidateConfigRangeTestValueIsNullReturnFalse() {
+        boolean result = configurationManagerImplSpy.shouldValidateConfigRange(Config.ConsoleProxyUrlDomain.name(), null, Config.ConsoleProxyUrlDomain);
+        Assert.assertFalse(result);
+    }
+
+    @Test
+    public void shouldValidateConfigRangeTestConfigIsNullReturnFalse() {
+        boolean result = configurationManagerImplSpy.shouldValidateConfigRange("", "test", null);
+        Assert.assertFalse(result);
+    }
+
+    @Test
+    public void shouldValidateConfigRangeTestConfigDoesNotHaveARangeReturnFalse() {
+        boolean result = configurationManagerImplSpy.shouldValidateConfigRange(Config.ConsoleProxySessionMax.name(), "test", Config.ConsoleProxySessionMax);
+        Assert.assertFalse(result);
+    }
+
+    @Test
+    public void shouldValidateConfigRangeTestValueIsNotNullAndConfigHasRangeReturnTrue() {
+        boolean result = configurationManagerImplSpy.shouldValidateConfigRange(Config.ConsoleProxySessionMax.name(), "test", Config.ConsoleProxyUrlDomain);
+        Assert.assertTrue(result);
     }
 }
