@@ -23,15 +23,8 @@ import com.cloud.host.Status;
 import com.cloud.host.dao.HostDao;
 import com.cloud.hypervisor.Hypervisor;
 import com.cloud.org.Cluster;
-import com.cloud.service.ServiceOfferingVO;
-import com.cloud.service.dao.ServiceOfferingDao;
-import com.cloud.utils.Ternary;
 import com.cloud.utils.exception.CloudRuntimeException;
-import com.cloud.vm.UserVmDetailVO;
-import com.cloud.vm.VMInstanceVO;
-import com.cloud.vm.VmDetailConstants;
-import com.cloud.vm.dao.UserVmDetailsDao;
-
+import org.junit.After;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
@@ -61,12 +54,6 @@ public class RollingMaintenanceManagerImplTest {
     HostVO host4;
     @Mock
     Cluster cluster;
-    @Mock
-    VMInstanceVO vm;
-    @Mock
-    ServiceOfferingDao serviceOfferingDao;
-    @Mock
-    UserVmDetailsDao userVmDetailsDao;
 
     @Spy
     @InjectMocks
@@ -86,9 +73,11 @@ public class RollingMaintenanceManagerImplTest {
     private static final long podId = 1L;
     private static final long zoneId = 1L;
 
+    private AutoCloseable closeable;
+
     @Before
     public void setup() throws Exception {
-        MockitoAnnotations.initMocks(this);
+        closeable = MockitoAnnotations.openMocks(this);
         Mockito.when(hostDao.findByClusterId(clusterId1)).thenReturn(Arrays.asList(host1, host2));
         Mockito.when(hostDao.findByClusterId(clusterId2)).thenReturn(Arrays.asList(host3, host4));
         List<HostVO> hosts = Arrays.asList(host1, host2, host3, host4);
@@ -116,6 +105,11 @@ public class RollingMaintenanceManagerImplTest {
         Mockito.when(host2.getResourceState()).thenReturn(ResourceState.Enabled);
     }
 
+    @After
+    public void tearDown() throws Exception {
+        closeable.close();
+    }
+
     private void checkResults(Map<Long, List<Host>> result) {
         Assert.assertEquals(2, result.size());
         Assert.assertTrue(result.containsKey(clusterId1));
@@ -178,50 +172,4 @@ public class RollingMaintenanceManagerImplTest {
 
         Assert.assertEquals(1, hosts.size());
     }
-
-    @Test
-    public void testGetComputeResourcesCpuSpeedAndRamSize_ForNormalOffering() {
-        ServiceOfferingVO serviceOffering = Mockito.mock(ServiceOfferingVO.class);
-        Mockito.when(serviceOffering.isDynamic()).thenReturn(false);
-        Mockito.when(serviceOffering.getCpu()).thenReturn(1);
-        Mockito.when(serviceOffering.getSpeed()).thenReturn(500);
-        Mockito.when(serviceOffering.getRamSize()).thenReturn(512);
-
-        Mockito.when(vm.getServiceOfferingId()).thenReturn(1L);
-        Mockito.when(serviceOfferingDao.findById(1L)).thenReturn(serviceOffering);
-
-        Ternary<Integer, Integer, Integer> cpuSpeedAndRamSize = manager.getComputeResourcesCpuSpeedAndRamSize(vm);
-
-        Assert.assertEquals(1, cpuSpeedAndRamSize.first().intValue());
-        Assert.assertEquals(500, cpuSpeedAndRamSize.second().intValue());
-        Assert.assertEquals(512, cpuSpeedAndRamSize.third().intValue());
-    }
-
-    @Test
-    public void testGetComputeResourcesCpuSpeedAndRamSize_ForCustomOffering() {
-        ServiceOfferingVO serviceOffering = Mockito.mock(ServiceOfferingVO.class);
-        Mockito.when(serviceOffering.isDynamic()).thenReturn(true);
-        Mockito.when(serviceOffering.getCpu()).thenReturn(null);
-        Mockito.when(serviceOffering.getSpeed()).thenReturn(null);
-        Mockito.when(serviceOffering.getRamSize()).thenReturn(null);
-
-        List<UserVmDetailVO> vmDetails = new ArrayList<>();
-        UserVmDetailVO cpuDetail = new UserVmDetailVO(1L, VmDetailConstants.CPU_NUMBER, "2",  false);
-        vmDetails.add(cpuDetail);
-        UserVmDetailVO speedDetail = new UserVmDetailVO(1L, VmDetailConstants.CPU_SPEED, "1000",  false);
-        vmDetails.add(speedDetail);
-        UserVmDetailVO ramSizeDetail = new UserVmDetailVO(1L, VmDetailConstants.MEMORY, "1024",  false);
-        vmDetails.add(ramSizeDetail);
-
-        Mockito.when(vm.getId()).thenReturn(1L);
-        Mockito.when(vm.getServiceOfferingId()).thenReturn(1L);
-        Mockito.when(serviceOfferingDao.findById(1L)).thenReturn(serviceOffering);
-        Mockito.when(userVmDetailsDao.listDetails(1L)).thenReturn(vmDetails);
-
-        Ternary<Integer, Integer, Integer> cpuSpeedAndRamSize = manager.getComputeResourcesCpuSpeedAndRamSize(vm);
-
-        Assert.assertEquals(2, cpuSpeedAndRamSize.first().intValue());
-        Assert.assertEquals(1000, cpuSpeedAndRamSize.second().intValue());
-        Assert.assertEquals(1024, cpuSpeedAndRamSize.third().intValue());
-    }
 }
