@@ -18,26 +18,26 @@
 
 package com.cloud.template;
 
-import com.cloud.dc.DataCenterVO;
-import com.cloud.dc.dao.DataCenterDao;
-import com.cloud.event.EventTypes;
-import com.cloud.event.UsageEventUtils;
-import com.cloud.event.UsageEventVO;
-import com.cloud.event.dao.UsageEventDao;
-import com.cloud.exception.InvalidParameterValueException;
-import com.cloud.org.Grouping;
-import com.cloud.server.StatsCollector;
-import com.cloud.storage.Storage.ImageFormat;
-import com.cloud.storage.TemplateProfile;
-import com.cloud.storage.VMTemplateStorageResourceAssoc.Status;
-import com.cloud.storage.VMTemplateVO;
-import com.cloud.storage.dao.VMTemplateZoneDao;
-import com.cloud.test.TestAppender;
-import com.cloud.user.AccountVO;
-import com.cloud.user.ResourceLimitService;
-import com.cloud.user.dao.AccountDao;
-import com.cloud.utils.component.ComponentContext;
-import com.cloud.utils.exception.CloudRuntimeException;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.anyLong;
+import static org.mockito.Mockito.doAnswer;
+import static org.mockito.Mockito.eq;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.when;
+
+import java.lang.reflect.Field;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
+import java.util.concurrent.ExecutionException;
+
 import org.apache.cloudstack.engine.subsystem.api.storage.DataStore;
 import org.apache.cloudstack.engine.subsystem.api.storage.DataStoreManager;
 import org.apache.cloudstack.engine.subsystem.api.storage.TemplateDataFactory;
@@ -47,15 +47,14 @@ import org.apache.cloudstack.engine.subsystem.api.storage.TemplateService.Templa
 import org.apache.cloudstack.framework.async.AsyncCallFuture;
 import org.apache.cloudstack.framework.config.dao.ConfigurationDao;
 import org.apache.cloudstack.framework.events.Event;
-import org.apache.cloudstack.framework.events.EventBus;
-import org.apache.cloudstack.framework.events.EventBusException;
+import org.apache.cloudstack.framework.events.EventDistributor;
 import org.apache.cloudstack.framework.messagebus.MessageBus;
 import org.apache.cloudstack.secstorage.heuristics.HeuristicType;
 import org.apache.cloudstack.storage.datastore.db.TemplateDataStoreDao;
 import org.apache.cloudstack.storage.datastore.db.TemplateDataStoreVO;
 import org.apache.cloudstack.storage.heuristics.HeuristicRuleHelper;
 import org.apache.cloudstack.storage.image.datastore.ImageStoreEntity;
-import org.apache.log4j.Level;
+import org.apache.logging.log4j.Logger;
 import org.junit.After;
 import org.junit.Assert;
 import org.junit.Before;
@@ -71,30 +70,30 @@ import org.mockito.invocation.InvocationOnMock;
 import org.mockito.junit.MockitoJUnitRunner;
 import org.mockito.stubbing.Answer;
 
-import java.lang.reflect.Field;
-import java.lang.reflect.InvocationTargetException;
-import java.lang.reflect.Method;
-import java.util.ArrayList;
-import java.util.Collections;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.List;
-import java.util.Map;
-import java.util.Set;
-import java.util.concurrent.ExecutionException;
-import java.util.regex.Pattern;
-
-import static org.mockito.Mockito.any;
-import static org.mockito.Mockito.anyLong;
-import static org.mockito.Mockito.doAnswer;
-import static org.mockito.Mockito.eq;
-import static org.mockito.Mockito.mock;
-import static org.mockito.Mockito.when;
+import com.cloud.dc.DataCenterVO;
+import com.cloud.dc.dao.DataCenterDao;
+import com.cloud.event.EventTypes;
+import com.cloud.event.UsageEventUtils;
+import com.cloud.event.UsageEventVO;
+import com.cloud.event.dao.UsageEventDao;
+import com.cloud.exception.InvalidParameterValueException;
+import com.cloud.org.Grouping;
+import com.cloud.server.StatsCollector;
+import com.cloud.storage.Storage.ImageFormat;
+import com.cloud.storage.TemplateProfile;
+import com.cloud.storage.VMTemplateStorageResourceAssoc.Status;
+import com.cloud.storage.VMTemplateVO;
+import com.cloud.storage.dao.VMTemplateZoneDao;
+import com.cloud.user.AccountVO;
+import com.cloud.user.ResourceLimitService;
+import com.cloud.user.dao.AccountDao;
+import com.cloud.utils.component.ComponentContext;
+import com.cloud.utils.exception.CloudRuntimeException;
 
 @RunWith(MockitoJUnitRunner.class)
 public class HypervisorTemplateAdapterTest {
     @Mock
-    EventBus _bus;
+    EventDistributor eventDistributor;
     List<Event> events = new ArrayList<>();
 
     @Mock
@@ -139,6 +138,9 @@ public class HypervisorTemplateAdapterTest {
     @Mock
     StatsCollector statsCollectorMock;
 
+    @Mock
+    Logger loggerMock;
+
     @Spy
     @InjectMocks
     HypervisorTemplateAdapter _adapter = new HypervisorTemplateAdapter();
@@ -166,7 +168,7 @@ public class HypervisorTemplateAdapterTest {
         closeable.close();
     }
 
-    public UsageEventUtils setupUsageUtils() throws EventBusException {
+    public UsageEventUtils setupUsageUtils() {
         Mockito.when(_configDao.getValue(eq("publish.usage.events"))).thenReturn("true");
         Mockito.when(_usageEventDao.persist(Mockito.any(UsageEventVO.class))).then(new Answer<Void>() {
             @Override public Void answer(InvocationOnMock invocation) throws Throwable {
@@ -178,16 +180,14 @@ public class HypervisorTemplateAdapterTest {
 
         Mockito.when(_usageEventDao.listAll()).thenReturn(usageEvents);
 
-        doAnswer(new Answer<Void>() {
-            @Override public Void answer(InvocationOnMock invocation) throws Throwable {
-                Event event = (Event)invocation.getArguments()[0];
-                events.add(event);
-                return null;
-            }
-        }).when(_bus).publish(any(Event.class));
+        doAnswer((Answer<Void>) invocation -> {
+            Event event = (Event)invocation.getArguments()[0];
+            events.add(event);
+            return null;
+        }).when(eventDistributor).publish(any(Event.class));
 
         componentContextMocked = Mockito.mockStatic(ComponentContext.class);
-        when(ComponentContext.getComponent(eq(EventBus.class))).thenReturn(_bus);
+        when(ComponentContext.getComponent(eq(EventDistributor.class))).thenReturn(eventDistributor);
 
         UsageEventUtils utils = new UsageEventUtils();
 
@@ -255,7 +255,7 @@ public class HypervisorTemplateAdapterTest {
     }
 
     //@Test
-    public void testEmitDeleteEventUuid() throws InterruptedException, ExecutionException, EventBusException {
+    public void testEmitDeleteEventUuid() throws InterruptedException, ExecutionException {
         //All the mocks required for this test to work.
         ImageStoreEntity store = mock(ImageStoreEntity.class);
         when(store.getId()).thenReturn(1l);
@@ -436,14 +436,9 @@ public class HypervisorTemplateAdapterTest {
         Set<Long> zoneSet = null;
         boolean isTemplatePrivate = false;
 
-        TestAppender.TestAppenderBuilder appenderBuilder = new TestAppender.TestAppenderBuilder();
-        appenderBuilder.addExpectedPattern(Level.WARN, Pattern.quote(String.format("Zone ID is null, cannot allocate ISO/template in image store [%s].", dataStoreMock)));
-        TestAppender testLogAppender = appenderBuilder.build();
-        TestAppender.safeAddAppender(HypervisorTemplateAdapter.s_logger, testLogAppender);
-
         boolean result = _adapter.isZoneAndImageStoreAvailable(dataStoreMock, zoneId, zoneSet, isTemplatePrivate);
 
-        testLogAppender.assertMessagesLogged();
+        Mockito.verify(loggerMock, Mockito.times(1)).warn(String.format("Zone ID is null, cannot allocate ISO/template in image store [%s].", dataStoreMock));
         Assert.assertFalse(result);
     }
 
@@ -458,15 +453,10 @@ public class HypervisorTemplateAdapterTest {
         Mockito.when(_dcDao.findById(Mockito.anyLong())).thenReturn(dataCenterVOMock);
         Mockito.when(dataStoreMock.getId()).thenReturn(2L);
 
-        TestAppender.TestAppenderBuilder appenderBuilder = new TestAppender.TestAppenderBuilder();
-        appenderBuilder.addExpectedPattern(Level.WARN, Pattern.quote(String.format("Unable to find zone by id [%s], so skip downloading template to its image store [%s].",
-                zoneId, dataStoreMock.getId())));
-        TestAppender testLogAppender = appenderBuilder.build();
-        TestAppender.safeAddAppender(HypervisorTemplateAdapter.s_logger, testLogAppender);
-
         boolean result = _adapter.isZoneAndImageStoreAvailable(dataStoreMock, zoneId, zoneSet, isTemplatePrivate);
 
-        testLogAppender.assertMessagesLogged();
+        Mockito.verify(loggerMock, Mockito.times(1)).warn(String.format("Unable to find zone by id [%s], so skip downloading template to its image store [%s].",
+                zoneId, dataStoreMock.getId()));
         Assert.assertFalse(result);
     }
 
@@ -482,14 +472,9 @@ public class HypervisorTemplateAdapterTest {
         Mockito.when(dataCenterVOMock.getAllocationState()).thenReturn(Grouping.AllocationState.Disabled);
         Mockito.when(dataStoreMock.getId()).thenReturn(2L);
 
-        TestAppender.TestAppenderBuilder appenderBuilder = new TestAppender.TestAppenderBuilder();
-        appenderBuilder.addExpectedPattern(Level.INFO, Pattern.quote(String.format("Zone [%s] is disabled. Skip downloading template to its image store [%s].", zoneId, dataStoreMock.getId())));
-        TestAppender testLogAppender = appenderBuilder.build();
-        TestAppender.safeAddAppender(HypervisorTemplateAdapter.s_logger, testLogAppender);
-
         boolean result = _adapter.isZoneAndImageStoreAvailable(dataStoreMock, zoneId, zoneSet, isTemplatePrivate);
 
-        testLogAppender.assertMessagesLogged();
+        Mockito.verify(loggerMock, Mockito.times(1)).info(String.format("Zone [%s] is disabled. Skip downloading template to its image store [%s].", zoneId, dataStoreMock.getId()));
         Assert.assertFalse(result);
     }
 
@@ -506,15 +491,10 @@ public class HypervisorTemplateAdapterTest {
         Mockito.when(dataStoreMock.getId()).thenReturn(2L);
         Mockito.when(statsCollectorMock.imageStoreHasEnoughCapacity(any(DataStore.class))).thenReturn(false);
 
-        TestAppender.TestAppenderBuilder appenderBuilder = new TestAppender.TestAppenderBuilder();
-        appenderBuilder.addExpectedPattern(Level.INFO, Pattern.quote(String.format("Image store doesn't have enough capacity. Skip downloading template to this image store [%s].",
-                dataStoreMock.getId())));
-        TestAppender testLogAppender = appenderBuilder.build();
-        TestAppender.safeAddAppender(HypervisorTemplateAdapter.s_logger, testLogAppender);
-
         boolean result = _adapter.isZoneAndImageStoreAvailable(dataStoreMock, zoneId, zoneSet, isTemplatePrivate);
 
-        testLogAppender.assertMessagesLogged();
+        Mockito.verify(loggerMock, times(1)).info(String.format("Image store doesn't have enough capacity. Skip downloading template to this image store [%s].",
+                dataStoreMock.getId()));
         Assert.assertFalse(result);
     }
 
@@ -530,15 +510,10 @@ public class HypervisorTemplateAdapterTest {
         Mockito.when(dataCenterVOMock.getAllocationState()).thenReturn(Grouping.AllocationState.Enabled);
         Mockito.when(statsCollectorMock.imageStoreHasEnoughCapacity(any(DataStore.class))).thenReturn(true);
 
-        TestAppender.TestAppenderBuilder appenderBuilder = new TestAppender.TestAppenderBuilder();
-        appenderBuilder.addExpectedPattern(Level.INFO, Pattern.quote(String.format("Zone set is null; therefore, the ISO/template should be allocated in every secondary storage " +
-                "of zone [%s].", dataCenterVOMock)));
-        TestAppender testLogAppender = appenderBuilder.build();
-        TestAppender.safeAddAppender(HypervisorTemplateAdapter.s_logger, testLogAppender);
-
         boolean result = _adapter.isZoneAndImageStoreAvailable(dataStoreMock, zoneId, zoneSet, isTemplatePrivate);
 
-        testLogAppender.assertMessagesLogged();
+        Mockito.verify(loggerMock, times(1)).info(String.format("Zone set is null; therefore, the ISO/template should be allocated in every secondary storage " +
+                "of zone [%s].", dataCenterVOMock));
         Assert.assertTrue(result);
     }
 
@@ -554,15 +529,10 @@ public class HypervisorTemplateAdapterTest {
         Mockito.when(dataCenterVOMock.getAllocationState()).thenReturn(Grouping.AllocationState.Enabled);
         Mockito.when(statsCollectorMock.imageStoreHasEnoughCapacity(any(DataStore.class))).thenReturn(true);
 
-        TestAppender.TestAppenderBuilder appenderBuilder = new TestAppender.TestAppenderBuilder();
-        appenderBuilder.addExpectedPattern(Level.INFO, Pattern.quote(String.format("The template is private and it is already allocated in a secondary storage in zone [%s]; " +
-                "therefore, image store [%s] will be skipped.", dataCenterVOMock, dataStoreMock)));
-        TestAppender testLogAppender = appenderBuilder.build();
-        TestAppender.safeAddAppender(HypervisorTemplateAdapter.s_logger, testLogAppender);
-
         boolean result = _adapter.isZoneAndImageStoreAvailable(dataStoreMock, zoneId, zoneSet, isTemplatePrivate);
 
-        testLogAppender.assertMessagesLogged();
+        Mockito.verify(loggerMock, times(1)).info(String.format("The template is private and it is already allocated in a secondary storage in zone [%s]; " +
+                "therefore, image store [%s] will be skipped.", dataCenterVOMock, dataStoreMock));
         Assert.assertFalse(result);
     }
 
@@ -578,15 +548,10 @@ public class HypervisorTemplateAdapterTest {
         Mockito.when(dataCenterVOMock.getAllocationState()).thenReturn(Grouping.AllocationState.Enabled);
         Mockito.when(statsCollectorMock.imageStoreHasEnoughCapacity(any(DataStore.class))).thenReturn(true);
 
-        TestAppender.TestAppenderBuilder appenderBuilder = new TestAppender.TestAppenderBuilder();
-        appenderBuilder.addExpectedPattern(Level.INFO, Pattern.quote(String.format("Private template will be allocated in image store [%s] in zone [%s].",
-                dataStoreMock, dataCenterVOMock)));
-        TestAppender testLogAppender = appenderBuilder.build();
-        TestAppender.safeAddAppender(HypervisorTemplateAdapter.s_logger, testLogAppender);
-
         boolean result = _adapter.isZoneAndImageStoreAvailable(dataStoreMock, zoneId, zoneSet, isTemplatePrivate);
 
-        testLogAppender.assertMessagesLogged();
+        Mockito.verify(loggerMock, times(1)).info(String.format("Private template will be allocated in image store [%s] in zone [%s].",
+                dataStoreMock, dataCenterVOMock));
         Assert.assertTrue(result);
     }
 
