@@ -26,11 +26,10 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
-import org.apache.cloudstack.acl.ControlledEntity;
-import org.apache.cloudstack.acl.Role;
-import org.apache.cloudstack.acl.RoleService;
-import org.apache.cloudstack.acl.RoleType;
 import org.apache.cloudstack.acl.SecurityChecker.AccessType;
+import org.apache.cloudstack.api.command.admin.user.DeleteUserCmd;
+
+import org.apache.cloudstack.acl.ControlledEntity;
 import org.apache.cloudstack.api.command.admin.user.GetUserKeysCmd;
 import org.apache.cloudstack.api.command.admin.user.UpdateUserCmd;
 import org.apache.cloudstack.api.response.UserTwoFactorAuthenticationSetupResponse;
@@ -39,16 +38,17 @@ import org.apache.cloudstack.auth.UserAuthenticator.ActionOnFailedAuthentication
 import org.apache.cloudstack.auth.UserTwoFactorAuthenticator;
 import org.apache.cloudstack.context.CallContext;
 import org.apache.cloudstack.framework.config.ConfigKey;
-import org.apache.cloudstack.resourcedetail.UserDetailVO;
+import org.apache.cloudstack.webhook.WebhookHelper;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.mockito.ArgumentCaptor;
 import org.mockito.InOrder;
 import org.mockito.Mock;
+import org.mockito.MockedStatic;
 import org.mockito.Mockito;
 import org.mockito.junit.MockitoJUnitRunner;
+import org.springframework.beans.factory.NoSuchBeanDefinitionException;
 
 import com.cloud.acl.DomainChecker;
 import com.cloud.api.auth.SetupUserTwoFactorAuthenticationCmd;
@@ -62,6 +62,7 @@ import com.cloud.projects.Project;
 import com.cloud.projects.ProjectAccountVO;
 import com.cloud.user.Account.State;
 import com.cloud.utils.Pair;
+import com.cloud.utils.component.ComponentContext;
 import com.cloud.utils.exception.CloudRuntimeException;
 import com.cloud.vm.UserVmManagerImpl;
 import com.cloud.vm.UserVmVO;
@@ -98,6 +99,12 @@ public class AccountManagerImplTest extends AccountManagetImplTestBase {
     @Mock
     private Account accountMock;
 
+    @Mock
+    private DomainVO domainVoMock;
+
+    @Mock
+    private AccountVO accountVoMock;
+
     @Mock
     private ProjectAccountVO projectAccountVO;
     @Mock
@@ -109,18 +116,10 @@ public class AccountManagerImplTest extends AccountManagetImplTestBase {
     @Mock
     ConfigKey<Boolean> enableUserTwoFactorAuthenticationMock;
 
-    @Mock
-    ConfigKey<Boolean> allowOperationsOnUsersInSameAccountMock;
-    @Mock
-    RoleService roleService;
-
     @Before
     public void setUp() throws Exception {
         enableUserTwoFactorAuthenticationMock = Mockito.mock(ConfigKey.class);
         accountManagerImpl.enableUserTwoFactorAuthentication = enableUserTwoFactorAuthenticationMock;
-
-        allowOperationsOnUsersInSameAccountMock = Mockito.mock(ConfigKey.class);
-        accountManagerImpl.allowOperationsOnUsersInSameAccount = allowOperationsOnUsersInSameAccountMock;
     }
 
     @Before
@@ -131,8 +130,6 @@ public class AccountManagerImplTest extends AccountManagetImplTestBase {
         Mockito.doReturn(accountMockId).when(userVoMock).getAccountId();
 
         Mockito.doReturn(userVoIdMock).when(userVoMock).getId();
-
-        Mockito.lenient().doNothing().when(accountManagerImpl).checkRoleEscalation(accountMock, accountMock);
     }
 
     @Test
@@ -174,7 +171,6 @@ public class AccountManagerImplTest extends AccountManagetImplTestBase {
         Mockito.lenient().when(securityChecker.checkAccess(Mockito.any(Account.class), Mockito.any(Domain.class))).thenReturn(true);
         Mockito.when(_vmSnapshotDao.listByAccountId(Mockito.anyLong())).thenReturn(new ArrayList<VMSnapshotVO>());
         Mockito.when(_autoscaleMgr.deleteAutoScaleVmGroupsByAccount(42l)).thenReturn(true);
-        Mockito.doNothing().when(accountManagerImpl).verifyCallerPrivilegeForUserOrAccountOperations(Mockito.any(Account.class));
 
         List<SSHKeyPairVO> sshkeyList = new ArrayList<SSHKeyPairVO>();
         SSHKeyPairVO sshkey = new SSHKeyPairVO();
@@ -183,6 +179,7 @@ public class AccountManagerImplTest extends AccountManagetImplTestBase {
         Mockito.when(_sshKeyPairDao.listKeyPairs(Mockito.anyLong(), Mockito.anyLong())).thenReturn(sshkeyList);
         Mockito.when(_sshKeyPairDao.remove(Mockito.anyLong())).thenReturn(true);
         Mockito.when(userDataDao.removeByAccountId(Mockito.anyLong())).thenReturn(222);
+        Mockito.doNothing().when(accountManagerImpl).deleteWebhooksForAccount(Mockito.anyLong());
 
         Assert.assertTrue(accountManagerImpl.deleteUserAccount(42l));
         // assert that this was a clean delete
@@ -202,13 +199,82 @@ public class AccountManagerImplTest extends AccountManagetImplTestBase {
         Mockito.when(_vmMgr.expunge(Mockito.any(UserVmVO.class))).thenReturn(false);
         Mockito.lenient().when(_domainMgr.getDomain(Mockito.anyLong())).thenReturn(domain);
         Mockito.lenient().when(securityChecker.checkAccess(Mockito.any(Account.class), Mockito.any(Domain.class))).thenReturn(true);
-        Mockito.doNothing().when(accountManagerImpl).verifyCallerPrivilegeForUserOrAccountOperations(Mockito.any(Account.class));
+        Mockito.doNothing().when(accountManagerImpl).deleteWebhooksForAccount(Mockito.anyLong());
 
         Assert.assertTrue(accountManagerImpl.deleteUserAccount(42l));
         // assert that this was NOT a clean delete
         Mockito.verify(_accountDao, Mockito.atLeastOnce()).markForCleanup(Mockito.eq(42l));
     }
 
+    @Test (expected = InvalidParameterValueException.class)
+    public void deleteUserAccountTestIfAccountIdIsEqualToCallerIdShouldThrowException() {
+        try (MockedStatic<CallContext> callContextMocked = Mockito.mockStatic(CallContext.class)) {
+            CallContext callContextMock = Mockito.mock(CallContext.class);
+            callContextMocked.when(CallContext::current).thenReturn(callContextMock);
+            long accountId = 1L;
+
+            Mockito.doReturn(accountVoMock).when(callContextMock).getCallingAccount();
+            Mockito.doReturn(accountVoMock).when(_accountDao).findById(Mockito.anyLong());
+            Mockito.doReturn(domainVoMock).when(_domainDao).findById(Mockito.anyLong());
+            Mockito.doReturn(1L).when(accountVoMock).getId();
+
+            accountManagerImpl.deleteUserAccount(accountId);
+        }
+    }
+
+    @Test
+    public void deleteUserAccountTestIfAccountIdIsNotEqualToCallerAccountIdShouldNotThrowException() {
+        try (MockedStatic<CallContext> callContextMocked = Mockito.mockStatic(CallContext.class)) {
+            CallContext callContextMock = Mockito.mock(CallContext.class);
+            callContextMocked.when(CallContext::current).thenReturn(callContextMock);
+            long accountId = 1L;
+
+            Mockito.doReturn(accountVoMock).when(callContextMock).getCallingAccount();
+            Mockito.doReturn(accountVoMock).when(_accountDao).findById(Mockito.anyLong());
+            Mockito.doReturn(2L).when(accountVoMock).getId();
+            Mockito.doReturn(true).when(accountManagerImpl).isDeleteNeeded(Mockito.any(), Mockito.anyLong(), Mockito.any());
+            Mockito.doReturn(new ArrayList<Long>()).when(_projectAccountDao).listAdministratedProjectIds(Mockito.anyLong());
+
+            accountManagerImpl.deleteUserAccount(accountId);
+        }
+    }
+
+    @Test (expected = InvalidParameterValueException.class)
+    public void deleteUserTestIfUserIdIsEqualToCallerIdShouldThrowException() {
+        try (MockedStatic<CallContext> callContextMocked = Mockito.mockStatic(CallContext.class)) {
+            DeleteUserCmd cmd = Mockito.mock(DeleteUserCmd.class);
+            CallContext callContextMock = Mockito.mock(CallContext.class);
+            callContextMocked.when(CallContext::current).thenReturn(callContextMock);
+
+            Mockito.doReturn(userVoMock).when(callContextMock).getCallingUser();
+            Mockito.doReturn(1L).when(cmd).getId();
+            Mockito.doReturn(userVoMock).when(accountManagerImpl).getValidUserVO(Mockito.anyLong());
+            Mockito.doReturn(accountVoMock).when(_accountDao).findById(Mockito.anyLong());
+            Mockito.doReturn(domainVoMock).when(_domainDao).findById(Mockito.anyLong());
+            Mockito.doReturn(1L).when(userVoMock).getId();
+
+            accountManagerImpl.deleteUser(cmd);
+        }
+    }
+
+    @Test
+    public void deleteUserTestIfUserIdIsNotEqualToCallerIdShouldNotThrowException() {
+        try (MockedStatic<CallContext> callContextMocked = Mockito.mockStatic(CallContext.class)) {
+            DeleteUserCmd cmd = Mockito.mock(DeleteUserCmd.class);
+            CallContext callContextMock = Mockito.mock(CallContext.class);
+            callContextMocked.when(CallContext::current).thenReturn(callContextMock);
+
+            Mockito.doReturn(userVoMock).when(callContextMock).getCallingUser();
+            Mockito.doReturn(1L).when(cmd).getId();
+            Mockito.doReturn(userVoMock).when(accountManagerImpl).getValidUserVO(Mockito.anyLong());
+            Mockito.doReturn(accountVoMock).when(_accountDao).findById(Mockito.anyLong());
+            Mockito.doReturn(2L).when(userVoMock).getId();
+
+            Mockito.doNothing().when(accountManagerImpl).checkAccountAndAccess(Mockito.any(), Mockito.any());
+            accountManagerImpl.deleteUser(cmd);
+        }
+    }
+
     @Test
     public void testAuthenticateUser() throws UnknownHostException {
         Pair<Boolean, UserAuthenticator.ActionOnFailedAuthentication> successAuthenticationPair = new Pair<>(true, null);
@@ -271,6 +337,7 @@ public class AccountManagerImplTest extends AccountManagetImplTestBase {
 
         // Queried account - admin account
         AccountVO adminAccountMock = Mockito.mock(AccountVO.class);
+        Mockito.when(adminAccountMock.getAccountId()).thenReturn(2L);
         Mockito.when(_accountDao.findByIdIncludingRemoved(2L)).thenReturn(adminAccountMock);
         Mockito.lenient().when(accountService.isRootAdmin(2L)).thenReturn(true);
         Mockito.lenient().when(securityChecker.checkAccess(Mockito.any(Account.class),
@@ -318,12 +385,6 @@ public class AccountManagerImplTest extends AccountManagetImplTestBase {
 
     @Test
     public void updateUserTestTimeZoneAndEmailNull() {
-        Mockito.when(userVoMock.getAccountId()).thenReturn(10L);
-        Mockito.doReturn(accountMock).when(accountManagerImpl).getAccount(10L);
-        Mockito.when(accountMock.getAccountId()).thenReturn(10L);
-        Mockito.doReturn(false).when(accountManagerImpl).isRootAdmin(10L);
-        Mockito.lenient().when(accountManagerImpl.getRoleType(Mockito.eq(accountMock))).thenReturn(RoleType.User);
-
         prepareMockAndExecuteUpdateUserTest(0);
     }
 
@@ -331,11 +392,6 @@ public class AccountManagerImplTest extends AccountManagetImplTestBase {
     public void updateUserTestTimeZoneAndEmailNotNull() {
         Mockito.when(UpdateUserCmdMock.getEmail()).thenReturn("email");
         Mockito.when(UpdateUserCmdMock.getTimezone()).thenReturn("timezone");
-        Mockito.when(userVoMock.getAccountId()).thenReturn(10L);
-        Mockito.doReturn(accountMock).when(accountManagerImpl).getAccount(10L);
-        Mockito.when(accountMock.getAccountId()).thenReturn(10L);
-        Mockito.doReturn(false).when(accountManagerImpl).isRootAdmin(10L);
-        Mockito.lenient().when(accountManagerImpl.getRoleType(Mockito.eq(accountMock))).thenReturn(RoleType.User);
         prepareMockAndExecuteUpdateUserTest(1);
     }
 
@@ -349,26 +405,23 @@ public class AccountManagerImplTest extends AccountManagetImplTestBase {
         Mockito.doNothing().when(accountManagerImpl).validateAndUpdateFirstNameIfNeeded(UpdateUserCmdMock, userVoMock);
         Mockito.doNothing().when(accountManagerImpl).validateAndUpdateLastNameIfNeeded(UpdateUserCmdMock, userVoMock);
         Mockito.doNothing().when(accountManagerImpl).validateAndUpdateUsernameIfNeeded(UpdateUserCmdMock, userVoMock, accountMock);
-        Mockito.doNothing().when(accountManagerImpl).validateUserPasswordAndUpdateIfNeeded(Mockito.anyString(), Mockito.eq(userVoMock), Mockito.anyString());
+        Mockito.doNothing().when(accountManagerImpl).validateUserPasswordAndUpdateIfNeeded(Mockito.anyString(), Mockito.eq(userVoMock), Mockito.anyString(), Mockito.eq(false));
 
         Mockito.doReturn(true).when(userDaoMock).update(Mockito.anyLong(), Mockito.eq(userVoMock));
         Mockito.doReturn(Mockito.mock(UserAccountVO.class)).when(userAccountDaoMock).findById(Mockito.anyLong());
-        Mockito.doNothing().when(accountManagerImpl).checkAccess(nullable(User.class), nullable(Account.class));
 
         accountManagerImpl.updateUser(UpdateUserCmdMock);
 
-        Mockito.lenient().doNothing().when(accountManagerImpl).checkRoleEscalation(accountMock, accountMock);
-
         InOrder inOrder = Mockito.inOrder(userVoMock, accountManagerImpl, userDaoMock, userAccountDaoMock);
 
         inOrder.verify(accountManagerImpl).retrieveAndValidateUser(UpdateUserCmdMock);
-        inOrder.verify(accountManagerImpl).retrieveAndValidateAccount(userVoMock);
         inOrder.verify(accountManagerImpl).validateAndUpdateApiAndSecretKeyIfNeeded(UpdateUserCmdMock, userVoMock);
+        inOrder.verify(accountManagerImpl).retrieveAndValidateAccount(userVoMock);
 
         inOrder.verify(accountManagerImpl).validateAndUpdateFirstNameIfNeeded(UpdateUserCmdMock, userVoMock);
         inOrder.verify(accountManagerImpl).validateAndUpdateLastNameIfNeeded(UpdateUserCmdMock, userVoMock);
         inOrder.verify(accountManagerImpl).validateAndUpdateUsernameIfNeeded(UpdateUserCmdMock, userVoMock, accountMock);
-        inOrder.verify(accountManagerImpl).validateUserPasswordAndUpdateIfNeeded(UpdateUserCmdMock.getPassword(), userVoMock, UpdateUserCmdMock.getCurrentPassword());
+        inOrder.verify(accountManagerImpl).validateUserPasswordAndUpdateIfNeeded(UpdateUserCmdMock.getPassword(), userVoMock, UpdateUserCmdMock.getCurrentPassword(), false);
 
         inOrder.verify(userVoMock, Mockito.times(numberOfExpectedCallsForSetEmailAndSetTimeZone)).setEmail(Mockito.anyString());
         inOrder.verify(userVoMock, Mockito.times(numberOfExpectedCallsForSetEmailAndSetTimeZone)).setTimezone(Mockito.anyString());
@@ -654,14 +707,14 @@ public class AccountManagerImplTest extends AccountManagetImplTestBase {
 
     @Test
     public void valiateUserPasswordAndUpdateIfNeededTestPasswordNull() {
-        accountManagerImpl.validateUserPasswordAndUpdateIfNeeded(null, userVoMock, null);
+        accountManagerImpl.validateUserPasswordAndUpdateIfNeeded(null, userVoMock, null, false);
 
         Mockito.verify(userVoMock, Mockito.times(0)).setPassword(Mockito.anyString());
     }
 
     @Test(expected = InvalidParameterValueException.class)
     public void valiateUserPasswordAndUpdateIfNeededTestBlankPassword() {
-        accountManagerImpl.validateUserPasswordAndUpdateIfNeeded("       ", userVoMock, null);
+        accountManagerImpl.validateUserPasswordAndUpdateIfNeeded("       ", userVoMock, null, false);
     }
 
     @Test(expected = InvalidParameterValueException.class)
@@ -675,7 +728,7 @@ public class AccountManagerImplTest extends AccountManagetImplTestBase {
 
         Mockito.lenient().doNothing().when(passwordPolicyMock).verifyIfPasswordCompliesWithPasswordPolicies(Mockito.anyString(), Mockito.anyString(), Mockito.anyLong());
 
-        accountManagerImpl.validateUserPasswordAndUpdateIfNeeded("newPassword", userVoMock, "  ");
+        accountManagerImpl.validateUserPasswordAndUpdateIfNeeded("newPassword", userVoMock, "  ", false);
     }
 
     @Test(expected = CloudRuntimeException.class)
@@ -690,7 +743,7 @@ public class AccountManagerImplTest extends AccountManagetImplTestBase {
 
         Mockito.lenient().doNothing().when(passwordPolicyMock).verifyIfPasswordCompliesWithPasswordPolicies(Mockito.anyString(), Mockito.anyString(), Mockito.anyLong());
 
-        accountManagerImpl.validateUserPasswordAndUpdateIfNeeded("newPassword", userVoMock, null);
+        accountManagerImpl.validateUserPasswordAndUpdateIfNeeded("newPassword", userVoMock, null, false);
     }
 
     @Test
@@ -709,7 +762,7 @@ public class AccountManagerImplTest extends AccountManagetImplTestBase {
 
         Mockito.lenient().doNothing().when(passwordPolicyMock).verifyIfPasswordCompliesWithPasswordPolicies(Mockito.anyString(), Mockito.anyString(), Mockito.anyLong());
 
-        accountManagerImpl.validateUserPasswordAndUpdateIfNeeded(newPassword, userVoMock, null);
+        accountManagerImpl.validateUserPasswordAndUpdateIfNeeded(newPassword, userVoMock, null, false);
 
         Mockito.verify(accountManagerImpl, Mockito.times(0)).validateCurrentPassword(Mockito.eq(userVoMock), Mockito.anyString());
         Mockito.verify(userVoMock, Mockito.times(1)).setPassword(expectedUserPasswordAfterEncoded);
@@ -731,7 +784,7 @@ public class AccountManagerImplTest extends AccountManagetImplTestBase {
 
         Mockito.lenient().doNothing().when(passwordPolicyMock).verifyIfPasswordCompliesWithPasswordPolicies(Mockito.anyString(), Mockito.anyString(), Mockito.anyLong());
 
-        accountManagerImpl.validateUserPasswordAndUpdateIfNeeded(newPassword, userVoMock, null);
+        accountManagerImpl.validateUserPasswordAndUpdateIfNeeded(newPassword, userVoMock, null, false);
 
         Mockito.verify(accountManagerImpl, Mockito.times(0)).validateCurrentPassword(Mockito.eq(userVoMock), Mockito.anyString());
         Mockito.verify(userVoMock, Mockito.times(1)).setPassword(expectedUserPasswordAfterEncoded);
@@ -754,7 +807,7 @@ public class AccountManagerImplTest extends AccountManagetImplTestBase {
 
         Mockito.lenient().doNothing().when(passwordPolicyMock).verifyIfPasswordCompliesWithPasswordPolicies(Mockito.anyString(), Mockito.anyString(), Mockito.anyLong());
 
-        accountManagerImpl.validateUserPasswordAndUpdateIfNeeded(newPassword, userVoMock, currentPassword);
+        accountManagerImpl.validateUserPasswordAndUpdateIfNeeded(newPassword, userVoMock, currentPassword, false);
 
         Mockito.verify(accountManagerImpl, Mockito.times(1)).validateCurrentPassword(userVoMock, currentPassword);
         Mockito.verify(userVoMock, Mockito.times(1)).setPassword(expectedUserPasswordAfterEncoded);
@@ -773,37 +826,7 @@ public class AccountManagerImplTest extends AccountManagetImplTestBase {
         Mockito.doThrow(new InvalidParameterValueException("")).when(passwordPolicyMock).verifyIfPasswordCompliesWithPasswordPolicies(Mockito.anyString(), Mockito.anyString(),
                 Mockito.anyLong());
 
-        accountManagerImpl.validateUserPasswordAndUpdateIfNeeded(newPassword, userVoMock, currentPassword);
-    }
-
-    @Test(expected = InvalidParameterValueException.class)
-    public void validateUserPasswordAndUpdateIfNeededTestSaml2UserShouldNotBeAllowedToUpdateTheirPassword() {
-        String newPassword = "newPassword";
-        String currentPassword = "theCurrentPassword";
-
-        Mockito.when(userVoMock.getSource()).thenReturn(User.Source.SAML2);
-
-        accountManagerImpl.validateUserPasswordAndUpdateIfNeeded(newPassword, userVoMock, currentPassword);
-    }
-
-    @Test(expected = InvalidParameterValueException.class)
-    public void validateUserPasswordAndUpdateIfNeededTestSaml2DisabledUserShouldNotBeAllowedToUpdateTheirPassword() {
-        String newPassword = "newPassword";
-        String currentPassword = "theCurrentPassword";
-
-        Mockito.when(userVoMock.getSource()).thenReturn(User.Source.SAML2DISABLED);
-
-        accountManagerImpl.validateUserPasswordAndUpdateIfNeeded(newPassword, userVoMock, currentPassword);
-    }
-
-    @Test(expected = InvalidParameterValueException.class)
-    public void validateUserPasswordAndUpdateIfNeededTestLdapUserShouldNotBeAllowedToUpdateTheirPassword() {
-        String newPassword = "newPassword";
-        String currentPassword = "theCurrentPassword";
-
-        Mockito.when(userVoMock.getSource()).thenReturn(User.Source.LDAP);
-
-        accountManagerImpl.validateUserPasswordAndUpdateIfNeeded(newPassword, userVoMock, currentPassword);
+        accountManagerImpl.validateUserPasswordAndUpdateIfNeeded(newPassword, userVoMock, currentPassword, false);
     }
 
     private String configureUserMockAuthenticators(String newPassword) {
@@ -1109,329 +1132,22 @@ public class AccountManagerImplTest extends AccountManagetImplTestBase {
     }
 
     @Test
-    public void deleteAndCleanupUserTestRemovesUserFromProjects() {
-        long userId = userVoMock.getId();
-        Mockito.doNothing().when(_projectAccountDao).removeUserFromProjects(userId);
-
-        accountManagerImpl.deleteAndCleanupUser(userVoMock);
-
-        Mockito.verify(_projectAccountDao).removeUserFromProjects(userId);
-    }
-
-    @Test(expected = PermissionDeniedException.class)
-    public void testValidateRoleChangeUnknownCaller() {
-        Account account = Mockito.mock(Account.class);
-        Mockito.when(account.getRoleId()).thenReturn(1L);
-        Role role = Mockito.mock(Role.class);
-        Mockito.when(role.getRoleType()).thenReturn(RoleType.Unknown);
-        Account caller = Mockito.mock(Account.class);
-        Mockito.when(caller.getRoleId()).thenReturn(2L);
-        Mockito.when(roleService.findRole(2L)).thenReturn(role);
-        accountManagerImpl.validateRoleChange(account, Mockito.mock(Role.class), caller);
-    }
-
-    @Test(expected = PermissionDeniedException.class)
-    public void testValidateRoleChangeUnknownNewRole() {
-        Account account = Mockito.mock(Account.class);
-        Mockito.when(account.getRoleId()).thenReturn(1L);
-        Role newRole = Mockito.mock(Role.class);
-        Mockito.when(newRole.getRoleType()).thenReturn(RoleType.Unknown);
-        Role callerRole = Mockito.mock(Role.class);
-        Mockito.when(callerRole.getRoleType()).thenReturn(RoleType.DomainAdmin);
-        Account caller = Mockito.mock(Account.class);
-        Mockito.when(caller.getRoleId()).thenReturn(2L);
-        Mockito.when(roleService.findRole(2L)).thenReturn(callerRole);
-        accountManagerImpl.validateRoleChange(account, newRole, caller);
+    public void testDeleteWebhooksForAccount() {
+        try (MockedStatic<ComponentContext> mockedComponentContext = Mockito.mockStatic(ComponentContext.class)) {
+            WebhookHelper webhookHelper = Mockito.mock(WebhookHelper.class);
+            Mockito.doNothing().when(webhookHelper).deleteWebhooksForAccount(Mockito.anyLong());
+            mockedComponentContext.when(() -> ComponentContext.getDelegateComponentOfType(WebhookHelper.class))
+                    .thenReturn(webhookHelper);
+            accountManagerImpl.deleteWebhooksForAccount(1L);
+        }
     }
 
     @Test
-    public void testValidateRoleNewRoleSameCaller() {
-        Account account = Mockito.mock(Account.class);
-        Mockito.when(account.getRoleId()).thenReturn(1L);
-        Role currentRole = Mockito.mock(Role.class);
-        Mockito.when(currentRole.getRoleType()).thenReturn(RoleType.User);
-        Mockito.when(roleService.findRole(1L)).thenReturn(currentRole);
-        Role newRole = Mockito.mock(Role.class);
-        Mockito.when(newRole.getRoleType()).thenReturn(RoleType.DomainAdmin);
-        Role callerRole = Mockito.mock(Role.class);
-        Mockito.when(callerRole.getRoleType()).thenReturn(RoleType.DomainAdmin);
-        Account caller = Mockito.mock(Account.class);
-        Mockito.when(caller.getRoleId()).thenReturn(2L);
-        Mockito.when(roleService.findRole(2L)).thenReturn(callerRole);
-        accountManagerImpl.validateRoleChange(account, newRole, caller);
-    }
-
-    @Test
-    public void testValidateRoleCurrentRoleSameCaller() {
-        Account account = Mockito.mock(Account.class);
-        Mockito.when(account.getRoleId()).thenReturn(1L);
-        Role accountRole = Mockito.mock(Role.class);
-        Mockito.when(accountRole.getRoleType()).thenReturn(RoleType.DomainAdmin);
-        Role newRole = Mockito.mock(Role.class);
-        Mockito.when(newRole.getRoleType()).thenReturn(RoleType.User);
-        Role callerRole = Mockito.mock(Role.class);
-        Mockito.when(callerRole.getRoleType()).thenReturn(RoleType.DomainAdmin);
-        Account caller = Mockito.mock(Account.class);
-        Mockito.when(caller.getRoleId()).thenReturn(2L);
-        Mockito.when(roleService.findRole(1L)).thenReturn(accountRole);
-        Mockito.when(roleService.findRole(2L)).thenReturn(callerRole);
-        accountManagerImpl.validateRoleChange(account, newRole, caller);
-    }
-
-    @Test(expected = PermissionDeniedException.class)
-    public void testValidateRoleNewRoleHigherCaller() {
-        Account account = Mockito.mock(Account.class);
-        Mockito.when(account.getRoleId()).thenReturn(1L);
-        Role newRole = Mockito.mock(Role.class);
-        Mockito.when(newRole.getRoleType()).thenReturn(RoleType.Admin);
-        Role callerRole = Mockito.mock(Role.class);
-        Mockito.when(callerRole.getRoleType()).thenReturn(RoleType.DomainAdmin);
-        Account caller = Mockito.mock(Account.class);
-        Mockito.when(caller.getRoleId()).thenReturn(2L);
-        Mockito.when(roleService.findRole(2L)).thenReturn(callerRole);
-        accountManagerImpl.validateRoleChange(account, newRole, caller);
-    }
-
-    @Test
-    public void testValidateRoleNewRoleLowerCaller() {
-        Account account = Mockito.mock(Account.class);
-        Mockito.when(account.getRoleId()).thenReturn(1L);
-        Role newRole = Mockito.mock(Role.class);
-        Mockito.when(newRole.getRoleType()).thenReturn(RoleType.User);
-        Role accountRole = Mockito.mock(Role.class);
-        Mockito.when(accountRole.getRoleType()).thenReturn(RoleType.User);
-        Role callerRole = Mockito.mock(Role.class);
-        Mockito.when(callerRole.getRoleType()).thenReturn(RoleType.DomainAdmin);
-        Account caller = Mockito.mock(Account.class);
-        Mockito.when(caller.getRoleId()).thenReturn(2L);
-        Mockito.when(roleService.findRole(1L)).thenReturn(accountRole);
-        Mockito.when(roleService.findRole(2L)).thenReturn(callerRole);
-        accountManagerImpl.validateRoleChange(account, newRole, caller);
-    }
-
-    @Test(expected = PermissionDeniedException.class)
-    public void testValidateRoleAdminCannotEscalateAdminFromNonRootDomain() {
-        Account account = Mockito.mock(Account.class);
-        Mockito.when(account.getRoleId()).thenReturn(1L);
-        Mockito.when(account.getDomainId()).thenReturn(2L);
-        Role newRole = Mockito.mock(Role.class);
-        Mockito.when(newRole.getRoleType()).thenReturn(RoleType.Admin);
-        Role accountRole = Mockito.mock(Role.class);
-        Role callerRole = Mockito.mock(Role.class);
-        Mockito.when(callerRole.getRoleType()).thenReturn(RoleType.Admin);
-        Account caller = Mockito.mock(Account.class);
-        Mockito.when(caller.getRoleId()).thenReturn(2L);
-        Mockito.when(roleService.findRole(1L)).thenReturn(accountRole);
-        Mockito.when(roleService.findRole(2L)).thenReturn(callerRole);
-        accountManagerImpl.validateRoleChange(account, newRole, caller);
-    }
-
-    @Test
-    public void checkIfAccountManagesProjectsTestNotThrowExceptionWhenTheAccountIsNotAProjectAdministrator() {
-        long accountId = 1L;
-        List<Long> managedProjectIds = new ArrayList<>();
-
-        Mockito.when(_projectAccountDao.listAdministratedProjectIds(accountId)).thenReturn(managedProjectIds);
-        accountManagerImpl.checkIfAccountManagesProjects(accountId);
-    }
-
-    @Test(expected = InvalidParameterValueException.class)
-    public void checkIfAccountManagesProjectsTestThrowExceptionWhenTheAccountIsAProjectAdministrator() {
-        long accountId = 1L;
-        List<Long> managedProjectIds = List.of(1L);
-
-        Mockito.when(_projectAccountDao.listAdministratedProjectIds(accountId)).thenReturn(managedProjectIds);
-        accountManagerImpl.checkIfAccountManagesProjects(accountId);
-    }
-
-    @Test
-    public void testClearUser2FA_When2FADisabled_NoChanges() {
-        UserAccount user = Mockito.mock(UserAccount.class);
-        Mockito.when(user.isUser2faEnabled()).thenReturn(false);
-        Mockito.when(user.getUser2faProvider()).thenReturn(null);
-        UserAccount result = accountManagerImpl.clearUserTwoFactorAuthenticationInSetupStateOnLogin(user);
-        Assert.assertSame(user, result);
-        Mockito.verifyNoInteractions(userDetailsDaoMock, userAccountDaoMock);
-    }
-
-    @Test
-    public void testClearUser2FA_When2FAInVerifiedState_NoChanges() {
-        UserAccount user = Mockito.mock(UserAccount.class);
-        Mockito.when(user.getId()).thenReturn(1L);
-        Mockito.when(user.isUser2faEnabled()).thenReturn(true);
-        UserDetailVO userDetail = new UserDetailVO();
-        userDetail.setValue(UserAccountVO.Setup2FAstatus.VERIFIED.name());
-        Mockito.when(userDetailsDaoMock.findDetail(1L, UserDetailVO.Setup2FADetail)).thenReturn(userDetail);
-        UserAccount result = accountManagerImpl.clearUserTwoFactorAuthenticationInSetupStateOnLogin(user);
-        Assert.assertSame(user, result);
-        Mockito.verify(userDetailsDaoMock).findDetail(1L, UserDetailVO.Setup2FADetail);
-        Mockito.verifyNoMoreInteractions(userDetailsDaoMock, userAccountDaoMock);
-    }
-
-    @Test
-    public void testClearUser2FA_When2FAInSetupState_Disable2FA() {
-        UserAccount user = Mockito.mock(UserAccount.class);
-        Mockito.when(user.getId()).thenReturn(1L);
-        Mockito.when(user.isUser2faEnabled()).thenReturn(true);
-        UserDetailVO userDetail = new UserDetailVO();
-        userDetail.setValue(UserAccountVO.Setup2FAstatus.ENABLED.name());
-        UserAccountVO userAccountVO = new UserAccountVO();
-        userAccountVO.setId(1L);
-        Mockito.when(userDetailsDaoMock.findDetail(1L, UserDetailVO.Setup2FADetail)).thenReturn(userDetail);
-        Mockito.when(userAccountDaoMock.findById(1L)).thenReturn(userAccountVO);
-        UserAccount result = accountManagerImpl.clearUserTwoFactorAuthenticationInSetupStateOnLogin(user);
-        Assert.assertNotNull(result);
-        Assert.assertFalse(result.isUser2faEnabled());
-        Assert.assertNull(result.getUser2faProvider());
-        Mockito.verify(userDetailsDaoMock).findDetail(1L, UserDetailVO.Setup2FADetail);
-        Mockito.verify(userDetailsDaoMock).remove(Mockito.anyLong());
-        Mockito.verify(userAccountDaoMock).findById(1L);
-        ArgumentCaptor<UserAccountVO> captor = ArgumentCaptor.forClass(UserAccountVO.class);
-        Mockito.verify(userAccountDaoMock).update(Mockito.eq(1L), captor.capture());
-        UserAccountVO updatedUser = captor.getValue();
-        Assert.assertFalse(updatedUser.isUser2faEnabled());
-        Assert.assertNull(updatedUser.getUser2faProvider());
-        Assert.assertNull(updatedUser.getKeyFor2fa());
-    }
-
-    @Test(expected = InvalidParameterValueException.class)
-    public void testAssertUserNotAlreadyInAccount_UserExistsInAccount() {
-        User existingUser = new UserVO();
-        existingUser.setUsername("testuser");
-        existingUser.setAccountId(1L);
-
-        Account newAccount = Mockito.mock(Account.class);
-        Mockito.when(newAccount.getId()).thenReturn(1L);
-
-        AccountVO existingAccount = Mockito.mock(AccountVO.class);
-        Mockito.when(existingAccount.getUuid()).thenReturn("existing-account-uuid");
-        Mockito.when(existingAccount.getAccountName()).thenReturn("existing-account");
-
-        Mockito.when(_accountDao.findById(1L)).thenReturn(existingAccount);
-
-        accountManagerImpl.assertUserNotAlreadyInAccount(existingUser, newAccount);
-    }
-
-    @Test
-    public void testAssertUserNotAlreadyInAccount_UserExistsInDiffAccount() {
-        User existingUser = new UserVO();
-        existingUser.setUsername("testuser");
-        existingUser.setAccountId(2L);
-
-        Account newAccount = Mockito.mock(Account.class);
-        Mockito.when(newAccount.getId()).thenReturn(1L);
-
-        accountManagerImpl.assertUserNotAlreadyInAccount(existingUser, newAccount);
-    }
-
-    @Test(expected = InvalidParameterValueException.class)
-    public void testAssertUserNotAlreadyInDomain_UserExistsInDomain() {
-        User existingUser = new UserVO();
-        existingUser.setUsername("testuser");
-        existingUser.setAccountId(1L);
-
-        Account originalAccount = Mockito.mock(Account.class);
-        Mockito.when(originalAccount.getDomainId()).thenReturn(1L);
-
-        AccountVO existingAccount = Mockito.mock(AccountVO.class);
-        Mockito.when(existingAccount.getDomainId()).thenReturn(1L);
-        Mockito.when(existingAccount.getUuid()).thenReturn("existing-account-uuid");
-        Mockito.when(existingAccount.getAccountName()).thenReturn("existing-account");
-
-        DomainVO existingDomain = Mockito.mock(DomainVO.class);
-        Mockito.when(existingDomain.getUuid()).thenReturn("existing-domain-uuid");
-        Mockito.when(existingDomain.getName()).thenReturn("existing-domain");
-
-        Mockito.when(_accountDao.findById(1L)).thenReturn(existingAccount);
-        Mockito.when(_domainDao.findById(1L)).thenReturn(existingDomain);
-
-        accountManagerImpl.assertUserNotAlreadyInDomain(existingUser, originalAccount);
-    }
-
-    @Test
-    public void testAssertUserNotAlreadyInDomain_UserExistsInDiffDomain() {
-        User existingUser = new UserVO();
-        existingUser.setUsername("testuser");
-        existingUser.setAccountId(1L);
-
-        Account originalAccount = Mockito.mock(Account.class);
-        Mockito.when(originalAccount.getDomainId()).thenReturn(1L);
-
-        AccountVO existingAccount = Mockito.mock(AccountVO.class);
-        Mockito.when(existingAccount.getDomainId()).thenReturn(2L);
-
-        Mockito.when(_accountDao.findById(1L)).thenReturn(existingAccount);
-
-        accountManagerImpl.assertUserNotAlreadyInDomain(existingUser, originalAccount);
-    }
-
-    @Test
-    public void testCheckCallerRoleTypeAllowedToUpdateUserSameAccount() {
-        Mockito.lenient().when(accountManagerImpl.getCurrentCallingAccount()).thenReturn(accountMock);
-        Mockito.lenient().when(accountManagerImpl.getRoleType(Mockito.eq(accountMock))).thenReturn(RoleType.DomainAdmin);
-
-        accountManagerImpl.checkCallerRoleTypeAllowedForUserOrAccountOperations(accountMock, userVoMock);
-    }
-
-    @Test(expected = PermissionDeniedException.class)
-    public void testCheckCallerRoleTypeAllowedToUpdateUserLowerAccountRoleType() {
-        Account callingAccount = Mockito.mock(Account.class);
-        Mockito.lenient().when(callingAccount.getAccountId()).thenReturn(2L);
-        Mockito.lenient().doReturn(callingAccount).when(accountManagerImpl).getAccount(2L);
-        Mockito.lenient().when(accountManagerImpl.getCurrentCallingAccount()).thenReturn(callingAccount);
-        Mockito.lenient().when(accountManagerImpl.getRoleType(Mockito.eq(callingAccount))).thenReturn(RoleType.DomainAdmin);
-        Mockito.lenient().when(accountManagerImpl.getRoleType(Mockito.eq(accountMock))).thenReturn(RoleType.Admin);
-        accountManagerImpl.checkCallerRoleTypeAllowedForUserOrAccountOperations(accountMock, userVoMock);
-    }
-
-    @Test
-    public void testcheckCallerApiPermissionsForUserOperationsRootAdminSameCaller() {
-        Mockito.lenient().when(accountManagerImpl.getCurrentCallingAccount()).thenReturn(accountMock);
-        Mockito.when(accountMock.getId()).thenReturn(2L);
-        Mockito.doReturn(true).when(accountManagerImpl).isRootAdmin(2L);
-        accountManagerImpl.checkCallerApiPermissionsForUserOrAccountOperations(accountMock);
-    }
-
-    @Test(expected = PermissionDeniedException.class)
-    public void testcheckCallerApiPermissionsForUserOperationsRootAdminDifferentAccount() {
-        Mockito.lenient().when(accountManagerImpl.getCurrentCallingAccount()).thenReturn(callingAccount);
-        Mockito.lenient().when(callingAccount.getAccountId()).thenReturn(3L);
-        Mockito.lenient().doReturn(callingAccount).when(accountManagerImpl).getAccount(3L);
-        Mockito.lenient().doReturn(false).when(accountManagerImpl).isRootAdmin(3L);
-
-        Mockito.when(accountMock.getAccountId()).thenReturn(2L);
-        Mockito.doReturn(true).when(accountManagerImpl).isRootAdmin(2L);
-
-        accountManagerImpl.checkCallerApiPermissionsForUserOrAccountOperations(accountMock);
-    }
-
-    @Test
-    public void testcheckCallerApiPermissionsForUserOperationsAllowedApis() {
-        Mockito.lenient().when(accountManagerImpl.getCurrentCallingAccount()).thenReturn(callingAccount);
-        Mockito.lenient().when(callingAccount.getAccountId()).thenReturn(3L);
-        Mockito.lenient().doReturn(callingAccount).when(accountManagerImpl).getAccount(3L);
-        Mockito.lenient().doReturn(false).when(accountManagerImpl).isRootAdmin(3L);
-
-        Mockito.when(accountMock.getAccountId()).thenReturn(2L);
-        Mockito.doReturn(false).when(accountManagerImpl).isRootAdmin(2L);
-
-        Mockito.lenient().doNothing().when(accountManagerImpl).checkRoleEscalation(callingAccount, accountMock);
-
-        accountManagerImpl.checkCallerApiPermissionsForUserOrAccountOperations(accountMock);
-    }
-
-    @Test(expected = PermissionDeniedException.class)
-    public void testcheckCallerApiPermissionsForUserOperationsNotAllowedApis() {
-        Mockito.lenient().when(accountManagerImpl.getCurrentCallingAccount()).thenReturn(callingAccount);
-        Mockito.lenient().when(callingAccount.getAccountId()).thenReturn(3L);
-        Mockito.lenient().doReturn(callingAccount).when(accountManagerImpl).getAccount(3L);
-        Mockito.lenient().doReturn(false).when(accountManagerImpl).isRootAdmin(3L);
-
-        Mockito.when(accountMock.getAccountId()).thenReturn(2L);
-        Mockito.doReturn(false).when(accountManagerImpl).isRootAdmin(2L);
-
-        Mockito.lenient().doThrow(PermissionDeniedException.class).when(accountManagerImpl).checkRoleEscalation(callingAccount, accountMock);
-
-        accountManagerImpl.checkCallerApiPermissionsForUserOrAccountOperations(accountMock);
+    public void testDeleteWebhooksForAccountNoBean() {
+        try (MockedStatic<ComponentContext> mockedComponentContext = Mockito.mockStatic(ComponentContext.class)) {
+            mockedComponentContext.when(() -> ComponentContext.getDelegateComponentOfType(WebhookHelper.class))
+                    .thenThrow(NoSuchBeanDefinitionException.class);
+            accountManagerImpl.deleteWebhooksForAccount(1L);
+        }
     }
 }
