@@ -210,11 +210,6 @@ public class MockUsageEventDao implements UsageEventDao{
         return 0;
     }
 
-    @Override
-    public int expunge(SearchCriteria<UsageEventVO> sc, long limit) {
-        return 0;
-    }
-
     @Override
     public void expunge() {
 
@@ -337,4 +332,19 @@ public class MockUsageEventDao implements UsageEventDao{
     public Pair<List<UsageEventVO>, Integer> searchAndCount(SearchCriteria<UsageEventVO> sc, Filter filter, boolean includeRemoved) {
         return null;
     }
+
+    @Override
+    public int expunge(SearchCriteria<UsageEventVO> sc, Filter filter) {
+        return 0;
+    }
+
+    @Override
+    public int batchExpunge(SearchCriteria<UsageEventVO> sc, Long batchSize) {
+        return 0;
+    }
+
+    @Override
+    public int expungeList(List<Long> longs) {
+        return 0;
+    }
 }
