@@ -17,6 +17,58 @@
 
 package org.apache.cloudstack.vm;
 
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyBoolean;
+import static org.mockito.ArgumentMatchers.anyInt;
+import static org.mockito.ArgumentMatchers.anyLong;
+import static org.mockito.ArgumentMatchers.anyMap;
+import static org.mockito.ArgumentMatchers.anyString;
+import static org.mockito.ArgumentMatchers.nullable;
+import static org.mockito.Mockito.doNothing;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
+
+import java.net.URI;
+import java.util.ArrayList;
+import java.util.HashMap;
+import java.util.LinkedHashMap;
+import java.util.List;
+import java.util.Map;
+import java.util.UUID;
+
+import org.apache.cloudstack.api.ResponseGenerator;
+import org.apache.cloudstack.api.ResponseObject;
+import org.apache.cloudstack.api.ServerApiException;
+import org.apache.cloudstack.api.command.admin.vm.ImportUnmanagedInstanceCmd;
+import org.apache.cloudstack.api.command.admin.vm.ImportVmCmd;
+import org.apache.cloudstack.api.command.admin.vm.ListUnmanagedInstancesCmd;
+import org.apache.cloudstack.api.command.admin.vm.ListVmsForImportCmd;
+import org.apache.cloudstack.api.response.ListResponse;
+import org.apache.cloudstack.api.response.UserVmResponse;
+import org.apache.cloudstack.context.CallContext;
+import org.apache.cloudstack.engine.orchestration.service.NetworkOrchestrationService;
+import org.apache.cloudstack.engine.orchestration.service.VolumeOrchestrationService;
+import org.apache.cloudstack.engine.subsystem.api.storage.DataStore;
+import org.apache.cloudstack.engine.subsystem.api.storage.DataStoreManager;
+import org.apache.cloudstack.framework.config.dao.ConfigurationDao;
+import org.apache.cloudstack.storage.datastore.db.ImageStoreDao;
+import org.apache.cloudstack.storage.datastore.db.ImageStoreVO;
+import org.apache.cloudstack.storage.datastore.db.PrimaryDataStoreDao;
+import org.apache.cloudstack.storage.datastore.db.StoragePoolVO;
+import org.junit.After;
+import org.junit.Assert;
+import org.junit.Before;
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.mockito.BDDMockito;
+import org.mockito.InjectMocks;
+import org.mockito.Mock;
+import org.mockito.MockedStatic;
+import org.mockito.Mockito;
+import org.mockito.MockitoAnnotations;
+import org.mockito.junit.MockitoJUnitRunner;
+
 import com.cloud.agent.AgentManager;
 import com.cloud.agent.api.Answer;
 import com.cloud.agent.api.CheckConvertInstanceAnswer;
@@ -31,8 +83,6 @@ import com.cloud.agent.api.GetRemoteVmsAnswer;
 import com.cloud.agent.api.GetRemoteVmsCommand;
 import com.cloud.agent.api.GetUnmanagedInstancesAnswer;
 import com.cloud.agent.api.GetUnmanagedInstancesCommand;
-import com.cloud.agent.api.ImportConvertedInstanceAnswer;
-import com.cloud.agent.api.ImportConvertedInstanceCommand;
 import com.cloud.agent.api.to.DataStoreTO;
 import com.cloud.configuration.Resource;
 import com.cloud.dc.ClusterVO;
@@ -51,6 +101,7 @@ import com.cloud.exception.InsufficientServerCapacityException;
 import com.cloud.exception.InvalidParameterValueException;
 import com.cloud.exception.OperationTimedoutException;
 import com.cloud.exception.PermissionDeniedException;
+import com.cloud.exception.ResourceAllocationException;
 import com.cloud.exception.UnsupportedServiceException;
 import com.cloud.host.Host;
 import com.cloud.host.HostVO;
@@ -65,7 +116,6 @@ import com.cloud.network.dao.NetworkDao;
 import com.cloud.network.dao.NetworkVO;
 import com.cloud.offering.NetworkOffering;
 import com.cloud.offering.ServiceOffering;
-import com.cloud.org.Grouping;
 import com.cloud.resource.ResourceManager;
 import com.cloud.resource.ResourceState;
 import com.cloud.service.ServiceOfferingVO;
@@ -110,57 +160,6 @@ import com.cloud.vm.dao.NicDao;
 import com.cloud.vm.dao.UserVmDao;
 import com.cloud.vm.dao.VMInstanceDao;
 import com.cloud.vm.snapshot.dao.VMSnapshotDao;
-import org.apache.cloudstack.api.ResponseGenerator;
-import org.apache.cloudstack.api.ResponseObject;
-import org.apache.cloudstack.api.ServerApiException;
-import org.apache.cloudstack.api.command.admin.vm.ImportUnmanagedInstanceCmd;
-import org.apache.cloudstack.api.command.admin.vm.ImportVmCmd;
-import org.apache.cloudstack.api.command.admin.vm.ListUnmanagedInstancesCmd;
-import org.apache.cloudstack.api.command.admin.vm.ListVmsForImportCmd;
-import org.apache.cloudstack.api.response.ListResponse;
-import org.apache.cloudstack.api.response.UserVmResponse;
-import org.apache.cloudstack.context.CallContext;
-import org.apache.cloudstack.engine.orchestration.service.NetworkOrchestrationService;
-import org.apache.cloudstack.engine.orchestration.service.VolumeOrchestrationService;
-import org.apache.cloudstack.engine.subsystem.api.storage.DataStore;
-import org.apache.cloudstack.engine.subsystem.api.storage.DataStoreManager;
-import org.apache.cloudstack.framework.config.dao.ConfigurationDao;
-import org.apache.cloudstack.storage.datastore.db.ImageStoreDao;
-import org.apache.cloudstack.storage.datastore.db.ImageStoreVO;
-import org.apache.cloudstack.storage.datastore.db.PrimaryDataStoreDao;
-import org.apache.cloudstack.storage.datastore.db.StoragePoolVO;
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.mockito.BDDMockito;
-import org.mockito.InjectMocks;
-import org.mockito.Mock;
-import org.mockito.MockedStatic;
-import org.mockito.Mockito;
-import org.mockito.MockitoAnnotations;
-import org.mockito.junit.MockitoJUnitRunner;
-
-import java.net.URI;
-import java.util.ArrayList;
-import java.util.HashMap;
-import java.util.LinkedHashMap;
-import java.util.List;
-import java.util.Map;
-import java.util.UUID;
-
-import static org.mockito.ArgumentMatchers.any;
-import static org.mockito.ArgumentMatchers.anyBoolean;
-import static org.mockito.ArgumentMatchers.anyInt;
-import static org.mockito.ArgumentMatchers.anyLong;
-import static org.mockito.ArgumentMatchers.anyMap;
-import static org.mockito.ArgumentMatchers.anyString;
-import static org.mockito.ArgumentMatchers.nullable;
-import static org.mockito.Mockito.doNothing;
-import static org.mockito.Mockito.mock;
-import static org.mockito.Mockito.verify;
-import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class UnmanagedVMsManagerImplTest {
@@ -277,7 +276,6 @@ public class UnmanagedVMsManagerImplTest {
         List<UnmanagedInstanceTO.Disk> instanceDisks = new ArrayList<>();
         UnmanagedInstanceTO.Disk instanceDisk = new UnmanagedInstanceTO.Disk();
         instanceDisk.setDiskId("1000-1");
-        instanceDisk.setPosition(0);
         instanceDisk.setLabel("DiskLabel");
         instanceDisk.setController("scsi");
         instanceDisk.setImagePath("[b6ccf44a1fa13e29b3667b4954fa10ee] TestInstance/ROOT-1.vmdk");
@@ -300,48 +298,47 @@ public class UnmanagedVMsManagerImplTest {
 
         ClusterVO clusterVO = new ClusterVO(1L, 1L, "Cluster");
         clusterVO.setHypervisorType(Hypervisor.HypervisorType.VMware.toString());
-        when(clusterDao.findById(Mockito.anyLong())).thenReturn(clusterVO);
+        when(clusterDao.findById(anyLong())).thenReturn(clusterVO);
         when(configurationDao.getValue(Mockito.anyString())).thenReturn(null);
-        doNothing().when(resourceLimitService).checkResourceLimit(Mockito.any(Account.class), Mockito.any(Resource.ResourceType.class), Mockito.anyLong());
+        doNothing().when(resourceLimitService).checkResourceLimit(any(Account.class), any(Resource.ResourceType.class), anyLong());
         List<HostVO> hosts = new ArrayList<>();
         HostVO hostVO = Mockito.mock(HostVO.class);
         when(hostVO.isInMaintenanceStates()).thenReturn(false);
         hosts.add(hostVO);
-        when(hostVO.checkHostServiceOfferingTags(Mockito.any())).thenReturn(true);
-        when(resourceManager.listHostsInClusterByStatus(Mockito.anyLong(), Mockito.any(Status.class))).thenReturn(hosts);
-        when(resourceManager.listAllUpAndEnabledHostsInOneZoneByHypervisor(any(Hypervisor.HypervisorType.class), Mockito.anyLong())).thenReturn(hosts);
+        when(resourceManager.listHostsInClusterByStatus(anyLong(), any(Status.class))).thenReturn(hosts);
+        when(resourceManager.listAllUpAndEnabledHostsInOneZoneByHypervisor(any(Hypervisor.HypervisorType.class), anyLong())).thenReturn(hosts);
         List<VMTemplateStoragePoolVO> templates = new ArrayList<>();
         when(templatePoolDao.listAll()).thenReturn(templates);
         List<VolumeVO> volumes = new ArrayList<>();
-        when(volumeDao.findIncludingRemovedByZone(Mockito.anyLong())).thenReturn(volumes);
+        when(volumeDao.findIncludingRemovedByZone(anyLong())).thenReturn(volumes);
         GetUnmanagedInstancesCommand cmd = Mockito.mock(GetUnmanagedInstancesCommand.class);
         HashMap<String, UnmanagedInstanceTO> map = new HashMap<>();
         map.put(instance.getName(), instance);
         Answer answer = new GetUnmanagedInstancesAnswer(cmd, "", map);
-        when(agentManager.easySend(Mockito.anyLong(), Mockito.any(GetUnmanagedInstancesCommand.class))).thenReturn(answer);
+        when(agentManager.easySend(anyLong(), any(GetUnmanagedInstancesCommand.class))).thenReturn(answer);
         GetRemoteVmsCommand remoteVmListcmd = Mockito.mock(GetRemoteVmsCommand.class);
         Answer remoteVmListAnswer = new GetRemoteVmsAnswer(remoteVmListcmd, "", map);
-        when(agentManager.easySend(Mockito.anyLong(), any(GetRemoteVmsCommand.class))).thenReturn(remoteVmListAnswer);
+        when(agentManager.easySend(anyLong(), any(GetRemoteVmsCommand.class))).thenReturn(remoteVmListAnswer);
         DataCenterVO zone = Mockito.mock(DataCenterVO.class);
         when(zone.getId()).thenReturn(1L);
-        when(dataCenterDao.findById(Mockito.anyLong())).thenReturn(zone);
-        when(accountService.getActiveAccountById(Mockito.anyLong())).thenReturn(Mockito.mock(Account.class));
+        when(dataCenterDao.findById(anyLong())).thenReturn(zone);
+        when(accountService.getActiveAccountById(anyLong())).thenReturn(Mockito.mock(Account.class));
         List<UserVO> users = new ArrayList<>();
         users.add(Mockito.mock(UserVO.class));
-        when(userDao.listByAccount(Mockito.anyLong())).thenReturn(users);
+        when(userDao.listByAccount(anyLong())).thenReturn(users);
         VMTemplateVO template = Mockito.mock(VMTemplateVO.class);
         when(template.getName()).thenReturn("Template");
-        when(templateDao.findById(Mockito.anyLong())).thenReturn(template);
+        when(templateDao.findById(anyLong())).thenReturn(template);
         ServiceOfferingVO serviceOffering = Mockito.mock(ServiceOfferingVO.class);
         when(serviceOffering.getId()).thenReturn(1L);
         when(serviceOffering.isDynamic()).thenReturn(false);
         when(serviceOffering.getCpu()).thenReturn(instance.getCpuCores());
         when(serviceOffering.getRamSize()).thenReturn(instance.getMemory());
         when(serviceOffering.getSpeed()).thenReturn(instance.getCpuSpeed());
-        when(serviceOfferingDao.findById(Mockito.anyLong())).thenReturn(serviceOffering);
+        when(serviceOfferingDao.findById(anyLong())).thenReturn(serviceOffering);
         when(serviceOfferingDao.findById(anyLong(), anyLong())).thenReturn(Mockito.mock(ServiceOfferingVO.class));
         DiskOfferingVO diskOfferingVO = Mockito.mock(DiskOfferingVO.class);
-        when(diskOfferingDao.findById(Mockito.anyLong())).thenReturn(diskOfferingVO);
+        when(diskOfferingDao.findById(anyLong())).thenReturn(diskOfferingVO);
         UserVmVO userVm = Mockito.mock(UserVmVO.class);
         when(userVm.getAccountId()).thenReturn(1L);
         when(userVm.getDataCenterId()).thenReturn(1L);
@@ -367,21 +364,21 @@ public class UnmanagedVMsManagerImplTest {
         when(networkVO.getGuestType()).thenReturn(Network.GuestType.L2);
         when(networkVO.getBroadcastUri()).thenReturn(URI.create(String.format("vlan://%d", instanceNic.getVlan())));
         when(networkVO.getDataCenterId()).thenReturn(1L);
-        when(networkDao.findById(Mockito.anyLong())).thenReturn(networkVO);
+        when(networkDao.findById(anyLong())).thenReturn(networkVO);
         List<NetworkVO> networks = new ArrayList<>();
         networks.add(networkVO);
-        when(networkDao.listByZone(Mockito.anyLong())).thenReturn(networks);
-        doNothing().when(networkModel).checkNetworkPermissions(Mockito.any(Account.class), Mockito.any(Network.class));
+        when(networkDao.listByZone(anyLong())).thenReturn(networks);
+        doNothing().when(networkModel).checkNetworkPermissions(any(Account.class), any(Network.class));
         NicProfile profile = Mockito.mock(NicProfile.class);
         Integer deviceId = 100;
-        Pair<NicProfile, Integer> pair = new Pair<>(profile, deviceId);
-        when(networkOrchestrationService.importNic(nullable(String.class), nullable(Integer.class), nullable(Network.class), nullable(Boolean.class), nullable(VirtualMachine.class), nullable(Network.IpAddresses.class), nullable(DataCenter.class), Mockito.anyBoolean())).thenReturn(pair);
-        when(volumeDao.findByInstance(Mockito.anyLong())).thenReturn(volumes);
+        Pair<NicProfile, Integer> pair = new Pair<NicProfile, Integer>(profile, deviceId);
+        when(networkOrchestrationService.importNic(nullable(String.class), nullable(Integer.class), nullable(Network.class), nullable(Boolean.class), nullable(VirtualMachine.class), nullable(Network.IpAddresses.class), nullable(DataCenter.class), anyBoolean())).thenReturn(pair);
+        when(volumeDao.findByInstance(anyLong())).thenReturn(volumes);
         List<UserVmResponse> userVmResponses = new ArrayList<>();
         UserVmResponse userVmResponse = new UserVmResponse();
         userVmResponse.setInstanceName(instance.getName());
         userVmResponses.add(userVmResponse);
-        when(responseGenerator.createUserVmResponse(Mockito.any(ResponseObject.ResponseView.class), Mockito.anyString(), Mockito.any(UserVm.class))).thenReturn(userVmResponses);
+        when(responseGenerator.createUserVmResponse(any(ResponseObject.ResponseView.class), Mockito.anyString(), any(UserVm.class))).thenReturn(userVmResponses);
 
         when(vmDao.findById(virtualMachineId)).thenReturn(virtualMachine);
         when(virtualMachine.getState()).thenReturn(VirtualMachine.State.Running);
@@ -405,7 +402,7 @@ public class UnmanagedVMsManagerImplTest {
         ListUnmanagedInstancesCmd cmd = Mockito.mock(ListUnmanagedInstancesCmd.class);
         ClusterVO cluster = new ClusterVO(1, 1, "Cluster");
         cluster.setHypervisorType(Hypervisor.HypervisorType.XenServer.toString());
-        when(clusterDao.findById(Mockito.anyLong())).thenReturn(cluster);
+        when(clusterDao.findById(anyLong())).thenReturn(cluster);
         unmanagedVMsManager.listUnmanagedInstances(cmd);
     }
 
@@ -424,7 +421,6 @@ public class UnmanagedVMsManagerImplTest {
         ImportUnmanagedInstanceCmd importUnmanageInstanceCmd = Mockito.mock(ImportUnmanagedInstanceCmd.class);
         when(importUnmanageInstanceCmd.getName()).thenReturn("TestInstance");
         when(importUnmanageInstanceCmd.getDomainId()).thenReturn(null);
-        when(volumeApiService.doesStoragePoolSupportDiskOfferingTags(any(StoragePool.class), any())).thenReturn(true);
         try (MockedStatic<UsageEventUtils> ignored = Mockito.mockStatic(UsageEventUtils.class)) {
             unmanagedVMsManager.importUnmanagedInstance(importUnmanageInstanceCmd);
         }
@@ -563,7 +559,7 @@ public class UnmanagedVMsManagerImplTest {
     public void testBasicAccessChecksUnsupportedHypervisorType() {
         ClusterVO clusterVO = new ClusterVO(1L, 1L, "Cluster");
         clusterVO.setHypervisorType(Hypervisor.HypervisorType.XenServer.toString());
-        when(clusterDao.findById(Mockito.anyLong())).thenReturn(clusterVO);
+        when(clusterDao.findById(anyLong())).thenReturn(clusterVO);
         unmanagedVMsManager.basicAccessChecks(1L);
     }
 
@@ -601,7 +597,6 @@ public class UnmanagedVMsManagerImplTest {
 
         ClusterVO cluster = mock(ClusterVO.class);
         when(cluster.getId()).thenReturn(clusterId);
-        when(cluster.getAllocationState()).thenReturn(Grouping.AllocationState.Enabled);
         when(cluster.getHypervisorType()).thenReturn(Hypervisor.HypervisorType.KVM);
         when(cluster.getDataCenterId()).thenReturn(zoneId);
         when(clusterDao.findById(clusterId)).thenReturn(cluster);
@@ -615,7 +610,6 @@ public class UnmanagedVMsManagerImplTest {
         when(importVmCmd.getHostIp()).thenReturn(host);
         when(importVmCmd.getNicNetworkList()).thenReturn(Map.of("NIC 1", networkId));
         when(importVmCmd.getConvertInstanceHostId()).thenReturn(null);
-        when(importVmCmd.getImportInstanceHostId()).thenReturn(null);
         when(importVmCmd.getConvertStoragePoolId()).thenReturn(null);
 
         NetworkVO networkVO = Mockito.mock(NetworkVO.class);
@@ -637,14 +631,10 @@ public class UnmanagedVMsManagerImplTest {
         when(convertHost.getId()).thenReturn(convertHostId);
         when(convertHost.getName()).thenReturn("KVM-Convert-Host");
         when(convertHost.getType()).thenReturn(Host.Type.Routing);
-        when(convertHost.getDataCenterId()).thenReturn(zoneId);
         when(convertHost.getClusterId()).thenReturn(clusterId);
         if (selectConvertHost) {
             when(importVmCmd.getConvertInstanceHostId()).thenReturn(convertHostId);
-            when(importVmCmd.getImportInstanceHostId()).thenReturn(convertHostId);
             when(hostDao.findById(convertHostId)).thenReturn(convertHost);
-        } else {
-            when(hostDao.listByClusterAndHypervisorType(clusterId, Hypervisor.HypervisorType.KVM)).thenReturn(List.of(convertHost));
         }
 
         DataStoreTO dataStoreTO = mock(DataStoreTO.class);
@@ -704,16 +694,11 @@ public class UnmanagedVMsManagerImplTest {
             when(agentManager.send(Mockito.eq(convertHostId), Mockito.any(CheckConvertInstanceCommand.class))).thenReturn(checkConvertInstanceAnswer);
         }
 
-        when(volumeApiService.doesStoragePoolSupportDiskOfferingTags(any(StoragePool.class), any())).thenReturn(true);
-
         ConvertInstanceAnswer convertInstanceAnswer = mock(ConvertInstanceAnswer.class);
-        ImportConvertedInstanceAnswer convertImportedInstanceAnswer = mock(ImportConvertedInstanceAnswer.class);
         when(convertInstanceAnswer.getResult()).thenReturn(vcenterParameter != VcenterParameter.CONVERT_FAILURE);
-        when(convertImportedInstanceAnswer.getConvertedInstance()).thenReturn(instance);
-        when(convertImportedInstanceAnswer.getResult()).thenReturn(vcenterParameter != VcenterParameter.CONVERT_FAILURE);
+        when(convertInstanceAnswer.getConvertedInstance()).thenReturn(instance);
         if (VcenterParameter.AGENT_UNAVAILABLE != vcenterParameter) {
             when(agentManager.send(Mockito.eq(convertHostId), Mockito.any(ConvertInstanceCommand.class))).thenReturn(convertInstanceAnswer);
-            when(agentManager.send(Mockito.eq(convertHostId), Mockito.any(ImportConvertedInstanceCommand.class))).thenReturn(convertImportedInstanceAnswer);
         }
 
         try (MockedStatic<UsageEventUtils> ignored = Mockito.mockStatic(UsageEventUtils.class)) {
@@ -769,7 +754,7 @@ public class UnmanagedVMsManagerImplTest {
         storagePools.add(storagePool);
         when(primaryDataStoreDao.findLocalStoragePoolsByHostAndTags(anyLong(), any())).thenReturn(storagePools);
         when(primaryDataStoreDao.findById(anyLong())).thenReturn(storagePool);
-        when(volumeApiService.doesStoragePoolSupportDiskOfferingTags(any(StoragePool.class), any())).thenReturn(true);
+        when(volumeApiService.doesTargetStorageSupportDiskOffering(any(StoragePool.class), any())).thenReturn(true);
         StoragePoolHostVO storagePoolHost = Mockito.mock(StoragePoolHostVO.class);
         when(storagePoolHostDao.findByPoolHost(anyLong(), anyLong())).thenReturn(storagePoolHost);
         try (MockedStatic<UsageEventUtils> ignored = Mockito.mockStatic(UsageEventUtils.class)) {
@@ -777,7 +762,6 @@ public class UnmanagedVMsManagerImplTest {
         }
     }
 
-    @Test
     public void testImportVmFromVmwareToKvmExistingVcenter() throws OperationTimedoutException, AgentUnavailableException {
         baseTestImportVmFromVmwareToKvm(VcenterParameter.EXISTING, false, false);
     }
@@ -830,7 +814,7 @@ public class UnmanagedVMsManagerImplTest {
 
         long poolId = 1L;
         when(primaryDataStoreDao.findById(poolId)).thenReturn(null);
-        unmanagedVMsManager.selectInstanceConversionTemporaryLocation(cluster, null, poolId);
+        unmanagedVMsManager.selectInstanceConversionTemporaryLocation(cluster, poolId);
     }
 
     @Test(expected = CloudRuntimeException.class)
@@ -838,35 +822,20 @@ public class UnmanagedVMsManagerImplTest {
         ClusterVO cluster = getClusterForTests();
         long poolId = 1L;
         StoragePoolVO pool = mock(StoragePoolVO.class);
-        when(pool.getScope()).thenReturn(ScopeType.CLUSTER);
-        when(pool.getClusterId()).thenReturn(100L);
+        Mockito.when(pool.getScope()).thenReturn(ScopeType.CLUSTER);
+        Mockito.when(pool.getClusterId()).thenReturn(100L);
         when(primaryDataStoreDao.findById(poolId)).thenReturn(pool);
-        unmanagedVMsManager.selectInstanceConversionTemporaryLocation(cluster, null, poolId);
+        unmanagedVMsManager.selectInstanceConversionTemporaryLocation(cluster, poolId);
     }
 
-
-    @Test(expected = CloudRuntimeException.class)
-    public void testSelectInstanceConversionTemporaryLocationPoolConvertHostDifferentCluster() {
-        ClusterVO cluster = getClusterForTests();
-        long poolId = 1L;
-        StoragePoolVO pool = mock(StoragePoolVO.class);
-        when(pool.getScope()).thenReturn(ScopeType.CLUSTER);
-        when(pool.getClusterId()).thenReturn(1L);
-        HostVO host = mock(HostVO.class);
-        when(primaryDataStoreDao.findById(poolId)).thenReturn(pool);
-        when(host.getClusterId()).thenReturn(2L);
-        unmanagedVMsManager.selectInstanceConversionTemporaryLocation(cluster, host, poolId);
-    }
-
-
     @Test(expected = CloudRuntimeException.class)
     public void testSelectInstanceConversionTemporaryLocationLocalStoragePoolInvalid() {
         ClusterVO cluster = getClusterForTests();
         long poolId = 1L;
         StoragePoolVO pool = mock(StoragePoolVO.class);
-        when(pool.getScope()).thenReturn(ScopeType.HOST);
+        Mockito.when(pool.getScope()).thenReturn(ScopeType.HOST);
         when(primaryDataStoreDao.findById(poolId)).thenReturn(pool);
-        unmanagedVMsManager.selectInstanceConversionTemporaryLocation(cluster, null, poolId);
+        unmanagedVMsManager.selectInstanceConversionTemporaryLocation(cluster, poolId);
     }
 
     @Test(expected = CloudRuntimeException.class)
@@ -874,249 +843,53 @@ public class UnmanagedVMsManagerImplTest {
         ClusterVO cluster = getClusterForTests();
         long poolId = 1L;
         StoragePoolVO pool = mock(StoragePoolVO.class);
-        when(pool.getScope()).thenReturn(ScopeType.CLUSTER);
-        when(pool.getClusterId()).thenReturn(1L);
+        Mockito.when(pool.getScope()).thenReturn(ScopeType.CLUSTER);
+        Mockito.when(pool.getClusterId()).thenReturn(1L);
         when(primaryDataStoreDao.findById(poolId)).thenReturn(pool);
-        when(pool.getPoolType()).thenReturn(Storage.StoragePoolType.RBD);
-        unmanagedVMsManager.selectInstanceConversionTemporaryLocation(cluster, null, poolId);
+        Mockito.when(pool.getPoolType()).thenReturn(Storage.StoragePoolType.RBD);
+        unmanagedVMsManager.selectInstanceConversionTemporaryLocation(cluster, poolId);
     }
 
     @Test(expected = CloudRuntimeException.class)
     public void testSelectInstanceConversionTemporaryLocationNoPoolAvailable() {
         ClusterVO cluster = getClusterForTests();
-        when(imageStoreDao.findOneByZoneAndProtocol(anyLong(), anyString())).thenReturn(null);
-        unmanagedVMsManager.selectInstanceConversionTemporaryLocation(cluster, null, null);
+        Mockito.when(imageStoreDao.findOneByZoneAndProtocol(anyLong(), anyString())).thenReturn(null);
+        unmanagedVMsManager.selectInstanceConversionTemporaryLocation(cluster, null);
     }
 
     @Test
-    public void testSelectKVMHostForImportingInClusterWithImportInstanceIdSuccess() {
-        Long hostId = 1L;
-        ClusterVO cluster = getClusterForTests();
-        HostVO host = Mockito.mock(HostVO.class);
-        when(host.getResourceState()).thenReturn(ResourceState.Enabled);
-        when(host.getStatus()).thenReturn(Status.Up);
-        when(host.getType()).thenReturn(Host.Type.Routing);
-        when(host.getClusterId()).thenReturn(1L);
-
-        when(hostDao.findById(hostId)).thenReturn(host);
-
-        HostVO returnedHost = unmanagedVMsManager.selectKVMHostForImportingInCluster(cluster, hostId);
-        Assert.assertEquals(host, returnedHost);
-    }
-
-    @Test
-    public void testSelectKVMHostForImportingInClusterWithNullImportInstanceIdSuccess() {
-        ClusterVO cluster = getClusterForTests();
-        HostVO host = Mockito.mock(HostVO.class);
-        when(hostDao.listByClusterAndHypervisorType(cluster.getId(), cluster.getHypervisorType())).thenReturn(List.of(host));
-
-        HostVO returnedHost = unmanagedVMsManager.selectKVMHostForImportingInCluster(cluster, null);
-        Assert.assertEquals(host, returnedHost);
-    }
-
-    @Test(expected = CloudRuntimeException.class)
-    public void testSelectKVMHostForImportingInClusterFailure() {
-        ClusterVO cluster = getClusterForTests();
-        when(hostDao.listByClusterAndHypervisorType(cluster.getId(), cluster.getHypervisorType())).thenReturn(List.of());
-
-        unmanagedVMsManager.selectKVMHostForImportingInCluster(cluster, null);
-    }
-
-    @Test(expected = CloudRuntimeException.class)
-    public void testSelectKVMHostForImportingInClusterWithImportInstanceIdInvalidCluster() {
-        Long hostId = 1L;
-        ClusterVO cluster = getClusterForTests();
-        HostVO host = Mockito.mock(HostVO.class);
-        when(host.getResourceState()).thenReturn(ResourceState.Enabled);
-        when(host.getStatus()).thenReturn(Status.Up);
-        when(host.getType()).thenReturn(Host.Type.Routing);
-        when(host.getClusterId()).thenReturn(2L);
-
-        when(hostDao.findById(hostId)).thenReturn(host);
-
-        unmanagedVMsManager.selectKVMHostForImportingInCluster(cluster, hostId);
-    }
-
-    @Test(expected = CloudRuntimeException.class)
-    public void testSelectKVMHostForImportingInClusterWithImportInstanceIdInvalidType() {
-        Long hostId = 1L;
-        ClusterVO cluster = getClusterForTests();
-        HostVO host = Mockito.mock(HostVO.class);
-        when(host.getResourceState()).thenReturn(ResourceState.Enabled);
-        when(host.getStatus()).thenReturn(Status.Up);
-        when(host.getType()).thenReturn(Host.Type.Storage);
-
-        when(hostDao.findById(hostId)).thenReturn(host);
-
-        unmanagedVMsManager.selectKVMHostForImportingInCluster(cluster, hostId);
-    }
-
-    @Test(expected = CloudRuntimeException.class)
-    public void testSelectKVMHostForImportingInClusterWithImportInstanceIdInvalidStatus() {
-        Long hostId = 1L;
-        ClusterVO cluster = getClusterForTests();
-        HostVO host = Mockito.mock(HostVO.class);
-        when(host.getResourceState()).thenReturn(ResourceState.Enabled);
-        when(host.getStatus()).thenReturn(Status.Alert);
-
-        when(hostDao.findById(hostId)).thenReturn(host);
-
-        unmanagedVMsManager.selectKVMHostForImportingInCluster(cluster, hostId);
-    }
-
-    @Test(expected = CloudRuntimeException.class)
-    public void testSelectKVMHostForImportingInClusterWithImportInstanceIdInvalidResourceState() {
-        Long hostId = 1L;
-        ClusterVO cluster = getClusterForTests();
-        HostVO host = Mockito.mock(HostVO.class);
-        when(host.getResourceState()).thenReturn(ResourceState.Disabled);
-
-        when(hostDao.findById(hostId)).thenReturn(host);
-
-        unmanagedVMsManager.selectKVMHostForImportingInCluster(cluster, hostId);
-    }
-
-    @Test(expected = CloudRuntimeException.class)
-    public void testSelectKVMHostForImportingInClusterWithImportInstanceIdInvalidHostId() {
-        Long hostId = 1L;
-        ClusterVO cluster = getClusterForTests();
-
-        when(hostDao.findById(hostId)).thenReturn(null);
-
-        unmanagedVMsManager.selectKVMHostForImportingInCluster(cluster, hostId);
-    }
-
-    @Test
-    public void testSelectKVMHostForConversionInClusterWithImportInstanceIdEnabledHost() {
-        Long hostId = 1L;
-        ClusterVO cluster = getClusterForTests();
-        HostVO host = Mockito.mock(HostVO.class);
-        when(host.getResourceState()).thenReturn(ResourceState.Enabled);
-        when(host.getStatus()).thenReturn(Status.Up);
-        when(host.getType()).thenReturn(Host.Type.Routing);
-        when(host.getDataCenterId()).thenReturn(1L);
-
-        when(hostDao.findById(hostId)).thenReturn(host);
-
-        HostVO returnedHost = unmanagedVMsManager.selectKVMHostForConversionInCluster(cluster, hostId);
-        Assert.assertEquals(host, returnedHost);
-    }
-
-    @Test
-    public void testSelectKVMHostForConversionInClusterWithImportInstanceIdDisabledHost() {
-        Long hostId = 1L;
-        ClusterVO cluster = getClusterForTests();
-        HostVO host = Mockito.mock(HostVO.class);
-        when(host.getResourceState()).thenReturn(ResourceState.Disabled);
-        when(host.getStatus()).thenReturn(Status.Up);
-        when(host.getType()).thenReturn(Host.Type.Routing);
-        when(host.getDataCenterId()).thenReturn(1L);
-
-        when(hostDao.findById(hostId)).thenReturn(host);
-
-        HostVO returnedHost = unmanagedVMsManager.selectKVMHostForConversionInCluster(cluster, hostId);
-        Assert.assertEquals(host, returnedHost);
-    }
-
-    @Test
-    public void testSelectKVMHostForConversionInClusterWithImportInstanceIdSuccessCompatible() {
-        ClusterVO cluster = getClusterForTests();
-        HostVO host = Mockito.mock(HostVO.class);
-
-        when(hostDao.listByClusterHypervisorTypeAndHostCapability(cluster.getId(),
-                cluster.getHypervisorType(), Host.HOST_INSTANCE_CONVERSION)).thenReturn(List.of(host));
-
-        HostVO returnedHost = unmanagedVMsManager.selectKVMHostForConversionInCluster(cluster, null);
-        Assert.assertEquals(host, returnedHost);
-    }
-
-    @Test
-    public void testSelectKVMHostForConversionInClusterWithImportInstanceIdSuccessNonCompatible() {
-        ClusterVO cluster = getClusterForTests();
-        HostVO host = Mockito.mock(HostVO.class);
-
-        when(hostDao.listByClusterHypervisorTypeAndHostCapability(cluster.getId(),
-                cluster.getHypervisorType(), Host.HOST_INSTANCE_CONVERSION)).thenReturn(List.of());
-
-        when(hostDao.listByClusterAndHypervisorType(cluster.getId(), cluster.getHypervisorType())).thenReturn(List.of(host));
-
-        HostVO returnedHost = unmanagedVMsManager.selectKVMHostForConversionInCluster(cluster, null);
-        Assert.assertEquals(host, returnedHost);
-    }
-
-    @Test(expected = CloudRuntimeException.class)
-    public void testSelectKVMHostForConversionInClusterWithImportInstanceIdFailure() {
-        ClusterVO cluster = getClusterForTests();
-
-        when(hostDao.listByClusterHypervisorTypeAndHostCapability(cluster.getId(),
-                cluster.getHypervisorType(), Host.HOST_INSTANCE_CONVERSION)).thenReturn(List.of());
-
-        when(hostDao.listByClusterAndHypervisorType(cluster.getId(), cluster.getHypervisorType())).thenReturn(List.of());
-
-        unmanagedVMsManager.selectKVMHostForConversionInCluster(cluster, null);
-    }
-
-    @Test(expected = CloudRuntimeException.class)
-    public void testSelectKVMHostForConversionInClusterWithImportInstanceIdInvalidZone() {
-        Long hostId = 1L;
-        ClusterVO cluster = getClusterForTests();
-        HostVO host = Mockito.mock(HostVO.class);
-        when(host.getResourceState()).thenReturn(ResourceState.Enabled);
-        when(host.getStatus()).thenReturn(Status.Up);
-        when(host.getType()).thenReturn(Host.Type.Routing);
-        when(host.getDataCenterId()).thenReturn(2L);
-
-        when(hostDao.findById(hostId)).thenReturn(host);
-
-        unmanagedVMsManager.selectKVMHostForConversionInCluster(cluster, hostId);
-    }
-
-    @Test(expected = CloudRuntimeException.class)
-    public void testSelectKVMHostForConversionInClusterWithImportInstanceIdInvalidType() {
-        Long hostId = 1L;
-        ClusterVO cluster = getClusterForTests();
-        HostVO host = Mockito.mock(HostVO.class);
-        when(host.getResourceState()).thenReturn(ResourceState.Enabled);
-        when(host.getStatus()).thenReturn(Status.Up);
-        when(host.getType()).thenReturn(Host.Type.SecondaryStorage);
-
-        when(hostDao.findById(hostId)).thenReturn(host);
-
-        unmanagedVMsManager.selectKVMHostForConversionInCluster(cluster, hostId);
-    }
-
-    @Test(expected = CloudRuntimeException.class)
-    public void testSelectKVMHostForConversionInClusterWithImportInstanceIdInvalidStatus() {
-        Long hostId = 1L;
-        ClusterVO cluster = getClusterForTests();
-        HostVO host = Mockito.mock(HostVO.class);
-        when(host.getResourceState()).thenReturn(ResourceState.Enabled);
-        when(host.getStatus()).thenReturn(Status.Down);
-
-        when(hostDao.findById(hostId)).thenReturn(host);
-
-        unmanagedVMsManager.selectKVMHostForConversionInCluster(cluster, hostId);
-    }
-
-    @Test(expected = CloudRuntimeException.class)
-    public void testSelectKVMHostForConversionInClusterWithImportInstanceIdInvalidResourceState() {
-        Long hostId = 1L;
-        ClusterVO cluster = getClusterForTests();
-        HostVO host = Mockito.mock(HostVO.class);
-        when(host.getResourceState()).thenReturn(ResourceState.Maintenance);
-
-        when(hostDao.findById(hostId)).thenReturn(host);
-
-        unmanagedVMsManager.selectKVMHostForConversionInCluster(cluster, hostId);
-    }
-
-    @Test(expected = CloudRuntimeException.class)
-    public void testSelectKVMHostForConversionInClusterWithImportInstanceIdInvalidHostId() {
-        Long hostId = 1L;
-        ClusterVO cluster = getClusterForTests();
-
-        when(hostDao.findById(hostId)).thenReturn(null);
-
-        unmanagedVMsManager.selectKVMHostForConversionInCluster(cluster, hostId);
+    public void testCheckUnmanagedDiskLimits() {
+        Account owner = Mockito.mock(Account.class);
+        UnmanagedInstanceTO.Disk disk = Mockito.mock(UnmanagedInstanceTO.Disk.class);
+        Mockito.when(disk.getDiskId()).thenReturn("disk1");
+        Mockito.when(disk.getCapacity()).thenReturn(100L);
+        ServiceOffering serviceOffering = Mockito.mock(ServiceOffering.class);
+        Mockito.when(serviceOffering.getDiskOfferingId()).thenReturn(1L);
+        UnmanagedInstanceTO.Disk dataDisk = Mockito.mock(UnmanagedInstanceTO.Disk.class);
+        Mockito.when(dataDisk.getDiskId()).thenReturn("disk2");
+        Mockito.when(dataDisk.getCapacity()).thenReturn(1000L);
+        Map<String, Long> dataDiskMap = new HashMap<>();
+        dataDiskMap.put("disk2", 2L);
+        DiskOfferingVO offering1 = Mockito.mock(DiskOfferingVO.class);
+        Mockito.when(diskOfferingDao.findById(1L)).thenReturn(offering1);
+        String tag1 = "tag1";
+        Mockito.when(resourceLimitService.getResourceLimitStorageTags(offering1)).thenReturn(List.of(tag1));
+        DiskOfferingVO offering2 = Mockito.mock(DiskOfferingVO.class);
+        Mockito.when(diskOfferingDao.findById(2L)).thenReturn(offering2);
+        String tag2 = "tag2";
+        Mockito.when(resourceLimitService.getResourceLimitStorageTags(offering2)).thenReturn(List.of(tag2));
+        try {
+            Mockito.doNothing().when(resourceLimitService).checkResourceLimit(any(), any(), any());
+            Mockito.doNothing().when(resourceLimitService).checkResourceLimitWithTag(any(), any(), any(), any());
+            unmanagedVMsManager.checkUnmanagedDiskLimits(owner, disk, serviceOffering, List.of(dataDisk), dataDiskMap);
+            Mockito.verify(resourceLimitService, Mockito.times(1)).checkResourceLimit(owner, Resource.ResourceType.volume, 2);
+            Mockito.verify(resourceLimitService, Mockito.times(1)).checkResourceLimit(owner, Resource.ResourceType.primary_storage, 1100L);
+            Mockito.verify(resourceLimitService, Mockito.times(1)).checkResourceLimitWithTag(owner, Resource.ResourceType.volume, tag1,1);
+            Mockito.verify(resourceLimitService, Mockito.times(1)).checkResourceLimitWithTag(owner, Resource.ResourceType.volume, tag2,1);
+            Mockito.verify(resourceLimitService, Mockito.times(1)).checkResourceLimitWithTag(owner, Resource.ResourceType.primary_storage, tag1,100L);
+            Mockito.verify(resourceLimitService, Mockito.times(1)).checkResourceLimitWithTag(owner, Resource.ResourceType.primary_storage, tag2,1000L);
+        } catch (ResourceAllocationException e) {
+            Assert.fail("Exception encountered: " + e.getMessage());
+        }
     }
 }
