@@ -21,10 +21,12 @@ import logging
 import os
 import re
 import sys
-import urllib
-import urllib2
+import urllib.request
+import urllib.parse
+import urllib.error
 import time
 import copy
+import ipaddress
 
 from collections import OrderedDict
 from fcntl import flock, LOCK_EX, LOCK_UN
@@ -40,10 +42,17 @@ from cs.CsConfig import CsConfig
 from cs.CsProcess import CsProcess
 from cs.CsStaticRoutes import CsStaticRoutes
 from cs.CsVpcGuestNetwork import CsVpcGuestNetwork
+from cs.CsBgpPeers import CsBgpPeers
 
-ICMPV6_TYPE_ANY = "{ destination-unreachable, packet-too-big, time-exceeded, parameter-problem, echo-request, echo-reply, mld-listener-query, mld-listener-report, mld-listener-done, nd-router-solicit, nd-router-advert, nd-neighbor-solicit, nd-neighbor-advert, nd-redirect, router-renumbering }"
+ICMP_TYPE_ANY = "{ echo-reply, destination-unreachable, source-quench, redirect, echo-request, time-exceeded, \
+    parameter-problem, timestamp-request, timestamp-reply, info-request, info-reply, address-mask-request, \
+    address-mask-reply, router-advertisement, router-solicitation }"
+ICMPV6_TYPE_ANY = "{ destination-unreachable, packet-too-big, time-exceeded, parameter-problem, \
+    echo-request, echo-reply, mld-listener-query, mld-listener-report, mld-listener-done, \
+    nd-router-solicit, nd-router-advert, nd-neighbor-solicit, nd-neighbor-advert, nd-redirect, router-renumbering }"
 TCP_UDP_PORT_ANY = "{ 0-65535 }"
 
+
 def removeUndesiredCidrs(cidrs, version):
     version_char = ":"
     if version == 4:
@@ -61,15 +70,17 @@ def removeUndesiredCidrs(cidrs, version):
             return cidrs
     return None
 
+
 def appendStringIfNotEmpty(s1, s2):
     if s2:
-        if type(s2) != str:
+        if not isinstance(s2, str):
             s2 = str(s2)
         if s1:
             return s1 + " " + s2
         return s2
     return s1
 
+
 class CsPassword(CsDataBag):
 
     TOKEN_FILE = "/tmp/passwdsrvrtoken"
@@ -107,10 +118,10 @@ class CsPassword(CsDataBag):
             if proc.find():
                 url = "http://%s:8080/" % server_ip
                 payload = {"ip": vm_ip, "password": password, "token": token}
-                data = urllib.urlencode(payload)
-                request = urllib2.Request(url, data=data, headers={"DomU_Request": "save_password"})
+                data = urllib.parse.urlencode(payload).encode()
+                request = urllib.request.Request(url, data=data, headers={"DomU_Request": "save_password"})
                 try:
-                    resp = urllib2.urlopen(request, data)
+                    resp = urllib.request.urlopen(request, data)
                     logging.debug("Update password server result: http:%s, content:%s" % (resp.code, resp.read()))
                 except Exception as e:
                     logging.error("Failed to update password server due to: %s" % e)
@@ -165,15 +176,15 @@ class CsAcl(CsDataBag):
             icmp_type = ''
             rule = self.rule
             icmp_type = "any"
-            if "icmp_type" in self.rule.keys() and self.rule['icmp_type'] != -1:
+            if "icmp_type" in list(self.rule.keys()) and self.rule['icmp_type'] != -1:
                 icmp_type = self.rule['icmp_type']
-            if "icmp_code" in self.rule.keys() and rule['icmp_code'] != -1:
+            if "icmp_code" in list(self.rule.keys()) and rule['icmp_code'] != -1:
                 icmp_type = "%s/%s" % (self.rule['icmp_type'], self.rule['icmp_code'])
             rnge = ''
-            if "first_port" in self.rule.keys() and \
+            if "first_port" in list(self.rule.keys()) and \
                self.rule['first_port'] == self.rule['last_port']:
                 rnge = " --dport %s " % self.rule['first_port']
-            if "first_port" in self.rule.keys() and \
+            if "first_port" in list(self.rule.keys()) and \
                self.rule['first_port'] != self.rule['last_port']:
                 rnge = " --dport %s:%s" % (rule['first_port'], rule['last_port'])
 
@@ -266,6 +277,120 @@ class CsAcl(CsDataBag):
                 self.fw.append(["filter", "", "%s -j %s" % (fwr, rule['action'])])
                 logging.debug("EGRESS rule configured for protocol ==> %s, action ==> %s", rule['protocol'], rule['action'])
 
+    def add_routing_rules(self):
+        fw = self.config.get_nft_ipv4_fw()
+        logging.info("Processing routing firewall rules %s: %s" % (self.dbag, fw))
+        chains_added = False
+        egress_policy = None
+        for item in self.dbag:
+            if item == "id":
+                continue
+            rule = self.dbag[item]
+
+            network = ipaddress.ip_network(self.config.cmdline().get_eth0_ip() + "/" + self.config.cmdline().get_cidr_size(), False)
+            guest_cidr = network.with_prefixlen
+            if chains_added is False:
+                parent_chain = "FORWARD"
+                chain = "fw_chain_egress"
+                parent_chain_rule = "ip saddr %s jump %s" % (guest_cidr, chain)
+                fw.append({'type': "chain", 'chain': chain})
+                fw.append({'type': "", 'chain': parent_chain, 'rule': parent_chain_rule})
+                chain = "fw_chain_ingress"
+                parent_chain_rule = "ip daddr %s jump %s" % (guest_cidr, chain)
+                fw.append({'type': "chain", 'chain': chain})
+                fw.append({'type': "", 'chain': parent_chain, 'rule': parent_chain_rule})
+                if rule['default_egress_policy']:
+                    egress_policy = "accept"
+                else:
+                    egress_policy = "drop"
+                chains_added = True
+
+            rstr = ""
+
+            chain = "fw_chain_ingress"
+            if 'traffic_type' in rule and rule['traffic_type'].lower() == "egress":
+                chain = "fw_chain_egress"
+
+            saddr = ""
+            if 'source_cidr_list' in rule and len(rule['source_cidr_list']) > 0:
+                source_cidrs = rule['source_cidr_list']
+                if len(source_cidrs) == 1:
+                    source_cidrs = source_cidrs[0]
+                else:
+                    source_cidrs = "{" + (",".join(source_cidrs)) + "}"
+                saddr = "ip saddr " + source_cidrs
+            daddr = ""
+            if 'dest_cidr_list' in rule and len(rule['dest_cidr_list']) > 0:
+                dest_cidrs = rule['dest_cidr_list']
+                if len(dest_cidrs) == 1:
+                    dest_cidrs = dest_cidrs[0]
+                else:
+                    dest_cidrs = "{" + (",".join(dest_cidrs)) + "}"
+                daddr = "ip daddr " + dest_cidrs
+
+            proto = ""
+            protocol = rule['protocol']
+            if protocol != "all":
+                icmp_type = ""
+                proto = protocol
+                if proto == "icmp":
+                    proto = proto_str = "icmp"
+                    icmp_type = ICMP_TYPE_ANY
+                    if 'icmp_type' in rule and rule['icmp_type'] != -1:
+                        icmp_type = str(rule['icmp_type'])
+                    proto = "%s type %s" % (proto_str, icmp_type)
+                    if 'icmp_code' in rule and rule['icmp_code'] != -1:
+                        proto = "%s %s code %d" % (proto, proto_str, rule['icmp_code'])
+                first_port = ""
+                last_port = ""
+                if 'src_port_range' in rule:
+                    first_port = rule['src_port_range'][0]
+                    last_port = rule['src_port_range'][1]
+                port = ""
+                if first_port:
+                    port = first_port
+                if last_port and port and \
+                        last_port != first_port:
+                    port = "{%s-%s}" % (port, last_port)
+                if (protocol == "tcp" or protocol == "udp") and not port:
+                    port = TCP_UDP_PORT_ANY
+                if port:
+                    proto = "%s dport %s" % (proto, port)
+
+            action = "accept"
+            if chain == "fw_chain_egress":
+                # In case we have a default rule (accept all or drop all), we have to evaluate the action again.
+                if protocol == 'all' and not rule['source_cidr_list']:
+                    # For default egress ALLOW or DENY, the logic is inverted.
+                    # Having default_egress_policy == True, means that the default rule should have ACCEPT,
+                    # otherwise DROP. The rule should be appended, not inserted.
+                    if rule['default_egress_policy']:
+                        action = "accept"
+                    else:
+                        action = "drop"
+                else:
+                    # For other rules added, if default_egress_policy == True, following rules should be DROP,
+                    # otherwise ACCEPT
+                    if rule['default_egress_policy']:
+                        action = "drop"
+                    else:
+                        action = "accept"
+
+            rstr = saddr
+            type = ""
+            rstr = appendStringIfNotEmpty(rstr, daddr)
+            rstr = appendStringIfNotEmpty(rstr, proto)
+            if rstr and action:
+                rstr = rstr + " " + action
+                logging.debug("Process routing firewall rule %s" % rstr)
+                fw.append({'type': type, 'chain': chain, 'rule': rstr})
+        if chains_added:
+            base_rstr = "counter packets 0 bytes 0"
+            rstr = "%s drop" % base_rstr
+            fw.append({'type': "", 'chain': "fw_chain_ingress", 'rule': rstr})
+            rstr = "%s %s" % (base_rstr, egress_policy)
+            fw.append({'type': "", 'chain': "fw_chain_egress", 'rule': rstr})
+
     class AclDevice():
         """ A little class for each list of acls per device """
 
@@ -278,21 +403,100 @@ class CsAcl(CsDataBag):
             self.device = obj['device']
             self.ip = obj['nic_ip']
             self.ip6_cidr = None
-            if "nic_ip6_cidr" in obj.keys():
+            if "nic_ip6_cidr" in list(obj.keys()):
                 self.ip6_cidr = obj['nic_ip6_cidr']
             self.netmask = obj['nic_netmask']
             self.config = config
             self.cidr = "%s/%s" % (self.ip, self.netmask)
-            if "ingress_rules" in obj.keys():
+            if "ingress_rules" in list(obj.keys()):
                 self.ingress = obj['ingress_rules']
-            if "egress_rules" in obj.keys():
+            if "egress_rules" in list(obj.keys()):
                 self.egress = obj['egress_rules']
             self.fw = config.get_fw()
             self.ipv6_acl = config.get_ipv6_acl()
+            self.nft_ipv4_acl = config.get_nft_ipv4_acl()
 
         def create(self):
-            self.process("ingress", self.ingress, self.FIXED_RULES_INGRESS)
-            self.process("egress", self.egress, self.FIXED_RULES_EGRESS)
+            self.process("ingress", self.ingress, self.FIXED_RULES_INGRESS, self.config.is_routed())
+            self.process("egress", self.egress, self.FIXED_RULES_EGRESS, self.config.is_routed())
+
+        def __process_routing_ip4(self, direction, rule_list):
+            if not self.cidr:
+                return
+            tier_cidr = self.cidr
+            chain = "%s_%s_policy" % (self.device, direction)
+            parent_chain = "FORWARD"
+            cidr_key = "saddr"
+            if direction == "ingress":
+                cidr_key = "daddr"
+            parent_chain_rule = "ip %s %s jump %s" % (cidr_key, tier_cidr, chain)
+            self.nft_ipv4_acl.append({'type': "", 'chain': parent_chain, 'rule': parent_chain_rule})
+            self.nft_ipv4_acl.insert(0, {'type': "chain", 'chain': chain})
+            for rule in rule_list:
+                cidr = rule['cidr']
+                if cidr is not None and cidr != "":
+                    cidr = removeUndesiredCidrs(cidr, 6)
+                    if cidr is None or cidr == "":
+                        continue
+                addr = ""
+                if cidr:
+                    addr = "ip daddr " + cidr
+                    if direction == "ingress":
+                        addr = "ip saddr " + cidr
+
+                proto = ""
+                protocol = rule['type']
+                if protocol != "all":
+                    icmp_type = ""
+                    if protocol == "protocol":
+                        protocol = "ip nexthdr %d" % rule['protocol']
+                    proto = protocol
+                    if proto == "icmp":
+                        proto = proto_str = "icmp"
+                        icmp_type = ICMP_TYPE_ANY
+                        if 'icmp_type' in rule and rule['icmp_type'] != -1:
+                            icmp_type = str(rule['icmp_type'])
+                        proto = "%s type %s" % (proto_str, icmp_type)
+                        if 'icmp_code' in rule and rule['icmp_code'] != -1:
+                            proto = "%s %s code %d" % (proto, proto_str, rule['icmp_code'])
+
+                    first_port = ""
+                    last_port = ""
+                    if 'first_port' in rule:
+                        first_port = rule['first_port']
+                    if 'last_port' in rule:
+                        last_port = rule['last_port']
+                    port = ""
+                    if first_port:
+                        port = first_port
+                    if last_port and port and \
+                            last_port != first_port:
+                        port = "{%s-%s}" % (port, last_port)
+                    if (protocol == "tcp" or protocol == "udp") and not port:
+                        port = TCP_UDP_PORT_ANY
+                    if port:
+                        proto = "%s dport %s" % (proto, port)
+
+                action = "drop"
+                if 'allowed' in list(rule.keys()) and rule['allowed']:
+                    action = "accept"
+
+                rstr = addr
+                type = ""
+                rstr = appendStringIfNotEmpty(rstr, proto)
+                if rstr and action:
+                    rstr = rstr + " " + action
+                else:
+                    type = "chain"
+                    rstr = action
+                logging.debug("Process routing ACL rule %s" % rstr)
+                if type == "chain":
+                    self.nft_ipv4_acl.insert(0, {'type': type, 'chain': chain, 'rule': rstr})
+                else:
+                    self.nft_ipv4_acl.append({'type': type, 'chain': chain, 'rule': rstr})
+
+            rstr = "counter packets 0 bytes 0 drop"
+            self.nft_ipv4_acl.append({'type': "", 'chain': chain, 'rule': rstr})
 
         def __process_ip6(self, direction, rule_list):
             if not self.ip6_cidr:
@@ -308,9 +512,9 @@ class CsAcl(CsDataBag):
             self.ipv6_acl.insert(0, {'type': "chain", 'chain': chain})
             for rule in rule_list:
                 cidr = rule['cidr']
-                if cidr != None and cidr != "":
+                if cidr is not None and cidr != "":
                     cidr = removeUndesiredCidrs(cidr, 4)
-                    if cidr == None or cidr == "":
+                    if cidr is None or cidr == "":
                         continue
                 addr = ""
                 if cidr:
@@ -352,7 +556,7 @@ class CsAcl(CsDataBag):
                         proto = "%s dport %s" % (proto, port)
 
                 action = "drop"
-                if 'allowed' in rule.keys() and rule['allowed']:
+                if 'allowed' in list(rule.keys()) and rule['allowed']:
                     action = "accept"
 
                 rstr = addr
@@ -371,14 +575,19 @@ class CsAcl(CsDataBag):
             rstr = "counter packets 0 bytes 0 drop"
             self.ipv6_acl.append({'type': "", 'chain': chain, 'rule': rstr})
 
-        def process(self, direction, rule_list, base):
+        def process(self, direction, rule_list, base, is_routed):
+            if is_routed:
+                self.__process_routing_ip4(direction, rule_list)
+                self.__process_ip6(direction, rule_list)
+                return
+
             count = base
             for i in rule_list:
                 ruleData = copy.copy(i)
                 cidr = ruleData['cidr']
-                if cidr != None and cidr != "":
+                if cidr is not None and cidr != "":
                     cidr = removeUndesiredCidrs(cidr, 6)
-                    if cidr == None or cidr == "":
+                    if cidr is None or cidr == "":
                         continue
                 ruleData['cidr'] = cidr
                 r = self.AclRule(direction, self, ruleData, self.config, count)
@@ -392,7 +601,7 @@ class CsAcl(CsDataBag):
 
             def __init__(self, direction, acl, rule, config, count):
                 self.count = count
-                if config.is_vpc():
+                if config.is_vpc() and not config.is_routed():
                     self.init_vpc(direction, acl, rule, config)
 
             def init_vpc(self, direction, acl, rule, config):
@@ -411,9 +620,9 @@ class CsAcl(CsDataBag):
                 self.type = rule['type']
                 self.icmp_type = "any"
                 self.protocol = self.type
-                if "icmp_type" in rule.keys() and rule['icmp_type'] != -1:
+                if "icmp_type" in list(rule.keys()) and rule['icmp_type'] != -1:
                     self.icmp_type = rule['icmp_type']
-                if "icmp_code" in rule.keys() and rule['icmp_code'] != -1:
+                if "icmp_code" in list(rule.keys()) and rule['icmp_code'] != -1:
                     self.icmp_type = "%s/%s" % (self.icmp_type, rule['icmp_code'])
                 if self.type == "protocol":
                     if rule['protocol'] == 41:
@@ -421,11 +630,11 @@ class CsAcl(CsDataBag):
                     self.protocol = rule['protocol']
                 self.action = "DROP"
                 self.dport = ""
-                if 'allowed' in rule.keys() and rule['allowed']:
+                if 'allowed' in list(rule.keys()) and rule['allowed']:
                     self.action = "ACCEPT"
-                if 'first_port' in rule.keys():
+                if 'first_port' in list(rule.keys()):
                     self.dport = "-m %s --dport %s" % (self.protocol, rule['first_port'])
-                if 'last_port' in rule.keys() and self.dport and \
+                if 'last_port' in list(rule.keys()) and self.dport and \
                    rule['last_port'] != rule['first_port']:
                     self.dport = "%s:%s" % (self.dport, rule['last_port'])
 
@@ -438,7 +647,21 @@ class CsAcl(CsDataBag):
                 rstr = rstr.replace("  ", " ").lstrip()
                 self.fw.append([self.table, self.count, rstr])
 
+    def flushAllIptablesRules(self):
+        if not self.config.is_routed():
+            return
+        # Flush all iptables rules for routing networks, which are replaced by nftables rules
+        logging.info("Flush all iptables rules")
+        CsHelper.execute("iptables -F filter")
+        CsHelper.execute("iptables -F nat")
+        CsHelper.execute("iptables -F mangle")
+        CsHelper.execute("nft delete table ip filter")
+        CsHelper.execute("nft delete table ip nat")
+        CsHelper.execute("nft delete table ip mangle")
+
     def flushAllowAllEgressRules(self):
+        if self.config.is_routed():
+            return
         logging.debug("Flush allow 'all' egress firewall rule")
         # Ensure that FW_EGRESS_RULES chain exists
         CsHelper.execute("iptables-save | grep '^:FW_EGRESS_RULES' || iptables -t filter -N FW_EGRESS_RULES")
@@ -447,6 +670,26 @@ class CsAcl(CsDataBag):
         CsHelper.execute("ipset -L | grep Name:  | awk {'print $2'} | ipset flush")
         CsHelper.execute("ipset -L | grep Name:  | awk {'print $2'} | ipset destroy")
 
+    def flushAllIpv4RoutingRules(self):
+        if not self.config.is_routed():
+            return
+        logging.info("Flush all Routing firewall rules")
+        address_family = 'ip'
+        table = 'ip4_firewall'
+        tables = CsHelper.execute("nft list tables %s | grep %s" % (address_family, table))
+        if any(table in t for t in tables):
+            CsHelper.execute("nft delete table %s %s" % (address_family, table))
+
+    def flushAllIpv4RoutingACLRules(self):
+        if not self.config.is_routed():
+            return
+        logging.info("Flush all ACL rules for routing network")
+        address_family = 'ip'
+        table = 'ip4_acl'
+        tables = CsHelper.execute("nft list tables %s | grep %s" % (address_family, table))
+        if any(table in t for t in tables):
+            CsHelper.execute("nft delete table %s %s" % (address_family, table))
+
     def flushAllIpv6Rules(self):
         logging.info("Flush all IPv6 ACL rules")
         address_family = 'ip6'
@@ -456,6 +699,10 @@ class CsAcl(CsDataBag):
             CsHelper.execute("nft delete table %s %s" % (address_family, table))
 
     def process(self):
+        if self.config.is_routed() and not self.config.is_vpc():
+            self.add_routing_rules()
+            return
+
         for item in self.dbag:
             if item == "id":
                 continue
@@ -464,7 +711,6 @@ class CsAcl(CsDataBag):
             else:
                 self.AclIP(self.dbag[item], self.config).create()
 
-
 class CsIpv6Firewall(CsDataBag):
     """
         Deal with IPv6 Firewall
@@ -488,7 +734,7 @@ class CsIpv6Firewall(CsDataBag):
                 continue
             rule = self.dbag[item]
 
-            if chains_added == False:
+            if chains_added is False:
                 guest_cidr = rule['guest_ip6_cidr']
                 parent_chain = "fw_forward"
                 chain = "fw_chain_egress"
@@ -624,39 +870,43 @@ class CsVmMetadata(CsDataBag):
         if os.path.exists(datafile):
             os.remove(datafile)
 
+    def __writefile(self, dest, data, mode):
+        fh = open(dest, mode)
+        self.__exflock(fh)
+        fh.write(data)
+        self.__unflock(fh)
+        fh.close()
+        os.chmod(dest, 0o644)
+
     def __createfile(self, ip, folder, file, data):
         dest = "/var/www/html/" + folder + "/" + ip + "/" + file
         metamanifestdir = "/var/www/html/" + folder + "/" + ip
         metamanifest = metamanifestdir + "/meta-data"
 
-        # base64 decode userdata
-        if folder == "userdata" or folder == "user-data":
-            if data is not None:
+        if data is not None:
+            # base64 decode userdata
+            if folder == "userdata" or folder == "user-data":
                 # need to pad data if it is not valid base 64
                 if len(data) % 4 != 0:
                     data += (4 - (len(data) % 4)) * "="
                 data = base64.b64decode(data)
-
-        fh = open(dest, "w")
-        self.__exflock(fh)
-        if data is not None:
-            fh.write(data)
+            if isinstance(data, str):
+                self.__writefile(dest, data, "w")
+            elif isinstance(data, bytes):
+                self.__writefile(dest, data, "wb")
         else:
-            fh.write("")
-        self.__unflock(fh)
-        fh.close()
-        os.chmod(dest, 0644)
+            self.__writefile(dest, "", "w")
 
         if folder == "metadata" or folder == "meta-data":
             try:
-                os.makedirs(metamanifestdir, 0755)
+                os.makedirs(metamanifestdir, 0o755)
             except OSError as e:
                 # error 17 is already exists, we do it this way for concurrency
                 if e.errno != 17:
-                    print "failed to make directories " + metamanifestdir + " due to :" + e.strerror
+                    print("failed to make directories " + metamanifestdir + " due to :" + e.strerror)
                     sys.exit(1)
             if os.path.exists(metamanifest):
-                fh = open(metamanifest, "r+a")
+                fh = open(metamanifest, "a+")
                 self.__exflock(fh)
                 if file not in fh.read():
                     fh.write(file + '\n')
@@ -670,17 +920,17 @@ class CsVmMetadata(CsDataBag):
                 fh.close()
 
         if os.path.exists(metamanifest):
-            os.chmod(metamanifest, 0644)
+            os.chmod(metamanifest, 0o644)
 
     def __htaccess(self, ip, folder, file):
         entry = "RewriteRule ^" + file + "$  ../" + folder + "/%{REMOTE_ADDR}/" + file + " [L,NC,QSA]"
         htaccessFolder = "/var/www/html/latest"
         htaccessFile = htaccessFolder + "/.htaccess"
 
-        CsHelper.mkdir(htaccessFolder, 0755, True)
+        CsHelper.mkdir(htaccessFolder, 0o755, True)
 
         if os.path.exists(htaccessFile):
-            fh = open(htaccessFile, "r+a")
+            fh = open(htaccessFile, "a+")
             self.__exflock(fh)
             if entry not in fh.read():
                 fh.write(entry + '\n')
@@ -699,11 +949,11 @@ class CsVmMetadata(CsDataBag):
         htaccessFile = htaccessFolder+"/.htaccess"
 
         try:
-            os.makedirs(htaccessFolder, 0755)
+            os.makedirs(htaccessFolder, 0o755)
         except OSError as e:
             # error 17 is already exists, we do it this way for sake of concurrency
             if e.errno != 17:
-                print "failed to make directories " + htaccessFolder + " due to :" + e.strerror
+                print("failed to make directories " + htaccessFolder + " due to :" + e.strerror)
                 sys.exit(1)
 
         fh = open(htaccessFile, "w")
@@ -717,7 +967,7 @@ class CsVmMetadata(CsDataBag):
             htaccessFolder = "/var/www/html/latest"
             htaccessFile = htaccessFolder + "/.htaccess"
 
-            fh = open(htaccessFile, "r+a")
+            fh = open(htaccessFile, "a+")
             self.__exflock(fh)
             if entry not in fh.read():
                 fh.write(entry + '\n')
@@ -734,7 +984,7 @@ class CsVmMetadata(CsDataBag):
         try:
             flock(file, LOCK_EX)
         except IOError as e:
-            print "failed to lock file" + file.name + " due to : " + e.strerror
+            print("failed to lock file" + file.name + " due to : " + e.strerror)
             sys.exit(1)  # FIXME
         return True
 
@@ -742,7 +992,7 @@ class CsVmMetadata(CsDataBag):
         try:
             flock(file, LOCK_UN)
         except IOError as e:
-            print "failed to unlock file" + file.name + " due to : " + e.strerror
+            print("failed to unlock file" + file.name + " due to : " + e.strerror)
             sys.exit(1)  # FIXME
         return True
 
@@ -838,9 +1088,9 @@ class CsSite2SiteVpn(CsDataBag):
         file.addeq(" authby=secret")
         file.addeq(" keyexchange=%s" % ikeversion)
         file.addeq(" ike=%s" % ikepolicy)
-        file.addeq(" ikelifetime=%s" % self.convert_sec_to_h(obj['ike_lifetime']))
+        file.addeq(" ikelifetime=%s" % self.convert_sec_to_min(obj['ike_lifetime']))
         file.addeq(" esp=%s" % esppolicy)
-        file.addeq(" lifetime=%s" % self.convert_sec_to_h(obj['esp_lifetime']))
+        file.addeq(" lifetime=%s" % self.convert_sec_to_min(obj['esp_lifetime']))
         file.addeq(" keyingtries=2")
         file.addeq(" auto=route")
         if 'encap' not in obj:
@@ -850,7 +1100,7 @@ class CsSite2SiteVpn(CsDataBag):
             file.addeq(" dpddelay=30")
             file.addeq(" dpdtimeout=120")
             file.addeq(" dpdaction=restart")
-        if splitconnections and len(peerlistarr) > 1:
+        if splitconnections and peerlistarr.count > 1:
             logging.debug('Splitting connections for rightsubnets %s' % peerlistarr)
             for peeridx in range(1, len(peerlistarr)):
                 logging.debug('Adding split connection -%d for subnet %s' % (peeridx + 1, peerlistarr[peeridx]))
@@ -868,9 +1118,9 @@ class CsSite2SiteVpn(CsDataBag):
 
         # This will load the new config
         CsHelper.execute("ipsec reload")
-        os.chmod(vpnsecretsfile, 0400)
+        os.chmod(vpnsecretsfile, 0o400)
 
-        for i in xrange(3):
+        for i in range(3):
             done = True
             for peeridx in range(0, len(peerlistarr)):
                 # Check for the proper connection and subnet
@@ -891,9 +1141,9 @@ class CsSite2SiteVpn(CsDataBag):
             ipinsubnet = '.'.join(octets)
             CsHelper.execute("timeout 5 ping -c 3 %s" % ipinsubnet)
 
-    def convert_sec_to_h(self, val):
-        hrs = int(val) / 3600
-        return "%sh" % hrs
+    def convert_sec_to_min(self, val):
+        mins = int(val / 60)
+        return "%sm" % mins
 
 
 class CsVpnUser(CsDataBag):
@@ -1217,10 +1467,7 @@ class CsForwardingRules(CsDataBag):
         self.fw.append(["filter", "", fw7])
 
     def forward_vpc(self, rule):
-        fw_prerout_rule = "-A PREROUTING"
-        if "source_cidr_list" in rule and rule["source_cidr_list"]:
-            fw_prerout_rule += " -s %s" % rule["source_cidr_list"]
-        fw_prerout_rule += " -d %s/32" % rule["public_ip"]
+        fw_prerout_rule = "-A PREROUTING -d %s/32 " % (rule["public_ip"])
         if not rule["protocol"] == "any":
             fw_prerout_rule += " -m %s -p %s" % (rule["protocol"], rule["protocol"])
         if not rule["public_ports"] == "any":
@@ -1229,10 +1476,7 @@ class CsForwardingRules(CsDataBag):
         if not rule["internal_ports"] == "any":
             fw_prerout_rule += ":" + self.portsToString(rule["internal_ports"], "-")
 
-        fw_output_rule = "-A OUTPUT"
-        if "source_cidr_list" in rule and rule["source_cidr_list"]:
-            fw_output_rule += " -s %s" % rule["source_cidr_list"]
-        fw_output_rule += " -d %s/32" % rule["public_ip"]
+        fw_output_rule = "-A OUTPUT -d %s/32" % rule["public_ip"]
         if not rule["protocol"] == "any":
             fw_output_rule += " -m %s -p %s" % (rule["protocol"], rule["protocol"])
         if not rule["public_ports"] == "any":
@@ -1331,11 +1575,22 @@ class IpTablesExecutor:
         nf = CsNetfilters()
         nf.compare(self.config.get_fw())
 
-        logging.info("Configuring nftables ACL rules %s" % self.config.get_ipv6_acl())
+        logging.info("Configuring nftables IPv4 firewall rules %s" % self.config.get_nft_ipv4_fw())
+        acls.flushAllIpv4RoutingRules()
+        nf = CsNetfilters()
+        nf.apply_nft_ipv4_rules(self.config.get_nft_ipv4_fw(), "firewall")
+        acls.flushAllIptablesRules()
+
+        logging.info("Configuring nftables IPv4 ACL rules %s" % self.config.get_nft_ipv4_acl())
+        acls.flushAllIpv4RoutingACLRules()
+        nf = CsNetfilters()
+        nf.apply_nft_ipv4_rules(self.config.get_nft_ipv4_acl(), "acl")
+
+        logging.info("Configuring nftables IPv6 ACL rules %s" % self.config.get_ipv6_acl())
         nf = CsNetfilters()
         nf.apply_ip6_rules(self.config.get_ipv6_acl(), "acl")
 
-        logging.info("Configuring nftables IPv6 rules %s" % self.config.get_ipv6_fw())
+        logging.info("Configuring nftables IPv6 firewall rules %s" % self.config.get_ipv6_fw())
         nf = CsNetfilters()
         nf.apply_ip6_rules(self.config.get_ipv6_fw(), "firewall")
 
@@ -1345,6 +1600,8 @@ class IpTablesExecutor:
         CsHelper.save_iptables("iptables-save", "/etc/iptables/rules.v4")
         CsHelper.save_iptables("ip6tables-save", "/etc/iptables/rules.v6")
 
+        # Save nftables configuration
+        CsHelper.save_iptables("nft list ruleset", "/etc/iptables/rules.nftables")
 
 def main(argv):
     # The file we are currently processing, if it is "cmd_line.json" everything will be processed.
@@ -1367,6 +1624,7 @@ def main(argv):
     config.address().process()
 
     databag_map = OrderedDict([("guest_network",       {"process_iptables": True,  "executor": [CsVpcGuestNetwork("guestnetwork", config)]}),
+                               ("bgp_peers",           {"process_iptables": False,  "executor": [CsBgpPeers("bgppeers", config)]}),
                                ("ip_aliases",          {"process_iptables": True,  "executor": []}),
                                ("vm_password",         {"process_iptables": False, "executor": [CsPassword("vmpassword", config)]}),
                                ("vm_metadata",         {"process_iptables": False, "executor": [CsVmMetadata('vmdata', config)]}),
@@ -1382,14 +1640,14 @@ def main(argv):
                                ("dhcp",                {"process_iptables": False, "executor": [CsDhcp("dhcpentry", config)]}),
                                ("load_balancer",       {"process_iptables": True,  "executor": []}),
                                ("monitor_service",     {"process_iptables": False, "executor": [CsMonitor("monitorservice", config)]}),
-                               ("static_routes",       {"process_iptables": True, "executor": [CsStaticRoutes("staticroutes", config)]})
+                               ("static_routes",       {"process_iptables": False, "executor": [CsStaticRoutes("staticroutes", config)]})
                                ])
 
     if not config.is_vpc():
         databag_map.pop("guest_network")
 
     def execDatabag(key, db):
-        if key not in db.keys() or 'executor' not in db[key]:
+        if key not in list(db.keys()) or 'executor' not in db[key]:
             logging.warn("Unable to find config or executor(s) for the databag type %s" % key)
             return
         for executor in db[key]['executor']:
@@ -1403,10 +1661,10 @@ def main(argv):
 
     if json_type == "cmd_line":
         logging.debug("cmd_line.json changed. All other files will be processed as well.")
-        for key in databag_map.keys():
+        for key in list(databag_map.keys()):
             execDatabag(key, databag_map)
         execIptables(config)
-    elif json_type in databag_map.keys():
+    elif json_type in list(databag_map.keys()):
         execDatabag(json_type, databag_map)
         if databag_map[json_type]['process_iptables']:
             execIptables(config)
@@ -1417,5 +1675,6 @@ def main(argv):
     red.set()
     return 0
 
+
 if __name__ == "__main__":
     main(sys.argv)
