@@ -26,20 +26,20 @@ def merge(dbag, data):
         return dbagc
 
     # remove previously deleted user from the dict
-    for user in dbagc.keys():
+    for user in list(dbagc.keys()):
         if user == 'id':
             continue
         userrec = dbagc[user]
         add = userrec['add']
         if not add:
-            del(dbagc[user])
+            del dbagc[user]
 
     for user in data['vpn_users']:
         username = user['user']
         add = user['add']
-        if username not in dbagc.keys():
+        if username not in list(dbagc.keys()):
             dbagc[username] = user
-        elif username in dbagc.keys() and not add:
+        elif username in list(dbagc.keys()) and not add:
             dbagc[username] = user
 
     return dbagc
