@@ -225,10 +225,11 @@ export default {
       message: 'message.delete.account',
       dataView: true,
       disabled: (record, store) => {
-        return store.userInfo.accountid === record?.id
+        return record.id !== 'undefined' && store.userInfo.accountid === record.id
       },
+      groupAction: true,
       popup: true,
-      component: shallowRef(defineAsyncComponent(() => import('@/views/iam/DeleteAccountWrapper.vue')))
+      groupMap: (selection) => { return selection.map(x => { return { id: x } }) }
     }
   ]
 }
