@@ -131,6 +131,43 @@ export default {
         }
       ]
     },
+    {
+      name: 'backuprepository',
+      title: 'label.backup.repository',
+      icon: 'inbox-outlined',
+      docHelp: 'adminguide/backup_and_recovery.html',
+      permission: ['listBackupRepositories'],
+      searchFilters: ['zoneid'],
+      columns: ['name', 'provider', 'type', 'address', 'zonename'],
+      details: ['name', 'type', 'address', 'provider', 'zonename'],
+      actions: [
+        {
+          api: 'addBackupRepository',
+          icon: 'plus-outlined',
+          label: 'label.backup.repository.add',
+          listView: true,
+          args: [
+            'name', 'provider', 'address', 'type', 'mountopts', 'zoneid'
+          ],
+          mapping: {
+            type: {
+              options: ['nfs']
+            },
+            provider: {
+              value: (record) => { return 'nas' }
+            }
+          }
+        },
+        {
+          api: 'deleteBackupRepository',
+          icon: 'delete-outlined',
+          label: 'label.backup.repository.remove',
+          message: 'message.action.delete.backup.repository',
+          dataView: true,
+          popup: true
+        }
+      ]
+    },
     {
       name: 'hypervisorcapability',
       title: 'label.hypervisor.capabilities',
