@@ -51,7 +51,8 @@ import org.apache.commons.lang3.StringUtils;
 import org.apache.commons.net.util.SubnetUtils;
 import org.apache.commons.validator.routines.InetAddressValidator;
 import org.apache.commons.validator.routines.RegexValidator;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.apache.logging.log4j.LogManager;
 
 import com.cloud.utils.IteratorUtil;
 import com.cloud.utils.Pair;
@@ -62,9 +63,10 @@ import com.googlecode.ipv6.IPv6AddressRange;
 import com.googlecode.ipv6.IPv6Network;
 
 public class NetUtils {
-    protected final static Logger s_logger = Logger.getLogger(NetUtils.class);
+    protected static Logger LOGGER = LogManager.getLogger(NetUtils.class);
 
-    private static final int MAX_CIDR = 32;
+    public static final int MAX_CIDR = 32;
+    private static final long MAX_IPv4_ADDR = ip2Long("255.255.255.255");
     private static final int RFC_3021_31_BIT_CIDR = 31;
 
     public final static int HTTP_PORT = 80;
@@ -79,6 +81,7 @@ public class NetUtils {
     public final static String ANY_PROTO = "any";
     public final static String ICMP_PROTO = "icmp";
     public static final String ICMP6_PROTO = "icmp6";
+    public final static int ICMP_PROTO_NUMBER = 1;
     public final static String ALL_PROTO = "all";
     public final static String HTTP_PROTO = "http";
     public final static String HTTPS_PROTO = "https";
@@ -99,10 +102,6 @@ public class NetUtils {
     public final static int IPV6_EUI64_11TH_BYTE = -1;
     public final static int IPV6_EUI64_12TH_BYTE = -2;
 
-    // Regex
-    public final static Pattern HOSTNAME_PATTERN = Pattern.compile("[a-zA-Z0-9-]+");
-    public final static Pattern START_HOSTNAME_PATTERN = Pattern.compile("^[0-9-].*");
-
     public static String extractHost(String uri) throws URISyntaxException {
         return (new URI(uri)).getHost();
     }
@@ -148,7 +147,7 @@ public class NetUtils {
                 return localAddr.getHostName();
             }
         } catch (final UnknownHostException e) {
-            s_logger.warn("UnknownHostException when trying to get host name. ", e);
+            LOGGER.warn("UnknownHostException when trying to get host name. ", e);
         }
         return "localhost";
     }
@@ -160,7 +159,7 @@ public class NetUtils {
                 return localAddr.getCanonicalHostName();
             }
         } catch (UnknownHostException e) {
-            s_logger.warn("UnknownHostException when trying to get canonical host name. ", e);
+            LOGGER.warn("UnknownHostException when trying to get canonical host name. ", e);
         }
         return "localhost";
     }
@@ -169,7 +168,7 @@ public class NetUtils {
         try {
             return InetAddress.getLocalHost();
         } catch (final UnknownHostException e) {
-            s_logger.warn("UnknownHostException in getLocalInetAddress().", e);
+            LOGGER.warn("UnknownHostException in getLocalInetAddress().", e);
             return null;
         }
     }
@@ -179,7 +178,7 @@ public class NetUtils {
             final InetAddress addr = InetAddress.getByName(host);
             return addr.getHostAddress();
         } catch (final UnknownHostException e) {
-            s_logger.warn("Unable to resolve " + host + " to IP due to UnknownHostException");
+            LOGGER.warn("Unable to resolve " + host + " to IP due to UnknownHostException");
             return null;
         }
     }
@@ -195,7 +194,7 @@ public class NetUtils {
                 }
             }
         } catch (final SocketException e) {
-            s_logger.warn("SocketException in getAllLocalInetAddresses().", e);
+            LOGGER.warn("SocketException in getAllLocalInetAddresses().", e);
         }
 
         final InetAddress[] addrs = new InetAddress[addrList.size()];
@@ -225,7 +224,7 @@ public class NetUtils {
                 }
             }
         } catch (final SocketException e) {
-            s_logger.warn("UnknownHostException in getLocalCidrs().", e);
+            LOGGER.warn("UnknownHostException in getLocalCidrs().", e);
         }
 
         return cidrList.toArray(new String[0]);
@@ -247,7 +246,7 @@ public class NetUtils {
                     line = output.readLine();
                 }
             } catch (final IOException e) {
-                s_logger.debug("Caught IOException", e);
+                LOGGER.debug("Caught IOException", e);
             }
             return null;
         } else {
@@ -268,7 +267,7 @@ public class NetUtils {
             try {
                 info = NetUtils.getNetworkParams(nic);
             } catch (final NullPointerException ignored) {
-                s_logger.debug("Caught NullPointerException when trying to getDefaultHostIp");
+                LOGGER.debug("Caught NullPointerException when trying to getDefaultHostIp");
             }
             if (info != null) {
                 return info[0];
@@ -348,7 +347,7 @@ public class NetUtils {
                 formatter.format("%02X%s", mac[i], i < mac.length - 1 ? ":" : "");
             }
         } catch (final SocketException e) {
-            s_logger.error("SocketException when trying to retrieve MAC address", e);
+            LOGGER.error("SocketException when trying to retrieve MAC address", e);
         } finally {
             formatter.close();
         }
@@ -434,39 +433,39 @@ public class NetUtils {
     }
 
     public static String[] getNetworkParams(NetworkInterface nic) {
-        s_logger.debug(String.format("Retrieving network params of NIC [%s].", nic));
+        LOGGER.debug(String.format("Retrieving network params of NIC [%s].", nic));
 
-        s_logger.trace(String.format("Retrieving all NIC [%s] addresses.", nic));
+        LOGGER.trace(String.format("Retrieving all NIC [%s] addresses.", nic));
         List<InterfaceAddress> addrs = nic.getInterfaceAddresses();
         if (CollectionUtils.isEmpty(addrs)) {
-            s_logger.debug(String.format("NIC [%s] has no addresses, returning null.", nic));
+            LOGGER.debug(String.format("NIC [%s] has no addresses, returning null.", nic));
             return null;
         }
 
         String addrsToString = Arrays.toString(addrs.toArray());
-        s_logger.trace(String.format("Found [%s] as NIC [%s] addresses. Reversing the list order because it has reverse order in \"ip addr show\".",
+        LOGGER.trace(String.format("Found [%s] as NIC [%s] addresses. Reversing the list order because it has reverse order in \"ip addr show\".",
                 addrsToString, nic));
 
         Collections.reverse(addrs);
         InterfaceAddress addr = null;
 
-        s_logger.trace(String.format("Iterating through the NIC [%s] addresses [%s] to find a valid address.", nic, addrsToString));
+        LOGGER.trace(String.format("Iterating through the NIC [%s] addresses [%s] to find a valid address.", nic, addrsToString));
         for (InterfaceAddress iaddr : addrs) {
             InetAddress inet = iaddr.getAddress();
-            s_logger.trace(String.format("Validating address [%s].", inet));
+            LOGGER.trace(String.format("Validating address [%s].", inet));
             if (!inet.isLinkLocalAddress() && !inet.isLoopbackAddress() && !inet.isMulticastAddress() && inet.getAddress().length == 4) {
                 addr = iaddr;
                 break;
             }
-            s_logger.trace(String.format("Address [%s] is link local [%s], loopback [%s], multicast [%s], or does not have 4 octets [%s]; therefore we will not retrieve its" +
+            LOGGER.trace(String.format("Address [%s] is link local [%s], loopback [%s], multicast [%s], or does not have 4 octets [%s]; therefore we will not retrieve its" +
                     " interface params.", inet, inet.isLinkLocalAddress(), inet.isLoopbackAddress(), inet.isMulticastAddress(), inet.getAddress().length));
         }
         if (addr == null) {
-            s_logger.debug(String.format("Could not find a valid address in NIC [%s], returning null.", nic));
+            LOGGER.debug(String.format("Could not find a valid address in NIC [%s], returning null.", nic));
             return null;
         }
 
-        s_logger.debug(String.format("Retrieving params of address [%s] of NIC [%s].", addr, nic));
+        LOGGER.debug(String.format("Retrieving params of address [%s] of NIC [%s].", addr, nic));
 
         String[] result = new String[3];
         result[0] = addr.getAddress().getHostAddress();
@@ -475,7 +474,7 @@ public class NetUtils {
             final byte[] mac = nic.getHardwareAddress();
             result[1] = byte2Mac(mac);
         } catch (final SocketException e) {
-            s_logger.warn(String.format("Unable to get NIC's [%s] MAC address due to [%s].", nic, e.getMessage()), e);
+            LOGGER.warn(String.format("Unable to get NIC's [%s] MAC address due to [%s].", nic, e.getMessage()), e);
         }
 
         result[2] = prefix2Netmask(addr.getNetworkPrefixLength());
@@ -844,7 +843,7 @@ public class NetUtils {
         isSuperset, isSubset, neitherSubetNorSuperset, sameSubnet, errorInCidrFormat
     }
 
-    public static SupersetOrSubset isNetworkASubsetOrSupersetOfNetworkB(final String cidrA, final String cidrB) {
+    public static SupersetOrSubset isNetowrkASubsetOrSupersetOfNetworkB(final String cidrA, final String cidrB) {
         if (!areCidrsNotEmpty(cidrA, cidrB)) {
             return SupersetOrSubset.errorInCidrFormat;
         }
@@ -1063,16 +1062,16 @@ public class NetUtils {
         // If it's a host name, don't allow to start with digit
 
         if (hostName.length() > 63 || hostName.length() < 1) {
-            s_logger.warn("Domain name label must be between 1 and 63 characters long");
+            LOGGER.warn("Domain name label must be between 1 and 63 characters long");
             return false;
-        } else if (!HOSTNAME_PATTERN.matcher(hostName).matches()) {
-            s_logger.warn("Domain name label may contain only the ASCII letters 'a' through 'z' (in a case-insensitive manner)");
+        } else if (!hostName.toLowerCase().matches("[a-z0-9-]*")) {
+            LOGGER.warn("Domain name label may contain only the ASCII letters 'a' through 'z' (in a case-insensitive manner)");
             return false;
         } else if (hostName.startsWith("-") || hostName.endsWith("-")) {
-            s_logger.warn("Domain name label can not start or end with a hyphen");
+            LOGGER.warn("Domain name label can not start  with a hyphen and digit, and must not end with a hyphen");
             return false;
-        } else if (isHostName && START_HOSTNAME_PATTERN.matcher(hostName).matches()) {
-            s_logger.warn("Host name can't start with digit");
+        } else if (isHostName && hostName.matches("^[0-9-].*")) {
+            LOGGER.warn("Host name can't start with digit");
             return false;
         }
 
@@ -1082,12 +1081,12 @@ public class NetUtils {
     public static boolean verifyDomainName(final String domainName) {
         // don't allow domain name length to exceed 190 chars (190 + 63 (max host name length) = 253 = max domainName length
         if (domainName.length() < 1 || domainName.length() > 190) {
-            s_logger.trace("Domain name must be between 1 and 190 characters long");
+            LOGGER.trace("Domain name must be between 1 and 190 characters long");
             return false;
         }
 
         if (domainName.startsWith(".") || domainName.endsWith(".")) {
-            s_logger.trace("Domain name can't start or end with .");
+            LOGGER.trace("Domain name can't start or end with .");
             return false;
         }
 
@@ -1095,7 +1094,7 @@ public class NetUtils {
 
         for (int i = 0; i < domainNameLabels.length; i++) {
             if (!verifyDomainNameLabel(domainNameLabels[i], false)) {
-                s_logger.warn("Domain name label " + domainNameLabels[i] + " is incorrect");
+                LOGGER.warn("Domain name label " + domainNameLabels[i] + " is incorrect");
                 return false;
             }
         }
@@ -1113,11 +1112,11 @@ public class NetUtils {
     public static boolean isSameIpRange(final String cidrA, final String cidrB) {
 
         if (!NetUtils.isValidIp4Cidr(cidrA)) {
-            s_logger.info("Invalid value of cidr " + cidrA);
+            LOGGER.info("Invalid value of cidr " + cidrA);
             return false;
         }
         if (!NetUtils.isValidIp4Cidr(cidrB)) {
-            s_logger.info("Invalid value of cidr " + cidrB);
+            LOGGER.info("Invalid value of cidr " + cidrB);
             return false;
         }
         final String[] cidrPairFirst = cidrA.split("\\/");
@@ -1138,7 +1137,7 @@ public class NetUtils {
         return false;
     }
 
-    public static boolean validateGuestCidr(final String cidr) {
+    public static boolean validateGuestCidr(final String cidr, boolean checkCompliance) {
         // RFC 1918 - The Internet Assigned Numbers Authority (IANA) has reserved the
         // following three blocks of the IP address space for private internets:
         // 10.0.0.0 - 10.255.255.255 (10/8 prefix)
@@ -1151,10 +1150,13 @@ public class NetUtils {
         final String[] allowedNetBlocks = {"10.0.0.0/8", "172.16.0.0/12", "192.168.0.0/16", "100.64.0.0/10"};
 
         if (!isValidIp4Cidr(cidr)) {
-            s_logger.warn("Cidr " + cidr + " is not valid");
+            LOGGER.warn("Cidr " + cidr + " is not valid");
             return false;
         }
 
+        if (!checkCompliance) {
+            return true;
+        }
         for (String block: allowedNetBlocks) {
             if (isNetworkAWithinNetworkB(cidr, block)) {
                 return true;
@@ -1162,7 +1164,7 @@ public class NetUtils {
         }
 
         // not in allowedNetBlocks - return false
-        s_logger.warn("cidr " + cidr + " is not RFC 1918 or 6598 compliant");
+        LOGGER.warn("cidr " + cidr + " is not RFC 1918 or 6598 compliant");
         return false;
     }
 
@@ -1186,7 +1188,7 @@ public class NetUtils {
     public static boolean verifyInstanceName(final String instanceName) {
         //instance name for cloudstack vms shouldn't contain - and spaces
         if (instanceName.contains("-") || instanceName.contains(" ") || instanceName.contains("+")) {
-            s_logger.warn("Instance name can not contain hyphen, spaces and \"+\" char");
+            LOGGER.warn("Instance name can not contain hyphen, spaces and \"+\" char");
             return false;
         }
         return true;
@@ -1199,7 +1201,7 @@ public class NetUtils {
             final long shift = MAX_CIDR - (cidrALong[1] > cidrBLong[1] ? cidrBLong[1] : cidrALong[1]);
             return cidrALong[0] >> shift == cidrBLong[0] >> shift;
         } catch (CloudRuntimeException e) {
-            s_logger.error(e.getLocalizedMessage(),e);
+            LOGGER.error(e.getLocalizedMessage(),e);
         }
         return false;
     }
@@ -1257,9 +1259,9 @@ public class NetUtils {
         return true;
     }
 
-    public static boolean validateGuestCidrList(final String guestCidrList) {
+    public static boolean validateGuestCidrList(final String guestCidrList, boolean checkCompliance) {
         for (final String guestCidr : guestCidrList.split(",")) {
-            if (!validateGuestCidr(guestCidr)) {
+            if (!validateGuestCidr(guestCidr, checkCompliance)) {
                 return false;
             }
         }
@@ -1269,7 +1271,7 @@ public class NetUtils {
     public static boolean validateIcmpType(final long icmpType) {
         //Source - http://www.erg.abdn.ac.uk/~gorry/course/inet-pages/icmp-code.html
         if (!(icmpType >= 0 && icmpType <= 255)) {
-            s_logger.warn("impcType is not within 0-255 range");
+            LOGGER.warn("impcType is not within 0-255 range");
             return false;
         }
         return true;
@@ -1279,7 +1281,7 @@ public class NetUtils {
 
         // Reference: https://www.iana.org/assignments/icmp-parameters/icmp-parameters.xhtml#icmp-parameters-codes-9/#table-icmp-parameters-ext-classes
         if (!(icmpCode >= 0 && icmpCode <= 16)) {
-            s_logger.warn("Icmp code should be within 0-16 range");
+            LOGGER.warn("Icmp code should be within 0-16 range");
             return false;
         }
 
@@ -1374,7 +1376,7 @@ public class NetUtils {
                 return endInt.subtract(startInt).add(BigInteger.ONE);
             }
         } catch (final IllegalArgumentException ex) {
-            s_logger.error("Failed to convert a string to an IPv6 address", ex);
+            LOGGER.error("Failed to convert a string to an IPv6 address", ex);
         }
         return null;
     }
@@ -1770,7 +1772,7 @@ public class NetUtils {
     }
 
     public static NetworkInterface getNetworkInterface(String nicName) {
-        s_logger.debug(String.format("Retrieving network interface [%s].", nicName));
+        LOGGER.debug(String.format("Retrieving network interface [%s].", nicName));
         nicName = StringUtils.trimToNull(nicName);
 
         if (nicName == null) {
@@ -1781,15 +1783,91 @@ public class NetUtils {
         try {
             nic = NetworkInterface.getByName(nicName);
             if (nic == null) {
-                s_logger.debug(String.format("Unable to get network interface for NIC [%s].", nicName));
+                LOGGER.debug(String.format("Unable to get network interface for NIC [%s].", nicName));
                 return null;
             }
 
             return nic;
         } catch (final SocketException e) {
-            s_logger.warn(String.format("Unable to get network interface for NIC [%s] due to [%s].", nicName, e.getMessage()), e);
+            LOGGER.warn(String.format("Unable to get network interface for NIC [%s] due to [%s].", nicName, e.getMessage()), e);
             return null;
         }
     }
 
+    public static void validateIcmpTypeAndCode(Integer icmpType, Integer icmpCode) {
+        if ((icmpType == null) || (icmpCode == null)) {
+            throw new CloudRuntimeException("Invalid ICMP type/code specified, icmpType = " + icmpType + ", icmpCode = " + icmpCode);
+        }
+        if (icmpType == -1 && icmpCode != -1) {
+            throw new CloudRuntimeException("Invalid icmp code");
+        }
+        if (icmpType != -1 && icmpCode == -1) {
+            throw new CloudRuntimeException("Invalid icmp code: need non-negative icmp code ");
+        }
+        if (icmpCode > 255 || icmpType > 255 || icmpCode < -1 || icmpType < -1) {
+            throw new CloudRuntimeException("Invalid icmp type/code ");
+        }
+    }
+
+    /**
+     Return the size of CIDR which starts with the startIp, and not bigger than the endIp.
+     */
+    public static int getCidrSizeOfIpRange(long startIp, long endIp) {
+        assert startIp <= MAX_IPv4_ADDR : "Keep startIp smaller than or equals to " + MAX_IPv4_ADDR;
+        assert endIp <= MAX_IPv4_ADDR : "Keep endIp smaller than or equals to " + MAX_IPv4_ADDR;
+        for (int cidrSize = 1; cidrSize <= MAX_CIDR; cidrSize++) {
+            long minStartIp = startIp & (((long) 0xffffffff) >> (MAX_CIDR - cidrSize) << (MAX_CIDR - cidrSize));
+            long maxEndIp = (minStartIp | (((long) 0x1) << (MAX_CIDR - cidrSize)) - 1);
+            if (minStartIp == startIp && maxEndIp <= endIp) {
+                return cidrSize;
+            }
+        }
+        return MAX_CIDR;
+    }
+
+    /**
+     Return the list of pairs (Network Address, Network cidrsize)
+     */
+    public static List<Pair<Long, Integer>> splitIpRangeIntoSubnets(long startIp, long endIp) {
+        List<Pair<Long, Integer>> subnets = new ArrayList<>();
+        if (startIp > endIp) {
+            return subnets;
+        }
+        int cidrSize = getCidrSizeOfIpRange(startIp, endIp);
+        subnets.add(new Pair<>(startIp, cidrSize));
+        subnets.addAll(splitIpRangeIntoSubnets((startIp | (((long) 0x1) << (MAX_CIDR - cidrSize)) - 1) + 1, endIp));
+        return subnets;
+    }
+
+    /**
+     Return the startIp and endIp (in long value) of a CIDR, including the network address and broadcast address
+     */
+    public static long[] getIpRangeStartIpAndEndIpFromCidr(final String cidr) {
+        String[] subnetCidrPair = cidr.split("\\/");
+        Long size = Long.valueOf(subnetCidrPair[1]);
+        final long ip = ip2Long(subnetCidrPair[0]);
+        final long startNetMask = ip2Long(getCidrNetmask(size));
+        final long start = (ip & startNetMask);
+        long end = start;
+        end = end >> MAX_CIDR - size;
+        end++;
+        end = (end << MAX_CIDR - size) - 1;
+
+        long[] result = new long[2];
+        result[0] = start;
+        result[1] = end;
+        return result;
+    }
+
+    /**
+     Return the new format (startIp/cidrsize) of a CIDR
+     */
+    public static String transformCidr(final String cidr) {
+        String[] subnetCidrPair = cidr.split("\\/");
+        Long size = Long.valueOf(subnetCidrPair[1]);
+        final long ip = ip2Long(subnetCidrPair[0]);
+        final long startNetMask = ip2Long(getCidrNetmask(size));
+        final long start = (ip & startNetMask);
+        return String.format("%s/%s", long2Ip(start), size);
+    }
 }
