@@ -34,15 +34,17 @@ import javax.mail.internet.MimeMessage;
 import junit.framework.TestCase;
 import org.apache.commons.lang3.time.DateUtils;
 import org.apache.commons.mail.EmailConstants;
-import org.apache.log4j.Logger;
+import org.apache.logging.log4j.Logger;
+import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.mockito.InjectMocks;
 import org.mockito.Mock;
 import org.mockito.Mockito;
+import org.mockito.MockitoAnnotations;
 import org.mockito.Spy;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
 @RunWith(MockitoJUnitRunner.class)
 public class SMTPMailSenderTest extends TestCase {
@@ -63,11 +65,20 @@ public class SMTPMailSenderTest extends TestCase {
     private String namespace = "test";
     private String enabledProtocols = "mail.smtp.ssl.protocols";
 
+    private AutoCloseable closeable;
+
     @Before
     public void before() {
+        closeable = MockitoAnnotations.openMocks(this);
         smtpMailSender = new SMTPMailSender(configsMock, namespace);
     }
 
+    @Override
+    @After
+    public void tearDown() throws Exception {
+        closeable.close();
+    }
+
     private String getConfigName(String config) {
         return String.format("%s.%s", namespace, config);
     }
